<?php
declare(strict_types = 1);

return [
    'authorName' => 'Jed Foster and Dale Sande',
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<p class="sassmeister" data-gist-id="1122e441f0434ec6eb2a" data-height="480" data-theme="tomorrow"><a href="http://sassmeister.com/gist/1122e441f0434ec6eb2a">Play with this gist on SassMeister.</a></p><script src="http://cdn.sassmeister.com/js/embed.js" async></script>',
        'width' => null,
        'height' => 480,
        'ratio' => null
    ],
    'description' => 'SassMeister is a playground for Sass. Add some Sass and SassMeister will show you the rendered CSS.',
    'favicon' => 'https://www.sassmeister.com/favicon.ico',
    'feeds' => [],
    'icon' => 'https://www.sassmeister.com/logo192.png',
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Sassmeister',
    'providerUrl' => 'https://www.sassmeister.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'SassMeister | The Sass Playground!',
    'url' => 'https://www.sassmeister.com/gist/1122e441f0434ec6eb2a',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
