<?php
declare(strict_types = 1);

return [
    'authorName' => 'Wired Staff',
    'authorUrl' => 'https://www.wired.com/author/wired-staff/',
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="wp-embedded-content"><a href="https://www.wired.com/2016/07/review-yi-4k-action-camera/">Review: Yi 4K Action Camera</a></blockquote> <script type=\'text/javascript\'> <!--//--><![CDATA[//><!-- !function(a,b){"use strict";function c(){if(!e){e=!0;var a,c,d,f,g=-1!==navigator.appVersion.indexOf("MSIE 10"),h=!!navigator.userAgent.match(/Trident.*rv:11\\./),i=b.querySelectorAll("iframe.wp-embedded-content");for(c=0;c<i.length;c++)if(d=i[c],!d.getAttribute("data-secret")){if(f=Math.random().toString(36).substr(2,10),d.src+="#?secret="+f,d.setAttribute("data-secret",f),g||h)a=d.cloneNode(!0),a.removeAttribute("security"),d.parentNode.replaceChild(a,d)}else;}}var d=!1,e=!1;if(b.querySelector)if(a.addEventListener)d=!0;if(a.wp=a.wp||{},!a.wp.receiveEmbedMessage)if(a.wp.receiveEmbedMessage=function(c){var d=c.data;if(d.secret||d.message||d.value)if(!/[^a-zA-Z0-9]/.test(d.secret)){var e,f,g,h,i,j=b.querySelectorAll(\'iframe[data-secret="\'+d.secret+\'"]\'),k=b.querySelectorAll(\'blockquote[data-secret="\'+d.secret+\'"]\');for(e=0;e<k.length;e++)k[e].style.display="none";for(e=0;e<j.length;e++)if(f=j[e],c.source===f.contentWindow){if(f.removeAttribute("style"),"height"===d.message){if(g=parseInt(d.value,10),g>1e3)g=1e3;else if (~~g<200)g=200;f.height=g}if("link"===d.message)if(h=b.createElement("a"),i=b.createElement("a"),h.href=f.getAttribute("src"),i.href=d.value,i.host===h.host)if(b.activeElement===f)a.top.location.href=d.value}else;}},d)a.addEventListener("message",a.wp.receiveEmbedMessage,!1),b.addEventListener("DOMContentLoaded",c,!1),a.addEventListener("load",c,!1)}(window,document); //--><!]]> </script><iframe sandbox="allow-scripts" security="restricted" src="https://www.wired.com/2016/07/review-yi-4k-action-camera/embed/" width="600" height="338" title="&#8220;Review: Yi 4K Action Camera&#8221; &#8212; WIRED" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" class="wp-embedded-content"></iframe>',
        'width' => 600,
        'height' => 338,
        'ratio' => 56.333
    ],
    'description' => 'For nearly two years GoPro’s Hero4 Black has been the standard-bearer for action cameras. But there\'s a new contender.',
    'favicon' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/favicon.ico',
    'feeds' => [
        'https://www.wired.com/feed/'
    ],
    'icon' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/apple-touch-icon.png',
    'image' => 'https://www.wired.com/wp-content/uploads/2016/07/Yi-4KHP.jpg',
    'keywords' => [
        '4k'
    ],
    'language' => 'en-US',
    'languages' => [],
    'license' => null,
    'providerName' => 'WIRED',
    'providerUrl' => 'https://www.wired.com/',
    'publishedTime' => '2016-07-29 07:00:38',
    'redirect' => null,
    'title' => 'Review: Yi 4K Action Camera',
    'url' => 'https://www.wired.com/?p=2064839',
    'linkedData' => [
        'publisher' => [
            '@type' => 'Organization',
            'name' => 'WIRED',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                'width' => '1024 px',
                'height' => '1024 px'
            ]
        ],
        '@context' => 'http://schema.org',
        '@type' => 'NewsArticle',
        'mainEntityOfPage' => [
            '@type' => 'WebPage',
            '@id' => 'https://www.wired.com/2016/07/review-yi-4k-action-camera/'
        ],
        'headline' => 'Review: Yi 4K Action Camera',
        'datePublished' => '2016-07-29T07:00:38+00:00',
        'dateModified' => '2017-06-12T18:27:35+00:00',
        'keywords' => [
            '4k'
        ],
        'url' => 'https://www.wired.com/2016/07/review-yi-4k-action-camera/',
        'articleSection' => 'gear',
        'author' => [
            '@type' => 'Person',
            'name' => 'Brent Rose'
        ],
        'description' => 'For nearly two years GoPro’s Hero4 Black has been the standard-bearer for action cameras. But there\'s a new contender.',
        'image' => [
            '@type' => 'ImageObject',
            'url' => 'https://www.wired.com/wp-content/uploads/2016/07/Yi-4KHP.jpg',
            'height' => 2680,
            'width' => 1507
        ]
    ],
    'oEmbed' => [
        'version' => '1.0',
        'provider_name' => 'WIRED',
        'provider_url' => 'https://www.wired.com',
        'author_name' => 'Wired Staff',
        'author_url' => 'https://www.wired.com/author/wired-staff/',
        'title' => 'Review: Yi 4K Action Camera',
        'type' => 'rich',
        'width' => 600,
        'height' => 338,
        'html' => '<blockquote class="wp-embedded-content"><a href="https://www.wired.com/2016/07/review-yi-4k-action-camera/">Review: Yi 4K Action Camera</a></blockquote>
<script type=\'text/javascript\'>
<!--//--><![CDATA[//><!--
        !function(a,b){"use strict";function c(){if(!e){e=!0;var a,c,d,f,g=-1!==navigator.appVersion.indexOf("MSIE 10"),h=!!navigator.userAgent.match(/Trident.*rv:11\\./),i=b.querySelectorAll("iframe.wp-embedded-content");for(c=0;c<i.length;c++)if(d=i[c],!d.getAttribute("data-secret")){if(f=Math.random().toString(36).substr(2,10),d.src+="#?secret="+f,d.setAttribute("data-secret",f),g||h)a=d.cloneNode(!0),a.removeAttribute("security"),d.parentNode.replaceChild(a,d)}else;}}var d=!1,e=!1;if(b.querySelector)if(a.addEventListener)d=!0;if(a.wp=a.wp||{},!a.wp.receiveEmbedMessage)if(a.wp.receiveEmbedMessage=function(c){var d=c.data;if(d.secret||d.message||d.value)if(!/[^a-zA-Z0-9]/.test(d.secret)){var e,f,g,h,i,j=b.querySelectorAll(\'iframe[data-secret="\'+d.secret+\'"]\'),k=b.querySelectorAll(\'blockquote[data-secret="\'+d.secret+\'"]\');for(e=0;e<k.length;e++)k[e].style.display="none";for(e=0;e<j.length;e++)if(f=j[e],c.source===f.contentWindow){if(f.removeAttribute("style"),"height"===d.message){if(g=parseInt(d.value,10),g>1e3)g=1e3;else if (~~g<200)g=200;f.height=g}if("link"===d.message)if(h=b.createElement("a"),i=b.createElement("a"),h.href=f.getAttribute("src"),i.href=d.value,i.host===h.host)if(b.activeElement===f)a.top.location.href=d.value}else;}},d)a.addEventListener("message",a.wp.receiveEmbedMessage,!1),b.addEventListener("DOMContentLoaded",c,!1),a.addEventListener("load",c,!1)}(window,document);
//--><!]]>
</script><iframe sandbox="allow-scripts" security="restricted" src="https://www.wired.com/2016/07/review-yi-4k-action-camera/embed/" width="600" height="338" title="&#8220;Review: Yi 4K Action Camera&#8221; &#8212; WIRED" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" class="wp-embedded-content"></iframe>',
        'thumbnail_url' => 'https://www.wired.com/wp-content/uploads/2016/07/Yi-4KHP.jpg',
        'thumbnail_width' => 600,
        'thumbnail_height' => 337
    ],
    'allLinkedData' => [
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2016/07/review-yi-4k-action-camera/'
            ],
            'headline' => 'Review: Yi 4K Action Camera',
            'datePublished' => '2016-07-29T07:00:38+00:00',
            'dateModified' => '2017-06-12T18:27:35+00:00',
            'keywords' => [
                '4k'
            ],
            'url' => 'https://www.wired.com/2016/07/review-yi-4k-action-camera/',
            'articleSection' => 'gear',
            'author' => [
                '@type' => 'Person',
                'name' => 'Brent Rose'
            ],
            'description' => 'For nearly two years GoPro’s Hero4 Black has been the standard-bearer for action cameras. But there\'s a new contender.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2016/07/Yi-4KHP.jpg',
                'height' => 2680,
                'width' => 1507
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/04/geeks-guide-the-dispossessed/'
            ],
            'headline' => '‘The Dispossessed’ Is Still One of Sci-Fi’s Smartest Books',
            'datePublished' => '2021-04-02T11:36:39+00:00',
            'dateModified' => '2021-04-02T11:36:39+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/04/geeks-guide-the-dispossessed/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'Ursula K. Le Guin\'s 1974 novel, about a society with no government or laws, remains a thoughtful exploration of politics and economics decades later.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/04/Science_geeksguide_2CDFJY0.jpg',
                'height' => 2400,
                'width' => 1600
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/03/geeks-guide-adventure-games/'
            ],
            'headline' => 'It’s Never Been Easier to Make an Adventure Game',
            'datePublished' => '2021-03-26T11:40:18+00:00',
            'dateModified' => '2021-03-26T14:24:40+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/03/geeks-guide-adventure-games/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'The story-driven genre is enjoying an indie renaissance, thanks to new tools that are making the coding process simpler than ever.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/03/Culture_geeksguide_clip_boathouse_larger.jpg',
                'height' => 1200,
                'width' => 800
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/03/geeks-guide-griffin-mcelroy/'
            ],
            'headline' => 'Starting a Podcast Is Harder Than It Looks',
            'datePublished' => '2021-03-19T11:38:11+00:00',
            'dateModified' => '2021-03-19T11:38:11+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/03/geeks-guide-griffin-mcelroy/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'But Everybody Has a Podcast (Except You) author Griffin McElroy can help.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/03/Culture_podcast_1250239031.jpg',
                'height' => 2400,
                'width' => 1800
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/03/geeks-guide-amazon-upload/'
            ],
            'headline' => 'What If the Afterlife Had In-App Purchases?',
            'datePublished' => '2021-03-12T11:48:08+00:00',
            'dateModified' => '2021-03-12T11:48:08+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/03/geeks-guide-amazon-upload/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'The Amazon series Upload shows a comedic—and probably more realistic—version of what would happen if humans could live online after they die.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/03/Science_upload-UPLO_S1_Unit_108_0110RC_FNL_rgb.jpg',
                'height' => 2400,
                'width' => 1600
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/03/geeks-guide-drawing-chainmail/'
            ],
            'headline' => 'Yes, Chainmail Is Really Hard to Draw',
            'datePublished' => '2021-03-05T11:30:34+00:00',
            'dateModified' => '2021-03-05T11:30:34+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/03/geeks-guide-drawing-chainmail/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'Ultima artist Denis Loubet knows this for a fact.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/03/Culture_GeeksGuide_2BXF8JA-1.png',
                'height' => 2400,
                'width' => 1800
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/02/geeks-guide-blood-of-zeus/'
            ],
            'headline' => '‘Blood of Zeus’ Combines Myth With Saturday Morning Cartoons',
            'datePublished' => '2021-02-26T11:34:19+00:00',
            'dateModified' => '2021-02-26T11:34:19+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy',
                'netflix'
            ],
            'url' => 'https://www.wired.com/2021/02/geeks-guide-blood-of-zeus/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'The new Netflix animated series puts a new spin on old tales.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/02/culture_BloodofZeus_Season1_Episode1_00_13_58_20.jpg',
                'height' => 1620,
                'width' => 1080
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/02/geeks-guide-settle-alien-worlds/'
            ],
            'headline' => 'What Would It Take to Actually Settle an Alien World?',
            'datePublished' => '2021-02-19T11:59:02+00:00',
            'dateModified' => '2021-02-19T12:13:00+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/02/geeks-guide-settle-alien-worlds/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'David Gerrold\'s new novel Hella is about a low-gravity planet inhabited by dinosaur-like aliens. It does deep on the logistics of settling an alien planet.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/02/geeks-guide-alien-planet.jpg',
                'height' => 2400,
                'width' => 1350
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/02/geeks-guide-his-dark-materials-2/'
            ],
            'headline' => 'Mrs. Coulter Is One of the Best Villains on TV',
            'datePublished' => '2021-02-12T11:52:57+00:00',
            'dateModified' => '2021-02-12T11:52:57+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/02/geeks-guide-his-dark-materials-2/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'Ruth Wilson\'s character is the highlight of HBO\'s His Dark Materials.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/02/Culture_GeeksGuide_ruth-wilson_1.jpg',
                'height' => 1444,
                'width' => 963
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2019/09/apple-iphone-event-liveblog/'
            ],
            'headline' => 'Apple Event Liveblog: All the iPhone News as It Happens',
            'datePublished' => '2019-09-10T06:00:17+00:00',
            'dateModified' => '2019-09-10T12:00:57+00:00',
            'keywords' => [
                'apple',
                'iphone'
            ],
            'url' => 'https://www.wired.com/2019/09/apple-iphone-event-liveblog/',
            'articleSection' => 'gear',
            'author' => [
                '@type' => 'Person',
                'name' => 'Michael Calore'
            ],
            'description' => 'Join us for live commentary beginning at 1 pm Eastern, 10 am Pacific.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2019/09/Gear-Apple-Liveblog-FA-1157988242.jpg',
                'height' => 2400,
                'width' => 1679
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2019/06/apple-wwdc-2019-liveblog/'
            ],
            'headline' => 'WWDC 2019 Liveblog: All the Apple News as It Happens',
            'datePublished' => '2019-06-03T06:01:54+00:00',
            'dateModified' => '2019-06-03T14:09:28+00:00',
            'keywords' => [
                'apple',
                'liveblog',
                'wwdc'
            ],
            'url' => 'https://www.wired.com/2019/06/apple-wwdc-2019-liveblog/',
            'articleSection' => 'gear',
            'author' => [
                '@type' => 'Person',
                'name' => 'Wired Staff'
            ],
            'description' => 'Apple\'s developer conference kicks off June 3 at 10 am Pacific. Follow along with us for analysis and commentary from WIRED\'s editors.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2019/06/gear_wwdc_967230896.jpg',
                'height' => 2400,
                'width' => 1800
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/03/geeks-guide-adventure-games/'
            ],
            'headline' => 'It’s Never Been Easier to Make an Adventure Game',
            'datePublished' => '2021-03-26T11:40:18+00:00',
            'dateModified' => '2021-03-26T14:24:40+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/03/geeks-guide-adventure-games/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'The story-driven genre is enjoying an indie renaissance, thanks to new tools that are making the coding process simpler than ever.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/03/Culture_geeksguide_clip_boathouse_larger.jpg',
                'height' => 1200,
                'width' => 800
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2019/04/facebook-f8-liveblog-2019/'
            ],
            'headline' => 'F8 Liveblog: All the Facebook News as It Happens',
            'datePublished' => '2019-04-30T11:39:17+00:00',
            'dateModified' => '2019-04-30T13:03:50+00:00',
            'keywords' => [
                'f8',
                'facebook',
                'liveblog'
            ],
            'url' => 'https://www.wired.com/2019/04/facebook-f8-liveblog-2019/',
            'articleSection' => 'gear',
            'author' => [
                '@type' => 'Person',
                'name' => 'Wired Staff'
            ],
            'description' => 'When Facebook kicks off its annual developer conference with a keynote address on Tuesday morning, we\'ll be liveblogging it right here.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2019/04/f8-953545066.jpg',
                'height' => 2399,
                'width' => 1823
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2019/03/apple-media-event-liveblog/'
            ],
            'headline' => 'Apple Event Liveblog: All the News, as It Happens',
            'datePublished' => '2019-03-25T06:00:04+00:00',
            'dateModified' => '2019-03-25T12:05:50+00:00',
            'keywords' => [
                'apple',
                'apple-event'
            ],
            'url' => 'https://www.wired.com/2019/03/apple-media-event-liveblog/',
            'articleSection' => 'gear',
            'author' => [
                '@type' => 'Person',
                'name' => 'Wired Staff'
            ],
            'description' => 'On Monday morning, Apple hosts an event to outline plans for its news distribution and media streaming services. Our live coverage starts at 9 am Pacific.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2019/03/timcook-967356920.jpg',
                'height' => 2400,
                'width' => 1800
            ]
        ],
        [
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'WIRED',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wired.com/wp-content/themes/Phoenix/assets/images/article-icon.jpg',
                    'width' => '1024 px',
                    'height' => '1024 px'
                ]
            ],
            '@context' => 'http://schema.org',
            '@type' => 'NewsArticle',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.wired.com/2021/04/geeks-guide-the-dispossessed/'
            ],
            'headline' => '‘The Dispossessed’ Is Still One of Sci-Fi’s Smartest Books',
            'datePublished' => '2021-04-02T11:36:39+00:00',
            'dateModified' => '2021-04-02T11:36:39+00:00',
            'keywords' => [
                'geeks-guide-to-the-galaxy'
            ],
            'url' => 'https://www.wired.com/2021/04/geeks-guide-the-dispossessed/',
            'articleSection' => 'culture',
            'author' => [
                '@type' => 'Person',
                'name' => 'Geek\'s Guide to the Galaxy'
            ],
            'description' => 'Ursula K. Le Guin\'s 1974 novel, about a society with no government or laws, remains a thoughtful exploration of politics and economics decades later.',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/wp-content/uploads/2021/04/Science_geeksguide_2CDFJY0.jpg',
                'height' => 2400,
                'width' => 1600
            ]
        ],
        [
            '@context' => 'http://schema.org/',
            '@type' => 'Review',
            'itemReviewed' => [
                '@type' => 'Thing',
                'name' => 'Yi 4K Action Camera'
            ],
            'author' => [
                '@type' => 'Person',
                'name' => 'Brent Rose'
            ],
            'reviewRating' => [
                '@type' => 'Rating',
                'ratingValue' => '8',
                'bestRating' => '10'
            ],
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'Wired'
            ]
        ]
    ]
];
