<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://archive.org/embed/librivoxaudio" width="640" height="480" style="border:none" frameborder="0" allowTransparency="true"></iframe>',
        'width' => 640,
        'height' => 480,
        'ratio' => 75.0
    ],
    'description' => 'LibriVox - founded in 2005 - is a community of volunteers from all over the world who record public domain texts: poetry, short stories, whole books, even dramatic works, in many different languages. All LibriVox recordings are in the public domain in the USA and available as free downloads on...',
    'favicon' => 'https://archive.org/images/glogo.jpg',
    'feeds' => [
        'http://archive.org/services/collection-rss.php?collection=librivoxaudio'
    ],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Internet Archive',
    'providerUrl' => 'https://archive.org',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'The LibriVox Free Audiobook Collection : Free Audio : Free Download, Borrow and Streaming : Internet Archive',
    'url' => 'https://archive.org/details/librivoxaudio',
    'linkedData' => [],
    'oEmbed' => [],
    'api' => [],
    'allLinkedData' => []
];
