<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'jue., 24 may. 2018 19:00: Fernando Souto - MOBGENDesde que Google anunció en el MWC que Flutter entraba en oficialmente beta, el interés por esta plataforma se ha multiplicado.Flutter es un SDK en len',
    'favicon' => 'https://www.meetup.com/mu_static/es/favicon.a6878039.ico',
    'feeds' => [],
    'icon' => 'https://www.meetup.com/mu_static/es/m_swarm_120x120.4f86abc9.png',
    'image' => 'https://secure.meetupstatic.com/photos/event/d/4/6/e/600_485634382.jpeg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [
        'en' => 'https://www.meetup.com/GPUL-Labs/events/248885422/',
        'de-DE' => 'https://www.meetup.com/de-DE/GPUL-Labs/events/248885422/',
        'de' => 'https://www.meetup.com/de-DE/GPUL-Labs/events/248885422/',
        'en-AU' => 'https://www.meetup.com/en-AU/GPUL-Labs/events/248885422/',
        'es' => 'https://www.meetup.com/es/GPUL-Labs/events/248885422/',
        'es-ES' => 'https://www.meetup.com/es-ES/GPUL-Labs/events/248885422/',
        'fr-FR' => 'https://www.meetup.com/fr-FR/GPUL-Labs/events/248885422/',
        'fr' => 'https://www.meetup.com/fr-FR/GPUL-Labs/events/248885422/',
        'it-IT' => 'https://www.meetup.com/it-IT/GPUL-Labs/events/248885422/',
        'it' => 'https://www.meetup.com/it-IT/GPUL-Labs/events/248885422/',
        'ja-JP' => 'https://www.meetup.com/ja-JP/GPUL-Labs/events/248885422/',
        'ja' => 'https://www.meetup.com/ja-JP/GPUL-Labs/events/248885422/',
        'ko-KR' => 'https://www.meetup.com/ko-KR/GPUL-Labs/events/248885422/',
        'ko' => 'https://www.meetup.com/ko-KR/GPUL-Labs/events/248885422/',
        'nl-NL' => 'https://www.meetup.com/nl-NL/GPUL-Labs/events/248885422/',
        'nl' => 'https://www.meetup.com/nl-NL/GPUL-Labs/events/248885422/',
        'pl-PL' => 'https://www.meetup.com/pl-PL/GPUL-Labs/events/248885422/',
        'pl' => 'https://www.meetup.com/pl-PL/GPUL-Labs/events/248885422/',
        'pt-BR' => 'https://www.meetup.com/pt-BR/GPUL-Labs/events/248885422/',
        'pt' => 'https://www.meetup.com/pt-BR/GPUL-Labs/events/248885422/',
        'ru-RU' => 'https://www.meetup.com/ru-RU/GPUL-Labs/events/248885422/',
        'ru' => 'https://www.meetup.com/ru-RU/GPUL-Labs/events/248885422/',
        'th-TH' => 'https://www.meetup.com/th-TH/GPUL-Labs/events/248885422/',
        'th' => 'https://www.meetup.com/th-TH/GPUL-Labs/events/248885422/',
        'tr-TR' => 'https://www.meetup.com/tr-TR/GPUL-Labs/events/248885422/',
        'tr' => 'https://www.meetup.com/tr-TR/GPUL-Labs/events/248885422/',
        'x-default' => 'https://www.meetup.com/GPUL-Labs/events/248885422/'
    ],
    'license' => null,
    'providerName' => 'Meetup',
    'providerUrl' => 'https://www.meetup.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Introducción a Flutter',
    'url' => 'https://www.meetup.com/es/GPUL-Labs/events/248885422/',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'Event',
        'name' => 'Introducción a Flutter',
        'url' => 'https://www.meetup.com/es/GPUL-Labs/events/248885422/',
        'description' => 'Fernando Souto - MOBGEN

Desde que Google anunció en el MWC que Flutter entraba en oficialmente beta, el interés por esta plataforma se ha multiplicado.

Flutter es un SDK en lenguaje Dart para generar apps nativas multiplataforma, que permite un desarrollo eficaz, una interfaz de usuario expresiva y un buen rendimiento.

Si estás interesado en saber más y aprender sobre Flutter apúntate. Haremos una introducción práctica al funcionamiento de Flutter desarollando un ejemplo práctico aplicando un',
        'startDate' => '2018-05-24T19:00+02:00',
        'endDate' => '2018-05-24T22:00+02:00',
        'eventStatus' => 'https://schema.org/EventScheduled',
        'eventAttendanceMode' => 'https://schema.org/OfflineEventAttendanceMode',
        'location' => [
            '@type' => 'Place',
            'name' => 'Vivero de empresas Accede Papagaio',
            'address' => [
                '@type' => 'PostalAddress',
                'addressLocality' => 'A Coruña',
                'addressCountry' => 'España',
                'streetAddress' => 'Rúa Hospital, 19, 15002'
            ],
            'geo' => [
                '@type' => 'GeoCoordinates',
                'latitude' => 43.37335968017578,
                'longitude' => -8.399272918701172
            ]
        ],
        'offers' => [
            '@type' => 'Offer',
            'price' => '0',
            'priceCurrency' => 'USD'
        ],
        'organizer' => [
            '@type' => 'Organization',
            'name' => 'GPUL',
            'url' => 'https://www.meetup.com/es/GPUL-Labs/'
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'Event',
            'name' => 'Introducción a Flutter',
            'url' => 'https://www.meetup.com/es/GPUL-Labs/events/248885422/',
            'description' => 'Fernando Souto - MOBGEN

Desde que Google anunció en el MWC que Flutter entraba en oficialmente beta, el interés por esta plataforma se ha multiplicado.

Flutter es un SDK en lenguaje Dart para generar apps nativas multiplataforma, que permite un desarrollo eficaz, una interfaz de usuario expresiva y un buen rendimiento.

Si estás interesado en saber más y aprender sobre Flutter apúntate. Haremos una introducción práctica al funcionamiento de Flutter desarollando un ejemplo práctico aplicando un',
            'startDate' => '2018-05-24T19:00+02:00',
            'endDate' => '2018-05-24T22:00+02:00',
            'eventStatus' => 'https://schema.org/EventScheduled',
            'eventAttendanceMode' => 'https://schema.org/OfflineEventAttendanceMode',
            'location' => [
                '@type' => 'Place',
                'name' => 'Vivero de empresas Accede Papagaio',
                'address' => [
                    '@type' => 'PostalAddress',
                    'addressLocality' => 'A Coruña',
                    'addressCountry' => 'España',
                    'streetAddress' => 'Rúa Hospital, 19, 15002'
                ],
                'geo' => [
                    '@type' => 'GeoCoordinates',
                    'latitude' => 43.37335968017578,
                    'longitude' => -8.399272918701172
                ]
            ],
            'offers' => [
                '@type' => 'Offer',
                'price' => '0',
                'priceCurrency' => 'USD'
            ],
            'organizer' => [
                '@type' => 'Organization',
                'name' => 'GPUL',
                'url' => 'https://www.meetup.com/es/GPUL-Labs/'
            ]
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'BreadcrumbList',
            'itemListElement' => [
                [
                    '@type' => 'ListItem',
                    'position' => 1,
                    'item' => [
                        '@id' => 'https://www.meetup.com/es/GPUL-Labs/',
                        'name' => 'GPUL'
                    ]
                ],
                [
                    '@type' => 'ListItem',
                    'position' => 2,
                    'item' => [
                        '@id' => 'https://www.meetup.com/es/GPUL-Labs/events/',
                        'name' => 'Events'
                    ]
                ],
                [
                    '@type' => 'ListItem',
                    'position' => 3,
                    'item' => [
                        '@id' => 'https://www.meetup.com/es/GPUL-Labs/events/248885422/',
                        'name' => 'Introducción a Flutter'
                    ]
                ]
            ]
        ]
    ]
];
