<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Несмотря на успешный релиз Call of Duty: Modern Warfare II и Warzone 2.0, геймеры оказались не очень довольны техническим состоянием игр. Форум Reddit заполнен жалобами на баги и просьбами их исправить. Мольбы фанатов были услышаны — правда, другими разработчиками.',
    'favicon' => 'https://4pda.to/s/as6yYjz1ZD25PBECTAG7.png',
    'feeds' => [],
    'icon' => 'https://4pda.to/s/as6ywymaTWM6wnea1mxojxCz0Yet7IeumfOBnaxb.png',
    'image' => 'https://i.4pda.ws/s/as6yueQrUwnKt0LgJ5m26uBjbZsccTet21FqwJkADfGw.jpg?v=1669981373',
    'keywords' => ['состоялся релиз clown of duty — пародии на call of duty'],
    'language' => 'ru-RU',
    'languages' => [],
    'license' => null,
    'providerName' => '4PDA - Новости мира мобильных устройств',
    'providerUrl' => 'https://4pda.to',
    'publishedTime' => '2022-12-04 08:00:00',
    'redirect' => null,
    'title' => 'Состоялся релиз Clown of Duty — пародии на Call of Duty',
    'url' => 'https://4pda.to/2022/12/04/406834/sostoyalsya_reliz_clown_of_duty_parodii_na_call_of_duty/',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => [],
];
