<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<script type="text/javascript" charset="utf-8" src="https://secure.polldaddy.com/p/7012505.js"></script><noscript><iframe src="https://poll.fm/7012505/embed" frameborder="0" class="cs-iframe-embed"></iframe></noscript>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Poll Answers: Option #1, Option #2,',
    'favicon' => 'https://app.crowdsignal.com/images/favicon.png',
    'feeds' => [
        'https://poll.fm/7012505/feed'
    ],
    'icon' => null,
    'image' => 'https://app.crowdsignal.com/images/twitter-card.png',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Crowdsignal',
    'providerUrl' => 'https://crowdsignal.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Which design do you prefer?',
    'url' => 'https://poll.fm/7012505',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'rich',
        'version' => '1.0',
        'provider_name' => 'Crowdsignal',
        'provider_url' => 'https://crowdsignal.com',
        'title' => 'Which design do you prefer?',
        'html' => '<script type="text/javascript" charset="utf-8" src="https://secure.polldaddy.com/p/7012505.js"></script><noscript><iframe src="https://poll.fm/7012505/embed" frameborder="0" class="cs-iframe-embed"></iframe></noscript>'
    ],
    'allLinkedData' => []
];
