<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<script src="https://embed.githubusercontent.com/view/3d/skalnik/secret-bear-clip/master/stl/clip.stl"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'A clip to hold the Gooseneck Hue HD cameras to the Replicator 2 - skalnik/secret-bear-clip',
    'favicon' => 'https://github.githubassets.com/favicons/favicon.svg',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://avatars.githubusercontent.com/u/2546?s=400&v=4',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'GitHub',
    'providerUrl' => 'https://github.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'skalnik/secret-bear-clip',
    'url' => 'https://github.com/skalnik/secret-bear-clip/blob/master/stl/clip.stl',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
