<?php
declare(strict_types = 1);

return [
    'authorName' => 'Zzleeper',
    'authorUrl' => 'http://www.23hq.com/Zzleeper/',
    'cms' => null,
    'code' => null,
    'description' => 'På god väns inrådan kommer det även bultförband vid pilarna. Låter bra tycker jag. (Better safe than sorry)',
    'favicon' => 'http://www.23hq.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'http://www.23hq.com/16171062/16600737_ac392e8a4d667e4726fbafc8a21728d5_large.jpg',
    'keywords' => [
        'compartir fotos',
        'compartirfotos',
        '23',
        'foto digital',
        'galeria de fotos',
        'álbum de fotos',
        'comparte foto',
        'almacenamiento de fotos',
        'almacenamiento de imágenes',
        'picture storage',
        'álbum de fotos online',
        'picture gallery',
        'galería de imágenes',
        'impresiones de fotos',
        'compartir imágenes',
        'cámara digital',
        'organizar fotos',
        'telefono con cámara',
        'moblog',
        'mblog',
        'photoblog',
        'tags',
        'busqueda de fotos',
        'veintitres',
        'chassi framvagn'
    ],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => '23',
    'providerUrl' => 'http://www.23hq.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'På god väns inrådan kommer det även bultförband vid pilarna. Låter bra tycker jag. (Better safe than sorry)',
    'url' => 'http://www.23hq.com/16171062/16600737_ac392e8a4d667e4726fbafc8a21728d5_large.jpg',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'photo',
        'title' => 'På god väns inrådan kommer det även bultförband vid pilarna. Låter bra tycker jag. (Better safe than sorry)',
        'author_name' => 'Zzleeper',
        'author_url' => 'http://www.23hq.com/Zzleeper/',
        'cache_age' => 3600,
        'provider_name' => 23,
        'provider_url' => 'http://www.23hq.com',
        'width' => 756,
        'height' => 567,
        'url' => 'http://www.23hq.com/16171062/16600737_ac392e8a4d667e4726fbafc8a21728d5_large.jpg',
        'thumbnail_width' => 756,
        'thumbnail_height' => 567,
        'thumbnail_url' => 'http://www.23hq.com/16171062/16600737_ac392e8a4d667e4726fbafc8a21728d5_large.jpg'
    ],
    'allLinkedData' => []
];
