<?php
declare(strict_types = 1);

return [
    'authorName' => 'https://www.facebook.com/bbcnews',
    'authorUrl' => 'https://twitter.com/BBCNews',
    'cms' => null,
    'code' => null,
    'description' => 'Five things you need to know about the coronavirus pandemic this Sunday morning.',
    'favicon' => 'https://www.bbc.co.uk/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://ichef.bbci.co.uk/news/1024/branded_news/CC94/production/_111527325_index_daily_update_version02_cv_976new.png',
    'keywords' => [],
    'language' => 'en-GB',
    'languages' => [
        'en-gb' => 'https://www.bbc.co.uk/news/uk-54222286',
        'en' => 'https://www.bbc.com/news/uk-54222286'
    ],
    'license' => null,
    'providerName' => 'BBC News',
    'providerUrl' => 'https://www.bbc.co.uk',
    'publishedTime' => '2020-09-20 06:33:33',
    'redirect' => null,
    'title' => 'Coronavirus: £10,000 fines for failing to self-isolate and lockdown life in photos',
    'url' => 'https://www.bbc.co.uk/news/uk-54222286',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'ReportageNewsArticle',
        'url' => 'https://www.bbc.co.uk/news/uk-54222286',
        'publisher' => [
            '@type' => 'NewsMediaOrganization',
            'name' => 'BBC News',
            'publishingPrinciples' => 'http://www.bbc.co.uk/news/help-41670342',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1'
            ]
        ],
        'datePublished' => '2020-09-20T06:33:33.000Z',
        'dateModified' => '2020-09-20T06:33:33.000Z',
        'headline' => 'Coronavirus: £10,000 fines for failing to self-isolate and lockdown life in photos',
        'image' => [
            '@type' => 'ImageObject',
            'width' => 976,
            'height' => 549,
            'url' => 'https://ichef.bbci.co.uk/news/1024/branded_news/CC94/production/_111527325_index_daily_update_version02_cv_976new.png'
        ],
        'thumbnailUrl' => 'https://ichef.bbci.co.uk/news/1024/branded_news/CC94/production/_111527325_index_daily_update_version02_cv_976new.png',
        'mainEntityOfPage' => 'https://www.bbc.co.uk/news/uk-54222286',
        'author' => [
            '@type' => 'NewsMediaOrganization',
            'name' => 'BBC News',
            'noBylinesPolicy' => 'http://www.bbc.co.uk/news/help-41670342#authorexpertise',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1'
            ]
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'ReportageNewsArticle',
            'url' => 'https://www.bbc.co.uk/news/uk-54222286',
            'publisher' => [
                '@type' => 'NewsMediaOrganization',
                'name' => 'BBC News',
                'publishingPrinciples' => 'http://www.bbc.co.uk/news/help-41670342',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1'
                ]
            ],
            'datePublished' => '2020-09-20T06:33:33.000Z',
            'dateModified' => '2020-09-20T06:33:33.000Z',
            'headline' => 'Coronavirus: £10,000 fines for failing to self-isolate and lockdown life in photos',
            'image' => [
                '@type' => 'ImageObject',
                'width' => 976,
                'height' => 549,
                'url' => 'https://ichef.bbci.co.uk/news/1024/branded_news/CC94/production/_111527325_index_daily_update_version02_cv_976new.png'
            ],
            'thumbnailUrl' => 'https://ichef.bbci.co.uk/news/1024/branded_news/CC94/production/_111527325_index_daily_update_version02_cv_976new.png',
            'mainEntityOfPage' => 'https://www.bbc.co.uk/news/uk-54222286',
            'author' => [
                '@type' => 'NewsMediaOrganization',
                'name' => 'BBC News',
                'noBylinesPolicy' => 'http://www.bbc.co.uk/news/help-41670342#authorexpertise',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1'
                ]
            ]
        ]
    ]
];
