<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<script src="https://ideone.com/e.js/Whjntg"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Ideone is something more than a pastebin; it\'s an online compiler and debugging tool which allows to compile and run code online in more than 40 programming languages.',
    'favicon' => 'https://stx1.ideone.com/gfx2/img/favicon.png',
    'feeds' => [],
    'icon' => null,
    'image' => 'http://profile.ak.fbcdn.net/hprofile-ak-prn1/50232_245768360841_3377786_q.jpg',
    'keywords' => [
        'online compiler',
        'online ide',
        'learn programming online',
        'programming online',
        'run code online',
        'snippet',
        'snippets',
        'pastebin',
        'online debugging tool',
        'online interpreter',
        'run your code online',
        'run code',
        'execute code',
        'c++',
        'java',
        'python'
    ],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Ideone.com',
    'providerUrl' => 'https://ideone.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Ideone.com',
    'url' => 'https://ideone.com/Whjntg',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
