<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe width="100%" height="380" title="Spotify Embed: A Cantar con Xabarin (Vol. I &amp; II)" frameborder="0" allowfullscreen allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" src="https://open.spotify.com/embed/album/7s66wU1XJ2NsUuWM2NKiUV"></iframe>',
        'width' => 456,
        'height' => 380,
        'ratio' => 83.333
    ],
    'description' => 'Various Artists · Compilation · 1996 · 44 songs.',
    'favicon' => 'https://open.scdn.co/cdn/images/favicon32.a19b4f5b.png',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.scdn.co/image/ab67616d00001e02022aca057f08a1d40c1f0733',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Spotify',
    'providerUrl' => 'https://spotify.com/',
    'publishedTime' => '1996-03-05 00:00:00',
    'redirect' => null,
    'title' => 'A Cantar con Xabarin (Vol. I & II)',
    'url' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
    'linkedData' => [
        '@context' => 'http://schema.googleapis.com/',
        '@type' => 'MusicAlbum',
        '@id' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
        'url' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
        'name' => 'A Cantar con Xabarin (Vol. I & II)',
        'description' => 'Listen to A Cantar con Xabarin (Vol. I & II) on Spotify. Various Artists · Compilation · 1996 · 44 songs.',
        'datePublished' => '1996-03-05',
        'potentialAction' => [
            '@type' => 'ListenAction',
            'target' => [
                [
                    '@type' => 'EntryPoint',
                    'urlTemplate' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV?autoplay=true',
                    'actionPlatform' => [
                        'http://schema.org/DesktopWebPlatform',
                        'http://schema.org/IOSPlatform',
                        'http://schema.googleapis.com/GoogleAudioCast',
                        'http://schema.googleapis.com/GoogleVideoCast'
                    ]
                ],
                'android-app://com.spotify.music/spotify/album/7s66wU1XJ2NsUuWM2NKiUV/play'
            ],
            'expectsAcceptanceOf' => [
                '@type' => 'Offer',
                'category' => 'free',
                'eligibleRegion' => [
                    [
                        '@type' => 'Country',
                        'name' => 'AD'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AU'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'AZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BB'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BD'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BF'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BJ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BS'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BY'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'BZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CV'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CY'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'CZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'DE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'DJ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'DK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'DM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'DO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'DZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'EC'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'EE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'EG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ES'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'FI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'FJ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'FM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'FR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GB'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GD'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GQ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'GY'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'HK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'HN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'HR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'HT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'HU'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ID'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'IE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'IL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'IN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'IS'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'IT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'JM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'JO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'JP'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'KZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LB'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LC'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LS'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LU'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'LV'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MC'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MD'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ME'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ML'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MU'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MV'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MX'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MY'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'MZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NP'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'NZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'OM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PS'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'PY'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'QA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'RO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'RS'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'RU'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'RW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SB'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SC'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SE'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SI'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ST'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SV'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'SZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TD'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TH'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TL'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TO'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TR'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TT'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TV'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TW'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'TZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'UA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'UG'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'US'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'UY'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'UZ'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'VC'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'VN'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'VU'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'WS'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'XK'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ZA'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ZM'
                    ],
                    [
                        '@type' => 'Country',
                        'name' => 'ZW'
                    ]
                ]
            ]
        ]
    ],
    'oEmbed' => [
        'html' => '<iframe width="100%" height="380" title="Spotify Embed: A Cantar con Xabarin (Vol. I &amp; II)" frameborder="0" allowfullscreen allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" src="https://open.spotify.com/embed/album/7s66wU1XJ2NsUuWM2NKiUV"></iframe>',
        'width' => 456,
        'height' => 380,
        'version' => '1.0',
        'provider_name' => 'Spotify',
        'provider_url' => 'https://spotify.com',
        'type' => 'rich',
        'title' => 'A Cantar con Xabarin (Vol. I & II)',
        'thumbnail_url' => 'https://i.scdn.co/image/ab67616d00001e02022aca057f08a1d40c1f0733',
        'thumbnail_width' => 300,
        'thumbnail_height' => 300
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.googleapis.com/',
            '@type' => 'MusicAlbum',
            '@id' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
            'url' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
            'name' => 'A Cantar con Xabarin (Vol. I & II)',
            'description' => 'Listen to A Cantar con Xabarin (Vol. I & II) on Spotify. Various Artists · Compilation · 1996 · 44 songs.',
            'datePublished' => '1996-03-05',
            'potentialAction' => [
                '@type' => 'ListenAction',
                'target' => [
                    [
                        '@type' => 'EntryPoint',
                        'urlTemplate' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV?autoplay=true',
                        'actionPlatform' => [
                            'http://schema.org/DesktopWebPlatform',
                            'http://schema.org/IOSPlatform',
                            'http://schema.googleapis.com/GoogleAudioCast',
                            'http://schema.googleapis.com/GoogleVideoCast'
                        ]
                    ],
                    'android-app://com.spotify.music/spotify/album/7s66wU1XJ2NsUuWM2NKiUV/play'
                ],
                'expectsAcceptanceOf' => [
                    '@type' => 'Offer',
                    'category' => 'free',
                    'eligibleRegion' => [
                        [
                            '@type' => 'Country',
                            'name' => 'AD'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AU'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'AZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BB'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BD'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BF'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BJ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BS'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BY'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'BZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CV'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CY'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'CZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'DE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'DJ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'DK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'DM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'DO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'DZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'EC'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'EE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'EG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ES'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'FI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'FJ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'FM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'FR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GB'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GD'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GQ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'GY'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'HK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'HN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'HR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'HT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'HU'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ID'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'IE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'IL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'IN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'IS'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'IT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'JM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'JO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'JP'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'KZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LB'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LC'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LS'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LU'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'LV'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MC'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MD'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ME'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ML'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MU'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MV'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MX'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MY'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'MZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NP'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'NZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'OM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PS'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'PY'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'QA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'RO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'RS'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'RU'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'RW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SB'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SC'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SE'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SI'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ST'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SV'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'SZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TD'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TH'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TL'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TO'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TR'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TT'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TV'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TW'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'TZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'UA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'UG'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'US'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'UY'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'UZ'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'VC'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'VN'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'VU'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'WS'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'XK'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ZA'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ZM'
                        ],
                        [
                            '@type' => 'Country',
                            'name' => 'ZW'
                        ]
                    ]
                ]
            ]
        ]
    ]
];
