<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://ssl.gstatic.com/images/branding/product/1x/drive_2020q4_32dp.png',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Google Docs',
    'providerUrl' => 'https://drive.google.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Entrevista_Rianxo_RadioFusion_150724.mp3',
    'url' => 'https://drive.google.com/file/d/0B2rwN8wAbVSWbmFJdUdnV2VSTTg/view',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
