<?php
declare(strict_types = 1);

return [
    'authorName' => 'Antena 3 Noticias',
    'authorUrl' => 'https://www.tiktok.com/@a3noticias',
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="tiktok-embed" cite="https://www.tiktok.com/@a3noticias/video/6806030056956251397" data-video-id="6806030056956251397" style="max-width: 605px;min-width: 325px;" > <section> <a target="_blank" title="@a3noticias" href="https://www.tiktok.com/@a3noticias">@a3noticias</a> <p>Nuestro <a title="aplausosanitario" target="_blank" href="https://www.tiktok.com/tag/aplausosanitario">#AplausoSanitario</a> más sincero. Para todos. Y recuerda, <a title="quédateencasa" target="_blank" href="https://www.tiktok.com/tag/qu%C3%A9dateencasa">#QuédateEnCasa</a></p> <a target="_blank" title="♬ Resistiré - Duo Dinamico" href="https://www.tiktok.com/music/Resistiré-250824169968246784">♬ Resistiré - Duo Dinamico</a> </section> </blockquote> <script async src="https://www.tiktok.com/embed.js"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Antena 3 Noticias (@a3noticias) ha creado un video corto en TikTok con la música Resistiré. | Nuestro #AplausoSanitario más sincero. Para todos. Y recuerda, #QuédateEnCasa',
    'favicon' => 'https://s16.tiktokcdn.com/musical/resource/mtact/static/images/logo_144c91a.png?v=2',
    'feeds' => [],
    'icon' => 'https://s16.tiktokcdn.com/musical/resource/mtact/static/pwa/icon_128x128.png',
    'image' => 'https://p77-sign-va.tiktokcdn.com/obj/tos-maliva-p-0068/165175e006354d838501378cfb325b79_1584652367?x-expires=1617570000&x-signature=ug9Nat5BeroYU6zWPlDXVO6EDak%3D',
    'keywords' => [
        'antena 3 noticias',
        'a3noticias',
        'aplausosanitario',
        'quédateencasa',
        'tiktok',
        'ティックトック',
        'tik tok',
        'tick tock',
        'tic tok',
        'tic toc',
        'tictok',
        'тик ток',
        'ticktock'
    ],
    'language' => 'en',
    'languages' => [
        'x-default' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397',
        'en' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=en',
        'ar' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ar',
        'de-DE' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=de-DE',
        'es' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=es',
        'fi-FI' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=fi-FI',
        'fr' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=fr',
        'id-ID' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=id-ID',
        'ja-JP' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ja-JP',
        'ko-KR' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ko-KR',
        'ms-MY' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ms-MY',
        'ru-RU' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ru-RU',
        'th-TH' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=th-TH',
        'tr-TR' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=tr-TR',
        'vi-VN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=vi-VN',
        'zh-Hant' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=zh-Hant-TW',
        'af-ZA' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=af-ZA',
        'he-IL' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=he-IL',
        'jv-ID' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=jv-ID',
        'ceb-PH' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ceb-PH',
        'cs-CZ' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=cs-CZ',
        'it-IT' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=it-IT',
        'hu-HU' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=hu-HU',
        'nl-NL' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=nl-NL',
        'pl-PL' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=pl-PL',
        'pt-BR' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=pt-BR',
        'ro-RO' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ro-RO',
        'sv-SE' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=sv-SE',
        'sw' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=sw',
        'fil-PH' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=fil-PH',
        'el-GR' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=el-GR',
        'zu-ZA' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=zu-ZA',
        'uk-UA' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=uk-UA',
        'ur' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ur',
        'mr-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=mr-IN',
        'hi-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=hi-IN',
        'bn-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=bn-IN',
        'pa-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=pa-IN',
        'gu-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=gu-IN',
        'or-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=or-IN',
        'ta-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ta-IN',
        'te-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=te-IN',
        'kn-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=kn-IN',
        'ml-IN' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=ml-IN',
        'my-MM' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=my-MM',
        'km-KH' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397?lang=km-KH'
    ],
    'license' => null,
    'providerName' => 'TikTok',
    'providerUrl' => 'https://www.tiktok.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Nuestro #AplausoSanitario más sincero. Para todos. Y recuerda, #QuédateEnCasa',
    'url' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'video',
        'title' => 'Nuestro #AplausoSanitario más sincero. Para todos. Y recuerda, #QuédateEnCasa',
        'author_url' => 'https://www.tiktok.com/@a3noticias',
        'author_name' => 'Antena 3 Noticias',
        'width' => '100%',
        'height' => '100%',
        'html' => '<blockquote class="tiktok-embed" cite="https://www.tiktok.com/@a3noticias/video/6806030056956251397" data-video-id="6806030056956251397" style="max-width: 605px;min-width: 325px;" > <section> <a target="_blank" title="@a3noticias" href="https://www.tiktok.com/@a3noticias">@a3noticias</a> <p>Nuestro <a title="aplausosanitario" target="_blank" href="https://www.tiktok.com/tag/aplausosanitario">#AplausoSanitario</a> más sincero. Para todos. Y recuerda, <a title="quédateencasa" target="_blank" href="https://www.tiktok.com/tag/qu%C3%A9dateencasa">#QuédateEnCasa</a></p> <a target="_blank" title="♬ Resistiré - Duo Dinamico" href="https://www.tiktok.com/music/Resistiré-250824169968246784">♬ Resistiré - Duo Dinamico</a> </section> </blockquote> <script async src="https://www.tiktok.com/embed.js"></script>',
        'thumbnail_width' => 480,
        'thumbnail_height' => 848,
        'thumbnail_url' => 'https://p77-sign-va.tiktokcdn.com/obj/tos-maliva-p-0068/165175e006354d838501378cfb325b79_1584652367?x-expires=1617570000&x-signature=ug9Nat5BeroYU6zWPlDXVO6EDak%3D',
        'provider_url' => 'https://www.tiktok.com',
        'provider_name' => 'TikTok'
    ],
    'allLinkedData' => []
];
