<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="imgur-embed-pub" lang="en" data-id="X6rkCc5"><a href="https://imgur.com/X6rkCc5">Picture of a Mountain Gorilla right before he punched the photographer</a></blockquote><script async src="//s.imgur.com/min/embed.js" charset="utf-8"></script>',
        'width' => 540,
        'height' => 500,
        'ratio' => 92.593
    ],
    'description' => null,
    'favicon' => 'https://i.imgur.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.imgur.com/X6rkCc5.jpg',
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Imgur',
    'providerUrl' => 'https://imgur.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => null,
    'url' => 'https://i.imgur.com/X6rkCc5.jpg',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'rich',
        'provider_name' => 'Imgur',
        'provider_url' => 'https://imgur.com',
        'width' => 540,
        'height' => 500,
        'html' => '<blockquote class="imgur-embed-pub" lang="en" data-id="X6rkCc5"><a href="https://imgur.com/X6rkCc5">Picture of a Mountain Gorilla right before he punched the photographer</a></blockquote><script async src="//s.imgur.com/min/embed.js" charset="utf-8"></script>'
    ],
    'allLinkedData' => []
];
