<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="http://output.jsbin.com/vonesu/10" width="320" height="240" frameborder="0"></iframe>',
        'width' => 320,
        'height' => 240,
        'ratio' => 75.0
    ],
    'description' => null,
    'favicon' => 'http://output.jsbin.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Jsbin',
    'providerUrl' => 'http://output.jsbin.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'JS Bin',
    'url' => 'http://output.jsbin.com/vonesu/10',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'rich',
        'version' => '1.0',
        'title' => 'JS Bin',
        'url' => 'http://output.jsbin.com/vonesu/10',
        'width' => 320,
        'height' => 240,
        'html' => '<iframe src="http://output.jsbin.com/vonesu/10" width="320" height="240" frameborder="0"></iframe>'
    ],
    'allLinkedData' => []
];
