<?php
declare(strict_types = 1);

return [
    'authorName' => 'IDIDTHAT.co',
    'authorUrl' => 'https://soundcloud.com/ididthat-1',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="100%" height="400" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?visual=true&url=https%3A%2F%2Fapi.soundcloud.com%2Ftracks%2F191904624&show_artwork=true"></iframe>',
        'width' => null,
        'height' => 400,
        'ratio' => null
    ],
    'description' => 'IDIDTHAT.co Promotes and Connects South Africa’s Advertising and Production Industry.',
    'favicon' => 'https://a-v2.sndcdn.com/assets/images/sc-icons/favicon-2cadd14bdb.ico',
    'feeds' => [],
    'icon' => 'https://a-v2.sndcdn.com/assets/images/sc-icons/ios-a62dfc8fe7.png',
    'image' => 'https://soundcloud.com/images/fb_placeholder.png',
    'keywords' => [
        'record',
        'sounds',
        'share',
        'sound',
        'audio',
        'tracks',
        'music',
        'soundcloud'
    ],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'SoundCloud',
    'providerUrl' => 'https://soundcloud.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'LOWE CT Cape Times - World Cup by IDIDTHAT.co',
    'url' => 'https://soundcloud.com/ididthat-1/lowe-ct-cape-times-world-cup',
    'linkedData' => [],
    'oEmbed' => [
        'version' => 1.0,
        'type' => 'rich',
        'provider_name' => 'SoundCloud',
        'provider_url' => 'https://soundcloud.com',
        'height' => 400,
        'width' => '100%',
        'title' => 'LOWE CT Cape Times - World Cup by IDIDTHAT.co',
        'description' => '',
        'thumbnail_url' => 'https://soundcloud.com/images/fb_placeholder.png',
        'html' => '<iframe width="100%" height="400" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?visual=true&url=https%3A%2F%2Fapi.soundcloud.com%2Ftracks%2F191904624&show_artwork=true"></iframe>',
        'author_name' => 'IDIDTHAT.co',
        'author_url' => 'https://soundcloud.com/ididthat-1'
    ],
    'allLinkedData' => []
];
