<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => 'https://live.amcharts.com/czNjJ/',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="600" height="400" src="//live.amcharts.com/czNjJ/embed/" frameborder="0" ></iframe>',
        'width' => 600,
        'height' => 400,
        'ratio' => 66.667
    ],
    'description' => 'Let\\\'s see how the history of the winner of 2014 World Cup - Germany - compares to the two runners-up: Argentina and The Netherlands.',
    'favicon' => 'https://live.amcharts.com/static/img/page/favicon.png',
    'feeds' => [],
    'icon' => null,
    'image' => 'http://generated.amcharts.com/cz/czNjJ-full.png',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'amCharts',
    'providerUrl' => 'http://www.amcharts.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'World Cup History',
    'url' => 'https://live.amcharts.com/czNjJ/',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'rich',
        'html' => '<iframe width="600" height="400" src="//live.amcharts.com/czNjJ/embed/" frameborder="0" ></iframe>',
        'width' => 600,
        'height' => 400,
        'title' => 'World Cup History',
        'author_name' => '',
        'author_url' => '//live.amcharts.com/czNjJ/',
        'canonical' => '//live.amcharts.com/czNjJ/',
        'description' => 'Let\\\'s see how the history of the winner of 2014 World Cup - Germany - compares to the two runners-up: Argentina and The Netherlands.',
        'provider_name' => 'amCharts',
        'provider_url' => 'http://www.amcharts.com/',
        'thumbnail_url' => 'http://generated.amcharts.com/cz/czNjJ-full.png',
        'thumbnail_width' => 404,
        'thumbnail_height' => 300
    ],
    'allLinkedData' => []
];
