<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://st.deviantart.net/eclipse/icons/da_favicon_v2.ico',
    'feeds' => [],
    'icon' => 'https://st.deviantart.net/eclipse/icons/ios-180.png',
    'image' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg/v1/fill/w_695,h_900,q_75,strp/misty_by_sakimichan_d8foa93-fullview.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOiIsImlzcyI6InVybjphcHA6Iiwib2JqIjpbW3siaGVpZ2h0IjoiPD05MDAiLCJwYXRoIjoiXC9mXC85YWQ4ZmJjOC1hZWU4LTRlOTItYTA0Yi02YWJmN2EwMzZhNTFcL2Q4Zm9hOTMtOGUxZmFkZTktMTg1My00NjQ0LWFmODItMmVjMjE1OTBiZjk0LmpwZyIsIndpZHRoIjoiPD02OTUifV1dLCJhdWQiOlsidXJuOnNlcnZpY2U6aW1hZ2Uub3BlcmF0aW9ucyJdfQ.o3EGZf7MMCA0ycvTZ5sCjU2iEzRtD7JS38L_r-uzVyE',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Deviantart',
    'providerUrl' => 'https://www.deviantart.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Misty by sakimichan on DeviantArt',
    'url' => 'https://www.deviantart.com/sakimichan/art/Misty-510056679',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
