<?php
declare(strict_types = 1);

return [
    'authorName' => 'desescribir',
    'authorUrl' => 'https://www.flickr.com/photos/desescribir/',
    'cms' => null,
    'code' => [
        'html' => '<a data-flickr-embed=\'true\' href=\'https://www.flickr.com/photos/desescribir/sets/72157650686499888\' title=\'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane by desescribir, on Flickr\'><img src=\'https://live.staticflickr.com/8572/16055522574_ce77fde14e_b.jpg\' width=\'800\' height=\'600\' alt=\'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane\'></a><script async src=\'https://embedr.flickr.com/assets/client-code.js\' charset=\'utf-8\'></script>',
        'width' => 800,
        'height' => 600,
        'ratio' => 75.0
    ],
    'description' => 'Explore this photo album by desescribir on Flickr!',
    'favicon' => 'https://combo.staticflickr.com/pw/favicon.ico',
    'feeds' => [
        'https://www.flickr.com/services/feeds/photoset.gne?nsid=34912442@N03&set=72157650686499888&lang=en-us&format=atom'
    ],
    'icon' => 'https://combo.staticflickr.com/pw/images/favicons/favicon-120.png',
    'image' => 'https://live.staticflickr.com/8572/16055522574_ce77fde14e_b.jpg',
    'keywords' => [],
    'language' => 'en-us',
    'languages' => [],
    'license' => 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
    'providerName' => 'Flickr',
    'providerUrl' => 'https://www.flickr.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane',
    'url' => 'https://www.flickr.com/photos/desescribir/sets/72157650686499888',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'BlogPosting',
        'mainEntityOfPage' => [
            '@type' => 'WebPage',
            '@id' => 'https://www.flickr.com/photos/desescribir/sets/72157650686499888'
        ],
        'headline' => 'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane',
        'image' => [
            '@type' => 'ImageObject',
            'url' => 'https://live.staticflickr.com/8572/16055522574_ce77fde14e_b.jpg',
            'height' => 680,
            'width' => 1024
        ],
        'author' => [
            '@type' => 'Person',
            'name' => 'desescribir',
            'sameAs' => 'https://www.flickr.com/photos/desescribir/'
        ],
        'publisher' => [
            '@type' => 'Organization',
            'name' => 'Flickr',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.flickr.com/images/opensearch-flickr-logo.png',
                'width' => 64,
                'height' => 64
            ]
        ],
        'description' => 'Explore this photo album by desescribir on Flickr!'
    ],
    'oEmbed' => [
        'type' => 'rich',
        'flickr_type' => 'album',
        'title' => 'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane',
        'author_name' => 'desescribir',
        'author_url' => 'https://www.flickr.com/photos/desescribir/',
        'width' => 800,
        'height' => 600,
        'web_page' => 'https://www.flickr.com/photos/desescribir/sets/72157650686499888',
        'thumbnail_url' => 'https://live.staticflickr.com/8572/16055522574_ce77fde14e_b.jpg',
        'thumbnail_width' => 800,
        'thumbnail_height' => 600,
        'web_page_short_url' => 'https://flic.kr/s/aHsk8hUbqq',
        'license_url' => 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
        'html' => '<a data-flickr-embed=\'true\' href=\'https://www.flickr.com/photos/desescribir/sets/72157650686499888\' title=\'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane by desescribir, on Flickr\'><img src=\'https://live.staticflickr.com/8572/16055522574_ce77fde14e_b.jpg\' width=\'800\' height=\'600\' alt=\'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane\'></a><script async src=\'https://embedr.flickr.com/assets/client-code.js\' charset=\'utf-8\'></script>',
        'version' => '1.0',
        'cache_age' => 3600,
        'provider_name' => 'Flickr',
        'provider_url' => 'https://www.flickr.com/'
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'WebSite',
            'name' => 'Flickr',
            'url' => 'https://www.flickr.com',
            'potentialAction' => [
                '@type' => 'SearchAction',
                'target' => 'https://www.flickr.com/search?text={search_term_string}&structured=yes',
                'query-input' => 'required name=search_term_string'
            ]
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'Organization',
            'url' => 'http://www.flickr.com',
            'logo' => 'https://www.flickr.com/images/opensearch-flickr-logo.png'
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'Person',
            'name' => 'Flickr',
            'url' => 'https://www.flickr.com',
            'sameAs' => [
                'https://www.facebook.com/flickr',
                'https://instagram.com/flickr',
                'https://flickr.tumblr.com',
                'https://twitter.com/flickr',
                'https://plus.google.com/+flickr',
                'https://www.pinterest.com/flickr'
            ]
        ],
        [
            '@context' => 'https://schema.org',
            '@type' => 'BlogPosting',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.flickr.com/photos/desescribir/sets/72157650686499888'
            ],
            'headline' => 'Günther Förg. Verfolgen Malerei / Fundación Luís Seoane',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://live.staticflickr.com/8572/16055522574_ce77fde14e_b.jpg',
                'height' => 680,
                'width' => 1024
            ],
            'author' => [
                '@type' => 'Person',
                'name' => 'desescribir',
                'sameAs' => 'https://www.flickr.com/photos/desescribir/'
            ],
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'Flickr',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.flickr.com/images/opensearch-flickr-logo.png',
                    'width' => 64,
                    'height' => 64
                ]
            ],
            'description' => 'Explore this photo album by desescribir on Flickr!'
        ]
    ]
];
