<?php
declare(strict_types = 1);

return [
    'authorName' => 'dennisrieves',
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="reddit-card" > <a href="https://www.reddit.com/r/investing/comments/7pfpeq/buffett_on_cyrptocurrencies_i_can_say_almost_with/?ref_source=embed&amp;ref=share">Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'</a> from <a href="https://www.reddit.com/r/investing/">investing</a> </blockquote> <script async src="https://embed.redditmedia.com/widgets/platform.js" charset="UTF-8"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => '1,937 votes and 1,263 comments so far on Reddit',
    'favicon' => 'https://www.redditstatic.com/desktop2x/img/favicon/android-icon-192x192.png',
    'feeds' => [],
    'icon' => 'https://www.redditstatic.com/desktop2x/img/favicon/apple-icon-57x57.png',
    'image' => 'https://external-preview.redd.it/0e1ORiHMjPTnSvzC-f3SC1-3IfjyQHqzqkk5nJPlDts.jpg?auto=webp&s=ef51b1d9b2ec99ba5dc8031fd134011376932b38',
    'keywords' => [],
    'language' => 'en-US',
    'languages' => [],
    'license' => null,
    'providerName' => 'reddit',
    'providerUrl' => 'https://www.reddit.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'',
    'url' => 'https://www.reddit.com/r/investing/comments/7pfpeq/buffett_on_cyrptocurrencies_i_can_say_almost_with/',
    'linkedData' => [],
    'oEmbed' => [
        'provider_url' => 'https://www.reddit.com/',
        'version' => '1.0',
        'title' => 'Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'',
        'provider_name' => 'reddit',
        'type' => 'rich',
        'html' => '
    <blockquote class="reddit-card" >
      <a href="https://www.reddit.com/r/investing/comments/7pfpeq/buffett_on_cyrptocurrencies_i_can_say_almost_with/?ref_source=embed&amp;ref=share">Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'</a> from
      <a href="https://www.reddit.com/r/investing/">investing</a>
    </blockquote>
    <script async src="https://embed.redditmedia.com/widgets/platform.js" charset="UTF-8"></script>
',
        'author_name' => 'dennisrieves'
    ],
    'allLinkedData' => []
];
