<?php
declare(strict_types = 1);

return [
    'authorName' => '@La_SER',
    'authorUrl' => 'https://twitter.com/La_SER',
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://play.cadenaser.com/widget/audio/001RD010000004275766/" frameborder="0" width="100%" height="360" allowTransparency="true"></iframe>',
        'width' => null,
        'height' => 360,
        'ratio' => null
    ],
    'description' => 'Ana Pontón, candidata del BNG; Xoaquín Fernández Leiceaga, candidato del PSdG-PSOE; Luis Villares, candidato de En Marea, y Pedro Puy, candidato del PP por A Coruña y coordinador del programa electoral de Alberto Núñez Feijoo debaten en Hoy por Hoy',
    'favicon' => 'https://play.cadenaser.com/bundles/playserweb/img/favicon.ico?v3.3',
    'feeds' => [],
    'icon' => 'https://play.cadenaser.com/bundles/playserweb/img/apple-touch-icon-57x57.png?v3.3',
    'image' => 'https://cadenaser00.epimg.net/iconos/v1.x/v1.0/redes/imagenes_og/programas_v2/2019/imagen-control-hoy-por-hoy-angels.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'Cadena SER',
    'providerUrl' => 'https://play.cadenaser.com',
    'publishedTime' => '2016-09-16 00:00:00',
    'redirect' => null,
    'title' => 'Debate electoral gallego, en \'Hoy por Hoy\' | Hoy por Hoy | Audio | Cadena SER',
    'url' => 'https://play.cadenaser.com/audio/001RD010000004275766/',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'BreadcrumbList',
        'itemListElement' => [
            [
                '@type' => 'ListItem',
                'position' => 1,
                'item' => [
                    '@id' => 'https://play.cadenaser.com/',
                    'name' => 'PlaySER'
                ]
            ],
            [
                '@type' => 'ListItem',
                'position' => 2,
                'item' => [
                    '@id' => 'https://play.cadenaser.com/programa/hoy_por_hoy/',
                    'name' => 'Hoy por Hoy'
                ]
            ]
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@type' => 'BreadcrumbList',
            'itemListElement' => [
                [
                    '@type' => 'ListItem',
                    'position' => 1,
                    'item' => [
                        '@id' => 'https://play.cadenaser.com/',
                        'name' => 'PlaySER'
                    ]
                ],
                [
                    '@type' => 'ListItem',
                    'position' => 2,
                    'item' => [
                        '@id' => 'https://play.cadenaser.com/programa/hoy_por_hoy/',
                        'name' => 'Hoy por Hoy'
                    ]
                ]
            ]
        ],
        [
            '@context' => 'https://schema.org',
            '@type' => 'Corporation',
            'name' => 'cadenaser.com',
            'url' => 'https://cadenaser.com',
            'logo' => 'https://play.cadenaser.com/bundles/playserweb/img/logo_playser.svg',
            'sameAs' => [
                'https://www.facebook.com/cadenaser',
                'https://twitter.com/La_SER',
                'https://plus.google.com/+cadenaser/',
                'https://www.youtube.com/user/cadenaser'
            ]
        ]
    ]
];
