<?php
declare(strict_types = 1);

return [
    'authorName' => 'Tony Quesada',
    'authorUrl' => 'https://infogram.com/sabjnewsroom01',
    'cms' => null,
    'code' => [
        'html' => '<div class="infogram-embed" data-id="7743c36a-f3ca-4465-9a80-a8abbd5d8dc4" data-type="interactive" data-title="Frost Bank Advisors (online graphic)"></div><script>!function(e,i,n,s){var t="InfogramEmbeds",d=e.getElementsByTagName("script")[0];if(window[t]&&window[t].initialized)window[t].process&&window[t].process();else if(!e.getElementById(n)){var o=e.createElement("script");o.async=1,o.id=n,o.src="https://e.infogram.com/js/dist/embed-loader-min.js",d.parentNode.insertBefore(o,d)}}(document,0,"infogram-async");</script>',
        'width' => 550,
        'height' => 600,
        'ratio' => 109.091
    ],
    'description' => null,
    'favicon' => 'https://cdn.jifo.co/favicon/favicon.ico?v=2',
    'feeds' => [],
    'icon' => 'https://cdn.jifo.co/favicon/apple-touch-icon.png',
    'image' => 'https://infogram-thumbs-1024.s3-eu-west-1.amazonaws.com/4e31a649-39af-4bfd-a6a9-384e727e36e2.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Infogram',
    'providerUrl' => 'https://infogram.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Frost Bank Advisors (online graphic)',
    'url' => 'https://infogram.com/7743c36a-f3ca-4465-9a80-a8abbd5d8dc4',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'rich',
        'provider_url' => 'https://infogram.com/',
        'provider_name' => 'Infogram',
        'description' => '',
        'title' => 'Frost Bank Advisors (online graphic)',
        'thumbnail_url' => 'https://infogram-thumbs-1024.s3-eu-west-1.amazonaws.com/4e31a649-39af-4bfd-a6a9-384e727e36e2.jpg',
        'uri' => 'https://infogram.com/frost-bank-advisors-online-graphic-1g8e205xdj03pod',
        'html' => '<div class="infogram-embed" data-id="7743c36a-f3ca-4465-9a80-a8abbd5d8dc4" data-type="interactive" data-title="Frost Bank Advisors (online graphic)"></div><script>!function(e,i,n,s){var t="InfogramEmbeds",d=e.getElementsByTagName("script")[0];if(window[t]&&window[t].initialized)window[t].process&&window[t].process();else if(!e.getElementById(n)){var o=e.createElement("script");o.async=1,o.id=n,o.src="https://e.infogram.com/js/dist/embed-loader-min.js",d.parentNode.insertBefore(o,d)}}(document,0,"infogram-async");</script>',
        'width' => 550,
        'height' => 600,
        'author_url' => 'https://infogram.com/sabjnewsroom01',
        'author_name' => 'Tony Quesada'
    ],
    'allLinkedData' => []
];
