<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://consent.youtube.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Youtube',
    'providerUrl' => 'https://consent.youtube.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Error 404 (No se ha encontrado.)!!1',
    'url' => 'https://consent.youtube.com/\'https:/consent.youtube.com/ml?continue=https://www.youtube.com/channel/UCuZeHD5SGecQomz2pVDHGzg&gl=ES&hl=es&pc=yt&uxe=23983172&src=1&rffu=true\'',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
