<?php
declare(strict_types = 1);

return [
    'authorName' => 'JSFiddle',
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Test your JavaScript, CSS, HTML or CoffeeScript online with JSFiddle code editor.',
    'favicon' => 'http://jsfiddle.net/img/favicon.png',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [
        'online javascript editor',
        'testing javascript online',
        'online ide',
        'online code editor',
        'html',
        'css',
        'coffeescript',
        'scss online editor'
    ],
    'language' => null,
    'languages' => [],
    'license' => 'share alike',
    'providerName' => 'Jsfiddle',
    'providerUrl' => 'http://jsfiddle.net',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Edit fiddle - JSFiddle - Code Playground',
    'url' => 'http://jsfiddle.net/zhm5rjnz/',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
