<?php
declare(strict_types = 1);

return [
    'authorName' => 'Pepephone',
    'authorUrl' => 'https://twitter.com/pepephone',
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="twitter-tweet"><p lang="es" dir="ltr">RT <a href="https://twitter.com/PabloHerreros?ref_src=twsrc%5Etfw">@PabloHerreros</a> Pepephone rompe la baraja - <a href="http://t.co/mFn7mcB1vy">http://t.co/mFn7mcB1vy</a></p>&mdash; Pepephone (@pepephone) <a href="https://twitter.com/pepephone/status/436461658601713664?ref_src=twsrc%5Etfw">February 20, 2014</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>',
        'width' => 550,
        'height' => null,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://abs.twimg.com/favicons/twitter.ico',
    'feeds' => [],
    'icon' => 'https://abs.twimg.com/responsive-web/client-web-legacy/icon-ios.b1fc7275.png',
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [
        'x-default' => 'https://twitter.com/pepephone/status/436461658601713664',
        'en' => 'https://twitter.com/pepephone/status/436461658601713664?lang=en',
        'ar' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ar',
        'ar-x-fm' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ar-x-fm',
        'bg' => 'https://twitter.com/pepephone/status/436461658601713664?lang=bg',
        'bn' => 'https://twitter.com/pepephone/status/436461658601713664?lang=bn',
        'ca' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ca',
        'cs' => 'https://twitter.com/pepephone/status/436461658601713664?lang=cs',
        'da' => 'https://twitter.com/pepephone/status/436461658601713664?lang=da',
        'de' => 'https://twitter.com/pepephone/status/436461658601713664?lang=de',
        'el' => 'https://twitter.com/pepephone/status/436461658601713664?lang=el',
        'en-GB' => 'https://twitter.com/pepephone/status/436461658601713664?lang=en-GB',
        'en-ss' => 'https://twitter.com/pepephone/status/436461658601713664?lang=en-ss',
        'en-xx' => 'https://twitter.com/pepephone/status/436461658601713664?lang=en-xx',
        'es' => 'https://twitter.com/pepephone/status/436461658601713664?lang=es',
        'eu' => 'https://twitter.com/pepephone/status/436461658601713664?lang=eu',
        'fa' => 'https://twitter.com/pepephone/status/436461658601713664?lang=fa',
        'fi' => 'https://twitter.com/pepephone/status/436461658601713664?lang=fi',
        'fil' => 'https://twitter.com/pepephone/status/436461658601713664?lang=fil',
        'fr' => 'https://twitter.com/pepephone/status/436461658601713664?lang=fr',
        'ga' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ga',
        'gl' => 'https://twitter.com/pepephone/status/436461658601713664?lang=gl',
        'gu' => 'https://twitter.com/pepephone/status/436461658601713664?lang=gu',
        'he' => 'https://twitter.com/pepephone/status/436461658601713664?lang=he',
        'hi' => 'https://twitter.com/pepephone/status/436461658601713664?lang=hi',
        'hr' => 'https://twitter.com/pepephone/status/436461658601713664?lang=hr',
        'hu' => 'https://twitter.com/pepephone/status/436461658601713664?lang=hu',
        'id' => 'https://twitter.com/pepephone/status/436461658601713664?lang=id',
        'it' => 'https://twitter.com/pepephone/status/436461658601713664?lang=it',
        'ja' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ja',
        'kn' => 'https://twitter.com/pepephone/status/436461658601713664?lang=kn',
        'ko' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ko',
        'mr' => 'https://twitter.com/pepephone/status/436461658601713664?lang=mr',
        'ms' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ms',
        'nb' => 'https://twitter.com/pepephone/status/436461658601713664?lang=nb',
        'nl' => 'https://twitter.com/pepephone/status/436461658601713664?lang=nl',
        'pl' => 'https://twitter.com/pepephone/status/436461658601713664?lang=pl',
        'pt' => 'https://twitter.com/pepephone/status/436461658601713664?lang=pt',
        'ro' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ro',
        'ru' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ru',
        'sk' => 'https://twitter.com/pepephone/status/436461658601713664?lang=sk',
        'sr' => 'https://twitter.com/pepephone/status/436461658601713664?lang=sr',
        'sv' => 'https://twitter.com/pepephone/status/436461658601713664?lang=sv',
        'ta' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ta',
        'th' => 'https://twitter.com/pepephone/status/436461658601713664?lang=th',
        'tr' => 'https://twitter.com/pepephone/status/436461658601713664?lang=tr',
        'uk' => 'https://twitter.com/pepephone/status/436461658601713664?lang=uk',
        'ur' => 'https://twitter.com/pepephone/status/436461658601713664?lang=ur',
        'vi' => 'https://twitter.com/pepephone/status/436461658601713664?lang=vi',
        'zh' => 'https://twitter.com/pepephone/status/436461658601713664?lang=zh',
        'zh-Hant' => 'https://twitter.com/pepephone/status/436461658601713664?lang=zh-Hant'
    ],
    'license' => null,
    'providerName' => 'Twitter',
    'providerUrl' => 'https://twitter.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => null,
    'url' => 'https://twitter.com/pepephone/status/436461658601713664',
    'linkedData' => [],
    'oEmbed' => [
        'url' => 'https://twitter.com/pepephone/status/436461658601713664',
        'author_name' => 'Pepephone',
        'author_url' => 'https://twitter.com/pepephone',
        'html' => '<blockquote class="twitter-tweet"><p lang="es" dir="ltr">RT <a href="https://twitter.com/PabloHerreros?ref_src=twsrc%5Etfw">@PabloHerreros</a> Pepephone rompe la baraja - <a href="http://t.co/mFn7mcB1vy">http://t.co/mFn7mcB1vy</a></p>&mdash; Pepephone (@pepephone) <a href="https://twitter.com/pepephone/status/436461658601713664?ref_src=twsrc%5Etfw">February 20, 2014</a></blockquote>
<script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>
',
        'width' => 550,
        'height' => null,
        'type' => 'rich',
        'cache_age' => '3153600000',
        'provider_name' => 'Twitter',
        'provider_url' => 'https://twitter.com',
        'version' => '1.0'
    ],
    'api' => [],
    'allLinkedData' => []
];
