<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<audio src="https://www.soundhelix.com/examples/mp3/SoundHelix-Song-1.mp3" controls></audio>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://www.soundhelix.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Soundhelix',
    'providerUrl' => 'https://www.soundhelix.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => null,
    'url' => 'https://www.soundhelix.com/examples/mp3/SoundHelix-Song-1.mp3',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
