<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'ABANCA, a banca para particulares e negocios. Conta online, conta nómina, conta joven, hipotecas, depósitos, fondos, seguros e moito máis. Banco ABANCA.',
    'favicon' => 'https://www.abanca.com/favicon.png',
    'feeds' => [],
    'icon' => 'https://www.abanca.com/apple-touch-icon-152x152-precomposed.png',
    'image' => 'https://www.abanca.com/img/logo-social.jpg',
    'keywords' => [
        'abanca',
        'abanca particulares',
        'abanca empresas',
        'abanca autónomos',
        'servizos bancarios',
        'servizos financeios',
        'produtos financeiros',
        'produtos bancarios'
    ],
    'language' => 'gl',
    'languages' => [
        'gl' => 'https://www.abanca.com/gl/',
        'es' => 'https://www.abanca.com/es/'
    ],
    'license' => null,
    'providerName' => 'Abanca',
    'providerUrl' => 'https://www.abanca.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'ABANCA banca online para particulares e empresas | ABANCA',
    'url' => 'https://www.abanca.com/gl/',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'Organization',
        'name' => '',
        'url' => '//www.abanca.com',
        'logo' => '//www.abanca.com/img/logo-social.jpg',
        'sameAs' => [],
        'contactPoint' => [
            [
                '@type' => 'ContactPoint',
                'telephone' => '-',
                'contactType' => 'customer service'
            ]
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'Organization',
            'name' => '',
            'url' => '//www.abanca.com',
            'logo' => '//www.abanca.com/img/logo-social.jpg',
            'sameAs' => [],
            'contactPoint' => [
                [
                    '@type' => 'ContactPoint',
                    'telephone' => '-',
                    'contactType' => 'customer service'
                ]
            ]
        ]
    ]
];
