<?php
declare(strict_types = 1);

return [
    'authorName' => 'AOL',
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://s.yimg.com/cv/apiv2/aolfp/images/favicon/favicon-16x16.png',
    'feeds' => [],
    'icon' => 'https://s.yimg.com/cv/apiv2/aolfp/images/favicon/apple-touch-icon-57x57.png',
    'image' => 'https://s.yimg.com/cv/apiv2/aolfp/metadata/og-image.png',
    'keywords' => [],
    'language' => 'en-US',
    'languages' => [],
    'license' => null,
    'providerName' => 'AOL.com',
    'providerUrl' => 'https://www.aol.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'AOL Video - Serving the best video content from AOL and around the web',
    'url' => 'https://www.aol.com/video/view/pile-of-recovering-foster-kittens-is-purrfect/595fe75985eb42109b69bedb/',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
