<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="http://slides.com/alexwalker/responsive-svg/embed" width="576" height="420" style="border:none" frameborder="0" allowTransparency="true"></iframe>',
        'width' => 576,
        'height' => 420,
        'ratio' => 72.917
    ],
    'description' => 'A presentation created with Slides.',
    'favicon' => 'http://slides.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://media.slid.es/thumbnails/alexwalker/0b188c/responsive-svg.jpg',
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Slides',
    'providerUrl' => 'http://slides.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'responsive-svg',
    'url' => 'http://slides.com/alexwalker/responsive-svg/',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
