<?php
declare(strict_types = 1);

return [
    'authorName' => 'Joint Fire Science Program',
    'authorUrl' => 'https://www.scribd.com/user/151878975/Joint-Fire-Science-Program',
    'cms' => null,
    'code' => [
        'html' => '<iframe class="scribd_iframe_embed" src="https://www.scribd.com/embeds/110799637/content" data-aspect-ratio="1.2941176470588236" scrolling="no" id="110799637" width="100%" height="500" frameborder="0"></iframe><script type="text/javascript"> (function() { var scribd = document.createElement("script"); scribd.type = "text/javascript"; scribd.async = true; scribd.src = "https://www.scribd.com/javascripts/embed_code/inject.js"; var s = document.getElementsByTagName("script")[0]; s.parentNode.insertBefore(scribd, s); })() </script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'A review of current literature on studies that address effects of prescribed fire and mechanical thinning treatments on understory vegetation, and the effects of prescribed burning on rare, threatened and endangered species. The studies\' outcomes are presented in two sets of tables: (1) functional group results, and (2) species-specific results.',
    'favicon' => 'https://s-f.scribdassets.com/favicon.ico?10f70579d?v=4',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://imgv2-2-f.scribdassets.com/img/document/110799637/111x142/9fc8621525/1617346919?v=1',
    'keywords' => [],
    'language' => 'en',
    'languages' => [
        'x-default' => 'https://www.scribd.com/document/110799637/Synthesis-of-Knowledge-Effects-of-Fire-and-Thinning-Treatments-on-Understory-Vegetation-in-Dry-U-S-Forests',
        'en' => 'https://www.scribd.com/document/110799637/Synthesis-of-Knowledge-Effects-of-Fire-and-Thinning-Treatments-on-Understory-Vegetation-in-Dry-U-S-Forests',
        'es' => 'https://es.scribd.com/document/110799637/Synthesis-of-Knowledge-Effects-of-Fire-and-Thinning-Treatments-on-Understory-Vegetation-in-Dry-U-S-Forests'
    ],
    'license' => null,
    'providerName' => 'Scribd',
    'providerUrl' => 'https://www.scribd.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Synthesis of Knowledge: Effects of Fire and Thinning Treatments on Understory Vegetation in Dry U.S. Forests',
    'url' => 'https://www.scribd.com/document/110799637/Synthesis-of-Knowledge-Effects-of-Fire-and-Thinning-Treatments-on-Understory-Vegetation-in-Dry-U-S-Forests',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'MediaObject',
        'additionalType' => 'Product',
        'name' => 'Synthesis of Knowledge: Effects of Fire and Thinning Treatments on Understory Vegetation in Dry U.S. Forests',
        'image' => [
            'https://imgv2-1-f.scribdassets.com/img/document/110799637/149x198/ca766a678b/1521312948?v=1',
            'https://imgv2-2-f.scribdassets.com/img/document/110799637/298x396/889f159160/1521312948?v=1'
        ],
        'aggregateRating' => [
            '@type' => 'AggregateRating',
            'ratingValue' => 5.0,
            'ratingCount' => 1
        ],
        'isAccessibleForFree' => 'False',
        'hasPart' => [
            '@type' => 'WebPageElement',
            'isAccessibleForFree' => 'False',
            'cssSelector' => '.blurred_page'
        ]
    ],
    'oEmbed' => [
        'type' => 'rich',
        'version' => '1.0',
        'provider_name' => 'Scribd',
        'provider_url' => 'https://www.scribd.com/',
        'cache_age' => 604800,
        'title' => 'Synthesis of Knowledge: Effects of Fire and Thinning Treatments on Understory Vegetation in Dry U.S. Forests',
        'author_name' => 'Joint Fire Science Program',
        'author_url' => 'https://www.scribd.com/user/151878975/Joint-Fire-Science-Program',
        'thumbnail_url' => 'https://imgv2-2-f.scribdassets.com/img/document/110799637/111x142/9fc8621525/1617346919?v=1',
        'thumbnail_width' => 164,
        'thumbnail_height' => 212,
        'html' => '<iframe class="scribd_iframe_embed" src="https://www.scribd.com/embeds/110799637/content" data-aspect-ratio="1.2941176470588236" scrolling="no" id="110799637" width="100%" height="500" frameborder="0"></iframe><script type="text/javascript">
          (function() { var scribd = document.createElement("script"); scribd.type = "text/javascript"; scribd.async = true; scribd.src = "https://www.scribd.com/javascripts/embed_code/inject.js"; var s = document.getElementsByTagName("script")[0]; s.parentNode.insertBefore(scribd, s); })()
        </script>'
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'MediaObject',
            'additionalType' => 'Product',
            'name' => 'Synthesis of Knowledge: Effects of Fire and Thinning Treatments on Understory Vegetation in Dry U.S. Forests',
            'image' => [
                'https://imgv2-1-f.scribdassets.com/img/document/110799637/149x198/ca766a678b/1521312948?v=1',
                'https://imgv2-2-f.scribdassets.com/img/document/110799637/298x396/889f159160/1521312948?v=1'
            ],
            'aggregateRating' => [
                '@type' => 'AggregateRating',
                'ratingValue' => 5.0,
                'ratingCount' => 1
            ],
            'isAccessibleForFree' => 'False',
            'hasPart' => [
                '@type' => 'WebPageElement',
                'isAccessibleForFree' => 'False',
                'cssSelector' => '.blurred_page'
            ]
        ]
    ]
];
