<?php
declare(strict_types = 1);

return [
    'headers' => [
        'date' => [
            'Mon, 10 Jun 2024 13:42:59 GMT'
        ],
        'server' => [
            'mw1373.eqiad.wmnet'
        ],
        'x-content-type-options' => [
            'nosniff'
        ],
        'content-language' => [
            'en'
        ],
        'origin-trial' => [
            'AonOP4SwCrqpb0nhZbg554z9iJimP3DxUDB8V4yu9fyyepauGKD0NXqTknWi4gnuDfMG6hNb7TDUDTsl0mDw9gIAAABmeyJvcmlnaW4iOiJodHRwczovL3dpa2lwZWRpYS5vcmc6NDQzIiwiZmVhdHVyZSI6IlRvcExldmVsVHBjZCIsImV4cGlyeSI6MTczNTM0Mzk5OSwiaXNTdWJkb21haW4iOnRydWV9'
        ],
        'accept-ch' => [
            ''
        ],
        'vary' => [
            'Accept-Encoding,Cookie,Authorization'
        ],
        'last-modified' => [
            'Mon, 10 Jun 2024 13:41:10 GMT'
        ],
        'content-type' => [
            'text/html; charset=UTF-8'
        ],
        'content-encoding' => [
            'gzip'
        ],
        'age' => [
            '8180'
        ],
        'x-cache' => [
            'cp6012 hit, cp6016 hit/21'
        ],
        'x-cache-status' => [
            'hit-front'
        ],
        'server-timing' => [
            'cache;desc="hit-front", host;desc="cp6016"'
        ],
        'strict-transport-security' => [
            'max-age=106384710; includeSubDomains; preload'
        ],
        'report-to' => [
            '{ "group": "wm_nel", "max_age": 604800, "endpoints": [{ "url": "https://intake-logging.wikimedia.org/v1/events?stream=w3c.reportingapi.network_error&schema_uri=/w3c/reportingapi/network_error/1.0.0" }] }'
        ],
        'nel' => [
            '{ "report_to": "wm_nel", "max_age": 604800, "failure_fraction": 0.05, "success_fraction": 0.0}'
        ],
        'set-cookie' => [
            'WMF-Last-Access=10-Jun-2024;Path=/;HttpOnly;secure;Expires=Fri, 12 Jul 2024 12:00:00 GMT',
            'WMF-Last-Access-Global=10-Jun-2024;Path=/;Domain=.wikipedia.org;HttpOnly;secure;Expires=Fri, 12 Jul 2024 12:00:00 GMT',
            'WMF-DP=775;Path=/;HttpOnly;secure;Expires=Tue, 11 Jun 2024 00:00:00 GMT',
            'GeoIP=ES:GA:A_Coru__a:43.35:-8.41:v4; Path=/; secure; Domain=.wikipedia.org',
            'NetworkProbeLimit=0.001;Path=/;Secure;SameSite=Lax;Max-Age=3600'
        ],
        'x-client-ip' => [
            '89.141.175.178'
        ],
        'cache-control' => [
            'private, s-maxage=0, max-age=0, must-revalidate'
        ],
        'accept-ranges' => [
            'bytes'
        ],
        'content-length' => [
            '191992'
        ],
        'Content-Location' => [
            'https://en.wikipedia.org/wiki/Albert_Einstein'
        ],
        'X-Request-Time' => [
            '0.201 ms'
        ]
    ],
    'statusCode' => 200,
    'reasonPhrase' => 'OK',
    'body' => '<!DOCTYPE html>
<html class="client-nojs vector-feature-language-in-header-enabled vector-feature-language-in-main-page-header-disabled vector-feature-sticky-header-disabled vector-feature-page-tools-pinned-disabled vector-feature-toc-pinned-clientpref-1 vector-feature-main-menu-pinned-disabled vector-feature-limited-width-clientpref-1 vector-feature-limited-width-content-enabled vector-feature-custom-font-size-clientpref-0 vector-feature-appearance-disabled vector-feature-appearance-pinned-clientpref-0 vector-feature-night-mode-disabled skin-theme-clientpref-day vector-toc-available" lang="en" dir="ltr">
<head>
<meta charset="UTF-8">
<title>Albert Einstein - Wikipedia</title>
<script>(function(){var className="client-js vector-feature-language-in-header-enabled vector-feature-language-in-main-page-header-disabled vector-feature-sticky-header-disabled vector-feature-page-tools-pinned-disabled vector-feature-toc-pinned-clientpref-1 vector-feature-main-menu-pinned-disabled vector-feature-limited-width-clientpref-1 vector-feature-limited-width-content-enabled vector-feature-custom-font-size-clientpref-0 vector-feature-appearance-disabled vector-feature-appearance-pinned-clientpref-0 vector-feature-night-mode-disabled skin-theme-clientpref-day vector-toc-available";var cookie=document.cookie.match(/(?:^|; )enwikimwclientpreferences=([^;]+)/);if(cookie){cookie[1].split(\'%2C\').forEach(function(pref){className=className.replace(new RegExp(\'(^| )\'+pref.replace(/-clientpref-\\w+$|[^\\w-]+/g,\'\')+\'-clientpref-\\\\w+( |$)\'),\'$1\'+pref+\'$2\');});}document.documentElement.className=className;}());RLCONF={"wgBreakFrames":false,"wgSeparatorTransformTable":["",""],"wgDigitTransformTable":
["",""],"wgDefaultDateFormat":"dmy","wgMonthNames":["","January","February","March","April","May","June","July","August","September","October","November","December"],"wgRequestId":"ecb28d89-3183-4371-9c54-840a3ba36d68","wgCanonicalNamespace":"","wgCanonicalSpecialPageName":false,"wgNamespaceNumber":0,"wgPageName":"Albert_Einstein","wgTitle":"Albert Einstein","wgCurRevisionId":1227307757,"wgRevisionId":1227307757,"wgArticleId":736,"wgIsArticle":true,"wgIsRedirect":false,"wgAction":"view","wgUserName":null,"wgUserGroups":["*"],"wgCategories":["Pages using the Phonos extension","CS1 German-language sources (de)","Webarchive template wayback links","CS1 French-language sources (fr)","CS1 maint: location missing publisher","CS1 location test","CS1 maint: DOI inactive as of January 2024","Articles with short description","Short description is different from Wikidata","Wikipedia indefinitely semi-protected pages","Wikipedia indefinitely move-protected pages","Good articles",
"Use American English from November 2022","All Wikipedia articles written in American English","Use dmy dates from November 2022","Articles containing German-language text","Articles with hAudio microformats","Biography with signature","Articles with hCards","Pages with German IPA","Pages including recorded pronunciations","Pages using sidebar with the child parameter","CS1: long volume value","Wikipedia articles incorporating a citation from the 1922 Encyclopaedia Britannica with Wikisource reference","Pages using Sister project links with hidden wikidata","Articles with Curlie links","Articles with Project Gutenberg links","Articles with Internet Archive links","Articles with LibriVox links","Nobelprize template using Wikidata property P8024","Articles with FAST identifiers","Articles with ISNI identifiers","Articles with VIAF identifiers","Articles with WorldCat Entities identifiers","Articles with BIBSYS identifiers","Articles with BNC identifiers","Articles with BNE identifiers",
"Articles with BNF identifiers","Articles with BNFdata identifiers","Articles with CANTICN identifiers","Articles with GND identifiers","Articles with ICCU identifiers","Articles with J9U identifiers","Articles with KANTO identifiers","Articles with KBR identifiers","Articles with LCCN identifiers","Articles with Libris identifiers","Articles with LNB identifiers","Articles with NCL identifiers","Articles with NDL identifiers","Articles with NKC identifiers","Articles with NLA identifiers","Articles with NLG identifiers","Articles with NLK identifiers","Articles with NLR identifiers","Articles with NSK identifiers","Articles with NTA identifiers","Articles with PLWABN identifiers","Articles with PortugalA identifiers","Articles with RSL identifiers","Articles with VcBA identifiers","Articles with CINII identifiers","Articles with Google Scholar identifiers","Articles with Leopoldina identifiers","Articles with MATHSN identifiers","Articles with MGP identifiers",
"Articles with ORCID identifiers","Articles with Scopus identifiers","Articles with ZBMATH identifiers","Articles with MusicBrainz identifiers","Articles with ULAN identifiers","Articles with DTBIO identifiers","Articles with Trove identifiers","Articles with EMU identifiers","Articles with HDS identifiers","Articles with NARA identifiers","Articles with RISM identifiers","Articles with SNAC-ID identifiers","Articles with SUDOC identifiers","Albert Einstein","1879 births","1955 deaths","19th-century German Jews","20th-century American engineers","20th-century American inventors","20th-century American male writers","20th-century American non-fiction writers","20th-century American physicists","20th-century Swiss inventors","Academic staff of Charles University","Academic staff of ETH Zurich","Academic staff of the University of Bern","Academic staff of the University of Zurich","American agnostics","American Ashkenazi Jews","American democratic socialists","American humanists",
"American letter writers","American male non-fiction writers","American Nobel laureates","American pacifists","American relativity theorists","American science writers","American Zionists","Anti-nationalists","Deaths from abdominal aortic aneurysm","Denaturalized citizens of Germany","Einstein family","ETH Zurich alumni","European democratic socialists","German agnostics","German Ashkenazi Jews","German emigrants to Switzerland","German humanists","German male non-fiction writers","German Nobel laureates","German relativity theorists","German Zionists","Institute for Advanced Study faculty","Jewish agnostics","Jewish American non-fiction writers","Jewish American physicists","Jewish German physicists","Jewish emigrants from Nazi Germany to the United States","Jewish scientists","Jewish socialists","Labor Zionists","Max Planck Institute directors","Members of the American Philosophical Society","Members of the Royal Netherlands Academy of Arts and Sciences",
"Members of the United States National Academy of Sciences","Naturalised citizens of Austria","Naturalised citizens of Switzerland","Naturalized citizens of the United States","Nobel laureates in Physics","Pantheists","Patent examiners","People from Ulm","People who lost German citizenship","People with multiple nationality","Philosophers of mathematics","Philosophers of science","Philosophy of science","Quantum physicists","Recipients of Franklin Medal","Scientists from Munich","Stateless people","Swiss agnostics","Swiss Ashkenazi Jews","Swiss cosmologists","Swiss emigrants to the United States","Swiss Nobel laureates","Swiss physicists","University of Zurich alumni","Winners of the Max Planck Medal","Württemberger emigrants to the United States"],"wgPageViewLanguage":"en","wgPageContentLanguage":"en","wgPageContentModel":"wikitext","wgRelevantPageName":"Albert_Einstein","wgRelevantArticleId":736,"wgIsProbablyEditable":false,"wgRelevantPageIsProbablyEditable":false,
"wgRestrictionEdit":["autoconfirmed"],"wgRestrictionMove":["sysop"],"wgNoticeProject":"wikipedia","wgCiteReferencePreviewsActive":false,"wgFlaggedRevsParams":{"tags":{"status":{"levels":1}}},"wgMediaViewerOnClick":true,"wgMediaViewerEnabledByDefault":true,"wgPopupsFlags":6,"wgVisualEditor":{"pageLanguageCode":"en","pageLanguageDir":"ltr","pageVariantFallbacks":"en"},"wgMFDisplayWikibaseDescriptions":{"search":true,"watchlist":true,"tagline":false,"nearby":true},"wgWMESchemaEditAttemptStepOversample":false,"wgWMEPageLength":200000,"wgULSCurrentAutonym":"English","wgCentralAuthMobileDomain":false,"wgEditSubmitButtonLabelPublish":true,"wgULSPosition":"interlanguage","wgULSisCompactLinksEnabled":false,"wgVector2022LanguageInHeader":true,"wgULSisLanguageSelectorEmpty":false,"wgWikibaseItemId":"Q937","wgCheckUserClientHintsHeadersJsApi":["architecture","bitness","brands","fullVersionList","mobile","model","platform","platformVersion"],"GEHomepageSuggestedEditsEnableTopics":true,
"wgGETopicsMatchModeEnabled":false,"wgGEStructuredTaskRejectionReasonTextInputEnabled":false,"wgGELevelingUpEnabledForUser":false};RLSTATE={"ext.globalCssJs.user.styles":"ready","site.styles":"ready","user.styles":"ready","ext.globalCssJs.user":"ready","user":"ready","user.options":"loading","ext.cite.styles":"ready","ext.phonos.styles":"ready","ext.phonos.icons":"ready","ext.tmh.player.styles":"ready","skins.vector.search.codex.styles":"ready","skins.vector.styles":"ready","skins.vector.icons":"ready","jquery.makeCollapsible.styles":"ready","ext.wikimediamessages.styles":"ready","ext.visualEditor.desktopArticleTarget.noscript":"ready","ext.uls.interlanguage":"ready","wikibase.client.init":"ready","ext.wikimediaBadges":"ready"};RLPAGEMODULES=["ext.cite.ux-enhancements","ext.phonos.init","ext.tmh.player","mediawiki.page.media","ext.scribunto.logs","site","mediawiki.page.ready","jquery.makeCollapsible","mediawiki.toc","skins.vector.js","ext.centralNotice.geoIP",
"ext.centralNotice.startUp","ext.gadget.ReferenceTooltips","ext.gadget.switcher","ext.urlShortener.toolbar","ext.centralauth.centralautologin","mmv.head","mmv.bootstrap.autostart","ext.popups","ext.visualEditor.desktopArticleTarget.init","ext.visualEditor.targetLoader","ext.echo.centralauth","ext.eventLogging","ext.wikimediaEvents","ext.navigationTiming","ext.uls.interface","ext.cx.eventlogging.campaigns","ext.cx.uls.quick.actions","wikibase.client.vector-2022","ext.checkUser.clientHints","ext.growthExperiments.SuggestedEditSession"];</script>
<script>(RLQ=window.RLQ||[]).push(function(){mw.loader.impl(function(){return["user.options@12s5i",function($,jQuery,require,module){mw.user.tokens.set({"patrolToken":"+\\\\","watchToken":"+\\\\","csrfToken":"+\\\\"});
}];});});</script>
<link rel="stylesheet" href="/w/load.php?lang=en&amp;modules=ext.cite.styles%7Cext.phonos.icons%2Cstyles%7Cext.tmh.player.styles%7Cext.uls.interlanguage%7Cext.visualEditor.desktopArticleTarget.noscript%7Cext.wikimediaBadges%7Cext.wikimediamessages.styles%7Cjquery.makeCollapsible.styles%7Cskins.vector.icons%2Cstyles%7Cskins.vector.search.codex.styles%7Cwikibase.client.init&amp;only=styles&amp;skin=vector-2022">
<script async="" src="/w/load.php?lang=en&amp;modules=startup&amp;only=scripts&amp;raw=1&amp;skin=vector-2022"></script>
<meta name="ResourceLoaderDynamicStyles" content="">
<link rel="stylesheet" href="/w/load.php?lang=en&amp;modules=site.styles&amp;only=styles&amp;skin=vector-2022">
<meta name="generator" content="MediaWiki 1.43.0-wmf.8">
<meta name="referrer" content="origin">
<meta name="referrer" content="origin-when-cross-origin">
<meta name="robots" content="max-image-preview:standard">
<meta name="format-detection" content="telephone=no">
<meta property="og:image" content="https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/1200px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg">
<meta property="og:image:width" content="1200">
<meta property="og:image:height" content="1576">
<meta property="og:image" content="https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/800px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg">
<meta property="og:image:width" content="800">
<meta property="og:image:height" content="1050">
<meta property="og:image" content="https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/640px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg">
<meta property="og:image:width" content="640">
<meta property="og:image:height" content="840">
<meta name="viewport" content="width=1000">
<meta property="og:title" content="Albert Einstein - Wikipedia">
<meta property="og:type" content="website">
<link rel="preconnect" href="//upload.wikimedia.org">
<link rel="alternate" media="only screen and (max-width: 720px)" href="//en.m.wikipedia.org/wiki/Albert_Einstein">
<link rel="apple-touch-icon" href="/static/apple-touch/wikipedia.png">
<link rel="icon" href="/static/favicon/wikipedia.ico">
<link rel="search" type="application/opensearchdescription+xml" href="/w/rest.php/v1/search" title="Wikipedia (en)">
<link rel="EditURI" type="application/rsd+xml" href="//en.wikipedia.org/w/api.php?action=rsd">
<link rel="canonical" href="https://en.wikipedia.org/wiki/Albert_Einstein">
<link rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/deed.en">
<link rel="alternate" type="application/atom+xml" title="Wikipedia Atom feed" href="/w/index.php?title=Special:RecentChanges&amp;feed=atom">
<link rel="dns-prefetch" href="//meta.wikimedia.org" />
<link rel="dns-prefetch" href="//login.wikimedia.org">
</head>
<body class="skin-vector skin-vector-search-vue mediawiki ltr sitedir-ltr mw-hide-empty-elt ns-0 ns-subject page-Albert_Einstein rootpage-Albert_Einstein skin-vector-2022 action-view"><a class="mw-jump-link" href="#bodyContent">Jump to content</a>
<div class="vector-header-container">
	<header class="vector-header mw-header">
		<div class="vector-header-start">
			<nav class="vector-main-menu-landmark" aria-label="Site">
				
<div id="vector-main-menu-dropdown" class="vector-dropdown vector-main-menu-dropdown vector-button-flush-left vector-button-flush-right"  >
	<input type="checkbox" id="vector-main-menu-dropdown-checkbox" role="button" aria-haspopup="true" data-event-name="ui.dropdown-vector-main-menu-dropdown" class="vector-dropdown-checkbox "  aria-label="Main menu"  >
	<label id="vector-main-menu-dropdown-label" for="vector-main-menu-dropdown-checkbox" class="vector-dropdown-label cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet cdx-button--icon-only " aria-hidden="true"  ><span class="vector-icon mw-ui-icon-menu mw-ui-icon-wikimedia-menu"></span>

<span class="vector-dropdown-label-text">Main menu</span>
	</label>
	<div class="vector-dropdown-content">


				<div id="vector-main-menu-unpinned-container" class="vector-unpinned-container">
		
<div id="vector-main-menu" class="vector-main-menu vector-pinnable-element">
	<div
	class="vector-pinnable-header vector-main-menu-pinnable-header vector-pinnable-header-unpinned"
	data-feature-name="main-menu-pinned"
	data-pinnable-element-id="vector-main-menu"
	data-pinned-container-id="vector-main-menu-pinned-container"
	data-unpinned-container-id="vector-main-menu-unpinned-container"
>
	<div class="vector-pinnable-header-label">Main menu</div>
	<button class="vector-pinnable-header-toggle-button vector-pinnable-header-pin-button" data-event-name="pinnable-header.vector-main-menu.pin">move to sidebar</button>
	<button class="vector-pinnable-header-toggle-button vector-pinnable-header-unpin-button" data-event-name="pinnable-header.vector-main-menu.unpin">hide</button>
</div>

	
<div id="p-navigation" class="vector-menu mw-portlet mw-portlet-navigation"  >
	<div class="vector-menu-heading">
		Navigation
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="n-mainpage-description" class="mw-list-item"><a href="/wiki/Main_Page" title="Visit the main page [z]" accesskey="z"><span>Main page</span></a></li><li id="n-contents" class="mw-list-item"><a href="/wiki/Wikipedia:Contents" title="Guides to browsing Wikipedia"><span>Contents</span></a></li><li id="n-currentevents" class="mw-list-item"><a href="/wiki/Portal:Current_events" title="Articles related to current events"><span>Current events</span></a></li><li id="n-randompage" class="mw-list-item"><a href="/wiki/Special:Random" title="Visit a randomly selected article [x]" accesskey="x"><span>Random article</span></a></li><li id="n-aboutsite" class="mw-list-item"><a href="/wiki/Wikipedia:About" title="Learn about Wikipedia and how it works"><span>About Wikipedia</span></a></li><li id="n-contactpage" class="mw-list-item"><a href="//en.wikipedia.org/wiki/Wikipedia:Contact_us" title="How to contact Wikipedia"><span>Contact us</span></a></li><li id="n-sitesupport" class="mw-list-item"><a href="https://donate.wikimedia.org/wiki/Special:FundraiserRedirector?utm_source=donate&amp;utm_medium=sidebar&amp;utm_campaign=C13_en.wikipedia.org&amp;uselang=en" title="Support us by donating to the Wikimedia Foundation"><span>Donate</span></a></li>
		</ul>
		
	</div>
</div>

	
	
<div id="p-interaction" class="vector-menu mw-portlet mw-portlet-interaction"  >
	<div class="vector-menu-heading">
		Contribute
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="n-help" class="mw-list-item"><a href="/wiki/Help:Contents" title="Guidance on how to use and edit Wikipedia"><span>Help</span></a></li><li id="n-introduction" class="mw-list-item"><a href="/wiki/Help:Introduction" title="Learn how to edit Wikipedia"><span>Learn to edit</span></a></li><li id="n-portal" class="mw-list-item"><a href="/wiki/Wikipedia:Community_portal" title="The hub for editors"><span>Community portal</span></a></li><li id="n-recentchanges" class="mw-list-item"><a href="/wiki/Special:RecentChanges" title="A list of recent changes to Wikipedia [r]" accesskey="r"><span>Recent changes</span></a></li><li id="n-upload" class="mw-list-item"><a href="/wiki/Wikipedia:File_upload_wizard" title="Add images or other media for use on Wikipedia"><span>Upload file</span></a></li>
		</ul>
		
	</div>
</div>

</div>

				</div>

	</div>
</div>

		</nav>
			
<a href="/wiki/Main_Page" class="mw-logo">
	<img class="mw-logo-icon" src="/static/images/icons/wikipedia.png" alt="" aria-hidden="true" height="50" width="50">
	<span class="mw-logo-container skin-invert">
		<img class="mw-logo-wordmark" alt="Wikipedia" src="/static/images/mobile/copyright/wikipedia-wordmark-en.svg" style="width: 7.5em; height: 1.125em;">
		<img class="mw-logo-tagline" alt="The Free Encyclopedia" src="/static/images/mobile/copyright/wikipedia-tagline-en.svg" width="117" height="13" style="width: 7.3125em; height: 0.8125em;">
	</span>
</a>

		</div>
		<div class="vector-header-end">
			
<div id="p-search" role="search" class="vector-search-box-vue  vector-search-box-collapses vector-search-box-show-thumbnail vector-search-box-auto-expand-width vector-search-box">
	<a href="/wiki/Special:Search" class="cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet cdx-button--icon-only search-toggle" title="Search Wikipedia [f]" accesskey="f"><span class="vector-icon mw-ui-icon-search mw-ui-icon-wikimedia-search"></span>

<span>Search</span>
	</a>
	<div class="vector-typeahead-search-container">
		<div class="cdx-typeahead-search cdx-typeahead-search--show-thumbnail cdx-typeahead-search--auto-expand-width">
			<form action="/w/index.php" id="searchform" class="cdx-search-input cdx-search-input--has-end-button">
				<div id="simpleSearch" class="cdx-search-input__input-wrapper"  data-search-loc="header-moved">
					<div class="cdx-text-input cdx-text-input--has-start-icon">
						<input
							class="cdx-text-input__input"
							 type="search" name="search" placeholder="Search Wikipedia" aria-label="Search Wikipedia" autocapitalize="sentences" title="Search Wikipedia [f]" accesskey="f" id="searchInput"
							>
						<span class="cdx-text-input__icon cdx-text-input__start-icon"></span>
					</div>
					<input type="hidden" name="title" value="Special:Search">
				</div>
				<button class="cdx-button cdx-search-input__end-button">Search</button>
			</form>
		</div>
	</div>
</div>

			<nav class="vector-user-links vector-user-links-wide" aria-label="Personal tools">
	<div class="vector-user-links-main">
	
<div id="p-vector-user-menu-preferences" class="vector-menu mw-portlet emptyPortlet"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			
		</ul>
		
	</div>
</div>

	
<div id="p-vector-user-menu-userpage" class="vector-menu mw-portlet emptyPortlet"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			
		</ul>
		
	</div>
</div>

	<nav class="vector-appearance-landmark" aria-label="Appearance">
		
		
	</nav>
	
<div id="p-vector-user-menu-notifications" class="vector-menu mw-portlet emptyPortlet"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			
		</ul>
		
	</div>
</div>

	
<div id="p-vector-user-menu-overflow" class="vector-menu mw-portlet"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			<li id="pt-createaccount-2" class="user-links-collapsible-item mw-list-item user-links-collapsible-item"><a data-mw="interface" href="/w/index.php?title=Special:CreateAccount&amp;returnto=Albert+Einstein" title="You are encouraged to create an account and log in; however, it is not mandatory" class=""><span>Create account</span></a>
</li>
<li id="pt-login-2" class="user-links-collapsible-item mw-list-item user-links-collapsible-item"><a data-mw="interface" href="/w/index.php?title=Special:UserLogin&amp;returnto=Albert+Einstein" title="You&#039;re encouraged to log in; however, it&#039;s not mandatory. [o]" accesskey="o" class=""><span>Log in</span></a>
</li>

			
		</ul>
		
	</div>
</div>

	</div>
	
<div id="vector-user-links-dropdown" class="vector-dropdown vector-user-menu vector-button-flush-right vector-user-menu-logged-out"  title="Log in and more options" >
	<input type="checkbox" id="vector-user-links-dropdown-checkbox" role="button" aria-haspopup="true" data-event-name="ui.dropdown-vector-user-links-dropdown" class="vector-dropdown-checkbox "  aria-label="Personal tools"  >
	<label id="vector-user-links-dropdown-label" for="vector-user-links-dropdown-checkbox" class="vector-dropdown-label cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet cdx-button--icon-only " aria-hidden="true"  ><span class="vector-icon mw-ui-icon-ellipsis mw-ui-icon-wikimedia-ellipsis"></span>

<span class="vector-dropdown-label-text">Personal tools</span>
	</label>
	<div class="vector-dropdown-content">


		
<div id="p-personal" class="vector-menu mw-portlet mw-portlet-personal user-links-collapsible-item"  title="User menu" >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="pt-createaccount" class="user-links-collapsible-item mw-list-item"><a href="/w/index.php?title=Special:CreateAccount&amp;returnto=Albert+Einstein" title="You are encouraged to create an account and log in; however, it is not mandatory"><span class="vector-icon mw-ui-icon-userAdd mw-ui-icon-wikimedia-userAdd"></span> <span>Create account</span></a></li><li id="pt-login" class="user-links-collapsible-item mw-list-item"><a href="/w/index.php?title=Special:UserLogin&amp;returnto=Albert+Einstein" title="You&#039;re encouraged to log in; however, it&#039;s not mandatory. [o]" accesskey="o"><span class="vector-icon mw-ui-icon-logIn mw-ui-icon-wikimedia-logIn"></span> <span>Log in</span></a></li>
		</ul>
		
	</div>
</div>

<div id="p-user-menu-anon-editor" class="vector-menu mw-portlet mw-portlet-user-menu-anon-editor"  >
	<div class="vector-menu-heading">
		Pages for logged out editors <a href="/wiki/Help:Introduction" aria-label="Learn more about editing"><span>learn more</span></a>
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="pt-anoncontribs" class="mw-list-item"><a href="/wiki/Special:MyContributions" title="A list of edits made from this IP address [y]" accesskey="y"><span>Contributions</span></a></li><li id="pt-anontalk" class="mw-list-item"><a href="/wiki/Special:MyTalk" title="Discussion about edits from this IP address [n]" accesskey="n"><span>Talk</span></a></li>
		</ul>
		
	</div>
</div>

	
	</div>
</div>

</nav>

		</div>
	</header>
</div>
<div class="mw-page-container">
	<div class="mw-page-container-inner">
		<div class="vector-sitenotice-container">
			<div id="siteNotice" class="notheme"><!-- CentralNotice --></div>
		</div>
		<div class="vector-column-start">
			<div class="vector-main-menu-container">
		<div id="mw-navigation">
			<nav id="mw-panel" class="vector-main-menu-landmark" aria-label="Site">
				<div id="vector-main-menu-pinned-container" class="vector-pinned-container">
				
				</div>
		</nav>
		</div>
	</div>
	<div class="vector-sticky-pinned-container">
				<nav id="mw-panel-toc" aria-label="Contents" data-event-name="ui.sidebar-toc" class="mw-table-of-contents-container vector-toc-landmark">
					<div id="vector-toc-pinned-container" class="vector-pinned-container">
					<div id="vector-toc" class="vector-toc vector-pinnable-element">
	<div
	class="vector-pinnable-header vector-toc-pinnable-header vector-pinnable-header-pinned"
	data-feature-name="toc-pinned"
	data-pinnable-element-id="vector-toc"
	
	
>
	<h2 class="vector-pinnable-header-label">Contents</h2>
	<button class="vector-pinnable-header-toggle-button vector-pinnable-header-pin-button" data-event-name="pinnable-header.vector-toc.pin">move to sidebar</button>
	<button class="vector-pinnable-header-toggle-button vector-pinnable-header-unpin-button" data-event-name="pinnable-header.vector-toc.unpin">hide</button>
</div>


	<ul class="vector-toc-contents" id="mw-panel-toc-list">
		<li id="toc-mw-content-text"
			class="vector-toc-list-item vector-toc-level-1">
			<a href="#" class="vector-toc-link">
				<div class="vector-toc-text">(Top)</div>
			</a>
		</li>
		<li id="toc-Life_and_career"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Life_and_career">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">1</span>
				<span>Life and career</span>
			</div>
		</a>
		
			<button aria-controls="toc-Life_and_career-sublist" class="cdx-button cdx-button--weight-quiet cdx-button--icon-only vector-toc-toggle">
				<span class="vector-icon mw-ui-icon-wikimedia-expand"></span>
				<span>Toggle Life and career subsection</span>
			</button>
		
		<ul id="toc-Life_and_career-sublist" class="vector-toc-list">
			<li id="toc-Childhood,_youth_and_education"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Childhood,_youth_and_education">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.1</span>
					<span>Childhood, youth and education</span>
				</div>
			</a>
			
			<ul id="toc-Childhood,_youth_and_education-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Marriages,_relationships_and_children"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Marriages,_relationships_and_children">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.2</span>
					<span>Marriages, relationships and children</span>
				</div>
			</a>
			
			<ul id="toc-Marriages,_relationships_and_children-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1902–1909:_Assistant_at_the_Swiss_Patent_Office"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1902–1909:_Assistant_at_the_Swiss_Patent_Office">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.3</span>
					<span>1902–1909: Assistant at the Swiss Patent Office</span>
				</div>
			</a>
			
			<ul id="toc-1902–1909:_Assistant_at_the_Swiss_Patent_Office-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1900–1905:_First_scientific_papers"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1900–1905:_First_scientific_papers">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.4</span>
					<span>1900–1905: First scientific papers</span>
				</div>
			</a>
			
			<ul id="toc-1900–1905:_First_scientific_papers-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1908–1933:_Early_academic_career"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1908–1933:_Early_academic_career">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.5</span>
					<span>1908–1933: Early academic career</span>
				</div>
			</a>
			
			<ul id="toc-1908–1933:_Early_academic_career-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1919:_Putting_general_relativity_to_the_test"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1919:_Putting_general_relativity_to_the_test">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.6</span>
					<span>1919: Putting general relativity to the test</span>
				</div>
			</a>
			
			<ul id="toc-1919:_Putting_general_relativity_to_the_test-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1921–1923:_Coming_to_terms_with_fame"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1921–1923:_Coming_to_terms_with_fame">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.7</span>
					<span>1921–1923: Coming to terms with fame</span>
				</div>
			</a>
			
			<ul id="toc-1921–1923:_Coming_to_terms_with_fame-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1922–1932:_Serving_the_League_of_Nations"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1922–1932:_Serving_the_League_of_Nations">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.8</span>
					<span>1922–1932: Serving the League of Nations</span>
				</div>
			</a>
			
			<ul id="toc-1922–1932:_Serving_the_League_of_Nations-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1925:_Touring_South_America"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1925:_Touring_South_America">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.9</span>
					<span>1925: Touring South America</span>
				</div>
			</a>
			
			<ul id="toc-1925:_Touring_South_America-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1930–1931:_Touring_the_US"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1930–1931:_Touring_the_US">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.10</span>
					<span>1930–1931: Touring the US</span>
				</div>
			</a>
			
			<ul id="toc-1930–1931:_Touring_the_US-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-1933:_Emigration_to_the_US"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1933:_Emigration_to_the_US">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.11</span>
					<span>1933: Emigration to the US</span>
				</div>
			</a>
			
			<ul id="toc-1933:_Emigration_to_the_US-sublist" class="vector-toc-list">
				<li id="toc-Refugee_status"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Refugee_status">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.11.1</span>
					<span>Refugee status</span>
				</div>
			</a>
			
			<ul id="toc-Refugee_status-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Resident_scholar_at_the_Institute_for_Advanced_Study"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Resident_scholar_at_the_Institute_for_Advanced_Study">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.11.2</span>
					<span>Resident scholar at the Institute for Advanced Study</span>
				</div>
			</a>
			
			<ul id="toc-Resident_scholar_at_the_Institute_for_Advanced_Study-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-World_War_II_and_the_Manhattan_Project"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#World_War_II_and_the_Manhattan_Project">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.11.3</span>
					<span>World War II and the Manhattan Project</span>
				</div>
			</a>
			
			<ul id="toc-World_War_II_and_the_Manhattan_Project-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-US_citizenship"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#US_citizenship">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.11.4</span>
					<span>US citizenship</span>
				</div>
			</a>
			
			<ul id="toc-US_citizenship-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
		<li id="toc-Personal_views"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Personal_views">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.12</span>
					<span>Personal views</span>
				</div>
			</a>
			
			<ul id="toc-Personal_views-sublist" class="vector-toc-list">
				<li id="toc-Political_views"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Political_views">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.12.1</span>
					<span>Political views</span>
				</div>
			</a>
			
			<ul id="toc-Political_views-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Relationship_with_Zionism"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Relationship_with_Zionism">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.12.2</span>
					<span>Relationship with Zionism</span>
				</div>
			</a>
			
			<ul id="toc-Relationship_with_Zionism-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Religious_and_philosophical_views"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Religious_and_philosophical_views">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.12.3</span>
					<span>Religious and philosophical views</span>
				</div>
			</a>
			
			<ul id="toc-Religious_and_philosophical_views-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Love_of_music"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Love_of_music">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.12.4</span>
					<span>Love of music</span>
				</div>
			</a>
			
			<ul id="toc-Love_of_music-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
		<li id="toc-Death"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Death">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">1.13</span>
					<span>Death</span>
				</div>
			</a>
			
			<ul id="toc-Death-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
	</li>
	<li id="toc-Scientific_career"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Scientific_career">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">2</span>
				<span>Scientific career</span>
			</div>
		</a>
		
			<button aria-controls="toc-Scientific_career-sublist" class="cdx-button cdx-button--weight-quiet cdx-button--icon-only vector-toc-toggle">
				<span class="vector-icon mw-ui-icon-wikimedia-expand"></span>
				<span>Toggle Scientific career subsection</span>
			</button>
		
		<ul id="toc-Scientific_career-sublist" class="vector-toc-list">
			<li id="toc-1905_–_Annus_Mirabilis_papers"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#1905_–_Annus_Mirabilis_papers">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.1</span>
					<span>1905 – <i>Annus Mirabilis</i> papers</span>
				</div>
			</a>
			
			<ul id="toc-1905_–_Annus_Mirabilis_papers-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Statistical_mechanics"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Statistical_mechanics">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.2</span>
					<span>Statistical mechanics</span>
				</div>
			</a>
			
			<ul id="toc-Statistical_mechanics-sublist" class="vector-toc-list">
				<li id="toc-Thermodynamic_fluctuations_and_statistical_physics"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Thermodynamic_fluctuations_and_statistical_physics">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.2.1</span>
					<span>Thermodynamic fluctuations and statistical physics</span>
				</div>
			</a>
			
			<ul id="toc-Thermodynamic_fluctuations_and_statistical_physics-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Theory_of_critical_opalescence"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Theory_of_critical_opalescence">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.2.2</span>
					<span>Theory of critical opalescence</span>
				</div>
			</a>
			
			<ul id="toc-Theory_of_critical_opalescence-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
		<li id="toc-Special_relativity"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Special_relativity">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.3</span>
					<span>Special relativity</span>
				</div>
			</a>
			
			<ul id="toc-Special_relativity-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-General_relativity"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#General_relativity">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4</span>
					<span>General relativity</span>
				</div>
			</a>
			
			<ul id="toc-General_relativity-sublist" class="vector-toc-list">
				<li id="toc-General_relativity_and_the_equivalence_principle"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#General_relativity_and_the_equivalence_principle">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.1</span>
					<span>General relativity and the equivalence principle</span>
				</div>
			</a>
			
			<ul id="toc-General_relativity_and_the_equivalence_principle-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Gravitational_waves"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Gravitational_waves">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.2</span>
					<span>Gravitational waves</span>
				</div>
			</a>
			
			<ul id="toc-Gravitational_waves-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Hole_argument_and_Entwurf_theory"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Hole_argument_and_Entwurf_theory">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.3</span>
					<span>Hole argument and Entwurf theory</span>
				</div>
			</a>
			
			<ul id="toc-Hole_argument_and_Entwurf_theory-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Physical_cosmology"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Physical_cosmology">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.4</span>
					<span>Physical cosmology</span>
				</div>
			</a>
			
			<ul id="toc-Physical_cosmology-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Energy_momentum_pseudotensor"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Energy_momentum_pseudotensor">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.5</span>
					<span>Energy momentum pseudotensor</span>
				</div>
			</a>
			
			<ul id="toc-Energy_momentum_pseudotensor-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Wormholes"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Wormholes">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.6</span>
					<span>Wormholes</span>
				</div>
			</a>
			
			<ul id="toc-Wormholes-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Einstein–Cartan_theory"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Einstein–Cartan_theory">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.7</span>
					<span>Einstein–Cartan theory</span>
				</div>
			</a>
			
			<ul id="toc-Einstein–Cartan_theory-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Equations_of_motion"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Equations_of_motion">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.4.8</span>
					<span>Equations of motion</span>
				</div>
			</a>
			
			<ul id="toc-Equations_of_motion-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
		<li id="toc-Old_quantum_theory"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Old_quantum_theory">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5</span>
					<span>Old quantum theory</span>
				</div>
			</a>
			
			<ul id="toc-Old_quantum_theory-sublist" class="vector-toc-list">
				<li id="toc-Photons_and_energy_quanta"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Photons_and_energy_quanta">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.1</span>
					<span>Photons and energy quanta</span>
				</div>
			</a>
			
			<ul id="toc-Photons_and_energy_quanta-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Quantized_atomic_vibrations"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Quantized_atomic_vibrations">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.2</span>
					<span>Quantized atomic vibrations</span>
				</div>
			</a>
			
			<ul id="toc-Quantized_atomic_vibrations-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Bose–Einstein_statistics"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Bose–Einstein_statistics">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.3</span>
					<span>Bose–Einstein statistics</span>
				</div>
			</a>
			
			<ul id="toc-Bose–Einstein_statistics-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Wave–particle_duality"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Wave–particle_duality">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.4</span>
					<span>Wave–particle duality</span>
				</div>
			</a>
			
			<ul id="toc-Wave–particle_duality-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Zero-point_energy"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Zero-point_energy">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.5</span>
					<span>Zero-point energy</span>
				</div>
			</a>
			
			<ul id="toc-Zero-point_energy-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Stimulated_emission"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Stimulated_emission">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.6</span>
					<span>Stimulated emission</span>
				</div>
			</a>
			
			<ul id="toc-Stimulated_emission-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Matter_waves"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Matter_waves">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.5.7</span>
					<span>Matter waves</span>
				</div>
			</a>
			
			<ul id="toc-Matter_waves-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
		<li id="toc-Quantum_mechanics"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Quantum_mechanics">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.6</span>
					<span>Quantum mechanics</span>
				</div>
			</a>
			
			<ul id="toc-Quantum_mechanics-sublist" class="vector-toc-list">
				<li id="toc-Einstein&#039;s_objections_to_quantum_mechanics"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Einstein&#039;s_objections_to_quantum_mechanics">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.6.1</span>
					<span>Einstein\'s objections to quantum mechanics</span>
				</div>
			</a>
			
			<ul id="toc-Einstein&#039;s_objections_to_quantum_mechanics-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Bohr_versus_Einstein"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Bohr_versus_Einstein">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.6.2</span>
					<span>Bohr versus Einstein</span>
				</div>
			</a>
			
			<ul id="toc-Bohr_versus_Einstein-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Einstein–Podolsky–Rosen_paradox"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Einstein–Podolsky–Rosen_paradox">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.6.3</span>
					<span>Einstein–Podolsky–Rosen paradox</span>
				</div>
			</a>
			
			<ul id="toc-Einstein–Podolsky–Rosen_paradox-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
		<li id="toc-Unified_field_theory"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Unified_field_theory">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.7</span>
					<span>Unified field theory</span>
				</div>
			</a>
			
			<ul id="toc-Unified_field_theory-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Other_investigations"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Other_investigations">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.8</span>
					<span>Other investigations</span>
				</div>
			</a>
			
			<ul id="toc-Other_investigations-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Collaboration_with_other_scientists"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Collaboration_with_other_scientists">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.9</span>
					<span>Collaboration with other scientists</span>
				</div>
			</a>
			
			<ul id="toc-Collaboration_with_other_scientists-sublist" class="vector-toc-list">
				<li id="toc-Einstein–de_Haas_experiment"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Einstein–de_Haas_experiment">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.9.1</span>
					<span>Einstein–de Haas experiment</span>
				</div>
			</a>
			
			<ul id="toc-Einstein–de_Haas_experiment-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Einstein_as_an_inventor"
			class="vector-toc-list-item vector-toc-level-3">
			<a class="vector-toc-link" href="#Einstein_as_an_inventor">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">2.9.2</span>
					<span>Einstein as an inventor</span>
				</div>
			</a>
			
			<ul id="toc-Einstein_as_an_inventor-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
		</li>
	</ul>
	</li>
	<li id="toc-Non-scientific_legacy"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Non-scientific_legacy">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">3</span>
				<span>Non-scientific legacy</span>
			</div>
		</a>
		
		<ul id="toc-Non-scientific_legacy-sublist" class="vector-toc-list">
		</ul>
	</li>
	<li id="toc-In_popular_culture"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#In_popular_culture">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">4</span>
				<span>In popular culture</span>
			</div>
		</a>
		
		<ul id="toc-In_popular_culture-sublist" class="vector-toc-list">
		</ul>
	</li>
	<li id="toc-Awards_and_honors"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Awards_and_honors">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">5</span>
				<span>Awards and honors</span>
			</div>
		</a>
		
		<ul id="toc-Awards_and_honors-sublist" class="vector-toc-list">
		</ul>
	</li>
	<li id="toc-Publications"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Publications">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">6</span>
				<span>Publications</span>
			</div>
		</a>
		
			<button aria-controls="toc-Publications-sublist" class="cdx-button cdx-button--weight-quiet cdx-button--icon-only vector-toc-toggle">
				<span class="vector-icon mw-ui-icon-wikimedia-expand"></span>
				<span>Toggle Publications subsection</span>
			</button>
		
		<ul id="toc-Publications-sublist" class="vector-toc-list">
			<li id="toc-Scientific"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Scientific">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">6.1</span>
					<span>Scientific</span>
				</div>
			</a>
			
			<ul id="toc-Scientific-sublist" class="vector-toc-list">
			</ul>
		</li>
		<li id="toc-Others"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Others">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">6.2</span>
					<span>Others</span>
				</div>
			</a>
			
			<ul id="toc-Others-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
	</li>
	<li id="toc-See_also"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#See_also">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">7</span>
				<span>See also</span>
			</div>
		</a>
		
		<ul id="toc-See_also-sublist" class="vector-toc-list">
		</ul>
	</li>
	<li id="toc-Notes"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Notes">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">8</span>
				<span>Notes</span>
			</div>
		</a>
		
		<ul id="toc-Notes-sublist" class="vector-toc-list">
		</ul>
	</li>
	<li id="toc-References"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#References">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">9</span>
				<span>References</span>
			</div>
		</a>
		
			<button aria-controls="toc-References-sublist" class="cdx-button cdx-button--weight-quiet cdx-button--icon-only vector-toc-toggle">
				<span class="vector-icon mw-ui-icon-wikimedia-expand"></span>
				<span>Toggle References subsection</span>
			</button>
		
		<ul id="toc-References-sublist" class="vector-toc-list">
			<li id="toc-Works_cited"
			class="vector-toc-list-item vector-toc-level-2">
			<a class="vector-toc-link" href="#Works_cited">
				<div class="vector-toc-text">
					<span class="vector-toc-numb">9.1</span>
					<span>Works cited</span>
				</div>
			</a>
			
			<ul id="toc-Works_cited-sublist" class="vector-toc-list">
			</ul>
		</li>
	</ul>
	</li>
	<li id="toc-Further_reading"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#Further_reading">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">10</span>
				<span>Further reading</span>
			</div>
		</a>
		
		<ul id="toc-Further_reading-sublist" class="vector-toc-list">
		</ul>
	</li>
	<li id="toc-External_links"
		class="vector-toc-list-item vector-toc-level-1">
		<a class="vector-toc-link" href="#External_links">
			<div class="vector-toc-text">
				<span class="vector-toc-numb">11</span>
				<span>External links</span>
			</div>
		</a>
		
		<ul id="toc-External_links-sublist" class="vector-toc-list">
		</ul>
	</li>
</ul>
</div>

					</div>
		</nav>
			</div>
		</div>
		<div class="mw-content-container">
			<main id="content" class="mw-body">
				<header class="mw-body-header vector-page-titlebar">
					<nav aria-label="Contents" class="vector-toc-landmark">
						
<div id="vector-page-titlebar-toc" class="vector-dropdown vector-page-titlebar-toc vector-button-flush-left"  >
	<input type="checkbox" id="vector-page-titlebar-toc-checkbox" role="button" aria-haspopup="true" data-event-name="ui.dropdown-vector-page-titlebar-toc" class="vector-dropdown-checkbox "  aria-label="Toggle the table of contents"  >
	<label id="vector-page-titlebar-toc-label" for="vector-page-titlebar-toc-checkbox" class="vector-dropdown-label cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet cdx-button--icon-only " aria-hidden="true"  ><span class="vector-icon mw-ui-icon-listBullet mw-ui-icon-wikimedia-listBullet"></span>

<span class="vector-dropdown-label-text">Toggle the table of contents</span>
	</label>
	<div class="vector-dropdown-content">


							<div id="vector-page-titlebar-toc-unpinned-container" class="vector-unpinned-container">
			</div>
		
	</div>
</div>

					</nav>
					<h1 id="firstHeading" class="firstHeading mw-first-heading"><span class="mw-page-title-main">Albert Einstein</span></h1>
							
<div id="p-lang-btn" class="vector-dropdown mw-portlet mw-portlet-lang"  >
	<input type="checkbox" id="p-lang-btn-checkbox" role="button" aria-haspopup="true" data-event-name="ui.dropdown-p-lang-btn" class="vector-dropdown-checkbox mw-interlanguage-selector" aria-label="Go to an article in another language. Available in 224 languages"   >
	<label id="p-lang-btn-label" for="p-lang-btn-checkbox" class="vector-dropdown-label cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet cdx-button--action-progressive mw-portlet-lang-heading-224" aria-hidden="true"  ><span class="vector-icon mw-ui-icon-language-progressive mw-ui-icon-wikimedia-language-progressive"></span>

<span class="vector-dropdown-label-text">224 languages</span>
	</label>
	<div class="vector-dropdown-content">

		<div class="vector-menu-content">
			
			<ul class="vector-menu-content-list">
				
				<li class="interlanguage-link interwiki-af mw-list-item"><a href="https://af.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Afrikaans" lang="af" hreflang="af" class="interlanguage-link-target"><span>Afrikaans</span></a></li><li class="interlanguage-link interwiki-als mw-list-item"><a href="https://als.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Alemannic" lang="gsw" hreflang="gsw" class="interlanguage-link-target"><span>Alemannisch</span></a></li><li class="interlanguage-link interwiki-am mw-list-item"><a href="https://am.wikipedia.org/wiki/%E1%8A%A0%E1%88%8D%E1%89%A0%E1%88%AD%E1%89%B5_%E1%8A%A0%E1%8B%AD%E1%8A%95%E1%88%B5%E1%89%B3%E1%8B%AD%E1%8A%95" title="አልበርት አይንስታይን – Amharic" lang="am" hreflang="am" class="interlanguage-link-target"><span>አማርኛ</span></a></li><li class="interlanguage-link interwiki-smn mw-list-item"><a href="https://smn.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Inari Sami" lang="smn" hreflang="smn" class="interlanguage-link-target"><span>Anarâškielâ</span></a></li><li class="interlanguage-link interwiki-anp mw-list-item"><a href="https://anp.wikipedia.org/wiki/%E0%A4%90%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%A8%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A4%BE%E0%A4%87%E0%A4%A8" title="ऐल्बर्ट आइनस्टाइन – Angika" lang="anp" hreflang="anp" class="interlanguage-link-target"><span>अंगिका</span></a></li><li class="interlanguage-link interwiki-ang mw-list-item"><a href="https://ang.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Old English" lang="ang" hreflang="ang" class="interlanguage-link-target"><span>Ænglisc</span></a></li><li class="interlanguage-link interwiki-ab mw-list-item"><a href="https://ab.wikipedia.org/wiki/%D0%95%D0%B8%D0%BD%D1%88%D1%82%D0%B5%D0%B8%D0%BD,_%D0%90%D0%BB%D0%B1%D0%B5%D1%80%D1%82" title="Еинштеин, Алберт – Abkhazian" lang="ab" hreflang="ab" class="interlanguage-link-target"><span>Аԥсшәа</span></a></li><li class="interlanguage-link interwiki-ar badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://ar.wikipedia.org/wiki/%D8%A3%D9%84%D8%A8%D8%B1%D8%AA_%D8%A3%D9%8A%D9%86%D8%B4%D8%AA%D8%A7%D9%8A%D9%86" title="ألبرت أينشتاين – Arabic" lang="ar" hreflang="ar" class="interlanguage-link-target"><span>العربية</span></a></li><li class="interlanguage-link interwiki-an badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://an.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Aragonese" lang="an" hreflang="an" class="interlanguage-link-target"><span>Aragonés</span></a></li><li class="interlanguage-link interwiki-hyw mw-list-item"><a href="https://hyw.wikipedia.org/wiki/%D4%B1%D5%AC%D5%BA%D5%A5%D6%80%D5%A9_%D4%B1%D5%B5%D5%B6%D5%B7%D5%A9%D5%A1%D5%B5%D5%B6" title="Ալպերթ Այնշթայն – Western Armenian" lang="hyw" hreflang="hyw" class="interlanguage-link-target"><span>Արեւմտահայերէն</span></a></li><li class="interlanguage-link interwiki-roa-rup mw-list-item"><a href="https://roa-rup.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Aromanian" lang="rup" hreflang="rup" class="interlanguage-link-target"><span>Armãneashti</span></a></li><li class="interlanguage-link interwiki-frp mw-list-item"><a href="https://frp.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Arpitan" lang="frp" hreflang="frp" class="interlanguage-link-target"><span>Arpetan</span></a></li><li class="interlanguage-link interwiki-as mw-list-item"><a href="https://as.wikipedia.org/wiki/%E0%A6%8F%E0%A6%B2%E0%A6%AC%E0%A6%BE%E0%A7%B0%E0%A7%8D%E0%A6%9F_%E0%A6%86%E0%A6%87%E0%A6%A8%E0%A6%B7%E0%A7%8D%E0%A6%9F%E0%A6%BE%E0%A6%87%E0%A6%A8" title="এলবাৰ্ট আইনষ্টাইন – Assamese" lang="as" hreflang="as" class="interlanguage-link-target"><span>অসমীয়া</span></a></li><li class="interlanguage-link interwiki-ast mw-list-item"><a href="https://ast.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Asturian" lang="ast" hreflang="ast" class="interlanguage-link-target"><span>Asturianu</span></a></li><li class="interlanguage-link interwiki-awa mw-list-item"><a href="https://awa.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%82%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A5%80%E0%A4%A8" title="अल्बर्ट आइंस्टीन – Awadhi" lang="awa" hreflang="awa" class="interlanguage-link-target"><span>अवधी</span></a></li><li class="interlanguage-link interwiki-gn mw-list-item"><a href="https://gn.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Guarani" lang="gn" hreflang="gn" class="interlanguage-link-target"><span>Avañe\'ẽ</span></a></li><li class="interlanguage-link interwiki-ay mw-list-item"><a href="https://ay.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Aymara" lang="ay" hreflang="ay" class="interlanguage-link-target"><span>Aymar aru</span></a></li><li class="interlanguage-link interwiki-az mw-list-item"><a href="https://az.wikipedia.org/wiki/Albert_Eyn%C5%9Fteyn" title="Albert Eynşteyn – Azerbaijani" lang="az" hreflang="az" class="interlanguage-link-target"><span>Azərbaycanca</span></a></li><li class="interlanguage-link interwiki-azb mw-list-item"><a href="https://azb.wikipedia.org/wiki/%D8%A2%D9%84%D8%A8%D8%B1%D8%AA_%D8%A2%DB%8C%D9%86%D8%B4%D8%AA%D8%A7%DB%8C%D9%86" title="آلبرت آینشتاین – South Azerbaijani" lang="azb" hreflang="azb" class="interlanguage-link-target"><span>تۆرکجه</span></a></li><li class="interlanguage-link interwiki-ban mw-list-item"><a href="https://ban.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Balinese" lang="ban" hreflang="ban" class="interlanguage-link-target"><span>Basa Bali</span></a></li><li class="interlanguage-link interwiki-bm mw-list-item"><a href="https://bm.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Bambara" lang="bm" hreflang="bm" class="interlanguage-link-target"><span>Bamanankan</span></a></li><li class="interlanguage-link interwiki-bn mw-list-item"><a href="https://bn.wikipedia.org/wiki/%E0%A6%86%E0%A6%B2%E0%A6%AC%E0%A6%BE%E0%A6%B0%E0%A7%8D%E0%A6%9F_%E0%A6%86%E0%A6%87%E0%A6%A8%E0%A6%B8%E0%A7%8D%E0%A6%9F%E0%A6%BE%E0%A6%87%E0%A6%A8" title="আলবার্ট আইনস্টাইন – Bangla" lang="bn" hreflang="bn" class="interlanguage-link-target"><span>বাংলা</span></a></li><li class="interlanguage-link interwiki-zh-min-nan mw-list-item"><a href="https://zh-min-nan.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Minnan" lang="nan" hreflang="nan" class="interlanguage-link-target"><span>閩南語 / Bân-lâm-gú</span></a></li><li class="interlanguage-link interwiki-map-bms mw-list-item"><a href="https://map-bms.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Basa Banyumasan" lang="jv-x-bms" hreflang="jv-x-bms" class="interlanguage-link-target"><span>Basa Banyumasan</span></a></li><li class="interlanguage-link interwiki-ba mw-list-item"><a href="https://ba.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Bashkir" lang="ba" hreflang="ba" class="interlanguage-link-target"><span>Башҡортса</span></a></li><li class="interlanguage-link interwiki-be badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://be.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D1%8D%D0%B9%D0%BD" title="Альберт Эйнштэйн – Belarusian" lang="be" hreflang="be" class="interlanguage-link-target"><span>Беларуская</span></a></li><li class="interlanguage-link interwiki-be-x-old mw-list-item"><a href="https://be-tarask.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D1%8D%D1%80%D1%82_%D0%90%D0%B9%D0%BD%D1%88%D1%82%D0%B0%D0%B9%D0%BD" title="Альбэрт Айнштайн – Belarusian (Taraškievica orthography)" lang="be-tarask" hreflang="be-tarask" class="interlanguage-link-target"><span>Беларуская (тарашкевіца)</span></a></li><li class="interlanguage-link interwiki-bh mw-list-item"><a href="https://bh.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%82%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A5%80%E0%A4%A8" title="अल्बर्ट आइंस्टीन – Bhojpuri" lang="bh" hreflang="bh" class="interlanguage-link-target"><span>भोजपुरी</span></a></li><li class="interlanguage-link interwiki-bcl mw-list-item"><a href="https://bcl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Central Bikol" lang="bcl" hreflang="bcl" class="interlanguage-link-target"><span>Bikol Central</span></a></li><li class="interlanguage-link interwiki-bg mw-list-item"><a href="https://bg.wikipedia.org/wiki/%D0%90%D0%BB%D0%B1%D0%B5%D1%80%D1%82_%D0%90%D0%B9%D0%BD%D1%89%D0%B0%D0%B9%D0%BD" title="Алберт Айнщайн – Bulgarian" lang="bg" hreflang="bg" class="interlanguage-link-target"><span>Български</span></a></li><li class="interlanguage-link interwiki-bo mw-list-item"><a href="https://bo.wikipedia.org/wiki/%E0%BD%A8%E0%BD%A2%E0%BC%8B%E0%BD%94%E0%BD%BC%E0%BC%8B%E0%BD%90%E0%BD%BA%E0%BC%8B%E0%BD%A8%E0%BD%A0%E0%BD%BA%E0%BC%8B%E0%BD%91%E0%BD%96%E0%BE%B1%E0%BD%B2%E0%BD%93%E0%BC%8B%E0%BD%A6%E0%BD%B2%E0%BC%8B%E0%BD%90%E0%BD%BA%E0%BD%93%E0%BC%8D" title="ཨར་པོ་ཐེ་ཨའེ་དབྱིན་སི་ཐེན། – Tibetan" lang="bo" hreflang="bo" class="interlanguage-link-target"><span>བོད་ཡིག</span></a></li><li class="interlanguage-link interwiki-bs mw-list-item"><a href="https://bs.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Bosnian" lang="bs" hreflang="bs" class="interlanguage-link-target"><span>Bosanski</span></a></li><li class="interlanguage-link interwiki-br mw-list-item"><a href="https://br.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Breton" lang="br" hreflang="br" class="interlanguage-link-target"><span>Brezhoneg</span></a></li><li class="interlanguage-link interwiki-bxr mw-list-item"><a href="https://bxr.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%90%D0%B9%D0%BD%D1%88%D1%82%D0%B0%D0%B9%D0%BD" title="Альберт Айнштайн – Russia Buriat" lang="bxr" hreflang="bxr" class="interlanguage-link-target"><span>Буряад</span></a></li><li class="interlanguage-link interwiki-ca mw-list-item"><a href="https://ca.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Catalan" lang="ca" hreflang="ca" class="interlanguage-link-target"><span>Català</span></a></li><li class="interlanguage-link interwiki-cv mw-list-item"><a href="https://cv.wikipedia.org/wiki/%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD,_%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82" title="Эйнштейн, Альберт – Chuvash" lang="cv" hreflang="cv" class="interlanguage-link-target"><span>Чӑвашла</span></a></li><li class="interlanguage-link interwiki-ceb mw-list-item"><a href="https://ceb.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Cebuano" lang="ceb" hreflang="ceb" class="interlanguage-link-target"><span>Cebuano</span></a></li><li class="interlanguage-link interwiki-cs mw-list-item"><a href="https://cs.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Czech" lang="cs" hreflang="cs" class="interlanguage-link-target"><span>Čeština</span></a></li><li class="interlanguage-link interwiki-cbk-zam mw-list-item"><a href="https://cbk-zam.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Chavacano" lang="cbk" hreflang="cbk" class="interlanguage-link-target"><span>Chavacano de Zamboanga</span></a></li><li class="interlanguage-link interwiki-tum mw-list-item"><a href="https://tum.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Tumbuka" lang="tum" hreflang="tum" class="interlanguage-link-target"><span>ChiTumbuka</span></a></li><li class="interlanguage-link interwiki-co mw-list-item"><a href="https://co.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Corsican" lang="co" hreflang="co" class="interlanguage-link-target"><span>Corsu</span></a></li><li class="interlanguage-link interwiki-cy mw-list-item"><a href="https://cy.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Welsh" lang="cy" hreflang="cy" class="interlanguage-link-target"><span>Cymraeg</span></a></li><li class="interlanguage-link interwiki-da mw-list-item"><a href="https://da.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Danish" lang="da" hreflang="da" class="interlanguage-link-target"><span>Dansk</span></a></li><li class="interlanguage-link interwiki-ary mw-list-item"><a href="https://ary.wikipedia.org/wiki/%D8%A3%D9%84%D8%A8%D9%8A%D8%B1%D8%B7_%D8%A3%D9%8A%D9%86%D8%B4%D8%B7%D8%A7%D9%8A%D9%86" title="ألبيرط أينشطاين – Moroccan Arabic" lang="ary" hreflang="ary" class="interlanguage-link-target"><span>الدارجة</span></a></li><li class="interlanguage-link interwiki-se mw-list-item"><a href="https://se.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Northern Sami" lang="se" hreflang="se" class="interlanguage-link-target"><span>Davvisámegiella</span></a></li><li class="interlanguage-link interwiki-de badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://de.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – German" lang="de" hreflang="de" class="interlanguage-link-target"><span>Deutsch</span></a></li><li class="interlanguage-link interwiki-nv mw-list-item"><a href="https://nv.wikipedia.org/wiki/Hastiin_Albert_Einstein" title="Hastiin Albert Einstein – Navajo" lang="nv" hreflang="nv" class="interlanguage-link-target"><span>Diné bizaad</span></a></li><li class="interlanguage-link interwiki-dty mw-list-item"><a href="https://dty.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%A8%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A4%BE%E0%A4%87%E0%A4%A8" title="अल्बर्ट आइनस्टाइन – Doteli" lang="dty" hreflang="dty" class="interlanguage-link-target"><span>डोटेली</span></a></li><li class="interlanguage-link interwiki-et mw-list-item"><a href="https://et.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Estonian" lang="et" hreflang="et" class="interlanguage-link-target"><span>Eesti</span></a></li><li class="interlanguage-link interwiki-el mw-list-item"><a href="https://el.wikipedia.org/wiki/%CE%86%CE%BB%CE%BC%CF%80%CE%B5%CF%81%CF%84_%CE%91%CF%8A%CE%BD%CF%83%CF%84%CE%AC%CE%B9%CE%BD" title="Άλμπερτ Αϊνστάιν – Greek" lang="el" hreflang="el" class="interlanguage-link-target"><span>Ελληνικά</span></a></li><li class="interlanguage-link interwiki-myv mw-list-item"><a href="https://myv.wikipedia.org/wiki/%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD,_%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82" title="Эйнштейн, Альберт – Erzya" lang="myv" hreflang="myv" class="interlanguage-link-target"><span>Эрзянь</span></a></li><li class="interlanguage-link interwiki-es mw-list-item"><a href="https://es.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Spanish" lang="es" hreflang="es" class="interlanguage-link-target"><span>Español</span></a></li><li class="interlanguage-link interwiki-eo badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://eo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Esperanto" lang="eo" hreflang="eo" class="interlanguage-link-target"><span>Esperanto</span></a></li><li class="interlanguage-link interwiki-ext mw-list-item"><a href="https://ext.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Extremaduran" lang="ext" hreflang="ext" class="interlanguage-link-target"><span>Estremeñu</span></a></li><li class="interlanguage-link interwiki-eu badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://eu.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Basque" lang="eu" hreflang="eu" class="interlanguage-link-target"><span>Euskara</span></a></li><li class="interlanguage-link interwiki-fa badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://fa.wikipedia.org/wiki/%D8%A2%D9%84%D8%A8%D8%B1%D8%AA_%D8%A7%DB%8C%D9%86%D8%B4%D8%AA%DB%8C%D9%86" title="آلبرت اینشتین – Persian" lang="fa" hreflang="fa" class="interlanguage-link-target"><span>فارسی</span></a></li><li class="interlanguage-link interwiki-hif mw-list-item"><a href="https://hif.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Fiji Hindi" lang="hif" hreflang="hif" class="interlanguage-link-target"><span>Fiji Hindi</span></a></li><li class="interlanguage-link interwiki-fo mw-list-item"><a href="https://fo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Faroese" lang="fo" hreflang="fo" class="interlanguage-link-target"><span>Føroyskt</span></a></li><li class="interlanguage-link interwiki-fr mw-list-item"><a href="https://fr.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – French" lang="fr" hreflang="fr" class="interlanguage-link-target"><span>Français</span></a></li><li class="interlanguage-link interwiki-fy mw-list-item"><a href="https://fy.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Western Frisian" lang="fy" hreflang="fy" class="interlanguage-link-target"><span>Frysk</span></a></li><li class="interlanguage-link interwiki-ff mw-list-item"><a href="https://ff.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Fula" lang="ff" hreflang="ff" class="interlanguage-link-target"><span>Fulfulde</span></a></li><li class="interlanguage-link interwiki-ga mw-list-item"><a href="https://ga.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Irish" lang="ga" hreflang="ga" class="interlanguage-link-target"><span>Gaeilge</span></a></li><li class="interlanguage-link interwiki-gv mw-list-item"><a href="https://gv.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Manx" lang="gv" hreflang="gv" class="interlanguage-link-target"><span>Gaelg</span></a></li><li class="interlanguage-link interwiki-gd mw-list-item"><a href="https://gd.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Scottish Gaelic" lang="gd" hreflang="gd" class="interlanguage-link-target"><span>Gàidhlig</span></a></li><li class="interlanguage-link interwiki-gl mw-list-item"><a href="https://gl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Galician" lang="gl" hreflang="gl" class="interlanguage-link-target"><span>Galego</span></a></li><li class="interlanguage-link interwiki-gan mw-list-item"><a href="https://gan.wikipedia.org/wiki/%E6%84%9B%E5%9B%A0%E6%96%AF%E5%9D%A6" title="愛因斯坦 – Gan" lang="gan" hreflang="gan" class="interlanguage-link-target"><span>贛語</span></a></li><li class="interlanguage-link interwiki-gu mw-list-item"><a href="https://gu.wikipedia.org/wiki/%E0%AA%86%E0%AA%B2%E0%AB%8D%E0%AA%AC%E0%AA%B0%E0%AB%8D%E0%AA%9F_%E0%AA%86%E0%AA%87%E0%AA%A8%E0%AB%8D%E0%AA%B8%E0%AB%8D%E0%AA%9F%E0%AA%BE%E0%AA%87%E0%AA%A8" title="આલ્બર્ટ આઇન્સ્ટાઇન – Gujarati" lang="gu" hreflang="gu" class="interlanguage-link-target"><span>ગુજરાતી</span></a></li><li class="interlanguage-link interwiki-gom mw-list-item"><a href="https://gom.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Goan Konkani" lang="gom" hreflang="gom" class="interlanguage-link-target"><span>गोंयची कोंकणी / Gõychi Konknni</span></a></li><li class="interlanguage-link interwiki-hak mw-list-item"><a href="https://hak.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Hakka Chinese" lang="hak" hreflang="hak" class="interlanguage-link-target"><span>客家語/Hak-kâ-ngî</span></a></li><li class="interlanguage-link interwiki-ko mw-list-item"><a href="https://ko.wikipedia.org/wiki/%EC%95%8C%EB%B2%A0%EB%A5%B4%ED%8A%B8_%EC%95%84%EC%9D%B8%EC%8A%88%ED%83%80%EC%9D%B8" title="알베르트 아인슈타인 – Korean" lang="ko" hreflang="ko" class="interlanguage-link-target"><span>한국어</span></a></li><li class="interlanguage-link interwiki-ha mw-list-item"><a href="https://ha.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Hausa" lang="ha" hreflang="ha" class="interlanguage-link-target"><span>Hausa</span></a></li><li class="interlanguage-link interwiki-haw mw-list-item"><a href="https://haw.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Hawaiian" lang="haw" hreflang="haw" class="interlanguage-link-target"><span>Hawaiʻi</span></a></li><li class="interlanguage-link interwiki-hy badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://hy.wikipedia.org/wiki/%D4%B1%D5%AC%D5%A2%D5%A5%D6%80%D5%BF_%D4%B1%D5%B5%D5%B6%D5%B7%D5%BF%D5%A1%D5%B5%D5%B6" title="Ալբերտ Այնշտայն – Armenian" lang="hy" hreflang="hy" class="interlanguage-link-target"><span>Հայերեն</span></a></li><li class="interlanguage-link interwiki-hi mw-list-item"><a href="https://hi.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%82%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A5%80%E0%A4%A8" title="अल्बर्ट आइंस्टीन – Hindi" lang="hi" hreflang="hi" class="interlanguage-link-target"><span>हिन्दी</span></a></li><li class="interlanguage-link interwiki-hsb mw-list-item"><a href="https://hsb.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Upper Sorbian" lang="hsb" hreflang="hsb" class="interlanguage-link-target"><span>Hornjoserbsce</span></a></li><li class="interlanguage-link interwiki-hr badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://hr.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Croatian" lang="hr" hreflang="hr" class="interlanguage-link-target"><span>Hrvatski</span></a></li><li class="interlanguage-link interwiki-gor mw-list-item"><a href="https://gor.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Gorontalo" lang="gor" hreflang="gor" class="interlanguage-link-target"><span>Bahasa Hulontalo</span></a></li><li class="interlanguage-link interwiki-io mw-list-item"><a href="https://io.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Ido" lang="io" hreflang="io" class="interlanguage-link-target"><span>Ido</span></a></li><li class="interlanguage-link interwiki-ig mw-list-item"><a href="https://ig.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Igbo" lang="ig" hreflang="ig" class="interlanguage-link-target"><span>Igbo</span></a></li><li class="interlanguage-link interwiki-ilo mw-list-item"><a href="https://ilo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Iloko" lang="ilo" hreflang="ilo" class="interlanguage-link-target"><span>Ilokano</span></a></li><li class="interlanguage-link interwiki-bpy mw-list-item"><a href="https://bpy.wikipedia.org/wiki/%E0%A6%86%E0%A6%B2%E0%A6%AC%E0%A6%BE%E0%A6%B0%E0%A7%8D%E0%A6%9F_%E0%A6%86%E0%A6%87%E0%A6%A8%E0%A6%B8%E0%A7%8D%E0%A6%9F%E0%A6%BE%E0%A6%87%E0%A6%A8" title="আলবার্ট আইনস্টাইন – Bishnupriya" lang="bpy" hreflang="bpy" class="interlanguage-link-target"><span>বিষ্ণুপ্রিয়া মণিপুরী</span></a></li><li class="interlanguage-link interwiki-id mw-list-item"><a href="https://id.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Indonesian" lang="id" hreflang="id" class="interlanguage-link-target"><span>Bahasa Indonesia</span></a></li><li class="interlanguage-link interwiki-ia mw-list-item"><a href="https://ia.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Interlingua" lang="ia" hreflang="ia" class="interlanguage-link-target"><span>Interlingua</span></a></li><li class="interlanguage-link interwiki-ie mw-list-item"><a href="https://ie.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Interlingue" lang="ie" hreflang="ie" class="interlanguage-link-target"><span>Interlingue</span></a></li><li class="interlanguage-link interwiki-os mw-list-item"><a href="https://os.wikipedia.org/wiki/%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD,_%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82" title="Эйнштейн, Альберт – Ossetic" lang="os" hreflang="os" class="interlanguage-link-target"><span>Ирон</span></a></li><li class="interlanguage-link interwiki-is mw-list-item"><a href="https://is.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Icelandic" lang="is" hreflang="is" class="interlanguage-link-target"><span>Íslenska</span></a></li><li class="interlanguage-link interwiki-it mw-list-item"><a href="https://it.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Italian" lang="it" hreflang="it" class="interlanguage-link-target"><span>Italiano</span></a></li><li class="interlanguage-link interwiki-he badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://he.wikipedia.org/wiki/%D7%90%D7%9C%D7%91%D7%A8%D7%98_%D7%90%D7%99%D7%99%D7%A0%D7%A9%D7%98%D7%99%D7%99%D7%9F" title="אלברט איינשטיין – Hebrew" lang="he" hreflang="he" class="interlanguage-link-target"><span>עברית</span></a></li><li class="interlanguage-link interwiki-jv mw-list-item"><a href="https://jv.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Javanese" lang="jv" hreflang="jv" class="interlanguage-link-target"><span>Jawa</span></a></li><li class="interlanguage-link interwiki-kbp mw-list-item"><a href="https://kbp.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Kabiye" lang="kbp" hreflang="kbp" class="interlanguage-link-target"><span>Kabɩyɛ</span></a></li><li class="interlanguage-link interwiki-kn mw-list-item"><a href="https://kn.wikipedia.org/wiki/%E0%B2%85%E0%B2%B2%E0%B3%8D%E0%B2%AC%E0%B2%B0%E0%B3%8D%E0%B2%9F%E0%B3%8D_%E0%B2%90%E0%B2%A8%E0%B3%8D%E2%80%8D%E0%B2%B8%E0%B3%8D%E0%B2%9F%E0%B3%88%E0%B2%A8%E0%B3%8D" title="ಅಲ್ಬರ್ಟ್ ಐನ್‍ಸ್ಟೈನ್ – Kannada" lang="kn" hreflang="kn" class="interlanguage-link-target"><span>ಕನ್ನಡ</span></a></li><li class="interlanguage-link interwiki-pam mw-list-item"><a href="https://pam.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Pampanga" lang="pam" hreflang="pam" class="interlanguage-link-target"><span>Kapampangan</span></a></li><li class="interlanguage-link interwiki-ka mw-list-item"><a href="https://ka.wikipedia.org/wiki/%E1%83%90%E1%83%9A%E1%83%91%E1%83%94%E1%83%A0%E1%83%A2_%E1%83%90%E1%83%98%E1%83%9C%E1%83%A8%E1%83%A2%E1%83%90%E1%83%98%E1%83%9C%E1%83%98" title="ალბერტ აინშტაინი – Georgian" lang="ka" hreflang="ka" class="interlanguage-link-target"><span>ქართული</span></a></li><li class="interlanguage-link interwiki-ks mw-list-item"><a href="https://ks.wikipedia.org/wiki/%D8%A7%D9%8E%D9%84%D8%A8%D8%B1%D9%B9_%D8%A2%D9%86%D9%90%D8%B3%D9%B9%D8%A7%DB%8C%D9%90%D9%86" title="اَلبرٹ آنِسٹایِن – Kashmiri" lang="ks" hreflang="ks" class="interlanguage-link-target"><span>कॉशुर / کٲشُر</span></a></li><li class="interlanguage-link interwiki-kk mw-list-item"><a href="https://kk.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Kazakh" lang="kk" hreflang="kk" class="interlanguage-link-target"><span>Қазақша</span></a></li><li class="interlanguage-link interwiki-kw mw-list-item"><a href="https://kw.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Cornish" lang="kw" hreflang="kw" class="interlanguage-link-target"><span>Kernowek</span></a></li><li class="interlanguage-link interwiki-sw mw-list-item"><a href="https://sw.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Swahili" lang="sw" hreflang="sw" class="interlanguage-link-target"><span>Kiswahili</span></a></li><li class="interlanguage-link interwiki-ht mw-list-item"><a href="https://ht.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Haitian Creole" lang="ht" hreflang="ht" class="interlanguage-link-target"><span>Kreyòl ayisyen</span></a></li><li class="interlanguage-link interwiki-gcr mw-list-item"><a href="https://gcr.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Guianan Creole" lang="gcr" hreflang="gcr" class="interlanguage-link-target"><span>Kriyòl gwiyannen</span></a></li><li class="interlanguage-link interwiki-ku mw-list-item"><a href="https://ku.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Kurdish" lang="ku" hreflang="ku" class="interlanguage-link-target"><span>Kurdî</span></a></li><li class="interlanguage-link interwiki-ky mw-list-item"><a href="https://ky.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Kyrgyz" lang="ky" hreflang="ky" class="interlanguage-link-target"><span>Кыргызча</span></a></li><li class="interlanguage-link interwiki-lad mw-list-item"><a href="https://lad.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Ladino" lang="lad" hreflang="lad" class="interlanguage-link-target"><span>Ladino</span></a></li><li class="interlanguage-link interwiki-la mw-list-item"><a href="https://la.wikipedia.org/wiki/Albertus_Einstein" title="Albertus Einstein – Latin" lang="la" hreflang="la" class="interlanguage-link-target"><span>Latina</span></a></li><li class="interlanguage-link interwiki-lv mw-list-item"><a href="https://lv.wikipedia.org/wiki/Alberts_Ein%C5%A1teins" title="Alberts Einšteins – Latvian" lang="lv" hreflang="lv" class="interlanguage-link-target"><span>Latviešu</span></a></li><li class="interlanguage-link interwiki-lb mw-list-item"><a href="https://lb.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Luxembourgish" lang="lb" hreflang="lb" class="interlanguage-link-target"><span>Lëtzebuergesch</span></a></li><li class="interlanguage-link interwiki-lez mw-list-item"><a href="https://lez.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Lezghian" lang="lez" hreflang="lez" class="interlanguage-link-target"><span>Лезги</span></a></li><li class="interlanguage-link interwiki-lt mw-list-item"><a href="https://lt.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Lithuanian" lang="lt" hreflang="lt" class="interlanguage-link-target"><span>Lietuvių</span></a></li><li class="interlanguage-link interwiki-lij mw-list-item"><a href="https://lij.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Ligurian" lang="lij" hreflang="lij" class="interlanguage-link-target"><span>Ligure</span></a></li><li class="interlanguage-link interwiki-li mw-list-item"><a href="https://li.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Limburgish" lang="li" hreflang="li" class="interlanguage-link-target"><span>Limburgs</span></a></li><li class="interlanguage-link interwiki-lfn mw-list-item"><a href="https://lfn.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Lingua Franca Nova" lang="lfn" hreflang="lfn" class="interlanguage-link-target"><span>Lingua Franca Nova</span></a></li><li class="interlanguage-link interwiki-olo mw-list-item"><a href="https://olo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Livvi-Karelian" lang="olo" hreflang="olo" class="interlanguage-link-target"><span>Livvinkarjala</span></a></li><li class="interlanguage-link interwiki-jbo mw-list-item"><a href="https://jbo.wikipedia.org/wiki/albert._ainctain" title="albert. ainctain – Lojban" lang="jbo" hreflang="jbo" class="interlanguage-link-target"><span>La .lojban.</span></a></li><li class="interlanguage-link interwiki-lg mw-list-item"><a href="https://lg.wikipedia.org/wiki/Alubbaati_Ansitayini" title="Alubbaati Ansitayini – Ganda" lang="lg" hreflang="lg" class="interlanguage-link-target"><span>Luganda</span></a></li><li class="interlanguage-link interwiki-lmo mw-list-item"><a href="https://lmo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Lombard" lang="lmo" hreflang="lmo" class="interlanguage-link-target"><span>Lombard</span></a></li><li class="interlanguage-link interwiki-hu mw-list-item"><a href="https://hu.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Hungarian" lang="hu" hreflang="hu" class="interlanguage-link-target"><span>Magyar</span></a></li><li class="interlanguage-link interwiki-mad mw-list-item"><a href="https://mad.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Madurese" lang="mad" hreflang="mad" class="interlanguage-link-target"><span>Madhurâ</span></a></li><li class="interlanguage-link interwiki-mai mw-list-item"><a href="https://mai.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%A8%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A4%BE%E0%A4%87%E0%A4%A8" title="अल्बर्ट आइनस्टाइन – Maithili" lang="mai" hreflang="mai" class="interlanguage-link-target"><span>मैथिली</span></a></li><li class="interlanguage-link interwiki-mk mw-list-item"><a href="https://mk.wikipedia.org/wiki/%D0%90%D0%BB%D0%B1%D0%B5%D1%80%D1%82_%D0%90%D1%98%D0%BD%D1%88%D1%82%D0%B0%D1%98%D0%BD" title="Алберт Ајнштајн – Macedonian" lang="mk" hreflang="mk" class="interlanguage-link-target"><span>Македонски</span></a></li><li class="interlanguage-link interwiki-mg mw-list-item"><a href="https://mg.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Malagasy" lang="mg" hreflang="mg" class="interlanguage-link-target"><span>Malagasy</span></a></li><li class="interlanguage-link interwiki-ml mw-list-item"><a href="https://ml.wikipedia.org/wiki/%E0%B4%86%E0%B5%BD%E0%B4%AC%E0%B5%BC%E0%B4%9F%E0%B5%8D%E0%B4%9F%E0%B5%8D_%E0%B4%90%E0%B5%BB%E0%B4%B8%E0%B5%8D%E0%B4%B1%E0%B5%8D%E0%B4%B1%E0%B5%88%E0%B5%BB" title="ആൽബർട്ട് ഐൻസ്റ്റൈൻ – Malayalam" lang="ml" hreflang="ml" class="interlanguage-link-target"><span>മലയാളം</span></a></li><li class="interlanguage-link interwiki-mt mw-list-item"><a href="https://mt.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Maltese" lang="mt" hreflang="mt" class="interlanguage-link-target"><span>Malti</span></a></li><li class="interlanguage-link interwiki-mr mw-list-item"><a href="https://mr.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%A8%E0%A5%8D%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A4%BE%E0%A4%87%E0%A4%A8" title="अल्बर्ट आइन्स्टाइन – Marathi" lang="mr" hreflang="mr" class="interlanguage-link-target"><span>मराठी</span></a></li><li class="interlanguage-link interwiki-xmf mw-list-item"><a href="https://xmf.wikipedia.org/wiki/%E1%83%90%E1%83%9A%E1%83%91%E1%83%94%E1%83%A0%E1%83%A2_%E1%83%90%E1%83%98%E1%83%9C%E1%83%A8%E1%83%A2%E1%83%90%E1%83%98%E1%83%9C%E1%83%98" title="ალბერტ აინშტაინი – Mingrelian" lang="xmf" hreflang="xmf" class="interlanguage-link-target"><span>მარგალური</span></a></li><li class="interlanguage-link interwiki-arz mw-list-item"><a href="https://arz.wikipedia.org/wiki/%D8%A7%D9%84%D8%A8%D8%B1%D8%AA_%D8%A7%D9%8A%D9%86%D8%B4%D8%AA%D8%A7%D9%8A%D9%86" title="البرت اينشتاين – Egyptian Arabic" lang="arz" hreflang="arz" class="interlanguage-link-target"><span>مصرى</span></a></li><li class="interlanguage-link interwiki-mnw mw-list-item"><a href="https://mnw.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Mon" lang="mnw" hreflang="mnw" class="interlanguage-link-target"><span>ဘာသာမန်</span></a></li><li class="interlanguage-link interwiki-mzn mw-list-item"><a href="https://mzn.wikipedia.org/wiki/%D8%A2%D9%84%D8%A8%D8%B1%D8%AA_%D8%A7%DB%8C%D9%86%D8%B4%D8%AA%DB%8C%D9%86" title="آلبرت اینشتین – Mazanderani" lang="mzn" hreflang="mzn" class="interlanguage-link-target"><span>مازِرونی</span></a></li><li class="interlanguage-link interwiki-ms mw-list-item"><a href="https://ms.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Malay" lang="ms" hreflang="ms" class="interlanguage-link-target"><span>Bahasa Melayu</span></a></li><li class="interlanguage-link interwiki-mni mw-list-item"><a href="https://mni.wikipedia.org/wiki/%EA%AF%91%EA%AF%9C%EA%AF%95%EA%AF%94%EA%AF%AD%EA%AF%A0_%EA%AF%91%EA%AF%A5%EA%AF%A2%EA%AF%9F%EA%AF%81%EA%AF%AD%EA%AF%87%EA%AF%A5%EA%AF%A2%EA%AF%9F" title="ꯑꯜꯕꯔ꯭ꯠ ꯑꯥꯢꯟꯁ꯭ꯇꯥꯢꯟ – Manipuri" lang="mni" hreflang="mni" class="interlanguage-link-target"><span>ꯃꯤꯇꯩ ꯂꯣꯟ</span></a></li><li class="interlanguage-link interwiki-cdo mw-list-item"><a href="https://cdo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Mindong" lang="cdo" hreflang="cdo" class="interlanguage-link-target"><span>閩東語 / Mìng-dĕ̤ng-ngṳ̄</span></a></li><li class="interlanguage-link interwiki-mwl mw-list-item"><a href="https://mwl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Mirandese" lang="mwl" hreflang="mwl" class="interlanguage-link-target"><span>Mirandés</span></a></li><li class="interlanguage-link interwiki-mn mw-list-item"><a href="https://mn.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Mongolian" lang="mn" hreflang="mn" class="interlanguage-link-target"><span>Монгол</span></a></li><li class="interlanguage-link interwiki-my mw-list-item"><a href="https://my.wikipedia.org/wiki/%E1%80%A1%E1%80%B2%E1%80%9C%E1%80%BA%E1%80%98%E1%80%90%E1%80%BA_%E1%80%A1%E1%80%AD%E1%80%AF%E1%80%84%E1%80%BA%E1%80%B8%E1%80%85%E1%80%90%E1%80%AD%E1%80%AF%E1%80%84%E1%80%BA%E1%80%B8" title="အဲလ်ဘတ် အိုင်းစတိုင်း – Burmese" lang="my" hreflang="my" class="interlanguage-link-target"><span>မြန်မာဘာသာ</span></a></li><li class="interlanguage-link interwiki-nah mw-list-item"><a href="https://nah.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Nāhuatl" lang="nah" hreflang="nah" class="interlanguage-link-target"><span>Nāhuatl</span></a></li><li class="interlanguage-link interwiki-nl mw-list-item"><a href="https://nl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Dutch" lang="nl" hreflang="nl" class="interlanguage-link-target"><span>Nederlands</span></a></li><li class="interlanguage-link interwiki-nds-nl mw-list-item"><a href="https://nds-nl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Low Saxon" lang="nds-NL" hreflang="nds-NL" class="interlanguage-link-target"><span>Nedersaksies</span></a></li><li class="interlanguage-link interwiki-ne mw-list-item"><a href="https://ne.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%A8%E0%A5%8D%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A4%BE%E0%A4%87%E0%A4%A8" title="अल्बर्ट आइन्स्टाइन – Nepali" lang="ne" hreflang="ne" class="interlanguage-link-target"><span>नेपाली</span></a></li><li class="interlanguage-link interwiki-new mw-list-item"><a href="https://new.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F_%E0%A4%86%E0%A4%87%E0%A4%A8%E0%A5%8D%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A4%BE%E0%A4%87%E0%A4%A8" title="अल्बर्ट आइन्स्टाइन – Newari" lang="new" hreflang="new" class="interlanguage-link-target"><span>नेपाल भाषा</span></a></li><li class="interlanguage-link interwiki-ja mw-list-item"><a href="https://ja.wikipedia.org/wiki/%E3%82%A2%E3%83%AB%E3%83%99%E3%83%AB%E3%83%88%E3%83%BB%E3%82%A2%E3%82%A4%E3%83%B3%E3%82%B7%E3%83%A5%E3%82%BF%E3%82%A4%E3%83%B3" title="アルベルト・アインシュタイン – Japanese" lang="ja" hreflang="ja" class="interlanguage-link-target"><span>日本語</span></a></li><li class="interlanguage-link interwiki-ce mw-list-item"><a href="https://ce.wikipedia.org/wiki/%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD,_%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82" title="Эйнштейн, Альберт – Chechen" lang="ce" hreflang="ce" class="interlanguage-link-target"><span>Нохчийн</span></a></li><li class="interlanguage-link interwiki-frr mw-list-item"><a href="https://frr.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Northern Frisian" lang="frr" hreflang="frr" class="interlanguage-link-target"><span>Nordfriisk</span></a></li><li class="interlanguage-link interwiki-no badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://no.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Norwegian Bokmål" lang="nb" hreflang="nb" class="interlanguage-link-target"><span>Norsk bokmål</span></a></li><li class="interlanguage-link interwiki-nn mw-list-item"><a href="https://nn.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Norwegian Nynorsk" lang="nn" hreflang="nn" class="interlanguage-link-target"><span>Norsk nynorsk</span></a></li><li class="interlanguage-link interwiki-nov mw-list-item"><a href="https://nov.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Novial" lang="nov" hreflang="nov" class="interlanguage-link-target"><span>Novial</span></a></li><li class="interlanguage-link interwiki-oc mw-list-item"><a href="https://oc.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Occitan" lang="oc" hreflang="oc" class="interlanguage-link-target"><span>Occitan</span></a></li><li class="interlanguage-link interwiki-or mw-list-item"><a href="https://or.wikipedia.org/wiki/%E0%AC%86%E0%AC%B2%E0%AC%AC%E0%AC%B0%E0%AD%8D%E0%AC%9F_%E0%AC%86%E0%AC%87%E0%AC%A8%E0%AC%B7%E0%AD%8D%E0%AC%9F%E0%AC%BE%E0%AC%87%E0%AC%A8" title="ଆଲବର୍ଟ ଆଇନଷ୍ଟାଇନ – Odia" lang="or" hreflang="or" class="interlanguage-link-target"><span>ଓଡ଼ିଆ</span></a></li><li class="interlanguage-link interwiki-om mw-list-item"><a href="https://om.wikipedia.org/wiki/Alberti_Anistaayin" title="Alberti Anistaayin – Oromo" lang="om" hreflang="om" class="interlanguage-link-target"><span>Oromoo</span></a></li><li class="interlanguage-link interwiki-uz mw-list-item"><a href="https://uz.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Uzbek" lang="uz" hreflang="uz" class="interlanguage-link-target"><span>Oʻzbekcha / ўзбекча</span></a></li><li class="interlanguage-link interwiki-pa mw-list-item"><a href="https://pa.wikipedia.org/wiki/%E0%A8%85%E0%A8%B2%E0%A8%AC%E0%A8%B0%E0%A8%9F_%E0%A8%86%E0%A8%88%E0%A8%A8%E0%A8%B8%E0%A8%9F%E0%A8%BE%E0%A8%88%E0%A8%A8" title="ਅਲਬਰਟ ਆਈਨਸਟਾਈਨ – Punjabi" lang="pa" hreflang="pa" class="interlanguage-link-target"><span>ਪੰਜਾਬੀ</span></a></li><li class="interlanguage-link interwiki-pnb mw-list-item"><a href="https://pnb.wikipedia.org/wiki/%D8%A7%DB%8C%D9%84%D8%A8%D8%B1%D9%B9_%D8%A2%D8%A6%DB%8C%D9%86%D8%B3%D9%B9%D8%A7%D8%A6%D9%86" title="ایلبرٹ آئینسٹائن – Western Punjabi" lang="pnb" hreflang="pnb" class="interlanguage-link-target"><span>پنجابی</span></a></li><li class="interlanguage-link interwiki-pap mw-list-item"><a href="https://pap.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Papiamento" lang="pap" hreflang="pap" class="interlanguage-link-target"><span>Papiamentu</span></a></li><li class="interlanguage-link interwiki-ps mw-list-item"><a href="https://ps.wikipedia.org/wiki/%D8%A7%D9%84%D8%A8%D8%B1%D9%BC_%D8%A2%D9%8A%D9%86%D8%B3%D9%BC%D8%A7%D9%8A%D9%86" title="البرټ آينسټاين – Pashto" lang="ps" hreflang="ps" class="interlanguage-link-target"><span>پښتو</span></a></li><li class="interlanguage-link interwiki-jam mw-list-item"><a href="https://jam.wikipedia.org/wiki/Alboert_Ainstain" title="Alboert Ainstain – Jamaican Creole English" lang="jam" hreflang="jam" class="interlanguage-link-target"><span>Patois</span></a></li><li class="interlanguage-link interwiki-km mw-list-item"><a href="https://km.wikipedia.org/wiki/%E1%9E%A2%E1%9E%B6%E1%9E%9B%E1%9F%8B%E1%9E%94%E1%9E%BA%E1%9E%8F_%E1%9E%A2%E1%9F%82%E1%9E%84%E1%9E%9F%E1%9F%92%E1%9E%8F%E1%9F%82%E1%9E%84" title="អាល់បឺត អែងស្តែង – Khmer" lang="km" hreflang="km" class="interlanguage-link-target"><span>ភាសាខ្មែរ</span></a></li><li class="interlanguage-link interwiki-pcd mw-list-item"><a href="https://pcd.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Picard" lang="pcd" hreflang="pcd" class="interlanguage-link-target"><span>Picard</span></a></li><li class="interlanguage-link interwiki-pms mw-list-item"><a href="https://pms.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Piedmontese" lang="pms" hreflang="pms" class="interlanguage-link-target"><span>Piemontèis</span></a></li><li class="interlanguage-link interwiki-tpi mw-list-item"><a href="https://tpi.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Tok Pisin" lang="tpi" hreflang="tpi" class="interlanguage-link-target"><span>Tok Pisin</span></a></li><li class="interlanguage-link interwiki-nds mw-list-item"><a href="https://nds.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Low German" lang="nds" hreflang="nds" class="interlanguage-link-target"><span>Plattdüütsch</span></a></li><li class="interlanguage-link interwiki-pl mw-list-item"><a href="https://pl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Polish" lang="pl" hreflang="pl" class="interlanguage-link-target"><span>Polski</span></a></li><li class="interlanguage-link interwiki-pt badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://pt.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Portuguese" lang="pt" hreflang="pt" class="interlanguage-link-target"><span>Português</span></a></li><li class="interlanguage-link interwiki-kaa mw-list-item"><a href="https://kaa.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Kara-Kalpak" lang="kaa" hreflang="kaa" class="interlanguage-link-target"><span>Qaraqalpaqsha</span></a></li><li class="interlanguage-link interwiki-crh mw-list-item"><a href="https://crh.wikipedia.org/wiki/Albert_Eyn%C5%9Fteyn" title="Albert Eynşteyn – Crimean Tatar" lang="crh" hreflang="crh" class="interlanguage-link-target"><span>Qırımtatarca</span></a></li><li class="interlanguage-link interwiki-ksh mw-list-item"><a href="https://ksh.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Colognian" lang="ksh" hreflang="ksh" class="interlanguage-link-target"><span>Ripoarisch</span></a></li><li class="interlanguage-link interwiki-ro mw-list-item"><a href="https://ro.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Romanian" lang="ro" hreflang="ro" class="interlanguage-link-target"><span>Română</span></a></li><li class="interlanguage-link interwiki-rm mw-list-item"><a href="https://rm.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Romansh" lang="rm" hreflang="rm" class="interlanguage-link-target"><span>Rumantsch</span></a></li><li class="interlanguage-link interwiki-qu mw-list-item"><a href="https://qu.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Quechua" lang="qu" hreflang="qu" class="interlanguage-link-target"><span>Runa Simi</span></a></li><li class="interlanguage-link interwiki-rue mw-list-item"><a href="https://rue.wikipedia.org/wiki/%D0%90%D0%BB%D0%B1%D0%B5%D1%80%D1%82_%D0%90%D0%B9%D0%BD%D1%88%D1%82%D0%B0%D0%B9%D0%BD" title="Алберт Айнштайн – Rusyn" lang="rue" hreflang="rue" class="interlanguage-link-target"><span>Русиньскый</span></a></li><li class="interlanguage-link interwiki-ru badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://ru.wikipedia.org/wiki/%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD,_%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82" title="Эйнштейн, Альберт – Russian" lang="ru" hreflang="ru" class="interlanguage-link-target"><span>Русский</span></a></li><li class="interlanguage-link interwiki-sah mw-list-item"><a href="https://sah.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Yakut" lang="sah" hreflang="sah" class="interlanguage-link-target"><span>Саха тыла</span></a></li><li class="interlanguage-link interwiki-szy mw-list-item"><a href="https://szy.wikipedia.org/wiki/Alpute.ayinsedan" title="Alpute.ayinsedan – Sakizaya" lang="szy" hreflang="szy" class="interlanguage-link-target"><span>Sakizaya</span></a></li><li class="interlanguage-link interwiki-sa mw-list-item"><a href="https://sa.wikipedia.org/wiki/%E0%A4%85%E0%A4%B2%E0%A5%8D%E0%A4%AC%E0%A4%B0%E0%A5%8D%E0%A4%9F%E0%A5%8D_%E0%A4%90%E0%A4%A8%E0%A5%8D%E0%A4%B8%E0%A5%8D%E0%A4%9F%E0%A5%88%E0%A4%A8%E0%A5%8D" title="अल्बर्ट् ऐन्स्टैन् – Sanskrit" lang="sa" hreflang="sa" class="interlanguage-link-target"><span>संस्कृतम्</span></a></li><li class="interlanguage-link interwiki-sat mw-list-item"><a href="https://sat.wikipedia.org/wiki/%E1%B1%9F%E1%B1%9E%E1%B1%B5%E1%B1%9A%E1%B1%A8%E1%B1%B4_%E1%B1%9F%E1%B1%AD%E1%B1%A4%E1%B1%B1%E1%B1%A5%E1%B1%B4%E1%B1%9F%E1%B1%AD%E1%B1%A4%E1%B1%B1" title="ᱟᱞᱵᱚᱨᱴ ᱟᱭᱤᱱᱥᱴᱟᱭᱤᱱ – Santali" lang="sat" hreflang="sat" class="interlanguage-link-target"><span>ᱥᱟᱱᱛᱟᱲᱤ</span></a></li><li class="interlanguage-link interwiki-skr mw-list-item"><a href="https://skr.wikipedia.org/wiki/%D8%A7%D9%84%D8%A8%D8%B1%D9%B9_%D8%A2%D8%A6%D9%86%D8%B3%D9%B9%D8%A7%D8%A6%D9%86" title="البرٹ آئنسٹائن – Saraiki" lang="skr" hreflang="skr" class="interlanguage-link-target"><span>سرائیکی</span></a></li><li class="interlanguage-link interwiki-sc mw-list-item"><a href="https://sc.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Sardinian" lang="sc" hreflang="sc" class="interlanguage-link-target"><span>Sardu</span></a></li><li class="interlanguage-link interwiki-sco mw-list-item"><a href="https://sco.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Scots" lang="sco" hreflang="sco" class="interlanguage-link-target"><span>Scots</span></a></li><li class="interlanguage-link interwiki-sq mw-list-item"><a href="https://sq.wikipedia.org/wiki/Albert_Ajnshtajni" title="Albert Ajnshtajni – Albanian" lang="sq" hreflang="sq" class="interlanguage-link-target"><span>Shqip</span></a></li><li class="interlanguage-link interwiki-scn mw-list-item"><a href="https://scn.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Sicilian" lang="scn" hreflang="scn" class="interlanguage-link-target"><span>Sicilianu</span></a></li><li class="interlanguage-link interwiki-si mw-list-item"><a href="https://si.wikipedia.org/wiki/%E0%B6%87%E0%B6%BD%E0%B7%8A%E0%B6%B6%E0%B6%A7%E0%B7%8A%E2%80%8D_%E0%B6%85%E0%B6%BA%E0%B7%92%E0%B6%B1%E0%B7%8A%E0%B7%83%E0%B7%8A%E0%B6%A7%E0%B6%BA%E0%B7%92%E0%B6%B1%E0%B7%8A" title="ඇල්බට්‍ අයින්ස්ටයින් – Sinhala" lang="si" hreflang="si" class="interlanguage-link-target"><span>සිංහල</span></a></li><li class="interlanguage-link interwiki-simple mw-list-item"><a href="https://simple.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Simple English" lang="en-simple" hreflang="en-simple" class="interlanguage-link-target"><span>Simple English</span></a></li><li class="interlanguage-link interwiki-sd mw-list-item"><a href="https://sd.wikipedia.org/wiki/%D8%A7%D9%84%D8%A8%D8%B1%D9%BD_%D8%A2%D8%A6%D9%86%D8%B3%D9%BD%D8%A7%D8%A6%D9%86" title="البرٽ آئنسٽائن – Sindhi" lang="sd" hreflang="sd" class="interlanguage-link-target"><span>سنڌي</span></a></li><li class="interlanguage-link interwiki-sk mw-list-item"><a href="https://sk.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Slovak" lang="sk" hreflang="sk" class="interlanguage-link-target"><span>Slovenčina</span></a></li><li class="interlanguage-link interwiki-sl mw-list-item"><a href="https://sl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Slovenian" lang="sl" hreflang="sl" class="interlanguage-link-target"><span>Slovenščina</span></a></li><li class="interlanguage-link interwiki-szl mw-list-item"><a href="https://szl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Silesian" lang="szl" hreflang="szl" class="interlanguage-link-target"><span>Ślůnski</span></a></li><li class="interlanguage-link interwiki-so mw-list-item"><a href="https://so.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Somali" lang="so" hreflang="so" class="interlanguage-link-target"><span>Soomaaliga</span></a></li><li class="interlanguage-link interwiki-ckb mw-list-item"><a href="https://ckb.wikipedia.org/wiki/%D8%A6%DB%95%D9%84%D8%A8%DB%95%D8%B1%D8%AA_%D8%A6%D8%A7%DB%8C%D9%86%D8%B4%D8%AA%D8%A7%DB%8C%D9%86" title="ئەلبەرت ئاینشتاین – Central Kurdish" lang="ckb" hreflang="ckb" class="interlanguage-link-target"><span>کوردی</span></a></li><li class="interlanguage-link interwiki-sr badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://sr.wikipedia.org/wiki/%D0%90%D0%BB%D0%B1%D0%B5%D1%80%D1%82_%D0%90%D1%98%D0%BD%D1%88%D1%82%D0%B0%D1%98%D0%BD" title="Алберт Ајнштајн – Serbian" lang="sr" hreflang="sr" class="interlanguage-link-target"><span>Српски / srpski</span></a></li><li class="interlanguage-link interwiki-sh badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://sh.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Serbo-Croatian" lang="sh" hreflang="sh" class="interlanguage-link-target"><span>Srpskohrvatski / српскохрватски</span></a></li><li class="interlanguage-link interwiki-su mw-list-item"><a href="https://su.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Sundanese" lang="su" hreflang="su" class="interlanguage-link-target"><span>Sunda</span></a></li><li class="interlanguage-link interwiki-fi mw-list-item"><a href="https://fi.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Finnish" lang="fi" hreflang="fi" class="interlanguage-link-target"><span>Suomi</span></a></li><li class="interlanguage-link interwiki-sv mw-list-item"><a href="https://sv.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Swedish" lang="sv" hreflang="sv" class="interlanguage-link-target"><span>Svenska</span></a></li><li class="interlanguage-link interwiki-tl mw-list-item"><a href="https://tl.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Tagalog" lang="tl" hreflang="tl" class="interlanguage-link-target"><span>Tagalog</span></a></li><li class="interlanguage-link interwiki-ta mw-list-item"><a href="https://ta.wikipedia.org/wiki/%E0%AE%86%E0%AE%B2%E0%AF%8D%E0%AE%AA%E0%AE%B0%E0%AF%8D%E0%AE%9F%E0%AF%8D_%E0%AE%90%E0%AE%A9%E0%AF%8D%E0%AE%B8%E0%AF%8D%E0%AE%9F%E0%AF%88%E0%AE%A9%E0%AF%8D" title="ஆல்பர்ட் ஐன்ஸ்டைன் – Tamil" lang="ta" hreflang="ta" class="interlanguage-link-target"><span>தமிழ்</span></a></li><li class="interlanguage-link interwiki-shi mw-list-item"><a href="https://shi.wikipedia.org/wiki/Albirt_Aync%E1%B9%ADayn" title="Albirt Ayncṭayn – Tachelhit" lang="shi" hreflang="shi" class="interlanguage-link-target"><span>Taclḥit</span></a></li><li class="interlanguage-link interwiki-kab mw-list-item"><a href="https://kab.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Kabyle" lang="kab" hreflang="kab" class="interlanguage-link-target"><span>Taqbaylit</span></a></li><li class="interlanguage-link interwiki-tt mw-list-item"><a href="https://tt.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Эйнштейн – Tatar" lang="tt" hreflang="tt" class="interlanguage-link-target"><span>Татарча / tatarça</span></a></li><li class="interlanguage-link interwiki-te mw-list-item"><a href="https://te.wikipedia.org/wiki/%E0%B0%86%E0%B0%B2%E0%B1%8D%E0%B0%AC%E0%B0%B0%E0%B1%8D%E0%B0%9F%E0%B1%8D_%E0%B0%90%E0%B0%A8%E0%B1%8D%E2%80%8C%E0%B0%B8%E0%B1%8D%E0%B0%9F%E0%B1%80%E0%B0%A8%E0%B1%8D" title="ఆల్బర్ట్ ఐన్‌స్టీన్ – Telugu" lang="te" hreflang="te" class="interlanguage-link-target"><span>తెలుగు</span></a></li><li class="interlanguage-link interwiki-th mw-list-item"><a href="https://th.wikipedia.org/wiki/%E0%B8%AD%E0%B8%B1%E0%B8%A5%E0%B9%80%E0%B8%9A%E0%B8%B4%E0%B8%A3%E0%B9%8C%E0%B8%95_%E0%B9%84%E0%B8%AD%E0%B8%99%E0%B9%8C%E0%B8%AA%E0%B9%84%E0%B8%95%E0%B8%99%E0%B9%8C" title="อัลเบิร์ต ไอน์สไตน์ – Thai" lang="th" hreflang="th" class="interlanguage-link-target"><span>ไทย</span></a></li><li class="interlanguage-link interwiki-tg mw-list-item"><a href="https://tg.wikipedia.org/wiki/%D0%90%D0%BB%D0%B1%D0%B5%D1%80%D1%82_%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Алберт Эйнштейн – Tajik" lang="tg" hreflang="tg" class="interlanguage-link-target"><span>Тоҷикӣ</span></a></li><li class="interlanguage-link interwiki-tcy mw-list-item"><a href="https://tcy.wikipedia.org/wiki/%E0%B2%86%E0%B2%B2%E0%B3%8D%E0%B2%AC%E0%B2%B0%E0%B3%8D%E0%B2%9F%E0%B3%8D_%E0%B2%90%E0%B2%A8%E0%B3%8D%E2%80%8D%E0%B2%B8%E0%B3%8D%E0%B2%9F%E0%B3%80%E0%B2%A8%E0%B3%8D" title="ಆಲ್ಬರ್ಟ್ ಐನ್‍ಸ್ಟೀನ್ – Tulu" lang="tcy" hreflang="tcy" class="interlanguage-link-target"><span>ತುಳು</span></a></li><li class="interlanguage-link interwiki-tr mw-list-item"><a href="https://tr.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Turkish" lang="tr" hreflang="tr" class="interlanguage-link-target"><span>Türkçe</span></a></li><li class="interlanguage-link interwiki-tk mw-list-item"><a href="https://tk.wikipedia.org/wiki/Albert_E%C3%BDn%C5%9Fte%C3%BDn" title="Albert Eýnşteýn – Turkmen" lang="tk" hreflang="tk" class="interlanguage-link-target"><span>Türkmençe</span></a></li><li class="interlanguage-link interwiki-tyv mw-list-item"><a href="https://tyv.wikipedia.org/wiki/%D0%AD%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD,_%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82" title="Эйнштейн, Альберт – Tuvinian" lang="tyv" hreflang="tyv" class="interlanguage-link-target"><span>Тыва дыл</span></a></li><li class="interlanguage-link interwiki-uk mw-list-item"><a href="https://uk.wikipedia.org/wiki/%D0%90%D0%BB%D1%8C%D0%B1%D0%B5%D1%80%D1%82_%D0%95%D0%B9%D0%BD%D1%88%D1%82%D0%B5%D0%B9%D0%BD" title="Альберт Ейнштейн – Ukrainian" lang="uk" hreflang="uk" class="interlanguage-link-target"><span>Українська</span></a></li><li class="interlanguage-link interwiki-ur badge-Q17437796 badge-featuredarticle mw-list-item" title="featured article badge"><a href="https://ur.wikipedia.org/wiki/%D8%A7%D9%84%D8%A8%D8%B1%D9%B9_%D8%A2%D8%A6%D9%86%D8%B3%D9%B9%D8%A7%D8%A6%D9%86" title="البرٹ آئنسٹائن – Urdu" lang="ur" hreflang="ur" class="interlanguage-link-target"><span>اردو</span></a></li><li class="interlanguage-link interwiki-ug mw-list-item"><a href="https://ug.wikipedia.org/wiki/%D8%A6%D8%A7%D9%84%D8%A8%DB%90%D8%B1%D8%AA_%D8%A6%DB%90%D9%8A%D9%86%D9%89%D8%B4%D8%AA%DB%90%D9%8A%D9%89%D9%86" title="ئالبېرت ئېينىشتېيىن – Uyghur" lang="ug" hreflang="ug" class="interlanguage-link-target"><span>ئۇيغۇرچە / Uyghurche</span></a></li><li class="interlanguage-link interwiki-za mw-list-item"><a href="https://za.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Zhuang" lang="za" hreflang="za" class="interlanguage-link-target"><span>Vahcuengh</span></a></li><li class="interlanguage-link interwiki-vec mw-list-item"><a href="https://vec.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Venetian" lang="vec" hreflang="vec" class="interlanguage-link-target"><span>Vèneto</span></a></li><li class="interlanguage-link interwiki-vep mw-list-item"><a href="https://vep.wikipedia.org/wiki/Ein%C5%A1tein_Al%27bert" title="Einštein Al&#039;bert – Veps" lang="vep" hreflang="vep" class="interlanguage-link-target"><span>Vepsän kel’</span></a></li><li class="interlanguage-link interwiki-vi mw-list-item"><a href="https://vi.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Vietnamese" lang="vi" hreflang="vi" class="interlanguage-link-target"><span>Tiếng Việt</span></a></li><li class="interlanguage-link interwiki-vo mw-list-item"><a href="https://vo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Volapük" lang="vo" hreflang="vo" class="interlanguage-link-target"><span>Volapük</span></a></li><li class="interlanguage-link interwiki-fiu-vro mw-list-item"><a href="https://fiu-vro.wikipedia.org/wiki/Einsteini_Albert" title="Einsteini Albert – Võro" lang="vro" hreflang="vro" class="interlanguage-link-target"><span>Võro</span></a></li><li class="interlanguage-link interwiki-wa mw-list-item"><a href="https://wa.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Walloon" lang="wa" hreflang="wa" class="interlanguage-link-target"><span>Walon</span></a></li><li class="interlanguage-link interwiki-zh-classical mw-list-item"><a href="https://zh-classical.wikipedia.org/wiki/%E6%84%9B%E5%9B%A0%E6%96%AF%E5%9D%A6" title="愛因斯坦 – Literary Chinese" lang="lzh" hreflang="lzh" class="interlanguage-link-target"><span>文言</span></a></li><li class="interlanguage-link interwiki-war mw-list-item"><a href="https://war.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Waray" lang="war" hreflang="war" class="interlanguage-link-target"><span>Winaray</span></a></li><li class="interlanguage-link interwiki-wo mw-list-item"><a href="https://wo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Wolof" lang="wo" hreflang="wo" class="interlanguage-link-target"><span>Wolof</span></a></li><li class="interlanguage-link interwiki-wuu mw-list-item"><a href="https://wuu.wikipedia.org/wiki/%E9%98%BF%E7%88%BE%E4%BC%AF%E7%89%B9%C2%B7%E6%84%9B%E5%9B%A0%E6%96%AF%E5%9D%A6" title="阿爾伯特·愛因斯坦 – Wu" lang="wuu" hreflang="wuu" class="interlanguage-link-target"><span>吴语</span></a></li><li class="interlanguage-link interwiki-yi mw-list-item"><a href="https://yi.wikipedia.org/wiki/%D7%90%D7%9C%D7%91%D7%A2%D7%A8%D7%98_%D7%90%D7%99%D7%99%D7%A0%D7%A9%D7%98%D7%99%D7%99%D7%9F" title="אלבערט איינשטיין – Yiddish" lang="yi" hreflang="yi" class="interlanguage-link-target"><span>ייִדיש</span></a></li><li class="interlanguage-link interwiki-yo mw-list-item"><a href="https://yo.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Yoruba" lang="yo" hreflang="yo" class="interlanguage-link-target"><span>Yorùbá</span></a></li><li class="interlanguage-link interwiki-zh-yue mw-list-item"><a href="https://zh-yue.wikipedia.org/wiki/%E6%AD%90%E6%8B%94%C2%B7%E6%84%9B%E5%9B%A0%E6%96%AF%E5%9D%A6" title="歐拔·愛因斯坦 – Cantonese" lang="yue" hreflang="yue" class="interlanguage-link-target"><span>粵語</span></a></li><li class="interlanguage-link interwiki-diq mw-list-item"><a href="https://diq.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Zazaki" lang="diq" hreflang="diq" class="interlanguage-link-target"><span>Zazaki</span></a></li><li class="interlanguage-link interwiki-zea mw-list-item"><a href="https://zea.wikipedia.org/wiki/Albert_Einstein" title="Albert Einstein – Zeelandic" lang="zea" hreflang="zea" class="interlanguage-link-target"><span>Zeêuws</span></a></li><li class="interlanguage-link interwiki-bat-smg mw-list-item"><a href="https://bat-smg.wikipedia.org/wiki/Alberts_Ein%C5%A1teins" title="Alberts Einšteins – Samogitian" lang="sgs" hreflang="sgs" class="interlanguage-link-target"><span>Žemaitėška</span></a></li><li class="interlanguage-link interwiki-zh badge-Q17437798 badge-goodarticle mw-list-item" title="good article badge"><a href="https://zh.wikipedia.org/wiki/%E9%98%BF%E5%B0%94%E4%BC%AF%E7%89%B9%C2%B7%E7%88%B1%E5%9B%A0%E6%96%AF%E5%9D%A6" title="阿尔伯特·爱因斯坦 – Chinese" lang="zh" hreflang="zh" class="interlanguage-link-target"><span>中文</span></a></li><li class="interlanguage-link interwiki-bew mw-list-item"><a href="https://bew.wikipedia.org/wiki/Albet_%C3%89nst%C3%A9n" title="Albet Énstén – Betawi" lang="bew" hreflang="bew" class="interlanguage-link-target"><span>Betawi</span></a></li><li class="interlanguage-link interwiki-tly mw-list-item"><a href="https://tly.wikipedia.org/wiki/Albert_Ejn%C5%A1tejn" title="Albert Ejnštejn – Talysh" lang="tly" hreflang="tly" class="interlanguage-link-target"><span>Tolışi</span></a></li>
			</ul>
			<div class="after-portlet after-portlet-lang"><span class="wb-langlinks-edit wb-langlinks-link"><a href="https://www.wikidata.org/wiki/Special:EntityPage/Q937#sitelinks-wikipedia" title="Edit interlanguage links" class="wbc-editpage">Edit links</a></span></div>
		</div>

	</div>
</div>
</header>
				<div class="vector-page-toolbar">
					<div class="vector-page-toolbar-container">
						<div id="left-navigation">
							<nav aria-label="Namespaces">
								
<div id="p-associated-pages" class="vector-menu vector-menu-tabs mw-portlet mw-portlet-associated-pages"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="ca-nstab-main" class="selected vector-tab-noicon mw-list-item"><a href="/wiki/Albert_Einstein" title="View the content page [c]" accesskey="c"><span>Article</span></a></li><li id="ca-talk" class="vector-tab-noicon mw-list-item"><a href="/wiki/Talk:Albert_Einstein" rel="discussion" title="Discuss improvements to the content page [t]" accesskey="t"><span>Talk</span></a></li>
		</ul>
		
	</div>
</div>

								
<div id="vector-variants-dropdown" class="vector-dropdown emptyPortlet"  >
	<input type="checkbox" id="vector-variants-dropdown-checkbox" role="button" aria-haspopup="true" data-event-name="ui.dropdown-vector-variants-dropdown" class="vector-dropdown-checkbox " aria-label="Change language variant"   >
	<label id="vector-variants-dropdown-label" for="vector-variants-dropdown-checkbox" class="vector-dropdown-label cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet" aria-hidden="true"  ><span class="vector-dropdown-label-text">English</span>
	</label>
	<div class="vector-dropdown-content">


					
<div id="p-variants" class="vector-menu mw-portlet mw-portlet-variants emptyPortlet"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			
		</ul>
		
	</div>
</div>

				
	</div>
</div>

							</nav>
						</div>
						<div id="right-navigation" class="vector-collapsible">
							<nav aria-label="Views">
								
<div id="p-views" class="vector-menu vector-menu-tabs mw-portlet mw-portlet-views"  >
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="ca-view" class="selected vector-tab-noicon mw-list-item"><a href="/wiki/Albert_Einstein"><span>Read</span></a></li><li id="ca-viewsource" class="vector-tab-noicon mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;action=edit" title="This page is protected.&#10;You can view its source [e]" accesskey="e"><span>View source</span></a></li><li id="ca-history" class="vector-tab-noicon mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;action=history" title="Past revisions of this page [h]" accesskey="h"><span>View history</span></a></li>
		</ul>
		
	</div>
</div>

							</nav>
				
							<nav class="vector-page-tools-landmark" aria-label="Page tools">
								
<div id="vector-page-tools-dropdown" class="vector-dropdown vector-page-tools-dropdown"  >
	<input type="checkbox" id="vector-page-tools-dropdown-checkbox" role="button" aria-haspopup="true" data-event-name="ui.dropdown-vector-page-tools-dropdown" class="vector-dropdown-checkbox "  aria-label="Tools"  >
	<label id="vector-page-tools-dropdown-label" for="vector-page-tools-dropdown-checkbox" class="vector-dropdown-label cdx-button cdx-button--fake-button cdx-button--fake-button--enabled cdx-button--weight-quiet" aria-hidden="true"  ><span class="vector-dropdown-label-text">Tools</span>
	</label>
	<div class="vector-dropdown-content">


									<div id="vector-page-tools-unpinned-container" class="vector-unpinned-container">
						
<div id="vector-page-tools" class="vector-page-tools vector-pinnable-element">
	<div
	class="vector-pinnable-header vector-page-tools-pinnable-header vector-pinnable-header-unpinned"
	data-feature-name="page-tools-pinned"
	data-pinnable-element-id="vector-page-tools"
	data-pinned-container-id="vector-page-tools-pinned-container"
	data-unpinned-container-id="vector-page-tools-unpinned-container"
>
	<div class="vector-pinnable-header-label">Tools</div>
	<button class="vector-pinnable-header-toggle-button vector-pinnable-header-pin-button" data-event-name="pinnable-header.vector-page-tools.pin">move to sidebar</button>
	<button class="vector-pinnable-header-toggle-button vector-pinnable-header-unpin-button" data-event-name="pinnable-header.vector-page-tools.unpin">hide</button>
</div>

	
<div id="p-cactions" class="vector-menu mw-portlet mw-portlet-cactions emptyPortlet vector-has-collapsible-items"  title="More options" >
	<div class="vector-menu-heading">
		Actions
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="ca-more-view" class="selected vector-more-collapsible-item mw-list-item"><a href="/wiki/Albert_Einstein"><span>Read</span></a></li><li id="ca-more-viewsource" class="vector-more-collapsible-item mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;action=edit"><span>View source</span></a></li><li id="ca-more-history" class="vector-more-collapsible-item mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;action=history"><span>View history</span></a></li>
		</ul>
		
	</div>
</div>

<div id="p-tb" class="vector-menu mw-portlet mw-portlet-tb"  >
	<div class="vector-menu-heading">
		General
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="t-whatlinkshere" class="mw-list-item"><a href="/wiki/Special:WhatLinksHere/Albert_Einstein" title="List of all English Wikipedia pages containing links to this page [j]" accesskey="j"><span>What links here</span></a></li><li id="t-recentchangeslinked" class="mw-list-item"><a href="/wiki/Special:RecentChangesLinked/Albert_Einstein" rel="nofollow" title="Recent changes in pages linked from this page [k]" accesskey="k"><span>Related changes</span></a></li><li id="t-upload" class="mw-list-item"><a href="/wiki/Wikipedia:File_Upload_Wizard" title="Upload files [u]" accesskey="u"><span>Upload file</span></a></li><li id="t-specialpages" class="mw-list-item"><a href="/wiki/Special:SpecialPages" title="A list of all special pages [q]" accesskey="q"><span>Special pages</span></a></li><li id="t-permalink" class="mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;oldid=1227307757" title="Permanent link to this revision of this page"><span>Permanent link</span></a></li><li id="t-info" class="mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;action=info" title="More information about this page"><span>Page information</span></a></li><li id="t-cite" class="mw-list-item"><a href="/w/index.php?title=Special:CiteThisPage&amp;page=Albert_Einstein&amp;id=1227307757&amp;wpFormIdentifier=titleform" title="Information on how to cite this page"><span>Cite this page</span></a></li><li id="t-urlshortener" class="mw-list-item"><a href="/w/index.php?title=Special:UrlShortener&amp;url=https%3A%2F%2Fen.wikipedia.org%2Fwiki%2FAlbert_Einstein"><span>Get shortened URL</span></a></li><li id="t-urlshortener-qrcode" class="mw-list-item"><a href="/w/index.php?title=Special:QrCode&amp;url=https%3A%2F%2Fen.wikipedia.org%2Fwiki%2FAlbert_Einstein"><span>Download QR code</span></a></li><li id="t-wikibase" class="mw-list-item"><a href="https://www.wikidata.org/wiki/Special:EntityPage/Q937" title="Structured data on this page hosted by Wikidata [g]" accesskey="g"><span>Wikidata item</span></a></li>
		</ul>
		
	</div>
</div>

<div id="p-coll-print_export" class="vector-menu mw-portlet mw-portlet-coll-print_export"  >
	<div class="vector-menu-heading">
		Print/export
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li id="coll-download-as-rl" class="mw-list-item"><a href="/w/index.php?title=Special:DownloadAsPdf&amp;page=Albert_Einstein&amp;action=show-download-screen" title="Download this page as a PDF file"><span>Download as PDF</span></a></li><li id="t-print" class="mw-list-item"><a href="/w/index.php?title=Albert_Einstein&amp;printable=yes" title="Printable version of this page [p]" accesskey="p"><span>Printable version</span></a></li>
		</ul>
		
	</div>
</div>

<div id="p-wikibase-otherprojects" class="vector-menu mw-portlet mw-portlet-wikibase-otherprojects"  >
	<div class="vector-menu-heading">
		In other projects
	</div>
	<div class="vector-menu-content">
		
		<ul class="vector-menu-content-list">
			
			<li class="wb-otherproject-link wb-otherproject-commons mw-list-item"><a href="https://commons.wikimedia.org/wiki/Albert_Einstein" hreflang="en"><span>Wikimedia Commons</span></a></li><li class="wb-otherproject-link wb-otherproject-sources mw-list-item"><a href="https://wikisource.org/wiki/Author:Albert_Einstein" hreflang="en"><span>Multilingual Wikisource</span></a></li><li class="wb-otherproject-link wb-otherproject-wikiquote mw-list-item"><a href="https://en.wikiquote.org/wiki/Albert_Einstein" hreflang="en"><span>Wikiquote</span></a></li><li class="wb-otherproject-link wb-otherproject-wikisource mw-list-item"><a href="https://en.wikisource.org/wiki/Author:Albert_Einstein" hreflang="en"><span>Wikisource</span></a></li><li class="wb-otherproject-link wb-otherproject-wikiversity mw-list-item"><a href="https://en.wikiversity.org/wiki/Albert_Einstein" hreflang="en"><span>Wikiversity</span></a></li>
		</ul>
		
	</div>
</div>

</div>

									</div>
				
	</div>
</div>

							</nav>
						</div>
					</div>
				</div>
				<div class="vector-column-end">
					<div class="vector-sticky-pinned-container">
						<nav class="vector-page-tools-landmark" aria-label="Page tools">
							<div id="vector-page-tools-pinned-container" class="vector-pinned-container">
				
							</div>
		</nav>
						<nav class="vector-appearance-landmark" aria-label="Appearance">
						</nav>
					</div>
				</div>
				<div id="bodyContent" class="vector-body" aria-labelledby="firstHeading" data-mw-ve-target-container>
					<div class="vector-body-before-content">
							<div class="mw-indicators">
		<div id="mw-indicator-good-star" class="mw-indicator"><div class="mw-parser-output"><span typeof="mw:File"><a href="/wiki/Wikipedia:Good_articles*" title="This is a good article. Click here for more information."><img alt="This is a good article. Click here for more information." src="//upload.wikimedia.org/wikipedia/en/thumb/9/94/Symbol_support_vote.svg/19px-Symbol_support_vote.svg.png" decoding="async" width="19" height="20" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/9/94/Symbol_support_vote.svg/29px-Symbol_support_vote.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/9/94/Symbol_support_vote.svg/39px-Symbol_support_vote.svg.png 2x" data-file-width="180" data-file-height="185" /></a></span></div></div>
		<div id="mw-indicator-pp-default" class="mw-indicator"><div class="mw-parser-output"><span typeof="mw:File"><a href="/wiki/Wikipedia:Protection_policy#semi" title="This article is semi-protected."><img alt="Page semi-protected" src="//upload.wikimedia.org/wikipedia/en/thumb/1/1b/Semi-protection-shackle.svg/20px-Semi-protection-shackle.svg.png" decoding="async" width="20" height="20" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/1/1b/Semi-protection-shackle.svg/30px-Semi-protection-shackle.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/1/1b/Semi-protection-shackle.svg/40px-Semi-protection-shackle.svg.png 2x" data-file-width="512" data-file-height="512" /></a></span></div></div>
		</div>

						<div id="siteSub" class="noprint">From Wikipedia, the free encyclopedia</div>
					</div>
					<div id="contentSub"><div id="mw-content-subtitle"></div></div>
					
					
					<div id="mw-content-text" class="mw-body-content"><div class="mw-content-ltr mw-parser-output" lang="en" dir="ltr"><div class="shortdescription nomobile noexcerpt noprint searchaux" style="display:none">German-born physicist (1879–1955)</div>
<style data-mw-deduplicate="TemplateStyles:r1033289096">.mw-parser-output .hatnote{font-style:italic}.mw-parser-output div.hatnote{padding-left:1.6em;margin-bottom:0.5em}.mw-parser-output .hatnote i{font-style:normal}.mw-parser-output .hatnote+link+.hatnote{margin-top:-0.5em}</style><div role="note" class="hatnote navigation-not-searchable">"Einstein" redirects here. For other uses, see <a href="/wiki/Einstein_(disambiguation)" class="mw-disambig" title="Einstein (disambiguation)">Einstein (disambiguation)</a> and <a href="/wiki/Albert_Einstein_(disambiguation)" class="mw-disambig" title="Albert Einstein (disambiguation)">Albert Einstein (disambiguation)</a>.</div>
<p class="mw-empty-elt">



</p>
<style data-mw-deduplicate="TemplateStyles:r1218072481">.mw-parser-output .infobox-subbox{padding:0;border:none;margin:-3px;width:auto;min-width:100%;font-size:100%;clear:none;float:none;background-color:transparent}.mw-parser-output .infobox-3cols-child{margin:auto}.mw-parser-output .infobox .navbar{font-size:100%}body.skin-minerva .mw-parser-output .infobox-header,body.skin-minerva .mw-parser-output .infobox-subheader,body.skin-minerva .mw-parser-output .infobox-above,body.skin-minerva .mw-parser-output .infobox-title,body.skin-minerva .mw-parser-output .infobox-image,body.skin-minerva .mw-parser-output .infobox-full-data,body.skin-minerva .mw-parser-output .infobox-below{text-align:center}html.skin-theme-clientpref-night .mw-parser-output .infobox-full-data div{background:#1f1f23!important;color:#f8f9fa}@media(prefers-color-scheme:dark){html.skin-theme-clientpref-os .mw-parser-output .infobox-full-data div{background:#1f1f23!important;color:#f8f9fa}}</style><table class="infobox biography vcard"><tbody><tr><th colspan="2" class="infobox-above"><div class="fn">Albert Einstein</div></th></tr><tr><td colspan="2" class="infobox-image"><span class="mw-default-size" typeof="mw:File/Frameless"><a href="/wiki/File:Einstein_1921_by_F_Schmutzer_-_restoration.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/220px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg" decoding="async" width="220" height="289" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/330px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/440px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg 2x" data-file-width="2523" data-file-height="3313" /></a></span><div class="infobox-caption">Einstein in 1921</div></td></tr><tr><th scope="row" class="infobox-label">Born</th><td class="infobox-data"><span style="display:none">(<span class="bday">1879-03-14</span>)</span>14 March 1879<br /><div style="display:inline" class="birthplace"><a href="/wiki/Ulm" title="Ulm">Ulm</a>, Kingdom of Württemberg, German Empire</div></td></tr><tr><th scope="row" class="infobox-label">Died</th><td class="infobox-data">18 April 1955<span style="display:none">(1955-04-18)</span> (aged&#160;76)<br /><div style="display:inline" class="deathplace"><a href="/wiki/Princeton,_New_Jersey" title="Princeton, New Jersey">Princeton, New Jersey</a>, U.S.</div></td></tr><tr><th scope="row" class="infobox-label">Citizenship</th><td class="infobox-data category"><style data-mw-deduplicate="TemplateStyles:r1126788409">.mw-parser-output .plainlist ol,.mw-parser-output .plainlist ul{line-height:inherit;list-style:none;margin:0;padding:0}.mw-parser-output .plainlist ol li,.mw-parser-output .plainlist ul li{margin-bottom:0}</style><div class="plainlist" style="margin-left:1em;text-indent:-1em;">
<ul><li><a href="/wiki/Kingdom_of_W%C3%BCrttemberg" title="Kingdom of Württemberg">Kingdom of Württemberg</a>, part of the German Empire (until 1896)<sup id="cite_ref-GEcitizen_4-0" class="reference"><a href="#cite_note-GEcitizen-4">&#91;note 1&#93;</a></sup></li>
<li><a href="/wiki/Statelessness" title="Statelessness">Stateless</a> (1896–1901)</li>
<li><a href="/wiki/Switzerland" title="Switzerland">Switzerland</a> (1901–1955)</li>
<li><a href="/wiki/Cisleithania" title="Cisleithania">Austria</a>, part of the <a href="/wiki/Austro-Hungarian_Empire" class="mw-redirect" title="Austro-Hungarian Empire">Austro-Hungarian Empire</a> (1911–1912)</li>
<li><a href="/wiki/Kingdom_of_Prussia" title="Kingdom of Prussia">Kingdom of Prussia</a>, part of the German Empire (1914–1918)<sup id="cite_ref-GEcitizen_4-1" class="reference"><a href="#cite_note-GEcitizen-4">&#91;note 1&#93;</a></sup></li>
<li><a href="/wiki/Free_State_of_Prussia" title="Free State of Prussia">Free State of Prussia</a> (<a href="/wiki/Weimar_Republic" title="Weimar Republic">Weimar Republic</a>, 1918–1933)<sup id="cite_ref-GEcitizen_4-2" class="reference"><a href="#cite_note-GEcitizen-4">&#91;note 1&#93;</a></sup></li>
<li><a href="/wiki/Citizenship_of_the_United_States" title="Citizenship of the United States">United States</a> (1940–1955)</li></ul>
</div></td></tr><tr><th scope="row" class="infobox-label">Education</th><td class="infobox-data"><a href="/wiki/ETH_Zurich" title="ETH Zurich">ETH Zurich</a> (Dipl., 1900)<br /><a href="/wiki/University_of_Zurich" title="University of Zurich">University of Zurich</a> (<a href="/wiki/PhD" class="mw-redirect" title="PhD">PhD</a>, 1905)</td></tr><tr><th scope="row" class="infobox-label">Known&#160;for</th><td class="infobox-data"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409"><div class="plainlist" style="margin-left:1em;text-indent:-1em;">
<ul><li><a href="/wiki/General_relativity" title="General relativity">General relativity</a></li>
<li><a href="/wiki/Special_relativity" title="Special relativity">Special relativity</a></li>
<li><a href="/wiki/Photoelectric_effect" title="Photoelectric effect">Photoelectric effect</a></li>
<li><a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence"><i>E</i>=<i>mc</i><sup>2</sup> (mass–energy equivalence)</a></li>
<li><a href="/wiki/Planck%E2%80%93Einstein_relation" class="mw-redirect" title="Planck–Einstein relation"><i>E</i>=<i>hf</i> (Planck–Einstein relation)</a></li>
<li>Theory of <a href="/wiki/Brownian_motion" title="Brownian motion">Brownian motion</a></li>
<li><a href="/wiki/Einstein_field_equations" title="Einstein field equations">Einstein field equations</a></li>
<li><a href="/wiki/Bose%E2%80%93Einstein_statistics" title="Bose–Einstein statistics">Bose–Einstein statistics</a></li>
<li><a href="/wiki/Bose%E2%80%93Einstein_condensate" title="Bose–Einstein condensate">Bose–Einstein condensate</a></li>
<li><a href="/wiki/Gravitational_wave" title="Gravitational wave">Gravitational wave</a></li>
<li><a href="/wiki/Cosmological_constant" title="Cosmological constant">Cosmological constant</a></li>
<li><a href="/wiki/Unified_field_theory" title="Unified field theory">Unified field theory</a></li>
<li><a href="/wiki/EPR_paradox" class="mw-redirect" title="EPR paradox">EPR paradox</a></li>
<li><a href="/wiki/Ensemble_interpretation" title="Ensemble interpretation">Ensemble interpretation</a></li>
<li><a href="/wiki/List_of_things_named_after_Albert_Einstein" title="List of things named after Albert Einstein">List of other concepts</a></li></ul>
</div></td></tr><tr><th scope="row" class="infobox-label">Spouses</th><td class="infobox-data"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409"><div class="plainlist">
<ul><li><style data-mw-deduplicate="TemplateStyles:r1151524712">.mw-parser-output .marriage-line-margin2px{line-height:0;margin-bottom:-2px}.mw-parser-output .marriage-line-margin3px{line-height:0;margin-bottom:-3px}.mw-parser-output .marriage-display-ws{display:inline;white-space:nowrap}</style></li></ul>
<div class="marriage-display-ws"><div style="display:inline-block;line-height:normal;margin-top:1px;white-space:normal;"><a href="/wiki/Mileva_Mari%C4%87" title="Mileva Marić">Mileva Marić</a></div>
   <div class="marriage-line-margin2px">&#8203;</div>&#32;<div style="display:inline-block;margin-bottom:1px;">&#8203;</div>&#40;<abbr title="married">m.</abbr>&#160;1903&#59;&#32;<abbr title="divorced">div.</abbr>&#160;1919&#41;<wbr />&#8203;</div>
<ul><li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1151524712"></li></ul>
<div class="marriage-display-ws"><div style="display:inline-block;line-height:normal;margin-top:1px;white-space:normal;"><a href="/wiki/Elsa_L%C3%B6wenthal" class="mw-redirect" title="Elsa Löwenthal">Elsa Löwenthal</a></div>
   <div class="marriage-line-margin2px">&#8203;</div>&#32;<div style="display:inline-block;margin-bottom:1px;">&#8203;</div>&#40;<abbr title="married">m.</abbr>&#160;1919&#59;&#32;died&#160;1936&#41;<wbr />&#8203;</div>
</div></td></tr><tr><th scope="row" class="infobox-label">Children</th><td class="infobox-data"><style data-mw-deduplicate="TemplateStyles:r1129693374">.mw-parser-output .hlist dl,.mw-parser-output .hlist ol,.mw-parser-output .hlist ul{margin:0;padding:0}.mw-parser-output .hlist dd,.mw-parser-output .hlist dt,.mw-parser-output .hlist li{margin:0;display:inline}.mw-parser-output .hlist.inline,.mw-parser-output .hlist.inline dl,.mw-parser-output .hlist.inline ol,.mw-parser-output .hlist.inline ul,.mw-parser-output .hlist dl dl,.mw-parser-output .hlist dl ol,.mw-parser-output .hlist dl ul,.mw-parser-output .hlist ol dl,.mw-parser-output .hlist ol ol,.mw-parser-output .hlist ol ul,.mw-parser-output .hlist ul dl,.mw-parser-output .hlist ul ol,.mw-parser-output .hlist ul ul{display:inline}.mw-parser-output .hlist .mw-empty-li{display:none}.mw-parser-output .hlist dt::after{content:": "}.mw-parser-output .hlist dd::after,.mw-parser-output .hlist li::after{content:" · ";font-weight:bold}.mw-parser-output .hlist dd:last-child::after,.mw-parser-output .hlist dt:last-child::after,.mw-parser-output .hlist li:last-child::after{content:none}.mw-parser-output .hlist dd dd:first-child::before,.mw-parser-output .hlist dd dt:first-child::before,.mw-parser-output .hlist dd li:first-child::before,.mw-parser-output .hlist dt dd:first-child::before,.mw-parser-output .hlist dt dt:first-child::before,.mw-parser-output .hlist dt li:first-child::before,.mw-parser-output .hlist li dd:first-child::before,.mw-parser-output .hlist li dt:first-child::before,.mw-parser-output .hlist li li:first-child::before{content:" (";font-weight:normal}.mw-parser-output .hlist dd dd:last-child::after,.mw-parser-output .hlist dd dt:last-child::after,.mw-parser-output .hlist dd li:last-child::after,.mw-parser-output .hlist dt dd:last-child::after,.mw-parser-output .hlist dt dt:last-child::after,.mw-parser-output .hlist dt li:last-child::after,.mw-parser-output .hlist li dd:last-child::after,.mw-parser-output .hlist li dt:last-child::after,.mw-parser-output .hlist li li:last-child::after{content:")";font-weight:normal}.mw-parser-output .hlist ol{counter-reset:listitem}.mw-parser-output .hlist ol>li{counter-increment:listitem}.mw-parser-output .hlist ol>li::before{content:" "counter(listitem)"\\a0 "}.mw-parser-output .hlist dd ol>li:first-child::before,.mw-parser-output .hlist dt ol>li:first-child::before,.mw-parser-output .hlist li ol>li:first-child::before{content:" ("counter(listitem)"\\a0 "}</style><div class="hlist">
<ul><li><a href="/wiki/Lieserl_Einstein" class="mw-redirect" title="Lieserl Einstein">Lieserl</a></li>
<li><a href="/wiki/Hans_Albert_Einstein" title="Hans Albert Einstein">Hans Albert</a></li>
<li><a href="/wiki/Einstein_family#Eduard_&quot;Tete&quot;_Einstein_(Albert&#39;s_second_son)" title="Einstein family">Eduard "Tete"</a></li></ul>
</div></td></tr><tr><th scope="row" class="infobox-label">Awards</th><td class="infobox-data"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409"><div class="plainlist" style="margin-left:1em;text-indent:-1em;">
<ul><li><a href="/wiki/Barnard_Medal_for_Meritorious_Service_to_Science" title="Barnard Medal for Meritorious Service to Science">Barnard Medal</a> (1920)</li>
<li><a href="/wiki/Nobel_Prize_in_Physics" title="Nobel Prize in Physics">Nobel Prize in Physics</a> (1921)</li>
<li><a href="/wiki/Matteucci_Medal" title="Matteucci Medal">Matteucci Medal</a> (1921)</li>
<li><a href="/wiki/ForMemRS" class="mw-redirect" title="ForMemRS">ForMemRS</a> (1921)<sup id="cite_ref-frs_1-0" class="reference"><a href="#cite_note-frs-1">&#91;1&#93;</a></sup></li>
<li><a href="/wiki/Copley_Medal" title="Copley Medal">Copley Medal</a> (1925)<sup id="cite_ref-frs_1-1" class="reference"><a href="#cite_note-frs-1">&#91;1&#93;</a></sup></li>
<li><a href="/wiki/Gold_Medal_of_the_Royal_Astronomical_Society" title="Gold Medal of the Royal Astronomical Society">Gold Medal of the Royal Astronomical Society</a> (1926)<sup id="cite_ref-2" class="reference"><a href="#cite_note-2">&#91;2&#93;</a></sup></li>
<li><a href="/wiki/Max_Planck_Medal" title="Max Planck Medal">Max Planck Medal</a> (1929)</li>
<li><a href="/wiki/Member_of_the_National_Academy_of_Sciences" title="Member of the National Academy of Sciences">Member of the National Academy of Sciences</a> (1942)<sup id="cite_ref-3" class="reference"><a href="#cite_note-3">&#91;3&#93;</a></sup></li>
<li><a href="/wiki/Time_100:_The_Most_Important_People_of_the_Century" title="Time 100: The Most Important People of the Century"><i>Time</i> Person of the Century</a> (1999)</li></ul>
</div></td></tr><tr><td colspan="2" class="infobox-full-data"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1218072481"><b>Scientific career</b></td></tr><tr><th scope="row" class="infobox-label">Fields</th><td class="infobox-data category"><a href="/wiki/Physics" title="Physics">Physics</a></td></tr><tr><th scope="row" class="infobox-label">Institutions</th><td class="infobox-data"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409"><div class="plainlist" style="margin-left:1em;text-indent:-1em;">
<ul><li><a href="/wiki/University_of_Bern" title="University of Bern">University of Bern</a> (1908–1909)</li>
<li><a href="/wiki/University_of_Zurich" title="University of Zurich">University of Zurich</a> (1909–1911)</li>
<li><a href="/wiki/Charles_University_in_Prague" class="mw-redirect" title="Charles University in Prague">Charles University in Prague</a> (1911–1912)</li>
<li><a href="/wiki/ETH_Zurich" title="ETH Zurich">ETH Zurich</a> (1912–1914)</li>
<li><a href="/wiki/Prussian_Academy_of_Sciences" title="Prussian Academy of Sciences">Prussian Academy of Sciences</a> (1914–1933)</li>
<li><a href="/wiki/Humboldt_University_of_Berlin" title="Humboldt University of Berlin">Humboldt University of Berlin</a> (1914–1933)</li>
<li><a href="/wiki/Kaiser_Wilhelm_Institute" class="mw-redirect" title="Kaiser Wilhelm Institute">Kaiser Wilhelm Institute</a> (director, 1917–1933)</li>
<li><a href="/wiki/German_Physical_Society" title="German Physical Society">German Physical Society</a> (president, 1916–1918)</li>
<li><a href="/wiki/Leiden_University" title="Leiden University">Leiden University</a> (visits, 1920)</li>
<li><a href="/wiki/Institute_for_Advanced_Study" title="Institute for Advanced Study">Institute for Advanced Study</a> (1933–1955)</li>
<li><a href="/wiki/California_Institute_of_Technology" title="California Institute of Technology">California Institute of Technology</a> (visits, 1931–1933)</li>
<li><a href="/wiki/University_of_Oxford" title="University of Oxford">University of Oxford</a> (visits, 1931–1933)</li>
<li><a href="/wiki/Brandeis_University" title="Brandeis University">Brandeis University</a> (director, 1946–1947)</li></ul>
</div></td></tr><tr><th scope="row" class="infobox-label"><a href="/wiki/Thesis" title="Thesis">Thesis</a></th><td class="infobox-data"><i><a rel="nofollow" class="external text" href="http://e-collection.library.ethz.ch/eserv/eth:30378/eth-30378-01.pdf"><span title="German-language text"><i lang="de">Eine neue Bestimmung der Moleküldimensionen</i></span> (A New Determination of Molecular Dimensions)</a></i>&#160;<span style="font-size:97%;">(1905)</span></td></tr><tr><th scope="row" class="infobox-label"><a href="/wiki/Doctoral_advisor" title="Doctoral advisor">Doctoral advisor</a></th><td class="infobox-data"><a href="/wiki/Alfred_Kleiner" title="Alfred Kleiner">Alfred Kleiner</a></td></tr><tr><th scope="row" class="infobox-label">Other&#160;academic advisors</th><td class="infobox-data"><a href="/wiki/Heinrich_Friedrich_Weber" title="Heinrich Friedrich Weber">Heinrich Friedrich Weber</a></td></tr><tr style="display:none"><td colspan="2">
</td></tr><tr><td colspan="2" class="infobox-full-data"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1218072481"></td></tr><tr><td colspan="2" class="infobox-full-data"><style data-mw-deduplicate="TemplateStyles:r1217611005">.mw-parser-output .side-box{margin:4px 0;box-sizing:border-box;border:1px solid #aaa;font-size:88%;line-height:1.25em;background-color:#f9f9f9;display:flow-root}.mw-parser-output .side-box-abovebelow,.mw-parser-output .side-box-text{padding:0.25em 0.9em}.mw-parser-output .side-box-image{padding:2px 0 2px 0.9em;text-align:center}.mw-parser-output .side-box-imageright{padding:2px 0.9em 2px 0;text-align:center}@media(min-width:500px){.mw-parser-output .side-box-flex{display:flex;align-items:center}.mw-parser-output .side-box-text{flex:1;min-width:0}}@media(min-width:720px){.mw-parser-output .side-box{width:238px}.mw-parser-output .side-box-right{clear:right;float:right;margin-left:1em}.mw-parser-output .side-box-left{margin-right:1em}}</style><style data-mw-deduplicate="TemplateStyles:r1096940132">.mw-parser-output .listen .side-box-text{line-height:1.1em}.mw-parser-output .listen-plain{border:none;background:transparent}.mw-parser-output .listen-embedded{width:100%;margin:0;border-width:1px 0 0 0;background:transparent}.mw-parser-output .listen-header{padding:2px}.mw-parser-output .listen-embedded .listen-header{padding:2px 0}.mw-parser-output .listen-file-header{padding:4px 0}.mw-parser-output .listen .description{padding-top:2px}.mw-parser-output .listen .mw-tmh-player{max-width:100%}@media(max-width:719px){.mw-parser-output .listen{clear:both}}@media(min-width:720px){.mw-parser-output .listen:not(.listen-noimage){width:320px}.mw-parser-output .listen-left{overflow:visible;float:left}.mw-parser-output .listen-center{float:none;margin-left:auto;margin-right:auto}}</style><div class="side-box side-box-left listen noprint listen-embedded listen-noimage listen-center"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409">
<div class="side-box-flex">
<div class="side-box-text plainlist"><div class="haudio">
<div class="listen-file-header"><a href="/wiki/File:03_ALBERT_EINSTEIN.ogg" title="File:03 ALBERT EINSTEIN.ogg">Albert Einstein\'s voice</a></div>
<div><span typeof="mw:File"><span><audio id="mwe_player_0" controls="" preload="none" class="mw-file-element" width="215" style="width:215px;" data-durationhint="91" data-mwtitle="03_ALBERT_EINSTEIN.ogg" data-mwprovider="wikimediacommons"><source src="//upload.wikimedia.org/wikipedia/commons/4/46/03_ALBERT_EINSTEIN.ogg" type="audio/ogg; codecs=&quot;vorbis&quot;" data-width="0" data-height="0" /><source src="//upload.wikimedia.org/wikipedia/commons/transcoded/4/46/03_ALBERT_EINSTEIN.ogg/03_ALBERT_EINSTEIN.ogg.mp3" type="audio/mpeg" data-transcodekey="mp3" data-width="0" data-height="0" /></audio></span></span></div>
<div class="description">Opening of Einstein\'s speech (11 April 1943) for the United Jewish Appeal (recording by Radio Universidad Nacional de La Plata, Argentina</div></div></div></div>
</div></td></tr><tr><th colspan="2" class="infobox-header">Signature</th></tr><tr><td colspan="2" class="infobox-full-data"><span class="infobox-signature skin-invert" typeof="mw:File"><a href="/wiki/File:Albert_Einstein_signature_1934.svg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/d/d7/Albert_Einstein_signature_1934.svg/150px-Albert_Einstein_signature_1934.svg.png" decoding="async" width="150" height="23" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/d/d7/Albert_Einstein_signature_1934.svg/225px-Albert_Einstein_signature_1934.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/d/d7/Albert_Einstein_signature_1934.svg/300px-Albert_Einstein_signature_1934.svg.png 2x" data-file-width="585" data-file-height="88" /></a></span></td></tr><tr style="display:none"><td colspan="2">
</td></tr></tbody></table>
<p><b>Albert Einstein</b> (<span class="rt-commentedText nowrap"><span class="IPA nopopups noexcerpt" lang="en-fonipa"><a href="/wiki/Help:IPA/English" title="Help:IPA/English">/<span style="border-bottom:1px dotted"><span title="/ˈ/: primary stress follows">ˈ</span><span title="/aɪ/: &#39;i&#39; in &#39;tide&#39;">aɪ</span><span title="&#39;n&#39; in &#39;nigh&#39;">n</span><span title="&#39;s&#39; in &#39;sigh&#39;">s</span><span title="&#39;t&#39; in &#39;tie&#39;">t</span><span title="/aɪ/: &#39;i&#39; in &#39;tide&#39;">aɪ</span><span title="&#39;n&#39; in &#39;nigh&#39;">n</span></span>/</a></span></span> <a href="/wiki/Help:Pronunciation_respelling_key" title="Help:Pronunciation respelling key"><i title="English pronunciation respelling"><span style="font-size:90%">EYEN</span>-styne</i></a>;<sup id="cite_ref-NDxay_5-0" class="reference"><a href="#cite_note-NDxay-5">&#91;4&#93;</a></sup> <style data-mw-deduplicate="TemplateStyles:r1177148991">.mw-parser-output .IPA-label-small{font-size:85%}.mw-parser-output .references .IPA-label-small,.mw-parser-output .infobox .IPA-label-small,.mw-parser-output .navbox .IPA-label-small{font-size:100%}</style><span class="IPA-label IPA-label-small">German:</span> <span class="IPA nowrap" lang="de-Latn-fonipa"><a href="/wiki/Help:IPA/Standard_German" title="Help:IPA/Standard German">&#91;ˈalbɛɐt<span class="wrap"> </span>ˈʔaɪnʃtaɪn&#93;</a></span> <span class="noprint"><span class="ext-phonos skin-invert"><span data-nosnippet="" id="ooui-php-1" class="ext-phonos-PhonosButton noexcerpt ext-phonos-PhonosButton-emptylabel oo-ui-widget oo-ui-widget-enabled oo-ui-buttonElement oo-ui-buttonElement-frameless oo-ui-iconElement oo-ui-buttonWidget" data-ooui="{&quot;_&quot;:&quot;mw.Phonos.PhonosButton&quot;,&quot;href&quot;:&quot;\\/\\/upload.wikimedia.org\\/wikipedia\\/commons\\/transcoded\\/7\\/77\\/De-Albert_Einstein.oga\\/De-Albert_Einstein.oga.mp3&quot;,&quot;rel&quot;:[&quot;nofollow&quot;],&quot;framed&quot;:false,&quot;icon&quot;:&quot;volumeUp&quot;,&quot;data&quot;:{&quot;ipa&quot;:&quot;&quot;,&quot;text&quot;:&quot;&quot;,&quot;lang&quot;:&quot;en&quot;,&quot;wikibase&quot;:&quot;&quot;,&quot;file&quot;:&quot;De-Albert Einstein.oga&quot;},&quot;classes&quot;:[&quot;ext-phonos-PhonosButton&quot;,&quot;noexcerpt&quot;,&quot;ext-phonos-PhonosButton-emptylabel&quot;]}"><a role="button" tabindex="0" href="//upload.wikimedia.org/wikipedia/commons/transcoded/7/77/De-Albert_Einstein.oga/De-Albert_Einstein.oga.mp3" rel="nofollow" aria-label="Play audio" title="Play audio" class="oo-ui-buttonElement-button"><span class="oo-ui-iconElement-icon oo-ui-icon-volumeUp"></span><span class="oo-ui-labelElement-label"></span><span class="oo-ui-indicatorElement-indicator oo-ui-indicatorElement-noIndicator"></span></a></span><sup class="ext-phonos-attribution noexcerpt navigation-not-searchable"><a href="/wiki/File:De-Albert_Einstein.oga" title="File:De-Albert Einstein.oga">ⓘ</a></sup></span></span>; 14 March 1879 – 18 April 1955) was a German-born <a href="/wiki/Theoretical_physicist" class="mw-redirect" title="Theoretical physicist">theoretical physicist</a> who is widely held to be one of the greatest and most influential scientists of all time. Best known for developing the <a href="/wiki/Theory_of_relativity" title="Theory of relativity">theory of relativity</a>, Einstein also made important contributions to <a href="/wiki/Quantum_mechanics" title="Quantum mechanics">quantum mechanics</a>, and was thus a central figure in the revolutionary reshaping of the scientific understanding of nature that <a href="/wiki/Modern_physics" title="Modern physics">modern physics</a> accomplished in the first decades of the twentieth century.<sup id="cite_ref-frs_1-2" class="reference"><a href="#cite_note-frs-1">&#91;1&#93;</a></sup><sup id="cite_ref-YangHamilton2010_6-0" class="reference"><a href="#cite_note-YangHamilton2010-6">&#91;5&#93;</a></sup> His <a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence">mass–energy equivalence</a> formula <span class="texhtml"><a href="/wiki/Mass%E2%80%93energy_equivalence#Mass–velocity_relationship" title="Mass–energy equivalence"><i>E</i> = <i>mc</i><sup>2</sup></a></span>, which arises from relativity theory, has been called "the world\'s most famous equation".<sup id="cite_ref-LnLVo_7-0" class="reference"><a href="#cite_note-LnLVo-7">&#91;6&#93;</a></sup> He received the 1921 <a href="/wiki/Nobel_Prize_in_Physics" title="Nobel Prize in Physics">Nobel Prize in Physics</a> "for his services to theoretical physics, and especially for his discovery of the law of the <a href="/wiki/Photoelectric_effect" title="Photoelectric effect">photoelectric effect</a>",<sup id="cite_ref-Nobel_Prize_8-0" class="reference"><a href="#cite_note-Nobel_Prize-8">&#91;7&#93;</a></sup> a pivotal step in the development of quantum theory. His work is also known for its influence on the <a href="/wiki/Philosophy_of_science" title="Philosophy of science">philosophy of science</a>.<sup id="cite_ref-xZQWt_9-0" class="reference"><a href="#cite_note-xZQWt-9">&#91;8&#93;</a></sup><sup id="cite_ref-3UiiT_10-0" class="reference"><a href="#cite_note-3UiiT-10">&#91;9&#93;</a></sup>
</p><p>Born in the <a href="/wiki/German_Empire" title="German Empire">German Empire</a>, Einstein moved to Switzerland in 1895, forsaking his German citizenship (as a subject of the <a href="/wiki/Kingdom_of_W%C3%BCrttemberg" title="Kingdom of Württemberg">Kingdom of Württemberg</a>)<sup id="cite_ref-GEcitizen_4-3" class="reference"><a href="#cite_note-GEcitizen-4">&#91;note 1&#93;</a></sup> the following year. In 1897, at the age of seventeen, he enrolled in the mathematics and physics teaching diploma program at the Swiss <a href="/wiki/ETH_Zurich" title="ETH Zurich">federal polytechnic school</a> in <a href="/wiki/Z%C3%BCrich" title="Zürich">Zürich</a>, graduating in 1900. In 1901, he acquired Swiss citizenship, which he kept for the rest of his life. In 1903, he secured a permanent position at the <a href="/wiki/Swiss_Patent_Office" class="mw-redirect" title="Swiss Patent Office">Swiss Patent Office</a> in Bern. In 1905, he submitted a successful PhD dissertation to the <a href="/wiki/University_of_Zurich" title="University of Zurich">University of Zurich</a>. In 1914, he moved to <a href="/wiki/Berlin" title="Berlin">Berlin</a> in order to join the <a href="/wiki/Prussian_Academy_of_Sciences" title="Prussian Academy of Sciences">Prussian Academy of Sciences</a> and the <a href="/wiki/Humboldt_University_of_Berlin" title="Humboldt University of Berlin">Humboldt University of Berlin</a>. In 1917, he became director of the <a href="/wiki/Kaiser_Wilhelm_Institute_for_Physics" class="mw-redirect" title="Kaiser Wilhelm Institute for Physics">Kaiser Wilhelm Institute for Physics</a>; he also became a German citizen again, this time as a subject of the <a href="/wiki/Kingdom_of_Prussia" title="Kingdom of Prussia">Kingdom of Prussia</a>.<sup id="cite_ref-GEcitizen_4-4" class="reference"><a href="#cite_note-GEcitizen-4">&#91;note 1&#93;</a></sup>
</p><p>In 1933, while he was visiting the United States, <a href="/wiki/Adolf_Hitler%27s_rise_to_power" title="Adolf Hitler&#39;s rise to power">Adolf Hitler came to power</a> in Germany. Horrified by the <a href="/wiki/Nazi_Germany" title="Nazi Germany">Nazi</a> "<a href="/wiki/Anti-Jewish_legislation_in_pre-war_Nazi_Germany" title="Anti-Jewish legislation in pre-war Nazi Germany">war of extermination</a>" against his fellow Jews,<sup id="cite_ref-zE9Bz_11-0" class="reference"><a href="#cite_note-zE9Bz-11">&#91;10&#93;</a></sup> Einstein decided to remain in the US, and was granted <a href="/wiki/American_citizen" class="mw-redirect" title="American citizen">American citizenship</a> in 1940.<sup id="cite_ref-BoyerDubofsky2001_12-0" class="reference"><a href="#cite_note-BoyerDubofsky2001-12">&#91;11&#93;</a></sup> On the eve of <a href="/wiki/World_War_II" title="World War II">World War II</a>, he endorsed <a href="/wiki/Einstein%E2%80%93Szilard_letter" title="Einstein–Szilard letter">a letter</a> to President <a href="/wiki/Franklin_D._Roosevelt" title="Franklin D. Roosevelt">Franklin D. Roosevelt</a> alerting him to the potential <a href="/wiki/German_nuclear_weapons_program" class="mw-redirect" title="German nuclear weapons program">German nuclear weapons program</a> and recommending that the US begin <a href="/wiki/Manhattan_Project" title="Manhattan Project">similar research</a>. Einstein supported the <a href="/wiki/Allies_of_World_War_II" title="Allies of World War II">Allies</a> but generally viewed the idea of <a href="/wiki/Nuclear_weapon" title="Nuclear weapon">nuclear weapons</a> with great dismay.<sup id="cite_ref-13" class="reference"><a href="#cite_note-13">&#91;12&#93;</a></sup>
</p><p>In 1905, sometimes described as his <i><a href="/wiki/Annus_mirabilis" title="Annus mirabilis">annus mirabilis</a></i> (miracle year), Einstein published <a href="/wiki/Annus_mirabilis_papers" title="Annus mirabilis papers">four groundbreaking papers</a>.<sup id="cite_ref-FOOTNOTEGalison2000377_14-0" class="reference"><a href="#cite_note-FOOTNOTEGalison2000377-14">&#91;13&#93;</a></sup> These outlined a theory of the photoelectric effect, explained <a href="/wiki/Brownian_motion" title="Brownian motion">Brownian motion</a>, introduced his <a href="/wiki/Special_theory_of_relativity" class="mw-redirect" title="Special theory of relativity">special theory of relativity</a>—a theory which addressed the inability of <a href="/wiki/Classical_mechanics" title="Classical mechanics">classical mechanics</a> to account satisfactorily for the behavior of the <a href="/wiki/Electromagnetic_field" title="Electromagnetic field">electromagnetic field</a>—and demonstrated that if the special theory is correct, mass and energy are equivalent to each other. In 1915, he proposed a <a href="/wiki/General_theory_of_relativity" class="mw-redirect" title="General theory of relativity">general theory of relativity</a> that extended his system of mechanics to incorporate <a href="/wiki/Gravitation" class="mw-redirect" title="Gravitation">gravitation</a>. A cosmological paper that he published the following year laid out the implications of general relativity for the modeling of the structure and evolution of the <a href="/wiki/Universe" title="Universe">universe</a> as a whole.<sup id="cite_ref-Nobel_15-0" class="reference"><a href="#cite_note-Nobel-15">&#91;14&#93;</a></sup><sup id="cite_ref-NYT-20151124_16-0" class="reference"><a href="#cite_note-NYT-20151124-16">&#91;15&#93;</a></sup> The middle part of his career also saw him making important contributions to <a href="/wiki/Statistical_mechanics" title="Statistical mechanics">statistical mechanics</a> and quantum theory. Especially notable was his work on the quantum physics of <a href="/wiki/Radiation" title="Radiation">radiation</a>, in which light consists of particles, subsequently called <a href="/wiki/Photon" title="Photon">photons</a>. With the Indian physicist <a href="/wiki/Satyendra_Nath_Bose" title="Satyendra Nath Bose">Satyendra Nath Bose</a>, he laid the groundwork for <a href="/wiki/Bose-Einstein_statistics" class="mw-redirect" title="Bose-Einstein statistics">Bose-Einstein statistics</a>. For much of the last phase of his academic life, Einstein worked on two endeavors that proved ultimately unsuccessful. First, he advocated against quantum theory\'s introduction of fundamental randomness into science\'s picture of the world, objecting that "God does not play dice".<sup id="cite_ref-17" class="reference"><a href="#cite_note-17">&#91;16&#93;</a></sup> Second, he attempted to devise a <a href="/wiki/Unified_field_theory" title="Unified field theory">unified field theory</a> by generalizing his geometric theory of gravitation to include <a href="/wiki/Electromagnetism" title="Electromagnetism">electromagnetism</a> too. As a result, he became increasingly isolated from the mainstream of modern physics. 
</p><p>In a 1999 poll of 130 leading physicists worldwide by the British journal <i><a href="/wiki/Physics_World" title="Physics World">Physics World</a></i>, Einstein was ranked the greatest physicist of all time.<sup id="cite_ref-18" class="reference"><a href="#cite_note-18">&#91;17&#93;</a></sup> His intellectual achievements and originality have made the word <i>Einstein</i> broadly synonymous with <i>genius</i>.<sup id="cite_ref-wordnetweb.princeton.edu_19-0" class="reference"><a href="#cite_note-wordnetweb.princeton.edu-19">&#91;18&#93;</a></sup>
</p>
<meta property="mw:PageProp/toc" />
<h2><span class="mw-headline" id="Life_and_career">Life and career</span></h2>
<h3><span id="Childhood.2C_youth_and_education"></span><span class="mw-headline" id="Childhood,_youth_and_education">Childhood, youth and education</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">See also: <a href="/wiki/Einstein_family" title="Einstein family">Einstein family</a></div>
<figure class="mw-default-size mw-halign-left" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_at_the_age_of_three_(1882).jpg" class="mw-file-description"><img alt="A young boy with short hair and a round face, wearing a white collar and large bow, with vest, coat, skirt, and high boots. He is leaning against an ornate chair." src="//upload.wikimedia.org/wikipedia/commons/thumb/f/fb/Albert_Einstein_at_the_age_of_three_%281882%29.jpg/170px-Albert_Einstein_at_the_age_of_three_%281882%29.jpg" decoding="async" width="170" height="246" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/f/fb/Albert_Einstein_at_the_age_of_three_%281882%29.jpg/255px-Albert_Einstein_at_the_age_of_three_%281882%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/f/fb/Albert_Einstein_at_the_age_of_three_%281882%29.jpg/340px-Albert_Einstein_at_the_age_of_three_%281882%29.jpg 2x" data-file-width="414" data-file-height="600" /></a><figcaption>Einstein in 1882, age&#160;3</figcaption></figure>
<p>Albert Einstein was born in <a href="/wiki/Ulm" title="Ulm">Ulm</a>,<sup id="cite_ref-Bio_20-0" class="reference"><a href="#cite_note-Bio-20">&#91;19&#93;</a></sup> in the Kingdom of Württemberg in the German Empire, on 14 March 1879.<sup id="cite_ref-21" class="reference"><a href="#cite_note-21">&#91;20&#93;</a></sup><sup id="cite_ref-22" class="reference"><a href="#cite_note-22">&#91;21&#93;</a></sup> His parents, secular <a href="/wiki/Ashkenazi_Jews" title="Ashkenazi Jews">Ashkenazi Jews</a>, were <a href="/wiki/Hermann_Einstein" class="mw-redirect" title="Hermann Einstein">Hermann Einstein</a>, a salesman and engineer, and <a href="/wiki/Pauline_Koch" class="mw-redirect" title="Pauline Koch">Pauline Koch</a>. In 1880, the family moved to <a href="/wiki/Munich" title="Munich">Munich</a>\'s borough of <a href="/wiki/Ludwigsvorstadt-Isarvorstadt" title="Ludwigsvorstadt-Isarvorstadt">Ludwigsvorstadt-Isarvorstadt</a>, where Einstein\'s father and his uncle Jakob founded Elektrotechnische Fabrik J. Einstein &amp; Cie, a company that manufactured electrical equipment based on <a href="/wiki/Direct_current" title="Direct current">direct current</a>.<sup id="cite_ref-Bio_20-1" class="reference"><a href="#cite_note-Bio-20">&#91;19&#93;</a></sup>
</p><p>Albert attended St.Peter‘s <a href="/wiki/Catholic_school" title="Catholic school">Catholic elementary school</a>  in Munich from the age of five. When he was eight, he was transferred to the <a href="/wiki/Luitpold_Gymnasium" title="Luitpold Gymnasium">Luitpold Gymnasium</a>, where he received advanced primary and then secondary school education.<sup id="cite_ref-FOOTNOTEStachel2002&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA59_59–61&#93;_23-0" class="reference"><a href="#cite_note-FOOTNOTEStachel2002[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA59_59–61]-23">&#91;22&#93;</a></sup>
</p><p>In 1894, Hermann and Jakob\'s company tendered for a contract to install electric lighting in Munich, but without success—they lacked the capital that would have been required to update their technology from direct current to the more efficient, <a href="/wiki/Alternating_current" title="Alternating current">alternating current</a> alternative.<sup id="cite_ref-EQyag_24-0" class="reference"><a href="#cite_note-EQyag-24">&#91;23&#93;</a></sup> The failure of their bid forced them to sell their Munich factory and search for new opportunities elsewhere. The Einstein family moved to Italy, first to <a href="/wiki/Milan" title="Milan">Milan</a> and a few months later to <a href="/wiki/Pavia" title="Pavia">Pavia</a>, where they settled in <a href="/wiki/Palazzo_Cornazzani" title="Palazzo Cornazzani">Palazzo Cornazzani</a>.<sup id="cite_ref-25" class="reference"><a href="#cite_note-25">&#91;24&#93;</a></sup> Einstein, then fifteen, stayed behind in Munich in order to finish his schooling. His father wanted him to study <a href="/wiki/Electrical_engineering" title="Electrical engineering">electrical engineering</a>, but he was a fractious pupil who found the Gymnasium\'s regimen and teaching methods far from congenial. He later wrote that the school\'s policy of strict <a href="/wiki/Rote_learning" title="Rote learning">rote learning</a> was harmful to creativity. At the end of December 1894, a letter from a doctor persuaded the Luitpold\'s authorities to release him from its care, and he joined his family in Pavia.<sup id="cite_ref-FOOTNOTEFölsing199730–31_26-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing199730–31-26">&#91;25&#93;</a></sup> While in Italy as a teenager, he wrote an essay entitled "On the Investigation of the State of the <a href="/wiki/Aether_(classical_element)" title="Aether (classical element)">Ether</a> in a Magnetic Field".<sup id="cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._5_27-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._5-27">&#91;26&#93;</a></sup><sup id="cite_ref-1RgTv_28-0" class="reference"><a href="#cite_note-1RgTv-28">&#91;27&#93;</a></sup>
</p><p>Einstein excelled at physics and mathematics from an early age, and soon acquired the mathematical expertise normally only found in a child several years his senior. He began teaching himself algebra, calculus and <a href="/wiki/Euclidean_geometry" title="Euclidean geometry">Euclidean geometry</a> when he was twelve; he made such rapid progress that he discovered an original proof of the <a href="/wiki/Pythagorean_theorem" title="Pythagorean theorem">Pythagorean theorem</a> before his thirteenth birthday.<sup id="cite_ref-FVfDU_29-0" class="reference"><a href="#cite_note-FVfDU-29">&#91;28&#93;</a></sup><sup id="cite_ref-FOOTNOTEIsaacson200716_30-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200716-30">&#91;29&#93;</a></sup><sup id="cite_ref-31" class="reference"><a href="#cite_note-31">&#91;30&#93;</a></sup> A family tutor, <a href="/wiki/Max_Talmud" class="mw-redirect" title="Max Talmud">Max Talmud</a>, said that only a short time after he had given the twelve year old Einstein a geometry textbook, the boy "had worked through the whole book. He thereupon devoted himself to higher mathematics&#160;... Soon the flight of his mathematical genius was so high I could not follow."<sup id="cite_ref-FOOTNOTEIsaacson200717_32-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200717-32">&#91;31&#93;</a></sup> Einstein recorded that he had "mastered <a href="/wiki/Integral" title="Integral">integral</a> and <a href="/wiki/Differential_calculus" title="Differential calculus">differential calculus</a>" while still just fourteen.<sup id="cite_ref-FOOTNOTEIsaacson200716_30-1" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200716-30">&#91;29&#93;</a></sup> His love of algebra and geometry was so great that at twelve, he was already confident that nature could be understood as a "mathematical structure".<sup id="cite_ref-FOOTNOTEIsaacson200717_32-1" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200717-32">&#91;31&#93;</a></sup>
</p>
<figure class="mw-default-size mw-halign-left" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_as_a_child.jpg" class="mw-file-description"><img alt="Studio photo of a boy seated in a relaxed posture and wearing a suit, posed in front of a backdrop of scenery." src="//upload.wikimedia.org/wikipedia/commons/thumb/a/ad/Albert_Einstein_as_a_child.jpg/200px-Albert_Einstein_as_a_child.jpg" decoding="async" width="200" height="171" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/a/ad/Albert_Einstein_as_a_child.jpg/300px-Albert_Einstein_as_a_child.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/a/ad/Albert_Einstein_as_a_child.jpg/400px-Albert_Einstein_as_a_child.jpg 2x" data-file-width="810" data-file-height="694" /></a><figcaption>Einstein in 1893, age&#160;14</figcaption></figure>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409"><style data-mw-deduplicate="TemplateStyles:r1224216912">.mw-parser-output .sidebar{width:22em;float:right;clear:right;margin:0.5em 0 1em 1em;background:var(--background-color-neutral-subtle,#f8f9fa);border:1px solid #aaa;padding:0.2em;text-align:center;line-height:1.4em;font-size:88%;border-collapse:collapse;display:table}body.skin-minerva .mw-parser-output .sidebar{display:table!important;float:right!important;margin:0.5em 0 1em 1em!important}.mw-parser-output .sidebar-subgroup{width:100%;margin:0;border-spacing:0}.mw-parser-output .sidebar-left{float:left;clear:left;margin:0.5em 1em 1em 0}.mw-parser-output .sidebar-none{float:none;clear:both;margin:0.5em 1em 1em 0}.mw-parser-output .sidebar-outer-title{padding:0 0.4em 0.2em;font-size:125%;line-height:1.2em;font-weight:bold}.mw-parser-output .sidebar-top-image{padding:0.4em}.mw-parser-output .sidebar-top-caption,.mw-parser-output .sidebar-pretitle-with-top-image,.mw-parser-output .sidebar-caption{padding:0.2em 0.4em 0;line-height:1.2em}.mw-parser-output .sidebar-pretitle{padding:0.4em 0.4em 0;line-height:1.2em}.mw-parser-output .sidebar-title,.mw-parser-output .sidebar-title-with-pretitle{padding:0.2em 0.8em;font-size:145%;line-height:1.2em}.mw-parser-output .sidebar-title-with-pretitle{padding:0.1em 0.4em}.mw-parser-output .sidebar-image{padding:0.2em 0.4em 0.4em}.mw-parser-output .sidebar-heading{padding:0.1em 0.4em}.mw-parser-output .sidebar-content{padding:0 0.5em 0.4em}.mw-parser-output .sidebar-content-with-subgroup{padding:0.1em 0.4em 0.2em}.mw-parser-output .sidebar-above,.mw-parser-output .sidebar-below{padding:0.3em 0.8em;font-weight:bold}.mw-parser-output .sidebar-collapse .sidebar-above,.mw-parser-output .sidebar-collapse .sidebar-below{border-top:1px solid #aaa;border-bottom:1px solid #aaa}.mw-parser-output .sidebar-navbar{text-align:right;font-size:115%;padding:0 0.4em 0.4em}.mw-parser-output .sidebar-list-title{padding:0 0.4em;text-align:left;font-weight:bold;line-height:1.6em;font-size:105%}.mw-parser-output .sidebar-list-title-c{padding:0 0.4em;text-align:center;margin:0 3.3em}@media(max-width:720px){body.mediawiki .mw-parser-output .sidebar{width:100%!important;clear:both;float:none!important;margin-left:0!important;margin-right:0!important}}</style><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1224216912"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1224216912"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1224216912"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1224216912"><table class="sidebar sidebar-collapse nomobile nowraplinks plainlist"><tbody><tr><td class="sidebar-pretitle">Part of a series on</td></tr><tr><th class="sidebar-title-with-pretitle"><a href="/wiki/Physical_cosmology" title="Physical cosmology">Physical cosmology</a></th></tr><tr><td class="sidebar-image"><span class="mw-default-size" typeof="mw:File/Frameless"><a href="/wiki/File:Ilc_9yr_moll4096.png" class="mw-file-description"><img alt="Full-sky image derived from nine years&#39; WMAP data" src="//upload.wikimedia.org/wikipedia/commons/thumb/3/3c/Ilc_9yr_moll4096.png/220px-Ilc_9yr_moll4096.png" decoding="async" width="220" height="110" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/3/3c/Ilc_9yr_moll4096.png/330px-Ilc_9yr_moll4096.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/3/3c/Ilc_9yr_moll4096.png/440px-Ilc_9yr_moll4096.png 2x" data-file-width="4096" data-file-height="2048" /></a></span></td></tr><tr><td class="sidebar-above" style="border:0;font-weight:normal; display:block;margin-bottom:0.4em;">
<ul><li><a href="/wiki/Big_Bang" title="Big Bang">Big Bang</a>&#160;<b>·</b> <a href="/wiki/Universe" title="Universe">Universe</a></li>
<li><a href="/wiki/Age_of_the_universe" title="Age of the universe">Age of the universe</a></li>
<li><a href="/wiki/Chronology_of_the_universe" title="Chronology of the universe">Chronology of the universe</a></li></ul></td></tr><tr><td class="sidebar-content-with-subgroup">
<div class="sidebar-list mw-collapsible mw-collapsed"><div class="sidebar-list-title" style="background:#ddd8e7;text-align:center;;color: var(--color-base)">Early universe</div><div class="sidebar-list-content mw-collapsible-content"><table class="sidebar-subgroup"><tbody><tr><td class="sidebar-content">
<ul><li><a href="/wiki/Inflation_(cosmology)" title="Inflation (cosmology)">Inflation</a>&#160;<b>·</b> <a href="/wiki/Big_Bang_nucleosynthesis" title="Big Bang nucleosynthesis">Nucleosynthesis</a></li></ul></td>
</tr><tr><th class="sidebar-heading" style="font-weight:normal;font-style:italic;">
Backgrounds</th></tr><tr><td class="sidebar-content">
<ul><li><a href="/wiki/Gravitational_wave_background" title="Gravitational wave background">Gravitational wave (GWB)</a></li>
<li><a href="/wiki/Cosmic_microwave_background" title="Cosmic microwave background">Microwave (CMB)</a>&#160;<b>·</b> <a href="/wiki/Cosmic_neutrino_background" title="Cosmic neutrino background">Neutrino (CNB)</a></li></ul></td>
</tr></tbody></table></div></div></td>
</tr><tr><td class="sidebar-content">
<div class="sidebar-list mw-collapsible mw-collapsed"><div class="sidebar-list-title" style="background:#ddd8e7;text-align:center;;color: var(--color-base)">Expansion&#160;<b>·</b> Future</div><div class="sidebar-list-content mw-collapsible-content">
<ul><li><a href="/wiki/Hubble%27s_law" title="Hubble&#39;s law">Hubble\'s law</a>&#160;<b>·</b> <a href="/wiki/Redshift" title="Redshift">Redshift</a></li>
<li><a href="/wiki/Expansion_of_the_universe" title="Expansion of the universe">Expansion of the universe</a></li>
<li><a href="/wiki/Friedmann%E2%80%93Lema%C3%AEtre%E2%80%93Robertson%E2%80%93Walker_metric" title="Friedmann–Lemaître–Robertson–Walker metric">FLRW metric</a>&#160;<b>·</b> <a href="/wiki/Friedmann_equations" title="Friedmann equations">Friedmann equations</a></li>
<li><a href="/wiki/Inhomogeneous_cosmology" title="Inhomogeneous cosmology">Inhomogeneous cosmology</a></li>
<li><a href="/wiki/Future_of_an_expanding_universe" title="Future of an expanding universe">Future of an expanding universe</a></li>
<li><a href="/wiki/Ultimate_fate_of_the_universe" title="Ultimate fate of the universe">Ultimate fate of the universe</a></li></ul></div></div></td>
</tr><tr><td class="sidebar-content-with-subgroup">
<div class="sidebar-list mw-collapsible mw-collapsed"><div class="sidebar-list-title" style="background:#ddd8e7;text-align:center;;color: var(--color-base)">Components&#160;<b>·</b> Structure</div><div class="sidebar-list-content mw-collapsible-content"><table class="sidebar-subgroup"><tbody><tr><th class="sidebar-heading" style="font-weight:normal;font-style:italic;">
Components</th></tr><tr><td class="sidebar-content">
<ul><li><a href="/wiki/Lambda-CDM_model" title="Lambda-CDM model">Lambda-CDM model</a></li>
<li><a href="/wiki/Dark_energy" title="Dark energy">Dark energy</a>&#160;<b>·</b> <a href="/wiki/Dark_matter" title="Dark matter">Dark matter</a></li></ul></td>
</tr><tr><th class="sidebar-heading" style="font-weight:normal;font-style:italic;">
Structure</th></tr><tr><td class="sidebar-content">
<ul><li><a href="/wiki/Shape_of_the_universe" title="Shape of the universe">Shape of the universe</a></li>
<li><a href="/wiki/Galaxy_filament" title="Galaxy filament">Galaxy filament</a>&#160;<b>·</b> <a href="/wiki/Galaxy_formation_and_evolution" title="Galaxy formation and evolution">Galaxy formation</a></li>
<li><a href="/wiki/Large_quasar_group" title="Large quasar group">Large quasar group</a></li>
<li><a href="/wiki/Observable_universe#Large-scale_structure" title="Observable universe">Large-scale structure</a></li>
<li><a href="/wiki/Reionization" title="Reionization">Reionization</a>&#160;<b>·</b> <a href="/wiki/Structure_formation" title="Structure formation">Structure formation</a></li></ul></td>
</tr></tbody></table></div></div></td>
</tr><tr><td class="sidebar-content">
<div class="sidebar-list mw-collapsible mw-collapsed"><div class="sidebar-list-title" style="background:#ddd8e7;text-align:center;;color: var(--color-base)"><a href="/wiki/Observational_cosmology" title="Observational cosmology">Experiments</a></div><div class="sidebar-list-content mw-collapsible-content">
<ul><li><a href="/wiki/Black_Hole_Initiative" title="Black Hole Initiative">Black Hole Initiative (BHI)</a></li>
<li><a href="/wiki/BOOMERanG_experiment" title="BOOMERanG experiment">BOOMERanG</a></li>
<li><a href="/wiki/Cosmic_Background_Explorer" title="Cosmic Background Explorer">Cosmic Background Explorer (COBE)</a></li>
<li><a href="/wiki/Dark_Energy_Survey" title="Dark Energy Survey">Dark Energy Survey</a></li>
<li><a href="/wiki/Planck_(spacecraft)" title="Planck (spacecraft)">Planck space observatory</a></li>
<li><a href="/wiki/Sloan_Digital_Sky_Survey" title="Sloan Digital Sky Survey">Sloan Digital Sky Survey (SDSS)</a></li>
<li><a href="/wiki/2dF_Galaxy_Redshift_Survey" title="2dF Galaxy Redshift Survey">2dF Galaxy Redshift Survey ("2dF")</a></li>
<li><div style="display:inline-block; padding:0.2em 0.4em; line-height:1.2em;"><a href="/wiki/Wilkinson_Microwave_Anisotropy_Probe" title="Wilkinson Microwave Anisotropy Probe">Wilkinson Microwave Anisotropy<br />Probe (WMAP)</a></div></li></ul></div></div></td>
</tr><tr><td class="sidebar-content">
<div class="sidebar-list mw-collapsible"><div class="sidebar-list-title" style="background:#ddd8e7;text-align:center;;color: var(--color-base)">Scientists</div><div class="sidebar-list-content mw-collapsible-content"><div class="hlist" style="padding:0 0.9em;">
<ul><li><a href="/wiki/Marc_Aaronson" title="Marc Aaronson">Aaronson</a></li>
<li><a href="/wiki/Hannes_Alfv%C3%A9n" title="Hannes Alfvén">Alfvén</a></li>
<li><a href="/wiki/Ralph_Asher_Alpher" class="mw-redirect" title="Ralph Asher Alpher">Alpher</a></li>
<li><a href="/wiki/Nicolaus_Copernicus" title="Nicolaus Copernicus">Copernicus</a></li>
<li><a href="/wiki/Willem_de_Sitter" title="Willem de Sitter">de Sitter</a></li>
<li><a href="/wiki/Robert_H._Dicke" title="Robert H. Dicke">Dicke</a></li>
<li><a href="/wiki/J%C3%BCrgen_Ehlers" title="Jürgen Ehlers">Ehlers</a></li>
<li><a class="mw-selflink selflink">Einstein</a></li>
<li><a href="/wiki/George_F._R._Ellis" title="George F. R. Ellis">Ellis</a></li>
<li><a href="/wiki/Alexander_Friedmann" title="Alexander Friedmann">Friedmann</a></li>
<li><a href="/wiki/Galileo_Galilei" title="Galileo Galilei">Galileo</a></li>
<li><a href="/wiki/George_Gamow" title="George Gamow">Gamow</a></li>
<li><a href="/wiki/Alan_Guth" title="Alan Guth">Guth</a></li>
<li><a href="/wiki/Stephen_Hawking" title="Stephen Hawking">Hawking</a></li>
<li><a href="/wiki/Edwin_Hubble" title="Edwin Hubble">Hubble</a></li>
<li><a href="/wiki/Christiaan_Huygens" title="Christiaan Huygens">Huygens</a></li>
<li><a href="/wiki/Johannes_Kepler" title="Johannes Kepler">Kepler</a></li>
<li><a href="/wiki/Georges_Lema%C3%AEtre" title="Georges Lemaître">Lemaître</a></li>
<li><a href="/wiki/John_C._Mather" title="John C. Mather">Mather</a></li>
<li><a href="/wiki/Isaac_Newton" title="Isaac Newton">Newton</a></li>
<li><a href="/wiki/Roger_Penrose" title="Roger Penrose">Penrose</a></li>
<li><a href="/wiki/Arno_Allan_Penzias" title="Arno Allan Penzias">Penzias</a></li>
<li><a href="/wiki/Vera_Rubin" title="Vera Rubin">Rubin</a></li>
<li><a href="/wiki/Brian_Schmidt" title="Brian Schmidt">Schmidt</a></li>
<li><a href="/wiki/George_Smoot" title="George Smoot">Smoot</a></li>
<li><a href="/wiki/Nicholas_B._Suntzeff" title="Nicholas B. Suntzeff">Suntzeff</a></li>
<li><a href="/wiki/Rashid_Sunyaev" title="Rashid Sunyaev">Sunyaev</a></li>
<li><a href="/wiki/Richard_C._Tolman" title="Richard C. Tolman">Tolman</a></li>
<li><a href="/wiki/Robert_Woodrow_Wilson" title="Robert Woodrow Wilson">Wilson</a></li>
<li><a href="/wiki/Yakov_Zeldovich" title="Yakov Zeldovich">Zeldovich</a></li></ul>
</div>
<ul><li><a href="/wiki/List_of_cosmologists" title="List of cosmologists">List of cosmologists</a></li></ul></div></div></td>
</tr><tr><td class="sidebar-content">
<div class="sidebar-list mw-collapsible mw-collapsed"><div class="sidebar-list-title" style="background:#ddd8e7;text-align:center;;color: var(--color-base)"><a href="/wiki/Physical_cosmology#Subject_history" title="Physical cosmology">Subject history</a></div><div class="sidebar-list-content mw-collapsible-content">
<ul><li><div style="display:inline-block; padding:0.2em 0.4em; line-height:1.2em;"><a href="/wiki/Discovery_of_cosmic_microwave_background_radiation" title="Discovery of cosmic microwave background radiation">Discovery of cosmic microwave<br />background radiation</a></div></li>
<li><a href="/wiki/History_of_the_Big_Bang_theory" title="History of the Big Bang theory">History of the Big Bang theory</a></li>
<li><a href="/wiki/Timeline_of_cosmological_theories" title="Timeline of cosmological theories">Timeline of cosmological theories</a></li></ul></div></div></td>
</tr><tr><td class="sidebar-below" style="display:block;margin-top:0.4em; line-height:1.6em;padding-bottom:0.5em;">
<ul><li><span class="noviewer" typeof="mw:File"><span title="Category"><img alt="" src="//upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/16px-Symbol_category_class.svg.png" decoding="async" width="16" height="16" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/23px-Symbol_category_class.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/31px-Symbol_category_class.svg.png 2x" data-file-width="180" data-file-height="185" /></span></span>&#160;<a href="/wiki/Category:Physical_cosmology" title="Category:Physical cosmology">Category</a></li>
<li><span class="nowrap"><span class="noviewer" typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/0/00/Crab_Nebula.jpg/16px-Crab_Nebula.jpg" decoding="async" width="16" height="16" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/0/00/Crab_Nebula.jpg/24px-Crab_Nebula.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/0/00/Crab_Nebula.jpg/32px-Crab_Nebula.jpg 2x" data-file-width="3864" data-file-height="3864" /></span></span> </span><a href="/wiki/Portal:Astronomy" title="Portal:Astronomy">Astronomy&#32;portal</a></li></ul></td></tr><tr><td class="sidebar-navbar"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><style data-mw-deduplicate="TemplateStyles:r1063604349">.mw-parser-output .navbar{display:inline;font-size:88%;font-weight:normal}.mw-parser-output .navbar-collapse{float:left;text-align:left}.mw-parser-output .navbar-boxtext{word-spacing:0}.mw-parser-output .navbar ul{display:inline-block;white-space:nowrap;line-height:inherit}.mw-parser-output .navbar-brackets::before{margin-right:-0.125em;content:"[ "}.mw-parser-output .navbar-brackets::after{margin-left:-0.125em;content:" ]"}.mw-parser-output .navbar li{word-spacing:-0.125em}.mw-parser-output .navbar a>span,.mw-parser-output .navbar a>abbr{text-decoration:inherit}.mw-parser-output .navbar-mini abbr{font-variant:small-caps;border-bottom:none;text-decoration:none;cursor:inherit}.mw-parser-output .navbar-ct-full{font-size:114%;margin:0 7em}.mw-parser-output .navbar-ct-mini{font-size:114%;margin:0 4em}</style><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:Physical_cosmology" title="Template:Physical cosmology"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:Physical_cosmology" title="Template talk:Physical cosmology"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:Physical_cosmology" title="Special:EditPage/Template:Physical cosmology"><abbr title="Edit this template">e</abbr></a></li></ul></div></td></tr></tbody></table>
<p>At thirteen, when his range of enthusiasms had broadened to include music and philosophy,<sup id="cite_ref-FOOTNOTECalapriceLipscombe20058_33-0" class="reference"><a href="#cite_note-FOOTNOTECalapriceLipscombe20058-33">&#91;32&#93;</a></sup> Talmud introduced Einstein to <a href="/wiki/Kant" class="mw-redirect" title="Kant">Kant</a>\'s <i><a href="/wiki/Critique_of_Pure_Reason" title="Critique of Pure Reason">Critique of Pure Reason</a></i>. Kant became his favorite philosopher; according to Talmud, "At the time he was still a child, only thirteen years old, yet Kant\'s works, incomprehensible to ordinary mortals, seemed to be clear to him."<sup id="cite_ref-FOOTNOTEIsaacson200717_32-2" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200717-32">&#91;31&#93;</a></sup>
</p>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein%27s_exam_of_maturity_grades_(color2).jpg" class="mw-file-description"><img alt="Einstein&#39;s matriculation certificate at the age of 17. The heading translates as &quot;The Education Committee of the Canton of Aargau&quot;. His scores were German 5, French 3, Italian 5, History 6, Geography 4, Algebra 6, Geometry 6, Descriptive Geometry 6, Physics 6, Chemistry 5, Natural History 5, Art Drawing 4, Technical Drawing 4. 6 = very good, 5 = good, 4 = sufficient, 3 = insufficient, 2 = poor, 1 = very poor." src="//upload.wikimedia.org/wikipedia/commons/thumb/c/c3/Albert_Einstein%27s_exam_of_maturity_grades_%28color2%29.jpg/170px-Albert_Einstein%27s_exam_of_maturity_grades_%28color2%29.jpg" decoding="async" width="170" height="278" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/c/c3/Albert_Einstein%27s_exam_of_maturity_grades_%28color2%29.jpg/255px-Albert_Einstein%27s_exam_of_maturity_grades_%28color2%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/c/c3/Albert_Einstein%27s_exam_of_maturity_grades_%28color2%29.jpg/340px-Albert_Einstein%27s_exam_of_maturity_grades_%28color2%29.jpg 2x" data-file-width="1479" data-file-height="2419" /></a><figcaption>Einstein\'s <i><a href="/wiki/Matura" title="Matura">Matura</a></i> certificate, 1896<sup id="cite_ref-MaturaScore_34-0" class="reference"><a href="#cite_note-MaturaScore-34">&#91;note 2&#93;</a></sup></figcaption></figure>
<p>In 1895, at the age of sixteen, Einstein sat the entrance examination for the <a href="/wiki/ETH_Zurich" title="ETH Zurich">federal polytechnic school</a> (later the Eidgenössische Technische Hochschule, ETH) in Zürich, Switzerland. He failed to reach the required standard in the general part of the test,<sup id="cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_p._11_35-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_p._11-35">&#91;33&#93;</a></sup> but performed with distinction in physics and mathematics.<sup id="cite_ref-FOOTNOTEFölsing199736–37_36-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing199736–37-36">&#91;34&#93;</a></sup> On the advice of the polytechnic\'s principal, he completed his secondary education at the <a href="/wiki/Old_Cantonal_School_Aarau" title="Old Cantonal School Aarau">Argovian cantonal school</a> (a <a href="/wiki/Gymnasium_(school)" title="Gymnasium (school)"><i>gymnasium</i></a>) in <a href="/wiki/Aarau" title="Aarau">Aarau</a>, Switzerland, graduating in 1896.<sup id="cite_ref-b250_37-0" class="reference"><a href="#cite_note-b250-37">&#91;35&#93;</a></sup> While lodging in Aarau with the family of <a href="/wiki/Jost_Winteler" title="Jost Winteler">Jost Winteler</a>, he fell in love with Winteler\'s daughter, Marie. (His sister, <a href="/wiki/Maja_Einstein" class="mw-redirect" title="Maja Einstein">Maja</a>, later married Winteler\'s son Paul.<sup id="cite_ref-FOOTNOTEHighfieldCarter199321,_31,_56–57_38-0" class="reference"><a href="#cite_note-FOOTNOTEHighfieldCarter199321,_31,_56–57-38">&#91;36&#93;</a></sup>)
</p><p>In January 1896, with his father\'s approval, Einstein renounced his <a href="/wiki/German_citizenship" class="mw-redirect" title="German citizenship">citizenship of the German Kingdom of Württemberg</a> in order to avoid <a href="/wiki/Conscription_in_Germany" title="Conscription in Germany">conscription into military service</a>.<sup id="cite_ref-FOOTNOTEFölsing199740_39-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing199740-39">&#91;37&#93;</a></sup> The <i><a href="/wiki/Matura" title="Matura">Matura</a></i> (graduation for the successful completion of higher secondary schooling) awarded to him in the September of that year acknowledged him to have performed well across most of the curriculum, allotting him a <a href="/wiki/Grading_systems_by_country#Switzerland" title="Grading systems by country">top grade of 6</a> for history, physics, algebra, geometry, and descriptive geometry.<sup id="cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_docs._21–27_40-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_docs._21–27-40">&#91;38&#93;</a></sup> At seventeen, he enrolled in the four-year mathematics and physics teaching diploma program at the federal polytechnic school. Marie Winteler, a year older than him, took up a teaching post in <a href="/wiki/Olsberg,_Aargau" title="Olsberg, Aargau">Olsberg</a>, Switzerland.<sup id="cite_ref-FOOTNOTEHighfieldCarter199321,_31,_56–57_38-1" class="reference"><a href="#cite_note-FOOTNOTEHighfieldCarter199321,_31,_56–57-38">&#91;36&#93;</a></sup>
</p><p>The five other polytechnic school freshmen following the same course as Einstein included just one woman, a twenty year old <a href="/wiki/Serbs" title="Serbs">Serbian</a>, <a href="/wiki/Mileva_Mari%C4%87" title="Mileva Marić">Mileva Marić</a>. Over the next few years, the pair spent many hours discussing their shared interests and learning about topics in physics that the polytechnic school\'s lectures did not cover. In his letters to Marić, Einstein confessed that exploring science with her by his side was much more enjoyable than reading a textbook in solitude. Eventually the two students became not only friends but also lovers.<sup id="cite_ref-mileva_41-0" class="reference"><a href="#cite_note-mileva-41">&#91;39&#93;</a></sup>
</p><p>Historians of physics are divided on the question of the extent to which Marić contributed to the insights of Einstein\'s <i>annus mirabilis</i> publications. There is at least some evidence that he was influenced by her scientific ideas,<sup id="cite_ref-mileva_41-1" class="reference"><a href="#cite_note-mileva-41">&#91;39&#93;</a></sup><sup id="cite_ref-7HA7H_42-0" class="reference"><a href="#cite_note-7HA7H-42">&#91;40&#93;</a></sup><sup id="cite_ref-1zJdH_43-0" class="reference"><a href="#cite_note-1zJdH-43">&#91;41&#93;</a></sup> but there are scholars who doubt whether her impact on his thought was of any great significance at all.<sup id="cite_ref-FOOTNOTEPais19941–29_44-0" class="reference"><a href="#cite_note-FOOTNOTEPais19941–29-44">&#91;42&#93;</a></sup><sup id="cite_ref-xKrMG_45-0" class="reference"><a href="#cite_note-xKrMG-45">&#91;43&#93;</a></sup><sup id="cite_ref-FOOTNOTEStachel2002&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA49_49–56&#93;_46-0" class="reference"><a href="#cite_note-FOOTNOTEStachel2002[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA49_49–56]-46">&#91;44&#93;</a></sup><sup id="cite_ref-dUxMl_47-0" class="reference"><a href="#cite_note-dUxMl-47">&#91;45&#93;</a></sup>
</p>
<h3><span id="Marriages.2C_relationships_and_children"></span><span class="mw-headline" id="Marriages,_relationships_and_children">Marriages, relationships and children</span></h3>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_and_his_wife_Mileva_Maric.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/8/87/Albert_Einstein_and_his_wife_Mileva_Maric.jpg/220px-Albert_Einstein_and_his_wife_Mileva_Maric.jpg" decoding="async" width="220" height="152" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/8/87/Albert_Einstein_and_his_wife_Mileva_Maric.jpg/330px-Albert_Einstein_and_his_wife_Mileva_Maric.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/8/87/Albert_Einstein_and_his_wife_Mileva_Maric.jpg/440px-Albert_Einstein_and_his_wife_Mileva_Maric.jpg 2x" data-file-width="3324" data-file-height="2300" /></a><figcaption>Albert Einstein and <a href="/wiki/Mileva_Mari%C4%87" title="Mileva Marić">Mileva Marić</a> Einstein, 1912</figcaption></figure>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_and_Elsa_Einstein_arriving_by_ship,_San_Diego,_1930_(cropped).jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/5/54/Albert_Einstein_and_Elsa_Einstein_arriving_by_ship%2C_San_Diego%2C_1930_%28cropped%29.jpg/220px-Albert_Einstein_and_Elsa_Einstein_arriving_by_ship%2C_San_Diego%2C_1930_%28cropped%29.jpg" decoding="async" width="220" height="163" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/5/54/Albert_Einstein_and_Elsa_Einstein_arriving_by_ship%2C_San_Diego%2C_1930_%28cropped%29.jpg/330px-Albert_Einstein_and_Elsa_Einstein_arriving_by_ship%2C_San_Diego%2C_1930_%28cropped%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/5/54/Albert_Einstein_and_Elsa_Einstein_arriving_by_ship%2C_San_Diego%2C_1930_%28cropped%29.jpg/440px-Albert_Einstein_and_Elsa_Einstein_arriving_by_ship%2C_San_Diego%2C_1930_%28cropped%29.jpg 2x" data-file-width="5422" data-file-height="4005" /></a><figcaption>Albert Einstein and Elsa Einstein, 1930</figcaption></figure>
<p>Correspondence between Einstein and Marić, discovered and published in 1987, revealed that in early 1902, while Marić was visiting her parents in <a href="/wiki/Novi_Sad" title="Novi Sad">Novi Sad</a>, she gave birth to a daughter, <a href="/wiki/Lieserl_Einstein" class="mw-redirect" title="Lieserl Einstein">Lieserl</a>. When Marić returned to Switzerland it was without the child, whose fate is uncertain. A letter of Einstein\'s that he wrote in September 1903 suggests that the girl was either given up for adoption or died of <a href="/wiki/Scarlet_fever" title="Scarlet fever">scarlet fever</a> in infancy.<sup id="cite_ref-HBMes_48-0" class="reference"><a href="#cite_note-HBMes-48">&#91;46&#93;</a></sup><sup id="cite_ref-FOOTNOTECalapriceLipscombe200522–23_49-0" class="reference"><a href="#cite_note-FOOTNOTECalapriceLipscombe200522–23-49">&#91;47&#93;</a></sup>
</p><p>Einstein and Marić married in January 1903. In May 1904, their son <a href="/wiki/Hans_Albert_Einstein" title="Hans Albert Einstein">Hans Albert</a> was born in <a href="/wiki/Bern" title="Bern">Bern</a>, Switzerland. Their son <a href="/wiki/Einstein_family#Eduard_&quot;Tete&quot;_Einstein_(Albert&#39;s_second_son)" title="Einstein family">Eduard</a> was born in Zürich in July 1910. In letters that Einstein wrote to Marie Winteler in the months before Eduard\'s arrival, he described his love for his wife as "misguided" and mourned the "missed life" that he imagined he would have enjoyed if he had married Winteler instead: "I think of you in heartfelt love every spare minute and am so unhappy as only a man can be."<sup id="cite_ref-MlQLY_50-0" class="reference"><a href="#cite_note-MlQLY-50">&#91;48&#93;</a></sup>
</p><p>In 1912, Einstein entered into a relationship with <a href="/wiki/Elsa_L%C3%B6wenthal" class="mw-redirect" title="Elsa Löwenthal">Elsa Löwenthal</a>, who was both his first cousin on his mother\'s side and his second cousin on his father\'s.<sup id="cite_ref-FOOTNOTECalapriceLipscombe2005&#91;httpsbooksgooglecombooksid5eWh2O_3OAQCpgPA50_50&#93;_51-0" class="reference"><a href="#cite_note-FOOTNOTECalapriceLipscombe2005[httpsbooksgooglecombooksid5eWh2O_3OAQCpgPA50_50]-51">&#91;49&#93;</a></sup><sup id="cite_ref-dh_52-0" class="reference"><a href="#cite_note-dh-52">&#91;50&#93;</a></sup><sup id="cite_ref-FOOTNOTEStachel1966_53-0" class="reference"><a href="#cite_note-FOOTNOTEStachel1966-53">&#91;51&#93;</a></sup> When Marić learned of his infidelity soon after moving to Berlin with him in April 1914, she returned to Zürich, taking Hans Albert and Eduard with her.<sup id="cite_ref-mileva_41-2" class="reference"><a href="#cite_note-mileva-41">&#91;39&#93;</a></sup> Einstein and Marić were granted a divorce on 14 February 1919 on the grounds of having lived apart for five years.<sup id="cite_ref-54" class="reference"><a href="#cite_note-54">&#91;52&#93;</a></sup><sup id="cite_ref-FOOTNOTEStachel2002&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA50_50&#93;_55-0" class="reference"><a href="#cite_note-FOOTNOTEStachel2002[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA50_50]-55">&#91;53&#93;</a></sup> As part of the divorce settlement, Einstein agreed that if he were to win a Nobel Prize, he would give the money that he received to Marić; he won the prize two years later.<sup id="cite_ref-56" class="reference"><a href="#cite_note-56">&#91;54&#93;</a></sup>
</p><p>Einstein married Löwenthal in 1919.<sup id="cite_ref-FOOTNOTEIsaacson2007&quot;Main_characters&quot;,_front_matter_57-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007&quot;Main_characters&quot;,_front_matter-57">&#91;55&#93;</a></sup><sup id="cite_ref-FOOTNOTECalapriceKennefickSchulmann201562_58-0" class="reference"><a href="#cite_note-FOOTNOTECalapriceKennefickSchulmann201562-58">&#91;56&#93;</a></sup> In 1923, he began a relationship with a secretary named Betty Neumann, the niece of his close friend Hans Mühsam.<sup id="cite_ref-59" class="reference"><a href="#cite_note-59">&#91;57&#93;</a></sup><sup id="cite_ref-60" class="reference"><a href="#cite_note-60">&#91;58&#93;</a></sup><sup id="cite_ref-61" class="reference"><a href="#cite_note-61">&#91;59&#93;</a></sup><sup id="cite_ref-62" class="reference"><a href="#cite_note-62">&#91;60&#93;</a></sup> Löwenthal nevertheless remained loyal to him, accompanying him when he emigrated to the United States in 1933. In 1935, she was diagnosed with heart and kidney problems. She died in December 1936.<sup id="cite_ref-FOOTNOTEHighfieldCarter1993216_63-0" class="reference"><a href="#cite_note-FOOTNOTEHighfieldCarter1993216-63">&#91;61&#93;</a></sup>
</p><p>A volume of Einstein\'s letters released by <a href="/wiki/Hebrew_University_of_Jerusalem" title="Hebrew University of Jerusalem">Hebrew University of Jerusalem</a> in 2006<sup id="cite_ref-64" class="reference"><a href="#cite_note-64">&#91;62&#93;</a></sup> added further names to the catalog of women with whom he was romantically involved. They included Margarete Lebach (a married Austrian),<sup id="cite_ref-65" class="reference"><a href="#cite_note-65">&#91;63&#93;</a></sup> Estella Katzenellenbogen (the rich owner of a florist business), Toni Mendel (a wealthy Jewish widow) and Ethel Michanowski (a Berlin socialite), with whom he spent time and from whom he accepted gifts while married to Löwenthal.<sup id="cite_ref-66" class="reference"><a href="#cite_note-66">&#91;64&#93;</a></sup><sup id="cite_ref-67" class="reference"><a href="#cite_note-67">&#91;65&#93;</a></sup> After being widowed, Einstein was briefly in a relationship with Margarita Konenkova, thought by some to be a Russian spy; her husband, the Russian sculptor <a href="/wiki/Sergei_Konenkov" class="mw-redirect" title="Sergei Konenkov">Sergei Konenkov</a>, created the bronze bust of Einstein at the <a href="/wiki/Institute_for_Advanced_Study" title="Institute for Advanced Study">Institute for Advanced Study</a> at Princeton.<sup id="cite_ref-68" class="reference"><a href="#cite_note-68">&#91;66&#93;</a></sup><sup id="cite_ref-69" class="reference"><a href="#cite_note-69">&#91;67&#93;</a></sup>
</p><p>Following an episode of acute mental illness at about the age of twenty, Einstein\'s son Eduard was diagnosed with <a href="/wiki/Schizophrenia" title="Schizophrenia">schizophrenia</a>.<sup id="cite_ref-Robinson2015a_70-0" class="reference"><a href="#cite_note-Robinson2015a-70">&#91;68&#93;</a></sup> He spent the remainder of his life either in the care of his mother or in temporary confinement in an asylum. After her death, he was committed permanently to <a href="/wiki/Burgh%C3%B6lzli" title="Burghölzli">Burghölzli</a>, the Psychiatric University Hospital in Zürich.<sup id="cite_ref-FOOTNOTENeffe2007&#91;httpsarchiveorgdetailseinsteinbiograph00neffpage203_203&#93;_71-0" class="reference"><a href="#cite_note-FOOTNOTENeffe2007[httpsarchiveorgdetailseinsteinbiograph00neffpage203_203]-71">&#91;69&#93;</a></sup>
</p>
<h3><span id="1902.E2.80.931909:_Assistant_at_the_Swiss_Patent_Office"></span><span class="mw-headline" id="1902–1909:_Assistant_at_the_Swiss_Patent_Office">1902–1909: Assistant at the Swiss Patent Office</span></h3>
<p>Einstein graduated from the federal polytechnic school in 1900, duly certified as competent to teach mathematics and physics.<sup id="cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._67_72-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._67-72">&#91;70&#93;</a></sup> His successful acquisition of Swiss citizenship in February 1901<sup id="cite_ref-FOOTNOTEFölsing199782_73-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing199782-73">&#91;71&#93;</a></sup> was not followed by the usual sequel of <a href="/wiki/Conscription_in_Switzerland" title="Conscription in Switzerland">conscription</a>; the Swiss authorities deemed him medically unfit for military service. He found that Swiss schools too appeared to have no use for him, failing to offer him a teaching position despite the almost two years that he spent applying for one. Eventually it was with the help of <a href="/wiki/Marcel_Grossmann" title="Marcel Grossmann">Marcel Grossmann</a>\'s father that he secured a post in <a href="/wiki/Bern" title="Bern">Bern</a> at the <a href="/wiki/Swiss_Patent_Office" class="mw-redirect" title="Swiss Patent Office">Swiss Patent Office</a>,<sup id="cite_ref-ODY5p_74-0" class="reference"><a href="#cite_note-ODY5p-74">&#91;72&#93;</a></sup><sup id="cite_ref-FOOTNOTEIsaacson200763_75-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200763-75">&#91;73&#93;</a></sup> as an <a href="/wiki/Patent_examiner" title="Patent examiner">assistant examiner – level III</a>.<sup id="cite_ref-MeZPN_76-0" class="reference"><a href="#cite_note-MeZPN-76">&#91;74&#93;</a></sup><sup id="cite_ref-IGEFAQ_77-0" class="reference"><a href="#cite_note-IGEFAQ-77">&#91;75&#93;</a></sup>
</p><p><a href="/wiki/Patent_application" title="Patent application">Patent applications</a> that landed on Einstein\'s desk for his evaluation included ideas for a gravel sorter and an electric typewriter.<sup id="cite_ref-IGEFAQ_77-1" class="reference"><a href="#cite_note-IGEFAQ-77">&#91;75&#93;</a></sup> His employers were pleased enough with his work to make his position permanent in 1903, although they did not think that he should be promoted until he had "fully mastered machine technology".<sup id="cite_ref-FOOTNOTEGalison2000370_78-0" class="reference"><a href="#cite_note-FOOTNOTEGalison2000370-78">&#91;76&#93;</a></sup> It is conceivable that his labors at the patent office had a bearing on his development of his special theory of relativity. He arrived at his revolutionary ideas about space, time and light through thought experiments about the transmission of signals and the synchronization of clocks, matters which also figured in some of the inventions submitted to him for assessment.<sup id="cite_ref-FOOTNOTEGalison2000377_14-1" class="reference"><a href="#cite_note-FOOTNOTEGalison2000377-14">&#91;13&#93;</a></sup>
</p><p>In 1902, Einstein and some friends whom he had met in Bern formed a group that held regular meetings to discuss science and philosophy. Their choice of a name for their club, the <a href="/wiki/Olympia_Academy" title="Olympia Academy">Olympia Academy</a>, was an ironic comment upon its far from Olympian status. Sometimes they were joined by Marić, who limited her participation in their proceedings to careful listening.<sup id="cite_ref-FOOTNOTEHighfieldCarter199396–98_79-0" class="reference"><a href="#cite_note-FOOTNOTEHighfieldCarter199396–98-79">&#91;77&#93;</a></sup> The thinkers whose works they reflected upon included <a href="/wiki/Henri_Poincar%C3%A9" title="Henri Poincaré">Henri Poincaré</a>, <a href="/wiki/Ernst_Mach" title="Ernst Mach">Ernst Mach</a> and <a href="/wiki/David_Hume" title="David Hume">David Hume</a>, all of whom significantly influenced Einstein\'s own subsequent ideas and beliefs.<sup id="cite_ref-FOOTNOTEIsaacson200779–84_80-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson200779–84-80">&#91;78&#93;</a></sup>
</p>
<h3><span id="1900.E2.80.931905:_First_scientific_papers"></span><span class="mw-headline" id="1900–1905:_First_scientific_papers">1900–1905: First scientific papers</span></h3>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein_thesis.png" class="mw-file-description"><img alt="Cover image of the PhD dissertation of Albert Einstein" src="//upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Einstein_thesis.png/170px-Einstein_thesis.png" decoding="async" width="170" height="279" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Einstein_thesis.png/255px-Einstein_thesis.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Einstein_thesis.png/340px-Einstein_thesis.png 2x" data-file-width="1134" data-file-height="1860" /></a><figcaption>Einstein\'s 1905 dissertation, <i>Eine neue Be&#173;stimm&#173;ung der Mol&#173;e&#173;kül&#173;di&#173;men&#173;si&#173;one</i> ("A new deter&#173;mi&#173;na&#173;tion of mo&#173;lec&#173;u&#173;lar di&#173;men&#173;sions")</figcaption></figure>
<p>Einstein\'s first paper, <a href="/wiki/List_of_scientific_publications_by_Albert_Einstein#Journal_articles" title="List of scientific publications by Albert Einstein">"Folgerungen aus den Capillaritätserscheinungen"</a> ("Conclusions drawn from the phenomena of capillarity"), in which he proposed a model of intermolecular attraction that he afterwards disavowed as worthless, was published in the journal <i><a href="/wiki/Annalen_der_Physik" title="Annalen der Physik">Annalen der Physik</a></i> in 1901.<sup id="cite_ref-FOOTNOTEEinstein1901_81-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1901-81">&#91;79&#93;</a></sup><sup id="cite_ref-82" class="reference"><a href="#cite_note-82">&#91;80&#93;</a></sup> His 24-page doctoral dissertation also addressed a topic in molecular physics. Titled "Eine neue Bestimmung der Moleküldimensionen" ("A New Determination of Molecular Dimensions") and dedicated to his friend Marcel Grossman, it was completed on 30 April 1905<sup id="cite_ref-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;_83-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;-83">&#91;81&#93;</a></sup> and approved by Professor <a href="/wiki/Alfred_Kleiner" title="Alfred Kleiner">Alfred Kleiner</a> of the University of Zurich three months later. (Einstein was formally awarded his PhD on 15 January 1906.)<sup id="cite_ref-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;_83-1" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;-83">&#91;81&#93;</a></sup><sup id="cite_ref-FOOTNOTEEinstein1926bchap._&quot;A_New_Determination_of_Molecular_Dimensions&quot;_84-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1926bchap._&quot;A_New_Determination_of_Molecular_Dimensions&quot;-84">&#91;82&#93;</a></sup><sup id="cite_ref-85" class="reference"><a href="#cite_note-85">&#91;83&#93;</a></sup> Four other pieces of work that Einstein completed in 1905—<a href="/wiki/Annus_mirabilis_papers" title="Annus mirabilis papers">his famous papers</a> on the <a href="/wiki/Photoelectric_effect" title="Photoelectric effect">photoelectric effect</a>, <a href="/wiki/Brownian_motion" title="Brownian motion">Brownian motion</a>, his <a href="/wiki/Special_theory_of_relativity" class="mw-redirect" title="Special theory of relativity">special theory of relativity</a> and the <a href="/wiki/Equivalence_of_mass_and_energy" class="mw-redirect" title="Equivalence of mass and energy">equivalence of mass and energy</a>—have led to the year being celebrated as an <i>annus mirabilis</i> for physics akin to 1666 (the year in which <a href="/wiki/Isaac_Newton" title="Isaac Newton">Isaac Newton</a> experienced his greatest epiphanies). The publications deeply impressed Einstein\'s contemporaries.<sup id="cite_ref-86" class="reference"><a href="#cite_note-86">&#91;84&#93;</a></sup>
</p>
<h3><span id="1908.E2.80.931933:_Early_academic_career"></span><span class="mw-headline" id="1908–1933:_Early_academic_career">1908–1933: Early academic career</span></h3>
<p>Einstein\'s sabbatical as a civil servant approached its end in 1908, when he secured a junior teaching position at the <a href="/wiki/University_of_Bern" title="University of Bern">University of Bern</a>. In 1909, a lecture on relativistic <a href="/wiki/Electrodynamics" class="mw-redirect" title="Electrodynamics">electrodynamics</a> that he gave at the University of Zurich, much admired by Alfred Kleiner, led to Zürich\'s luring him away from Bern with a newly created associate professorship.<sup id="cite_ref-bG2yp_87-0" class="reference"><a href="#cite_note-bG2yp-87">&#91;85&#93;</a></sup> Promotion to a full professorship followed in April 1911, when he accepted a chair at the German <a href="/wiki/Charles-Ferdinand_University" class="mw-redirect" title="Charles-Ferdinand University">Charles-Ferdinand University</a> in Prague, a move which required him to become an <a href="/wiki/Cisleithania" title="Cisleithania">Austrian</a> citizen of the <a href="/wiki/Austro-Hungarian_Empire" class="mw-redirect" title="Austro-Hungarian Empire">Austro-Hungarian Empire</a>.<sup id="cite_ref-FOOTNOTEIsaacson2007164_88-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007164-88">&#91;86&#93;</a></sup><sup id="cite_ref-Itl8r_89-0" class="reference"><a href="#cite_note-Itl8r-89">&#91;87&#93;</a></sup> His time in Prague saw him producing eleven research papers.<sup id="cite_ref-90" class="reference"><a href="#cite_note-90">&#91;88&#93;</a></sup>
</p>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein_patentoffice.jpg" class="mw-file-description"><img alt="Head and shoulders shot of a young, moustached man with dark, curly hair wearing a plaid suit and vest, striped shirt, and a dark tie." src="//upload.wikimedia.org/wikipedia/commons/thumb/a/a0/Einstein_patentoffice.jpg/240px-Einstein_patentoffice.jpg" decoding="async" width="240" height="314" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/a/a0/Einstein_patentoffice.jpg/360px-Einstein_patentoffice.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/a/a0/Einstein_patentoffice.jpg/480px-Einstein_patentoffice.jpg 2x" data-file-width="4360" data-file-height="5699" /></a><figcaption>Einstein in 1904, age&#160;25</figcaption></figure> <figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein-with-habicht-and-solovine.jpg" class="mw-file-description"><img alt="Three young men in suits with high white collars and bow ties, sitting." src="//upload.wikimedia.org/wikipedia/commons/thumb/d/d7/Einstein-with-habicht-and-solovine.jpg/240px-Einstein-with-habicht-and-solovine.jpg" decoding="async" width="240" height="158" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/d/d7/Einstein-with-habicht-and-solovine.jpg/360px-Einstein-with-habicht-and-solovine.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/d/d7/Einstein-with-habicht-and-solovine.jpg/480px-Einstein-with-habicht-and-solovine.jpg 2x" data-file-width="4672" data-file-height="3066" /></a><figcaption><a href="/wiki/Olympia_Academy" title="Olympia Academy">Olympia Academy</a> founders: <a href="/wiki/Conrad_Habicht" title="Conrad Habicht">Conrad Habicht</a>, <a href="/wiki/Maurice_Solovine" title="Maurice Solovine">Maurice Solovine</a>, and Einstein</figcaption></figure>
<p>In July 1912, he returned to his <i>alma mater</i>, the <a href="/wiki/ETH_Zurich" title="ETH Zurich">ETH Zurich</a>, to take up a chair in theoretical physics. His teaching activities there centred on <a href="/wiki/Thermodynamics" title="Thermodynamics">thermodynamics</a> and analytical mechanics, and his research interests included the molecular theory of heat, <a href="/wiki/Continuum_mechanics" title="Continuum mechanics">continuum mechanics</a> and the development of a relativistic theory of gravitation. In his work on the latter topic, he was assisted by his friend, Marcel Grossmann, whose knowledge of the kind of mathematics required was greater than his own.<sup id="cite_ref-hXQin_91-0" class="reference"><a href="#cite_note-hXQin-91">&#91;89&#93;</a></sup>
</p><p>In the spring of 1913, two German visitors, <a href="/wiki/Max_Planck" title="Max Planck">Max Planck</a> and <a href="/wiki/Walther_Nernst" title="Walther Nernst">Walther Nernst</a>, called upon Einstein in Zürich in the hope of persuading him to relocate to Berlin.<sup id="cite_ref-FOOTNOTEStachel2002534_92-0" class="reference"><a href="#cite_note-FOOTNOTEStachel2002534-92">&#91;90&#93;</a></sup> They offered him membership of the <a href="/wiki/Prussian_Academy_of_Sciences" title="Prussian Academy of Sciences">Prussian Academy of Sciences</a>, the directorship of the planned <a href="/wiki/Kaiser_Wilhelm_Institute_for_Physics" class="mw-redirect" title="Kaiser Wilhelm Institute for Physics">Kaiser Wilhelm Institute for Physics</a> and a chair at the <a href="/wiki/Humboldt_University_of_Berlin" title="Humboldt University of Berlin">Humboldt University of Berlin</a> that would allow him to pursue his research supported by a professorial salary but with no teaching duties to burden him.<sup id="cite_ref-dh_52-1" class="reference"><a href="#cite_note-dh-52">&#91;50&#93;</a></sup> Their invitation was all the more appealing to him because Berlin happened to be the home of his latest girlfriend, Elsa Löwenthal.<sup id="cite_ref-FOOTNOTEStachel2002534_92-1" class="reference"><a href="#cite_note-FOOTNOTEStachel2002534-92">&#91;90&#93;</a></sup> He duly joined the Academy on 24
July 1913,<sup id="cite_ref-jstor.org_93-0" class="reference"><a href="#cite_note-jstor.org-93">&#91;91&#93;</a></sup> and moved into an apartment in the Berlin district of <a href="/wiki/Dahlem_(Berlin)" title="Dahlem (Berlin)">Dahlem</a> on 1 April 1914.<sup id="cite_ref-dh_52-2" class="reference"><a href="#cite_note-dh-52">&#91;50&#93;</a></sup> He was installed in his Humboldt University position shortly thereafter.<sup id="cite_ref-jstor.org_93-1" class="reference"><a href="#cite_note-jstor.org-93">&#91;91&#93;</a></sup>
</p><p>The outbreak of the <a href="/wiki/First_World_War" class="mw-redirect" title="First World War">First World War</a> in July 1914 marked the beginning of Einstein\'s gradual estrangement from the nation of his birth. When the "<a href="/wiki/Manifesto_of_the_Ninety-Three" title="Manifesto of the Ninety-Three">Manifesto of the Ninety-Three</a>" was published in October 1914—a document signed by a host of prominent German thinkers that justified Germany\'s belligerence—Einstein was one of the few German intellectuals to distance himself from it and sign the alternative, eirenic "<a href="/wiki/Manifesto_to_the_Europeans" title="Manifesto to the Europeans">Manifesto to the Europeans</a>" instead.<sup id="cite_ref-FOOTNOTEScheideler2002333_94-0" class="reference"><a href="#cite_note-FOOTNOTEScheideler2002333-94">&#91;92&#93;</a></sup><sup id="cite_ref-FOOTNOTEWeinstein201518–19_95-0" class="reference"><a href="#cite_note-FOOTNOTEWeinstein201518–19-95">&#91;93&#93;</a></sup> But this expression of his doubts about German policy did not prevent him from being elected to a two-year term as president of the <a href="/wiki/German_Physical_Society" title="German Physical Society">German Physical Society</a> in 1916.<sup id="cite_ref-FOOTNOTECalapriceLipscombe2005&#91;httpsbooksgooglecombooksid5eWh2O_3OAQCpgPR19_&quot;Timeline&quot;,_p._xix&#93;_96-0" class="reference"><a href="#cite_note-FOOTNOTECalapriceLipscombe2005[httpsbooksgooglecombooksid5eWh2O_3OAQCpgPR19_&quot;Timeline&quot;,_p._xix]-96">&#91;94&#93;</a></sup> And when the Kaiser Wilhelm Institute for Physics opened its doors the following year—its foundation delayed because of the war—Einstein was appointed its first director, just as Planck and Nernst had promised.<sup id="cite_ref-EXcH6_97-0" class="reference"><a href="#cite_note-EXcH6-97">&#91;95&#93;</a></sup>
</p><p>Einstein was elected a Foreign Member of the <a href="/wiki/Royal_Netherlands_Academy_of_Arts_and_Sciences" title="Royal Netherlands Academy of Arts and Sciences">Royal Netherlands Academy of Arts and Sciences</a> in 1920,<sup id="cite_ref-3gcYy_98-0" class="reference"><a href="#cite_note-3gcYy-98">&#91;96&#93;</a></sup> and a <a href="/wiki/List_of_Fellows_of_the_Royal_Society_elected_in_1921" class="mw-redirect" title="List of Fellows of the Royal Society elected in 1921">Foreign Member of the Royal Society in 1921</a>. In 1922, he was awarded the 1921 <a href="/wiki/Nobel_Prize_in_Physics" title="Nobel Prize in Physics">Nobel Prize in Physics</a> "for his services to Theoretical Physics, and especially for his discovery of the law of the photoelectric effect".<sup id="cite_ref-Nobel_Prize_8-1" class="reference"><a href="#cite_note-Nobel_Prize-8">&#91;7&#93;</a></sup> At this point some physicists still regarded the general theory of relativity sceptically, and the Nobel citation displayed a degree of doubt even about the work on photoelectricity that it acknowledged: it did not assent to Einstein\'s notion of the particulate nature of light, which only won over the entire scientific community when <a href="/wiki/S._N._Bose" class="mw-redirect" title="S. N. Bose">S. N. Bose</a> derived the <a href="/wiki/Planck_spectrum" class="mw-redirect" title="Planck spectrum">Planck spectrum</a> in 1924. That same year, Einstein was elected an International Honorary Member of the <a href="/wiki/American_Academy_of_Arts_and_Sciences" title="American Academy of Arts and Sciences">American Academy of Arts and Sciences</a>.<sup id="cite_ref-99" class="reference"><a href="#cite_note-99">&#91;97&#93;</a></sup> Britain\'s closest equivalent of the Nobel award, the <a href="/wiki/Royal_Society" title="Royal Society">Royal Society</a>\'s <a href="/wiki/Copley_Medal" title="Copley Medal">Copley Medal</a>, was not hung around Einstein\'s neck until 1925.<sup id="cite_ref-frs_1-3" class="reference"><a href="#cite_note-frs-1">&#91;1&#93;</a></sup> He was elected an International Member of the <a href="/wiki/American_Philosophical_Society" title="American Philosophical Society">American Philosophical Society</a> in 1930.<sup id="cite_ref-100" class="reference"><a href="#cite_note-100">&#91;98&#93;</a></sup>
</p><p>Einstein resigned from the Prussian Academy in March 1933. His accomplishments in Berlin had included the completion of the general theory of relativity, proving the <a href="/wiki/Einstein%E2%80%93de_Haas_effect" title="Einstein–de Haas effect">Einstein–de Haas effect</a>, contributing to the quantum theory of radiation, and the development of <a href="/wiki/Bose%E2%80%93Einstein_statistics" title="Bose–Einstein statistics">Bose–Einstein statistics</a>.<sup id="cite_ref-dh_52-3" class="reference"><a href="#cite_note-dh-52">&#91;50&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="1919:_Putting_general_relativity_to_the_test">1919: Putting general relativity to the test</span></h3>
<figure class="mw-default-size mw-halign-right" typeof="mw:File/Thumb"><a href="/wiki/File:19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/1/1a/19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png/220px-19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png" decoding="async" width="220" height="250" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/1/1a/19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png/330px-19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/1/1a/19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png/440px-19191125_A_New_Physics_Based_on_Einstein_-_The_New_York_Times.png 2x" data-file-width="761" data-file-height="864" /></a><figcaption><i>The New York Times</i> reported confirmation of the bending of light by gravitation after  observations (made in <a href="/wiki/Pr%C3%ADncipe" title="Príncipe">Príncipe</a> and <a href="/wiki/Sobral,_Cear%C3%A1" title="Sobral, Ceará">Sobral</a>) of the 29 May 1919 eclipse were presented to a joint meeting in London of the <a href="/wiki/Royal_Society" title="Royal Society">Royal Society</a> and the <a href="/wiki/Royal_Astronomical_Society" title="Royal Astronomical Society">Royal Astronomical Society</a> on 6 November 1919.<sup id="cite_ref-NYTimes_19191125_101-0" class="reference"><a href="#cite_note-NYTimes_19191125-101">&#91;99&#93;</a></sup></figcaption></figure>
<p>In 1907, Einstein reached a milestone on his long journey from his special theory of relativity to a new idea of gravitation with the formulation of his <a href="/wiki/Equivalence_principle" title="Equivalence principle">equivalence principle</a>, which asserts that an observer in an infinitesimally small box falling freely in a gravitational field would be unable to find any evidence that the field exists. In 1911, he used the principle to estimate the amount by which a ray of light from a distant star would be <a href="/wiki/Gravitational_lens" title="Gravitational lens">bent</a> by the gravitational pull of the Sun as it passed close to the Sun\'s <a href="/wiki/Photosphere" title="Photosphere">photosphere</a> (that is, the Sun\'s apparent surface). He reworked his calculation in 1913, having now found a way to model gravitation with the <a href="/wiki/Riemann_curvature_tensor" title="Riemann curvature tensor">Riemann curvature tensor</a> of a non-Euclidean four-dimensional <a href="/wiki/Spacetime" title="Spacetime">spacetime</a>. By the fall of 1915, his reimagining of the mathematics of gravitation in terms of Riemannian geometry was complete, and he applied his new theory not just to the behavior of the Sun as a gravitational lens but also to another astronomical phenomenon, the <a href="/wiki/Precession_of_the_perihelion_of_Mercury" class="mw-redirect" title="Precession of the perihelion of Mercury">precession of the perihelion of Mercury</a> (a slow drift in the point in Mercury\'s elliptical orbit at which it approaches the Sun most closely).<sup id="cite_ref-dh_52-4" class="reference"><a href="#cite_note-dh-52">&#91;50&#93;</a></sup><sup id="cite_ref-102" class="reference"><a href="#cite_note-102">&#91;100&#93;</a></sup> A <a href="/wiki/Solar_eclipse_of_May_29,_1919" title="Solar eclipse of May 29, 1919">total eclipse of the Sun that took place on 29 May 1919</a> provided an opportunity to put his theory of gravitational lensing to the test, and observations performed by Sir <a href="/wiki/Arthur_Eddington" title="Arthur Eddington">Arthur Eddington</a> yielded results that were consistent with his calculations. Eddington\'s work was reported at length in newspapers around the world. On 7 November 1919, for example, the leading British newspaper, <i><a href="/wiki/The_Times" title="The Times">The Times</a></i>, printed a banner headline that read: "Revolution in Science&#160;– New Theory of the Universe&#160;– Newtonian Ideas Overthrown".<sup id="cite_ref-Eddington_103-0" class="reference"><a href="#cite_note-Eddington-103">&#91;101&#93;</a></sup>
</p>
<h3><span id="1921.E2.80.931923:_Coming_to_terms_with_fame"></span><span class="mw-headline" id="1921–1923:_Coming_to_terms_with_fame">1921–1923: Coming to terms with fame</span></h3>
<figure class="mw-default-size mw-halign-left" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_(Nobel).png" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/5/50/Albert_Einstein_%28Nobel%29.png/170px-Albert_Einstein_%28Nobel%29.png" decoding="async" width="170" height="240" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/5/50/Albert_Einstein_%28Nobel%29.png/255px-Albert_Einstein_%28Nobel%29.png 1.5x, //upload.wikimedia.org/wikipedia/commons/5/50/Albert_Einstein_%28Nobel%29.png 2x" data-file-width="280" data-file-height="396" /></a><figcaption>Einstein\'s official portrait after receiving the 1921 Nobel Prize for Physics</figcaption></figure>
<p>With Eddington\'s eclipse observations widely reported not just in academic journals but by the popular press as well, Einstein became "perhaps the world\'s first celebrity scientist", a genius who had shattered a paradigm that had been basic to physicists\' understanding of the universe since the seventeenth century.<sup id="cite_ref-104" class="reference"><a href="#cite_note-104">&#91;102&#93;</a></sup>
</p><p>Einstein began his new life as an intellectual icon in America, where he arrived on 2 April 1921. He was welcomed to New York City by Mayor <a href="/wiki/John_Francis_Hylan" title="John Francis Hylan">John Francis Hylan</a>, and then spent three weeks giving lectures and attending receptions.<sup id="cite_ref-105" class="reference"><a href="#cite_note-105">&#91;103&#93;</a></sup> He spoke several times at <a href="/wiki/Columbia_University" title="Columbia University">Columbia University</a> and <a href="/wiki/Princeton" class="mw-redirect" title="Princeton">Princeton</a>, and in Washington, he visited the <a href="/wiki/White_House" title="White House">White House</a> with representatives of the <a href="/wiki/National_Academy_of_Sciences" title="National Academy of Sciences">National Academy of Sciences</a>. He returned to Europe via London, where he was the guest of the philosopher and statesman <a href="/wiki/Viscount_Haldane" class="mw-redirect" title="Viscount Haldane">Viscount Haldane</a>. He used his time in the British capital to meet several people prominent in British scientific, political or intellectual life, and to deliver a lecture at <a href="/wiki/King%27s_College_London" title="King&#39;s College London">King\'s College</a>.<sup id="cite_ref-FOOTNOTEHoffmann1972145–148_106-0" class="reference"><a href="#cite_note-FOOTNOTEHoffmann1972145–148-106">&#91;104&#93;</a></sup><sup id="cite_ref-FOOTNOTEFölsing1997499–508_107-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing1997499–508-107">&#91;105&#93;</a></sup> In July 1921, he published an essay, "My First Impression of the U.S.A.", in which he sought to sketch the American character, much as had <a href="/wiki/Alexis_de_Tocqueville" title="Alexis de Tocqueville">Alexis de Tocqueville</a> in <i><a href="/wiki/Democracy_in_America" title="Democracy in America">Democracy in America</a></i> (1835).<sup id="cite_ref-7gwHd_108-0" class="reference"><a href="#cite_note-7gwHd-108">&#91;106&#93;</a></sup> He wrote of his transatlantic hosts in highly approving terms: "What strikes a visitor is the joyous, positive attitude to life ... The American is friendly, self-confident, optimistic, and without envy."<sup id="cite_ref-FOOTNOTEHolton198420_109-0" class="reference"><a href="#cite_note-FOOTNOTEHolton198420-109">&#91;107&#93;</a></sup>
</p><p>In 1922, Einstein\'s travels were to the old world rather than the new. He devoted six months to a tour of Asia that saw him speaking in Japan, Singapore and Sri Lanka (then known as <a href="/wiki/Ceylon" class="mw-redirect" title="Ceylon">Ceylon</a>). After his first public lecture in Tokyo, he met <a href="/wiki/Emperor_Yoshihito" class="mw-redirect" title="Emperor Yoshihito">Emperor Yoshihito</a> and his wife at the <a href="/wiki/Tokyo_Imperial_Palace" title="Tokyo Imperial Palace">Imperial Palace</a>, with thousands of spectators thronging the streets in the hope of catching a glimpse of him. (In a letter to his sons, he wrote that Japanese people seemed to him to be generally modest, intelligent and considerate, and to have a true appreciation of art.<sup id="cite_ref-FOOTNOTEIsaacson2007307–308_110-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007307–308-110">&#91;108&#93;</a></sup> But his picture of them in his diary was less flattering: "[the] intellectual needs of this nation seem to be weaker than their artistic ones – natural disposition?" His journal also contains views of China and India which were uncomplimentary. Of Chinese people, he wrote that "even the children are spiritless and look obtuse... It would be a pity if these Chinese supplant all other races. For the likes of us the mere thought is unspeakably dreary".<sup id="cite_ref-38YkY_111-0" class="reference"><a href="#cite_note-38YkY-111">&#91;109&#93;</a></sup><sup id="cite_ref-112" class="reference"><a href="#cite_note-112">&#91;110&#93;</a></sup>) He was greeted with even greater enthusiasm on the last leg of his tour, in which he spent twelve days in <a href="/wiki/Mandatory_Palestine" title="Mandatory Palestine">Mandatory Palestine</a>, newly entrusted to British rule by the <a href="/wiki/League_of_Nations" title="League of Nations">League of Nations</a> in the aftermath of the First World War. <a href="/wiki/Sir_Herbert_Samuel" class="mw-redirect" title="Sir Herbert Samuel">Sir Herbert Samuel</a>, the British High Commissioner, welcomed him with a degree of ceremony normally only accorded to a visiting head of state, including a cannon salute. One reception held in his honor was stormed by people determined to hear him speak: he told them that he was happy that Jews were beginning to be recognized as a force in the world.<sup id="cite_ref-FOOTNOTEIsaacson2007308_113-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007308-113">&#91;111&#93;</a></sup>
</p><p>Einstein\'s decision to tour the eastern hemisphere in 1922 meant that he was unable to go to <a href="/wiki/Stockholm" title="Stockholm">Stockholm</a> in the December of that year to participate in the Nobel prize ceremony. His place at the traditional Nobel banquet was taken by a German diplomat, who gave a speech praising him not only as a physicist but also as a campaigner for peace.<sup id="cite_ref-oxak7_114-0" class="reference"><a href="#cite_note-oxak7-114">&#91;112&#93;</a></sup> A two week visit to Spain that he undertook in 1923 saw him collecting another award, a membership of the Spanish Academy of Sciences signified by a diploma handed to him by <a href="/wiki/King_Alfonso_XIII" class="mw-redirect" title="King Alfonso XIII">King Alfonso XIII</a>. (His Spanish trip also gave him a chance to meet a fellow Nobel laureate, the neuroanatomist <a href="/wiki/Santiago_Ram%C3%B3n_y_Cajal" title="Santiago Ramón y Cajal">Santiago Ramón y Cajal</a>.)<sup id="cite_ref-w74nv_115-0" class="reference"><a href="#cite_note-w74nv-115">&#91;113&#93;</a></sup>
</p>
<h3><span id="1922.E2.80.931932:_Serving_the_League_of_Nations"></span><span class="mw-headline" id="1922–1932:_Serving_the_League_of_Nations">1922–1932: Serving the League of Nations</span></h3>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:League_of_Nations_Commission_067.tif" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/6/63/League_of_Nations_Commission_067.tif/lossy-page1-220px-League_of_Nations_Commission_067.tif.jpg" decoding="async" width="220" height="169" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/6/63/League_of_Nations_Commission_067.tif/lossy-page1-330px-League_of_Nations_Commission_067.tif.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/6/63/League_of_Nations_Commission_067.tif/lossy-page1-440px-League_of_Nations_Commission_067.tif.jpg 2x" data-file-width="5008" data-file-height="3840" /></a><figcaption>Einstein at a session of the <a href="/wiki/International_Committee_on_Intellectual_Cooperation" title="International Committee on Intellectual Cooperation">International Committee on Intellectual Cooperation</a> (<a href="/wiki/League_of_Nations" title="League of Nations">League of Nations</a>) of which he was a member from 1922 to 1932</figcaption></figure>
<p>From 1922 until 1932, with the exception of a few months in 1923 and 1924, Einstein was a member of the Geneva-based <a href="/wiki/International_Committee_on_Intellectual_Cooperation" title="International Committee on Intellectual Cooperation">International Committee on Intellectual Cooperation</a> of the <a href="/wiki/League_of_Nations" title="League of Nations">League of Nations</a>, a group set up by the League to encourage scientists, artists, scholars, teachers and other people engaged in the life of the mind to work more closely with their counterparts in other countries.<sup id="cite_ref-Q5hgx_116-0" class="reference"><a href="#cite_note-Q5hgx-116">&#91;114&#93;</a></sup><sup id="cite_ref-vNNnX_117-0" class="reference"><a href="#cite_note-vNNnX-117">&#91;115&#93;</a></sup> He was appointed as a German delegate rather than as a representative of Switzerland because of the machinations of two Catholic activists, <a href="/wiki/Oskar_Halecki" title="Oskar Halecki">Oskar Halecki</a> and <a href="/wiki/Giuseppe_Motta" title="Giuseppe Motta">Giuseppe Motta</a>. By persuading Secretary General <a href="/wiki/Eric_Drummond" class="mw-redirect" title="Eric Drummond">Eric Drummond</a> to deny Einstein the place on the committee reserved for a Swiss thinker, they created an opening for <a href="/wiki/Gonzague_de_Reynold" title="Gonzague de Reynold">Gonzague de Reynold</a>, who used his League of Nations position as a platform from which to promote traditional Catholic doctrine.<sup id="cite_ref-e9Xyh_118-0" class="reference"><a href="#cite_note-e9Xyh-118">&#91;116&#93;</a></sup> Einstein\'s former physics professor <a href="/wiki/Hendrik_Lorentz" title="Hendrik Lorentz">Hendrik Lorentz</a> and the Polish chemist <a href="/wiki/Marie_Curie" title="Marie Curie">Marie Curie</a> were also members of the committee.<sup id="cite_ref-119" class="reference"><a href="#cite_note-119">&#91;117&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="1925:_Touring_South_America">1925: Touring South America</span></h3>
<p>In March and April 1925, Einstein and his wife visited South America, where they spent about a week in Brazil, a week in Uruguay and a month in Argentina.<sup id="cite_ref-120" class="reference"><a href="#cite_note-120">&#91;118&#93;</a></sup> Their tour was suggested by Jorge Duclout (1856–1927) and Mauricio Nirenstein (1877–1935)<sup id="cite_ref-121" class="reference"><a href="#cite_note-121">&#91;119&#93;</a></sup> with the support of several Argentine scholars, including <a href="/wiki/Julio_Rey_Pastor" title="Julio Rey Pastor">Julio Rey Pastor</a>, <a href="/wiki/Jakob_Laub" title="Jakob Laub">Jakob Laub</a>, and <a href="/wiki/Leopoldo_Lugones" title="Leopoldo Lugones">Leopoldo Lugones</a>. and was financed primarily by the Council of the <a href="/wiki/University_of_Buenos_Aires" title="University of Buenos Aires">University of Buenos Aires</a> and the <i>Asociación Hebraica Argentina</i> (Argentine Hebraic Association) with a smaller contribution from the Argentine-Germanic Cultural Institution.<sup id="cite_ref-122" class="reference"><a href="#cite_note-122">&#91;120&#93;</a></sup>
</p>
<h3><span id="1930.E2.80.931931:_Touring_the_US"></span><span class="mw-headline" id="1930–1931:_Touring_the_US">1930–1931: Touring the US</span></h3>
<p>In December 1930, Einstein began another significant sojourn in the United States, drawn back to the US by the offer of a two month research fellowship at the <a href="/wiki/California_Institute_of_Technology" title="California Institute of Technology">California Institute of Technology</a>. Caltech supported him in his wish that he should not be exposed to quite as much attention from the media as he had experienced when visiting the US in 1921, and he therefore declined all the invitations to receive prizes or make speeches that his admirers poured down upon him. But he remained willing to allow his fans at least some of the time with him that they requested.<sup id="cite_ref-FOOTNOTEIsaacson2007368_123-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007368-123">&#91;121&#93;</a></sup>
</p><p>After arriving in New York City, Einstein was taken to various places and events, including <a href="/wiki/Chinatown,_Manhattan" title="Chinatown, Manhattan">Chinatown</a>, a lunch with the editors of <i>The New York Times</i>, and a performance of <i>Carmen</i> at the <a href="/wiki/Metropolitan_Opera" title="Metropolitan Opera">Metropolitan Opera</a>, where he was cheered by the audience on his arrival. During the days following, he was given the keys to the city by Mayor <a href="/wiki/Jimmy_Walker" title="Jimmy Walker">Jimmy Walker</a> and met <a href="/wiki/Nicholas_Murray_Butler" title="Nicholas Murray Butler">Nicholas Murray Butler</a>, the president of <a href="/wiki/Columbia_University" title="Columbia University">Columbia University</a>, who described Einstein as "the ruling monarch of the mind".<sup id="cite_ref-FOOTNOTEIsaacson2007370_124-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007370-124">&#91;122&#93;</a></sup> <a href="/wiki/Harry_Emerson_Fosdick" title="Harry Emerson Fosdick">Harry Emerson Fosdick</a>, pastor at New York\'s <a href="/wiki/Riverside_Church" title="Riverside Church">Riverside Church</a>, gave Einstein a tour of the church and showed him a full-size statue that the church made of Einstein, standing at the entrance.<sup id="cite_ref-FOOTNOTEIsaacson2007370_124-1" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007370-124">&#91;122&#93;</a></sup> Also during his stay in New York, he joined a crowd of 15,000 people at <a href="/wiki/Madison_Square_Garden_(1925)" title="Madison Square Garden (1925)">Madison Square Garden</a> during a <a href="/wiki/Hanukkah" title="Hanukkah">Hanukkah</a> celebration.<sup id="cite_ref-FOOTNOTEIsaacson2007370_124-2" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007370-124">&#91;122&#93;</a></sup>
</p>
<figure class="mw-default-size mw-halign-left" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/9/9c/Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg/200px-Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg" decoding="async" width="200" height="201" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/9/9c/Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg/300px-Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/9/9c/Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg/400px-Albert_Einstein_and_Charlie_Chaplin_City_Lights_premiere_1931.jpg 2x" data-file-width="1281" data-file-height="1288" /></a><figcaption>Einstein with <a href="/wiki/Charlie_Chaplin" title="Charlie Chaplin">Charlie Chaplin</a> at the <a href="/wiki/Hollywood,_Los_Angeles" title="Hollywood, Los Angeles">Hollywood</a> premiere of Chaplin\'s <i><a href="/wiki/City_Lights" title="City Lights">City Lights</a></i>, January 1931</figcaption></figure>
<p>Einstein next traveled to California, where he met <a href="/wiki/Caltech" class="mw-redirect" title="Caltech">Caltech</a> president and Nobel laureate <a href="/wiki/Robert_A._Millikan" class="mw-redirect" title="Robert A. Millikan">Robert A. Millikan</a>. His friendship with Millikan was "awkward", as Millikan "had a penchant for patriotic militarism", where Einstein was a pronounced <a href="/wiki/Pacifist" class="mw-redirect" title="Pacifist">pacifist</a>.<sup id="cite_ref-FOOTNOTEIsaacson2007373_125-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007373-125">&#91;123&#93;</a></sup> During an address to Caltech\'s students, Einstein noted that science was often inclined to do more harm than good.<sup id="cite_ref-FOOTNOTEIsaacson2007374_126-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007374-126">&#91;124&#93;</a></sup>
</p><p>This aversion to war also led Einstein to befriend author <a href="/wiki/Upton_Sinclair" title="Upton Sinclair">Upton Sinclair</a> and film star <a href="/wiki/Charlie_Chaplin" title="Charlie Chaplin">Charlie Chaplin</a>, both noted for their pacifism. <a href="/wiki/Carl_Laemmle" title="Carl Laemmle">Carl Laemmle</a>, head of <a href="/wiki/Universal_Studios" class="mw-redirect" title="Universal Studios">Universal Studios</a>, gave Einstein a tour of his studio and introduced him to Chaplin. They had an instant rapport, with Chaplin inviting Einstein and his wife, Elsa, to his home for dinner. Chaplin said Einstein\'s outward persona, calm and gentle, seemed to conceal a "highly emotional temperament", from which came his "extraordinary intellectual energy".<sup id="cite_ref-FOOTNOTEChaplin1964320_127-0" class="reference"><a href="#cite_note-FOOTNOTEChaplin1964320-127">&#91;125&#93;</a></sup>
</p><p>Chaplin\'s film <i><a href="/wiki/City_Lights" title="City Lights">City Lights</a></i> was to premiere a few days later in Hollywood, and Chaplin invited Einstein and Elsa to join him as his special guests. <a href="/wiki/Walter_Isaacson" title="Walter Isaacson">Walter Isaacson</a>, Einstein\'s biographer, described this as "one of the most memorable scenes in the new era of celebrity".<sup id="cite_ref-FOOTNOTEIsaacson2007374_126-1" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007374-126">&#91;124&#93;</a></sup> Chaplin visited Einstein at his home on a later trip to Berlin and recalled his "modest little flat" and the piano at which he had begun writing his theory. Chaplin speculated that it was "possibly used as kindling wood by the Nazis".<sup id="cite_ref-FOOTNOTEChaplin1964322_128-0" class="reference"><a href="#cite_note-FOOTNOTEChaplin1964322-128">&#91;126&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="1933:_Emigration_to_the_US">1933: Emigration to the US</span></h3>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein-cartoon1.jpg" class="mw-file-description"><img alt="Cartoon of Einstein, who has shed his &quot;Pacifism&quot; wings, standing next to a pillar labeled &quot;World Peace&quot;. He is rolling up his sleeves and holding a sword labeled &quot;Preparedness&quot;." src="//upload.wikimedia.org/wikipedia/commons/thumb/8/8b/Einstein-cartoon1.jpg/170px-Einstein-cartoon1.jpg" decoding="async" width="170" height="186" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/8/8b/Einstein-cartoon1.jpg/255px-Einstein-cartoon1.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/8/8b/Einstein-cartoon1.jpg/340px-Einstein-cartoon1.jpg 2x" data-file-width="624" data-file-height="682" /></a><figcaption>Cartoon of Einstein after shedding his "pacifism" wings (<a href="/wiki/Charles_R._Macauley" title="Charles R. Macauley">Charles R. Macauley</a>, <abbr title="circa">c.</abbr><span style="white-space:nowrap;">&#8201;1933</span>)</figcaption></figure>
<p>In February 1933, while on a visit to the United States, Einstein knew he could not return to Germany with the rise to power of the <a href="/wiki/Nazi_Germany" title="Nazi Germany">Nazis</a> under Germany\'s new chancellor, <a href="/wiki/Adolf_Hitler" title="Adolf Hitler">Adolf Hitler</a>.<sup id="cite_ref-FOOTNOTEFölsing1997659_129-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing1997659-129">&#91;127&#93;</a></sup><sup id="cite_ref-FOOTNOTEIsaacson2007404_130-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007404-130">&#91;128&#93;</a></sup>
</p><p>While at American universities in early 1933, he undertook his third two-month visiting professorship at the <a href="/wiki/California_Institute_of_Technology" title="California Institute of Technology">California Institute of Technology</a> in Pasadena. In February and March 1933, the <a href="/wiki/Gestapo" title="Gestapo">Gestapo</a> repeatedly raided his family\'s apartment in Berlin.<sup id="cite_ref-131" class="reference"><a href="#cite_note-131">&#91;129&#93;</a></sup> He and his wife Elsa returned to Europe in March, and during the trip, they learned that the German Reichstag had passed the <a href="/wiki/Enabling_Act_of_1933" title="Enabling Act of 1933">Enabling Act</a> on 23 March, transforming Hitler\'s government into a <i>de facto</i> legal dictatorship, and that they would not be able to proceed to Berlin. Later on, they heard that their cottage had been raided by the Nazis and Einstein\'s personal sailboat confiscated. Upon landing in <a href="/wiki/Antwerp" title="Antwerp">Antwerp</a>, Belgium on 28 March, Einstein immediately went to the German consulate and surrendered his passport, formally renouncing his German citizenship.<sup id="cite_ref-FOOTNOTEIsaacson2007407–410_132-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007407–410-132">&#91;130&#93;</a></sup> The Nazis later sold his boat and converted his cottage into a <a href="/wiki/Hitler_Youth" title="Hitler Youth">Hitler Youth</a> camp.<sup id="cite_ref-el4GB_133-0" class="reference"><a href="#cite_note-el4GB-133">&#91;131&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Refugee_status">Refugee status</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein%27s_landing_card_(5706142737).jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/7/78/Einstein%27s_landing_card_%285706142737%29.jpg/220px-Einstein%27s_landing_card_%285706142737%29.jpg" decoding="async" width="220" height="144" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/7/78/Einstein%27s_landing_card_%285706142737%29.jpg/330px-Einstein%27s_landing_card_%285706142737%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/7/78/Einstein%27s_landing_card_%285706142737%29.jpg/440px-Einstein%27s_landing_card_%285706142737%29.jpg 2x" data-file-width="1391" data-file-height="909" /></a><figcaption>Landing card for Einstein\'s 26 May 1933 arrival in <a href="/wiki/Dover" title="Dover">Dover</a>, England from <a href="/wiki/Ostend" title="Ostend">Ostend</a>, Belgium, enroute to <a href="/wiki/Oxford" title="Oxford">Oxford</a></figcaption></figure>
<p>In April 1933, Einstein discovered that the new German government had passed <a href="/wiki/Law_for_the_Restoration_of_the_Professional_Civil_Service" title="Law for the Restoration of the Professional Civil Service">laws barring Jews from holding any official positions</a>, including teaching at universities.<sup id="cite_ref-FOOTNOTEIsaacson2007407–410_132-1" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007407–410-132">&#91;130&#93;</a></sup> Historian <a href="/wiki/Gerald_Holton" title="Gerald Holton">Gerald Holton</a> describes how, with "virtually no audible protest being raised by their colleagues", thousands of Jewish scientists were suddenly forced to give up their university positions and their names were removed from the rolls of institutions where they were employed.<sup id="cite_ref-FOOTNOTEHolton1984_134-0" class="reference"><a href="#cite_note-FOOTNOTEHolton1984-134">&#91;132&#93;</a></sup>
</p><p>A month later, Einstein\'s works were among those targeted by the <a href="/wiki/German_Student_Union" title="German Student Union">German Student Union</a> in the <a href="/wiki/Nazi_book_burnings" title="Nazi book burnings">Nazi book burnings</a>, with Nazi propaganda minister <a href="/wiki/Joseph_Goebbels" title="Joseph Goebbels">Joseph Goebbels</a> proclaiming, "Jewish intellectualism is dead."<sup id="cite_ref-FOOTNOTEIsaacson2007407–410_132-2" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007407–410-132">&#91;130&#93;</a></sup> One German magazine included him in a list of enemies of the German regime with the phrase, "not yet hanged", offering a $5,000 bounty on his head.<sup id="cite_ref-FOOTNOTEIsaacson2007407–410_132-3" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007407–410-132">&#91;130&#93;</a></sup><sup id="cite_ref-Jerome_135-0" class="reference"><a href="#cite_note-Jerome-135">&#91;133&#93;</a></sup> In a subsequent letter to physicist and friend <a href="/wiki/Max_Born" title="Max Born">Max Born</a>, who had already emigrated from Germany to England, Einstein wrote, "...&#160;I must confess that the degree of their brutality and cowardice came as something of a surprise."<sup id="cite_ref-FOOTNOTEIsaacson2007407–410_132-4" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007407–410-132">&#91;130&#93;</a></sup> After moving to the US, he described the book burnings as a "spontaneous emotional outburst" by those who "shun popular enlightenment", and "more than anything else in the world, fear the influence of men of intellectual independence".<sup id="cite_ref-FOOTNOTEEinstein1954197_136-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1954197-136">&#91;134&#93;</a></sup>
</p><p>Einstein was now without a permanent home, unsure where he would live and work, and equally worried about the fate of countless other scientists still in Germany. Aided by the <a href="/wiki/Academic_Assistance_Council" class="mw-redirect" title="Academic Assistance Council">Academic Assistance Council</a>, founded in April 1933 by British Liberal politician <a href="/wiki/William_Beveridge" title="William Beveridge">William Beveridge</a> to help academics escape Nazi persecution, Einstein was able to leave Germany.<sup id="cite_ref-Albert_Hall_137-0" class="reference"><a href="#cite_note-Albert_Hall-137">&#91;135&#93;</a></sup> He rented a house in De Haan, Belgium, where he lived for a few months. In late July 1933, he visited England for about six weeks at the invitation of the British Member of Parliament Commander <a href="/wiki/Oliver_Locker-Lampson" title="Oliver Locker-Lampson">Oliver Locker-Lampson</a>, who had become friends with him in the preceding years.<sup id="cite_ref-138" class="reference"><a href="#cite_note-138">&#91;136&#93;</a></sup> Locker-Lampson invited him to stay near his <a href="/wiki/Cromer" title="Cromer">Cromer</a> home in a secluded wooden cabin on Roughton Heath in the Parish of <a href="/wiki/Roughton,_Norfolk" title="Roughton, Norfolk">Roughton, Norfolk</a>. To protect Einstein, Locker-Lampson had two bodyguards watch over him; a photo of them carrying shotguns and guarding Einstein was published in the <i>Daily Herald</i> on 24 July 1933.<sup id="cite_ref-FOOTNOTEIsaacson2007422_139-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007422-139">&#91;137&#93;</a></sup><sup id="cite_ref-3zIp7_140-0" class="reference"><a href="#cite_note-3zIp7-140">&#91;138&#93;</a></sup>
</p>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Churchill_and_Einstein_in_1933.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/f/f0/Churchill_and_Einstein_in_1933.jpg/220px-Churchill_and_Einstein_in_1933.jpg" decoding="async" width="220" height="172" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/f/f0/Churchill_and_Einstein_in_1933.jpg 1.5x" data-file-width="310" data-file-height="243" /></a><figcaption><a href="/wiki/Winston_Churchill" title="Winston Churchill">Winston Churchill</a> and Einstein at <a href="/wiki/Chartwell" title="Chartwell">Chartwell</a> House, 31 May 1933</figcaption></figure>
<p>Locker-Lampson took Einstein to meet <a href="/wiki/Winston_Churchill" title="Winston Churchill">Winston Churchill</a> at his home, and later, <a href="/wiki/Austen_Chamberlain" title="Austen Chamberlain">Austen Chamberlain</a> and former Prime Minister <a href="/wiki/Lloyd_George" class="mw-redirect" title="Lloyd George">Lloyd George</a>.<sup id="cite_ref-FOOTNOTEIsaacson2007419–420_141-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007419–420-141">&#91;139&#93;</a></sup> Einstein asked them to help bring Jewish scientists out of Germany. British historian <a href="/wiki/Martin_Gilbert" title="Martin Gilbert">Martin Gilbert</a> notes that Churchill responded immediately, and sent his friend, physicist <a href="/wiki/Frederick_Lindemann" class="mw-redirect" title="Frederick Lindemann">Frederick Lindemann</a>, to Germany to seek out Jewish scientists and place them in British universities.<sup id="cite_ref-Gilbert_142-0" class="reference"><a href="#cite_note-Gilbert-142">&#91;140&#93;</a></sup> Churchill later observed that as a result of Germany having driven the Jews out, they had lowered their "technical standards" and put <a href="/wiki/Allies_of_World_War_II" title="Allies of World War II">the Allies</a>\' technology ahead of theirs.<sup id="cite_ref-Gilbert_142-1" class="reference"><a href="#cite_note-Gilbert-142">&#91;140&#93;</a></sup>
</p><p>Einstein later contacted leaders of other nations, including <a href="/wiki/Turkey" title="Turkey">Turkey</a>\'s Prime Minister, <a href="/wiki/%C4%B0smet_%C4%B0n%C3%B6n%C3%BC" title="İsmet İnönü">İsmet İnönü</a>, to whom he wrote in September 1933 requesting placement of unemployed German-Jewish scientists. As a result of Einstein\'s letter, Jewish invitees to Turkey eventually totaled over "1,000 saved individuals".<sup id="cite_ref-aDu8s_143-0" class="reference"><a href="#cite_note-aDu8s-143">&#91;141&#93;</a></sup>
</p><p>Locker-Lampson also submitted a bill to parliament to extend British citizenship to Einstein, during which period Einstein made a number of public appearances describing the crisis brewing in Europe.<sup id="cite_ref-FOOTNOTEClark1971_144-0" class="reference"><a href="#cite_note-FOOTNOTEClark1971-144">&#91;142&#93;</a></sup> In one of his speeches he denounced Germany\'s treatment of Jews, while at the same time he introduced a bill promoting Jewish citizenship in Palestine, as they were being denied citizenship elsewhere.<sup id="cite_ref-AP_145-0" class="reference"><a href="#cite_note-AP-145">&#91;143&#93;</a></sup> In his speech he described Einstein as a "citizen of the world" who should be offered a temporary shelter in the UK.<sup id="cite_ref-gnriE_146-0" class="reference"><a href="#cite_note-gnriE-146">&#91;note 3&#93;</a></sup><sup id="cite_ref-Guardian_147-0" class="reference"><a href="#cite_note-Guardian-147">&#91;144&#93;</a></sup> Both bills failed, however, and Einstein then accepted an earlier offer from the <a href="/wiki/Institute_for_Advanced_Study" title="Institute for Advanced Study">Institute for Advanced Study</a>, in <a href="/wiki/Princeton,_New_Jersey" title="Princeton, New Jersey">Princeton, New Jersey</a>, US, to become a resident scholar.<sup id="cite_ref-FOOTNOTEClark1971_144-1" class="reference"><a href="#cite_note-FOOTNOTEClark1971-144">&#91;142&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Resident_scholar_at_the_Institute_for_Advanced_Study">Resident scholar at the Institute for Advanced Study</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein-formal_portrait-35_(cropped).jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/b/b2/Einstein-formal_portrait-35_%28cropped%29.jpg/170px-Einstein-formal_portrait-35_%28cropped%29.jpg" decoding="async" width="170" height="213" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/b/b2/Einstein-formal_portrait-35_%28cropped%29.jpg/255px-Einstein-formal_portrait-35_%28cropped%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/b/b2/Einstein-formal_portrait-35_%28cropped%29.jpg/340px-Einstein-formal_portrait-35_%28cropped%29.jpg 2x" data-file-width="510" data-file-height="638" /></a><figcaption>Portrait of Einstein taken in 1935 at Princeton</figcaption></figure>
<p>On 3 October 1933, Einstein delivered a speech on the importance of academic freedom before a packed audience at the <a href="/wiki/Royal_Albert_Hall" title="Royal Albert Hall">Royal Albert Hall</a> in London, with <i><a href="/wiki/The_Times" title="The Times">The Times</a></i> reporting he was wildly cheered throughout.<sup id="cite_ref-Albert_Hall_137-1" class="reference"><a href="#cite_note-Albert_Hall-137">&#91;135&#93;</a></sup> Four days later he returned to the US and took up a position at the <a href="/wiki/Institute_for_Advanced_Study" title="Institute for Advanced Study">Institute for Advanced Study</a>,<sup id="cite_ref-FOOTNOTEClark1971_144-2" class="reference"><a href="#cite_note-FOOTNOTEClark1971-144">&#91;142&#93;</a></sup><sup id="cite_ref-FOOTNOTEFölsing1997649,_678_148-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing1997649,_678-148">&#91;145&#93;</a></sup> noted for having become a refuge for scientists fleeing Nazi Germany.<sup id="cite_ref-Arntzenius2011_149-0" class="reference"><a href="#cite_note-Arntzenius2011-149">&#91;146&#93;</a></sup> At the time, most American universities, including Harvard, Princeton and Yale, had minimal or no Jewish faculty or students, as a result of their <a href="/wiki/Jewish_quota" title="Jewish quota">Jewish quotas</a>, which lasted until the late 1940s.<sup id="cite_ref-Arntzenius2011_149-1" class="reference"><a href="#cite_note-Arntzenius2011-149">&#91;146&#93;</a></sup>
</p><p>Einstein was still undecided on his future. He had offers from several European universities, including <a href="/wiki/Christ_Church,_Oxford" title="Christ Church, Oxford">Christ Church, Oxford</a>, where he stayed for three short periods between May 1931 and June 1933 and was offered a five-year research <a href="/wiki/Fellowship" class="mw-redirect" title="Fellowship">fellowship</a> (called a "<a href="/wiki/Studentship" class="mw-redirect" title="Studentship">studentship</a>" at Christ Church),<sup id="cite_ref-FFt5E_150-0" class="reference"><a href="#cite_note-FFt5E-150">&#91;147&#93;</a></sup><sup id="cite_ref-v8v06_151-0" class="reference"><a href="#cite_note-v8v06-151">&#91;148&#93;</a></sup> but in 1935, he arrived at the decision to remain permanently in the United States and apply for citizenship.<sup id="cite_ref-FOOTNOTEClark1971_144-3" class="reference"><a href="#cite_note-FOOTNOTEClark1971-144">&#91;142&#93;</a></sup><sup id="cite_ref-FOOTNOTEFölsing1997686–687_152-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing1997686–687-152">&#91;149&#93;</a></sup>
</p><p>Einstein\'s affiliation with the Institute for Advanced Study would last until his death in 1955.<sup id="cite_ref-mzNc5_153-0" class="reference"><a href="#cite_note-mzNc5-153">&#91;150&#93;</a></sup> He was one of the four first selected (along with <a href="/wiki/John_von_Neumann" title="John von Neumann">John von Neumann</a>, <a href="/wiki/Kurt_G%C3%B6del" title="Kurt Gödel">Kurt Gödel</a>, and <a href="/wiki/Hermann_Weyl" title="Hermann Weyl">Hermann Weyl</a><sup id="cite_ref-154" class="reference"><a href="#cite_note-154">&#91;151&#93;</a></sup>) at the new Institute. He soon developed a close friendship with Gödel; the two would take long walks together discussing their work. <a href="/wiki/Bruria_Kaufman" title="Bruria Kaufman">Bruria Kaufman</a>, his assistant, later became a physicist. During this period, Einstein tried to develop a <a href="/wiki/Unified_field_theory" title="Unified field theory">unified field theory</a> and to refute the <a href="/wiki/Copenhagen_interpretation" title="Copenhagen interpretation">accepted interpretation</a> of <a href="/wiki/Quantum_physics" class="mw-redirect" title="Quantum physics">quantum physics</a>, both unsuccessfully. He lived in Princeton at his home from 1935 onwards. The <a href="/wiki/Albert_Einstein_House" title="Albert Einstein House">Albert Einstein House</a> was made a <a href="/wiki/National_Historic_Landmark" title="National Historic Landmark">National Historic Landmark</a> in 1976.
</p>
<h4><span class="mw-headline" id="World_War_II_and_the_Manhattan_Project">World War II and the Manhattan Project</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">See also: <a href="/wiki/Einstein%E2%80%93Szil%C3%A1rd_letter" class="mw-redirect" title="Einstein–Szilárd letter">Einstein–Szilárd letter</a></div>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/8/8f/M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg/220px-M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg" decoding="async" width="220" height="330" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/8/8f/M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg/330px-M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/8/8f/M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg/440px-M%C3%BCnchen-2021-Deutsches_Museum-Einstein.jpg 2x" data-file-width="2877" data-file-height="4315" /></a><figcaption>Marble bust of Einstein at the <a href="/wiki/Deutsches_Museum" title="Deutsches Museum">Deutsches Museum</a> in <a href="/wiki/Munich" title="Munich">Munich</a></figcaption></figure>
<p>In 1939, a group of Hungarian scientists that included émigré physicist <a href="/wiki/Le%C3%B3_Szil%C3%A1rd" class="mw-redirect" title="Leó Szilárd">Leó Szilárd</a> attempted to alert <a href="/wiki/Washington,_D.C." title="Washington, D.C.">Washington</a> to ongoing Nazi atomic bomb research. The group\'s warnings were discounted. Einstein and Szilárd, along with other refugees such as <a href="/wiki/Edward_Teller" title="Edward Teller">Edward Teller</a> and <a href="/wiki/Eugene_Wigner" title="Eugene Wigner">Eugene Wigner</a>, "regarded it as their responsibility to alert Americans to the possibility that German scientists might win the <a href="/wiki/German_nuclear_energy_project" class="mw-redirect" title="German nuclear energy project">race to build an atomic bomb</a>, and to warn that Hitler would be more than willing to resort to such a weapon."<sup id="cite_ref-FOOTNOTEIsaacson2007630_155-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007630-155">&#91;152&#93;</a></sup><sup id="cite_ref-o4fkQ_156-0" class="reference"><a href="#cite_note-o4fkQ-156">&#91;153&#93;</a></sup> To make certain the US was aware of the danger, in July 1939, a few months before the beginning of World War II in Europe, Szilárd and Wigner visited Einstein to explain the possibility of atomic bombs, which Einstein, a pacifist, said he had never considered.<sup id="cite_ref-pRqWK_157-0" class="reference"><a href="#cite_note-pRqWK-157">&#91;154&#93;</a></sup> He was asked to lend his support by writing <a href="/wiki/Einstein%E2%80%93Szilard_letter" title="Einstein–Szilard letter">a letter</a>, with Szilárd, to President <a href="/wiki/Franklin_D._Roosevelt" title="Franklin D. Roosevelt">Roosevelt</a>, recommending the US pay attention and engage in its own nuclear weapons research.
</p><p>The letter is believed to be "arguably the key stimulus for the U.S. adoption of serious investigations into nuclear weapons on the eve of the U.S. entry into World War II".<sup id="cite_ref-4Z68g_158-0" class="reference"><a href="#cite_note-4Z68g-158">&#91;155&#93;</a></sup> In addition to the letter, Einstein used his connections with the <a href="/wiki/Belgian_royal_family" class="mw-redirect" title="Belgian royal family">Belgian royal family</a><sup id="cite_ref-eZym8_159-0" class="reference"><a href="#cite_note-eZym8-159">&#91;156&#93;</a></sup> and the Belgian queen mother to get access with a personal envoy to the White House\'s Oval Office. Some say that as a result of Einstein\'s letter and his meetings with Roosevelt, the US entered the "race" to develop the bomb, drawing on its "immense material, financial, and scientific resources" to initiate the <a href="/wiki/Manhattan_Project" title="Manhattan Project">Manhattan Project</a>.
</p><p>For Einstein, "war was a disease&#160;... [and] he called for resistance to war." By signing the letter to Roosevelt, some argue he went against his pacifist principles.<sup id="cite_ref-z73PK_160-0" class="reference"><a href="#cite_note-z73PK-160">&#91;157&#93;</a></sup> In 1954, a year before his death, Einstein said to his old friend, <a href="/wiki/Linus_Pauling" title="Linus Pauling">Linus Pauling</a>, "I made one great mistake in my life—when I signed the letter to President Roosevelt recommending that atom bombs be made; but there was some justification—the danger that the Germans would make them&#160;..."<sup id="cite_ref-FOOTNOTEClark1971752_161-0" class="reference"><a href="#cite_note-FOOTNOTEClark1971752-161">&#91;158&#93;</a></sup> In 1955, Einstein and ten other intellectuals and scientists, including British philosopher <a href="/wiki/Bertrand_Russell" title="Bertrand Russell">Bertrand Russell</a>, signed <a href="/wiki/Russell%E2%80%93Einstein_Manifesto" title="Russell–Einstein Manifesto">a manifesto</a> highlighting the danger of nuclear weapons.<sup id="cite_ref-162" class="reference"><a href="#cite_note-162">&#91;159&#93;</a></sup> In 1960 Einstein was included posthumously as a charter member of the <a href="/wiki/World_Academy_of_Art_and_Science" title="World Academy of Art and Science">World Academy of Art and Science</a> (WAAS),<sup id="cite_ref-163" class="reference"><a href="#cite_note-163">&#91;160&#93;</a></sup> an organization founded by distinguished scientists and intellectuals who committed themselves to the responsible and ethical advances of science, particularly in light of the development of nuclear weapons.
</p>
<h4><span class="mw-headline" id="US_citizenship">US citizenship</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Citizen-Einstein.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/8/8a/Citizen-Einstein.jpg/220px-Citizen-Einstein.jpg" decoding="async" width="220" height="167" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/8/8a/Citizen-Einstein.jpg/330px-Citizen-Einstein.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/8/8a/Citizen-Einstein.jpg/440px-Citizen-Einstein.jpg 2x" data-file-width="2220" data-file-height="1683" /></a><figcaption>Einstein accepting a <a href="/wiki/Citizenship_of_the_United_States" title="Citizenship of the United States">US citizenship</a> certificate from judge <a href="/wiki/Phillip_Forman" title="Phillip Forman">Phillip Forman</a></figcaption></figure>
<p>Einstein became an American citizen in 1940. Not long after settling into his career at the Institute for Advanced Study in Princeton, New Jersey, he expressed his appreciation of the <a href="/wiki/Meritocracy" title="Meritocracy">meritocracy</a> in American culture compared to Europe. He recognized the "right of individuals to say and think what they pleased" without social barriers. As a result, individuals were encouraged, he said, to be more creative, a trait he valued from his early education.<sup id="cite_ref-FOOTNOTEIsaacson2007432_164-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007432-164">&#91;161&#93;</a></sup>
</p><p>Einstein joined the <a href="/wiki/National_Association_for_the_Advancement_of_Colored_People" class="mw-redirect" title="National Association for the Advancement of Colored People">National Association for the Advancement of Colored People</a> (NAACP) in Princeton, where he campaigned for the <a href="/wiki/Civil_rights_movement_(1896%E2%80%931954)" title="Civil rights movement (1896–1954)">civil rights</a> of African Americans. He considered racism America\'s "worst disease",<sup id="cite_ref-Jerome_135-1" class="reference"><a href="#cite_note-Jerome-135">&#91;133&#93;</a></sup><sup id="cite_ref-smithsonianmag_165-0" class="reference"><a href="#cite_note-smithsonianmag-165">&#91;162&#93;</a></sup> seeing it as "handed down from one generation to the next".<sup id="cite_ref-FOOTNOTECalaprice2005148–149_166-0" class="reference"><a href="#cite_note-FOOTNOTECalaprice2005148–149-166">&#91;163&#93;</a></sup> As part of his involvement, he corresponded with civil rights activist <a href="/wiki/W._E._B._Du_Bois" title="W. E. B. Du Bois">W. E. B. Du Bois</a> and was prepared to testify on his behalf during his trial as an alleged foreign agent in 1951.<sup id="cite_ref-FOOTNOTERobeson2002565_167-0" class="reference"><a href="#cite_note-FOOTNOTERobeson2002565-167">&#91;164&#93;</a></sup> When Einstein offered to be a character witness for Du Bois, the judge decided to drop the case.<sup id="cite_ref-civil_168-0" class="reference"><a href="#cite_note-civil-168">&#91;165&#93;</a></sup>
</p><p>In 1946, Einstein visited <a href="/wiki/Lincoln_University_(Pennsylvania)" title="Lincoln University (Pennsylvania)">Lincoln University</a> in Pennsylvania, a <a href="/wiki/Historically_black_college" class="mw-redirect" title="Historically black college">historically black college</a>, where he was awarded an honorary degree. Lincoln was the first university in the United States to grant college degrees to African Americans; alumni include <a href="/wiki/Langston_Hughes" title="Langston Hughes">Langston Hughes</a> and <a href="/wiki/Thurgood_Marshall" title="Thurgood Marshall">Thurgood Marshall</a>. Einstein gave a speech about racism in America, adding, "I do not intend to be quiet about it."<sup id="cite_ref-Jerome_Isis_169-0" class="reference"><a href="#cite_note-Jerome_Isis-169">&#91;166&#93;</a></sup> A resident of Princeton recalls that Einstein had once paid the college tuition for a black student.<sup id="cite_ref-civil_168-1" class="reference"><a href="#cite_note-civil-168">&#91;165&#93;</a></sup> Einstein has said, "Being a Jew myself, perhaps I can understand and empathize with how black people feel as victims of discrimination".<sup id="cite_ref-smithsonianmag_165-1" class="reference"><a href="#cite_note-smithsonianmag-165">&#91;162&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="Personal_views">Personal views</span></h3>
<h4><span class="mw-headline" id="Political_views">Political views</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Political_views_of_Albert_Einstein" title="Political views of Albert Einstein">Political views of Albert Einstein</a></div>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein_Apr.1921_SS_Rotterdam_32099.jpg" class="mw-file-description"><img alt="Casual group shot of four men and two women standing on a brick pavement." src="//upload.wikimedia.org/wikipedia/commons/thumb/b/b0/Einstein_Apr.1921_SS_Rotterdam_32099.jpg/220px-Einstein_Apr.1921_SS_Rotterdam_32099.jpg" decoding="async" width="220" height="151" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/b/b0/Einstein_Apr.1921_SS_Rotterdam_32099.jpg/330px-Einstein_Apr.1921_SS_Rotterdam_32099.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/b/b0/Einstein_Apr.1921_SS_Rotterdam_32099.jpg/440px-Einstein_Apr.1921_SS_Rotterdam_32099.jpg 2x" data-file-width="4072" data-file-height="2792" /></a><figcaption>Albert Einstein and <a href="/wiki/Elsa_Einstein" title="Elsa Einstein">Elsa Einstein</a> arriving in New York in 1921. Accompanying them are Zionist leaders <a href="/wiki/Chaim_Weizmann" title="Chaim Weizmann">Chaim Weizmann</a> (future president of Israel), Weizmann\'s wife <a href="/wiki/Vera_Weizmann" title="Vera Weizmann">Vera Weizmann</a>, <a href="/wiki/Menahem_Ussishkin" class="mw-redirect" title="Menahem Ussishkin">Menahem Ussishkin</a>, and Ben-Zion Mossinson.</figcaption></figure>
<p>In 1918, Einstein was one of the signatories of the founding proclamation of the <a href="/wiki/German_Democratic_Party" title="German Democratic Party">German Democratic Party</a>, a liberal party.<sup id="cite_ref-170" class="reference"><a href="#cite_note-170">&#91;167&#93;</a></sup><sup id="cite_ref-171" class="reference"><a href="#cite_note-171">&#91;168&#93;</a></sup> Later in his life, Einstein\'s political view was in favor of <a href="/wiki/Socialism" title="Socialism">socialism</a> and critical of capitalism, which he detailed in his essays such as "<a href="/wiki/Why_Socialism%3F" title="Why Socialism?">Why Socialism?</a>".<sup id="cite_ref-FOOTNOTEEinstein1949_172-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1949-172">&#91;169&#93;</a></sup><sup id="cite_ref-LXsUJ_173-0" class="reference"><a href="#cite_note-LXsUJ-173">&#91;170&#93;</a></sup> His opinions on the <a href="/wiki/Bolsheviks" title="Bolsheviks">Bolsheviks</a> also changed with time. In 1925, he criticized them for not having a "well-regulated system of government" and called their rule a "regime of terror and a tragedy in human history". He later adopted a more moderated view, criticizing their methods but praising them, which is shown by his 1929 remark on <a href="/wiki/Vladimir_Lenin" title="Vladimir Lenin">Vladimir Lenin</a>:
</p>
<style data-mw-deduplicate="TemplateStyles:r1211633275">.mw-parser-output .templatequote{overflow:hidden;margin:1em 0;padding:0 32px}.mw-parser-output .templatequote .templatequotecite{line-height:1.5em;text-align:left;padding-left:1.6em;margin-top:0}</style><blockquote class="templatequote"><p>In Lenin I honor a man, who in total sacrifice of his own person has committed his entire energy to realizing social justice. I do not find his methods advisable. One thing is certain, however: men like him are the guardians and renewers of mankind\'s conscience.<sup id="cite_ref-FOOTNOTERoweSchulmann2013&#91;httpsbooksgooglecombooksid_X1dAAAAQBAJpg413_412,_413&#93;_174-0" class="reference"><a href="#cite_note-FOOTNOTERoweSchulmann2013[httpsbooksgooglecombooksid_X1dAAAAQBAJpg413_412,_413]-174">&#91;171&#93;</a></sup></p></blockquote>
<p>Einstein offered and was called on to give judgments and opinions on matters often unrelated to theoretical physics or mathematics.<sup id="cite_ref-FOOTNOTEClark1971_144-4" class="reference"><a href="#cite_note-FOOTNOTEClark1971-144">&#91;142&#93;</a></sup> He strongly advocated the idea of a democratic <a href="/wiki/Global_government" class="mw-redirect" title="Global government">global government</a> that would check the power of nation-states in the framework of a world federation.<sup id="cite_ref-FOOTNOTEIsaacson2007487,_494,_550_175-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007487,_494,_550-175">&#91;172&#93;</a></sup> He wrote "I advocate world government because I am convinced that there is no other possible way of eliminating the most terrible danger in which man has ever found himself."<sup id="cite_ref-176" class="reference"><a href="#cite_note-176">&#91;173&#93;</a></sup> The FBI created a secret dossier on Einstein in 1932; by the time of his death, it was 1,427 pages long.<sup id="cite_ref-ixWWZ_177-0" class="reference"><a href="#cite_note-ixWWZ-177">&#91;174&#93;</a></sup>
</p><p>Einstein was deeply impressed by <a href="/wiki/Mahatma_Gandhi" title="Mahatma Gandhi">Mahatma Gandhi</a>, with whom he corresponded. He described Gandhi as "a role model for the generations to come".<sup id="cite_ref-Albano-Müller_178-0" class="reference"><a href="#cite_note-Albano-Müller-178">&#91;175&#93;</a></sup> The initial connection was established on 27 September 1931, when <a href="/wiki/Wilfrid_Israel" title="Wilfrid Israel">Wilfrid Israel</a> took his Indian guest <a href="/wiki/V._A._Sundaram" title="V. A. Sundaram">V. A. Sundaram</a> to meet his friend Einstein at his summer home in the town of Caputh. Sundaram was Gandhi\'s disciple and special envoy, whom Wilfrid Israel met while visiting India and visiting the Indian leader\'s home in 1925. During the visit, Einstein wrote a short letter to Gandhi that was delivered to him through his envoy, and Gandhi responded quickly with his own letter. Although in the end Einstein and Gandhi were unable to meet as they had hoped, the direct connection between them was established through Wilfrid Israel.<sup id="cite_ref-179" class="reference"><a href="#cite_note-179">&#91;176&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Relationship_with_Zionism">Relationship with Zionism</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Political_views_of_Albert_Einstein#Zionism" title="Political views of Albert Einstein">Political views of Albert Einstein §&#160;Zionism</a></div>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_Head.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/d/d3/Albert_Einstein_Head.jpg/170px-Albert_Einstein_Head.jpg" decoding="async" width="170" height="227" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/d/d3/Albert_Einstein_Head.jpg/255px-Albert_Einstein_Head.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/d/d3/Albert_Einstein_Head.jpg/340px-Albert_Einstein_Head.jpg 2x" data-file-width="3250" data-file-height="4333" /></a><figcaption>Einstein in 1947</figcaption></figure>
<p>Einstein was a figurehead leader in the establishment of the <a href="/wiki/Hebrew_University_of_Jerusalem" title="Hebrew University of Jerusalem">Hebrew University of Jerusalem</a>,<sup id="cite_ref-180" class="reference"><a href="#cite_note-180">&#91;177&#93;</a></sup> which opened in 1925. Earlier, in 1921, he was asked by the biochemist and president of the <a href="/wiki/World_Zionist_Organization" title="World Zionist Organization">World Zionist Organization</a>, <a href="/wiki/Chaim_Weizmann" title="Chaim Weizmann">Chaim Weizmann</a>, to help raise funds for the planned university.<sup id="cite_ref-FOOTNOTEIsaacson2007290_181-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007290-181">&#91;178&#93;</a></sup> He made suggestions for the creation of an Institute of Agriculture, a Chemical Institute and an Institute of Microbiology in order to fight the various ongoing epidemics such as <a href="/wiki/Malaria" title="Malaria">malaria</a>, which he called an "evil" that was undermining a third of the country\'s development.<sup id="cite_ref-FOOTNOTERoweSchulmann2007161_182-0" class="reference"><a href="#cite_note-FOOTNOTERoweSchulmann2007161-182">&#91;179&#93;</a></sup> He also promoted the establishment of an Oriental Studies Institute, to include language courses given in both Hebrew and Arabic.<sup id="cite_ref-FOOTNOTERoweSchulmann2007158_183-0" class="reference"><a href="#cite_note-FOOTNOTERoweSchulmann2007158-183">&#91;180&#93;</a></sup>
</p><p>Einstein referred to himself as a member of the Zionist movement<sup id="cite_ref-184" class="reference"><a href="#cite_note-184">&#91;181&#93;</a></sup> and supported the right of Jewish people to return to Palestine, but favored a “<a href="/wiki/One-state_solution" title="One-state solution">free, bi-national Palestine</a>” in which Jews and Arabs would share sovereignty.<sup id="cite_ref-:0_185-0" class="reference"><a href="#cite_note-:0-185">&#91;182&#93;</a></sup> In a 1945 letter to Judge Jerome Frank, Einstein wrote, “Zionism has also a very good influence on the Jewish people…Jews who have a vivid feeling of Jewish national solidarity are much better equipped to overcome with dignity all the dangers and hardships which we have to face.” He continued, however,&#160;“I dislike nationalism very much — even Jewish nationalism. But our own national solidarity is forced upon us by a hostile world, and not the aggressive feelings which we connect with the word ‘Nationalism’.”<sup id="cite_ref-:0_185-1" class="reference"><a href="#cite_note-:0-185">&#91;182&#93;</a></sup> In a 1946 letter to Maurice Dunay, he wrote, “I am in favor of Palestine being developed as a Jewish Homeland, but not as a separate state.”<sup id="cite_ref-:0_185-2" class="reference"><a href="#cite_note-:0-185">&#91;182&#93;</a></sup>
</p><p>Upon the death of Israeli president Weizmann in November 1952, Prime Minister <a href="/wiki/David_Ben-Gurion" title="David Ben-Gurion">David Ben-Gurion</a> offered Einstein the largely ceremonial position of <a href="/wiki/President_of_Israel" title="President of Israel">President of Israel</a> at the urging of <a href="/wiki/Ezriel_Carlebach" title="Ezriel Carlebach">Ezriel Carlebach</a>.<sup id="cite_ref-Time_186-0" class="reference"><a href="#cite_note-Time-186">&#91;183&#93;</a></sup><sup id="cite_ref-Msb2q_187-0" class="reference"><a href="#cite_note-Msb2q-187">&#91;184&#93;</a></sup> The offer was presented by Israel\'s ambassador in Washington, <a href="/wiki/Abba_Eban" title="Abba Eban">Abba Eban</a>, who explained that the offer "embodies the deepest respect which the Jewish people can repose in any of its sons".<sup id="cite_ref-FOOTNOTEIsaacson2007522_188-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007522-188">&#91;185&#93;</a></sup> Einstein wrote that he was "deeply moved", but "at once saddened and ashamed" that he could not accept it.<sup id="cite_ref-FOOTNOTEIsaacson2007522_188-1" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2007522-188">&#91;185&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Religious_and_philosophical_views">Religious and philosophical views</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><span><audio id="mwe_player_1" controls="" preload="none" class="mw-file-element" width="220" style="width:220px;" data-durationhint="91" data-mwtitle="03_ALBERT_EINSTEIN.ogg" data-mwprovider="wikimediacommons" resource="/wiki/File:03_ALBERT_EINSTEIN.ogg"><source src="//upload.wikimedia.org/wikipedia/commons/4/46/03_ALBERT_EINSTEIN.ogg" type="audio/ogg; codecs=&quot;vorbis&quot;" data-width="0" data-height="0" /><source src="//upload.wikimedia.org/wikipedia/commons/transcoded/4/46/03_ALBERT_EINSTEIN.ogg/03_ALBERT_EINSTEIN.ogg.mp3" type="audio/mpeg" data-transcodekey="mp3" data-width="0" data-height="0" /></audio></span><figcaption>Opening of Einstein\'s speech (11 April 1943) for the United Jewish Appeal (recording by Radio Universidad Nacional de La Plata, Argentina) <hr /> "Ladies (coughs) and gentlemen, our age is proud of the progress it has made in man\'s intellectual development. The search and striving for truth and knowledge is one of the highest of man\'s qualities&#160;..."</figcaption></figure>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Religious_and_philosophical_views_of_Albert_Einstein" title="Religious and philosophical views of Albert Einstein">Religious and philosophical views of Albert Einstein</a></div>
<p>Einstein expounded his spiritual outlook in a wide array of writings and interviews.<sup id="cite_ref-018QJ_189-0" class="reference"><a href="#cite_note-018QJ-189">&#91;186&#93;</a></sup> He said he had sympathy for the impersonal <a href="/wiki/Pantheistic" class="mw-redirect" title="Pantheistic">pantheistic</a> God of <a href="/wiki/Spinozism" class="mw-redirect" title="Spinozism">Baruch Spinoza\'s philosophy</a>.<sup id="cite_ref-FOOTNOTEIsaacson2008&#91;httpsbooksgooglecombooksidG_iziBAPXtECpgPA325_325&#93;_190-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2008[httpsbooksgooglecombooksidG_iziBAPXtECpgPA325_325]-190">&#91;187&#93;</a></sup> He did not believe in a <a href="/wiki/Personal_god" title="Personal god">personal god</a> who concerns himself with fates and actions of human beings, a view which he described as naïve.<sup id="cite_ref-FOOTNOTECalaprice2000218_191-0" class="reference"><a href="#cite_note-FOOTNOTECalaprice2000218-191">&#91;188&#93;</a></sup> He clarified, however, that "I am not an atheist",<sup id="cite_ref-FOOTNOTEIsaacson2008&#91;httpsbooksgooglecombooksidcdxWNE7NY6QCpgPT390_390&#93;_192-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2008[httpsbooksgooglecombooksidcdxWNE7NY6QCpgPT390_390]-192">&#91;189&#93;</a></sup> preferring to call himself an agnostic,<sup id="cite_ref-FOOTNOTECalaprice2010&#91;httpsbooksgooglecombooksidG_iziBAPXtECpgPA340_340&#93;_193-0" class="reference"><a href="#cite_note-FOOTNOTECalaprice2010[httpsbooksgooglecombooksidG_iziBAPXtECpgPA340_340]-193">&#91;190&#93;</a></sup><sup id="cite_ref-flickr2687_194-0" class="reference"><a href="#cite_note-flickr2687-194">&#91;191&#93;</a></sup> or a "deeply religious nonbeliever".<sup id="cite_ref-FOOTNOTECalaprice2000218_191-1" class="reference"><a href="#cite_note-FOOTNOTECalaprice2000218-191">&#91;188&#93;</a></sup> When asked if he believed in an <a href="/wiki/Afterlife" title="Afterlife">afterlife</a>, Einstein replied, "No. And one life is enough for me."<sup id="cite_ref-FOOTNOTEIsaacson2008&#91;httpsbooksgooglecombooksidOzSJgdwk5esCpgPT461_461&#93;_195-0" class="reference"><a href="#cite_note-FOOTNOTEIsaacson2008[httpsbooksgooglecombooksidOzSJgdwk5esCpgPT461_461]-195">&#91;192&#93;</a></sup>
</p><p>Einstein was primarily affiliated with non-religious <a href="/wiki/Secular_humanist" class="mw-redirect" title="Secular humanist">humanist</a> and <a href="/wiki/Ethical_Culture" class="mw-redirect" title="Ethical Culture">Ethical Culture</a> groups in both the UK and US. He served on the advisory board of the <a href="/wiki/First_Humanist_Society_of_New_York" title="First Humanist Society of New York">First Humanist Society of New York</a>,<sup id="cite_ref-mKToJ_196-0" class="reference"><a href="#cite_note-mKToJ-196">&#91;193&#93;</a></sup> and was an honorary associate of the <a href="/wiki/Rationalist_Association" title="Rationalist Association">Rationalist Association</a>, which publishes <i><a href="/wiki/New_Humanist" title="New Humanist">New Humanist</a></i> in Britain. For the 75th anniversary of the <a href="/wiki/New_York_Society_for_Ethical_Culture" class="mw-redirect" title="New York Society for Ethical Culture">New York Society for Ethical Culture</a>, he stated that the idea of Ethical Culture embodied his personal conception of what is most valuable and enduring in religious idealism. He observed, "Without \'ethical culture\' there is no salvation for humanity."<sup id="cite_ref-FOOTNOTEEinstein1995&#91;httpsbooksgooglecombooksid9fJkBqwDD3sCpgPA62_62&#93;_197-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1995[httpsbooksgooglecombooksid9fJkBqwDD3sCpgPA62_62]-197">&#91;194&#93;</a></sup>
</p><p>
In a German-language letter to philosopher <a href="/wiki/Eric_Gutkind" title="Eric Gutkind">Eric Gutkind</a>, dated 3 January 1954, Einstein wrote:</p><blockquote><p><a href="/wiki/God_(word)" title="God (word)">The word God</a> is for me nothing more than the expression and product of human weaknesses, the Bible a collection of honorable, but still primitive legends which are nevertheless pretty childish. No interpretation no matter how subtle can (for me) change this. ... For me the <a href="/wiki/Jewish_religion" class="mw-redirect" title="Jewish religion">Jewish religion</a> like all other religions is an incarnation of the most childish superstitions. And the <a href="/wiki/Jewish_people" class="mw-redirect" title="Jewish people">Jewish people</a> to whom I gladly belong and with whose mentality I have a deep affinity have no different quality for me than all other people. ... I cannot see anything \'<a href="/wiki/Jews_as_the_chosen_people" title="Jews as the chosen people">chosen</a>\' about them.<sup id="cite_ref-xI99y_198-0" class="reference"><a href="#cite_note-xI99y-198">&#91;195&#93;</a></sup></p></blockquote><p>
Einstein had been sympathetic toward vegetarianism for a long time. In a letter in 1930 to Hermann Huth, vice-president of the <a href="/wiki/ProVeg_Deutschland#History" title="ProVeg Deutschland">German Vegetarian Federation (Deutsche Vegetarier-Bund)</a>, he wrote:</p><blockquote><p>Although I have been prevented by outward circumstances from observing a strictly vegetarian diet, I have long been an adherent to the cause in principle. Besides agreeing with the aims of vegetarianism for aesthetic and moral reasons, it is my view that a vegetarian manner of living by its purely physical effect on the human temperament would most beneficially influence the lot of mankind.<sup id="cite_ref-199" class="reference"><a href="#cite_note-199">&#91;196&#93;</a></sup></p></blockquote>
<p>He became a vegetarian himself only during the last part of his life. In March 1954 he wrote in a letter: "So I am living without fats, without meat, without fish, but am feeling quite well this way. It almost seems to me that man was not born to be a carnivore."<sup id="cite_ref-200" class="reference"><a href="#cite_note-200">&#91;197&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Love_of_music">Love of music</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/5/5f/Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg/220px-Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg" decoding="async" width="220" height="191" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/5/5f/Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg/330px-Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/5/5f/Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg/440px-Wanda_von_Debschitz-Kunowski_Albert_Einstein_beim_Geigenspiel_1927.jpg 2x" data-file-width="2115" data-file-height="1841" /></a><figcaption>Einstein playing the violin (image published in 1927)</figcaption></figure>
<p>Einstein developed an appreciation for music at an early age. In his late journals he wrote:
</p>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1211633275"><blockquote class="templatequote"><p>If I were not a physicist, I would probably be a musician. I often think in music. I live my daydreams in music. I see my life in terms of music&#160;... I get most joy in life out of music.<sup id="cite_ref-BQH5A_201-0" class="reference"><a href="#cite_note-BQH5A-201">&#91;198&#93;</a></sup><sup id="cite_ref-aBOjz_202-0" class="reference"><a href="#cite_note-aBOjz-202">&#91;199&#93;</a></sup></p></blockquote>
<p>His mother played the piano reasonably well and wanted her son to learn the violin, not only to instill in him a love of music but also to help him assimilate into <a href="/wiki/German_culture" class="mw-redirect" title="German culture">German culture</a>. According to conductor <a href="/wiki/Leon_Botstein" title="Leon Botstein">Leon Botstein</a>, Einstein began playing when he was 5. However, he did not enjoy it at that age.<sup id="cite_ref-Botstein_203-0" class="reference"><a href="#cite_note-Botstein-203">&#91;200&#93;</a></sup>
</p><p>When he turned 13, he discovered the <a href="/wiki/Mozart_violin_sonatas" class="mw-redirect" title="Mozart violin sonatas">violin sonatas of Mozart</a>, whereupon he became enamored of <a href="/wiki/Mozart" class="mw-redirect" title="Mozart">Mozart</a>\'s compositions and studied music more willingly. Einstein taught himself to play without "ever practicing systematically". He said that "love is a better teacher than a sense of duty".<sup id="cite_ref-Botstein_203-1" class="reference"><a href="#cite_note-Botstein-203">&#91;200&#93;</a></sup> At the age of 17, he was heard by a school examiner in Aarau while playing <a href="/wiki/Beethoven%27s_violin_sonatas_(disambiguation)" class="mw-redirect" title="Beethoven&#39;s violin sonatas (disambiguation)">Beethoven\'s violin sonatas</a>. The examiner stated afterward that his playing was "remarkable and revealing of \'great insight<span style="padding-right:.15em;">\'</span>". What struck the examiner, writes Botstein, was that Einstein "displayed a deep love of the music, a quality that was and remains in short supply. Music possessed an unusual meaning for this student."<sup id="cite_ref-Botstein_203-2" class="reference"><a href="#cite_note-Botstein-203">&#91;200&#93;</a></sup>
</p><p>Music took on a pivotal and permanent role in Einstein\'s life from that period on. Although the idea of becoming a professional musician himself was not on his mind at any time, among those with whom Einstein played <a href="/wiki/Chamber_music" title="Chamber music">chamber music</a> were a few professionals, including Kurt Appelbaum, and he performed for private audiences and friends. Chamber music had also become a regular part of his social life while living in Bern, Zürich, and Berlin, where he played with Max Planck and his son, among others. He is sometimes erroneously credited as the editor of the 1937 edition of the <a href="/wiki/K%C3%B6chel_catalog" class="mw-redirect" title="Köchel catalog">Köchel catalog</a> of Mozart\'s work; that edition was prepared by <a href="/wiki/Alfred_Einstein" title="Alfred Einstein">Alfred Einstein</a>, who may have been a distant relation.<sup id="cite_ref-kGuWC_204-0" class="reference"><a href="#cite_note-kGuWC-204">&#91;201&#93;</a></sup><sup id="cite_ref-OIn6p_205-0" class="reference"><a href="#cite_note-OIn6p-205">&#91;202&#93;</a></sup>
</p><p>In 1931, while engaged in research at the California Institute of Technology, he visited the Zoellner family conservatory in Los Angeles, where he played some of <a href="/wiki/Beethoven" class="mw-redirect" title="Beethoven">Beethoven</a> and Mozart\'s works with members of the <a href="/wiki/Zoellner_Quartet" title="Zoellner Quartet">Zoellner Quartet</a>.<sup id="cite_ref-Times_206-0" class="reference"><a href="#cite_note-Times-206">&#91;203&#93;</a></sup><sup id="cite_ref-RR_207-0" class="reference"><a href="#cite_note-RR-207">&#91;204&#93;</a></sup> Near the end of his life, when the young <a href="/wiki/Juilliard_Quartet" class="mw-redirect" title="Juilliard Quartet">Juilliard Quartet</a> visited him in Princeton, he played his violin with them, and the quartet was "impressed by Einstein\'s level of coordination and intonation".<sup id="cite_ref-Botstein_203-3" class="reference"><a href="#cite_note-Botstein-203">&#91;200&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="Death">Death</span></h3>
<p>On 17 April 1955, Einstein experienced <a href="/wiki/Internal_bleeding" title="Internal bleeding">internal bleeding</a> caused by the rupture of an <a href="/wiki/Abdominal_aortic_aneurysm" title="Abdominal aortic aneurysm">abdominal aortic aneurysm</a>, which had previously been reinforced surgically by <a href="/wiki/Rudolph_Nissen" title="Rudolph Nissen">Rudolph Nissen</a> in 1948.<sup id="cite_ref-BXLfp_208-0" class="reference"><a href="#cite_note-BXLfp-208">&#91;205&#93;</a></sup> He took the draft of a speech he was preparing for a television appearance commemorating the state of Israel\'s seventh anniversary with him to the hospital, but he did not live to complete it.<sup id="cite_ref-QN45b_209-0" class="reference"><a href="#cite_note-QN45b-209">&#91;206&#93;</a></sup>
</p><p>Einstein refused surgery, saying, "I want to go when I want. It is tasteless to prolong life artificially. I have done my share; it is time to go. I will do it elegantly."<sup id="cite_ref-BhiNM_210-0" class="reference"><a href="#cite_note-BhiNM-210">&#91;207&#93;</a></sup> He died in the <a href="/wiki/Princeton_Hospital" class="mw-redirect" title="Princeton Hospital">Princeton Hospital</a> early the next morning at the age of 76, having continued to work until near the end.<sup id="cite_ref-YUhsl_211-0" class="reference"><a href="#cite_note-YUhsl-211">&#91;208&#93;</a></sup>
</p><p>During the autopsy, the pathologist <a href="/wiki/Thomas_Stoltz_Harvey" title="Thomas Stoltz Harvey">Thomas Stoltz Harvey</a> removed <a href="/wiki/Einstein%27s_brain" class="mw-redirect" title="Einstein&#39;s brain">Einstein\'s brain</a> for preservation without the permission of his family, in the hope that the <a href="/wiki/Neuroscience" title="Neuroscience">neuroscience</a> of the future would be able to discover what made Einstein so intelligent.<sup id="cite_ref-MqyYW_212-0" class="reference"><a href="#cite_note-MqyYW-212">&#91;209&#93;</a></sup> Einstein\'s remains were cremated in <a href="/wiki/Trenton,_New_Jersey" title="Trenton, New Jersey">Trenton, New Jersey</a>,<sup id="cite_ref-213" class="reference"><a href="#cite_note-213">&#91;210&#93;</a></sup> and his ashes were scattered at an undisclosed location.<sup id="cite_ref-GQrBZ_214-0" class="reference"><a href="#cite_note-GQrBZ-214">&#91;211&#93;</a></sup><sup id="cite_ref-Obit_215-0" class="reference"><a href="#cite_note-Obit-215">&#91;212&#93;</a></sup>
</p><p>In a memorial lecture delivered on 13 December 1965 at <a href="/wiki/UNESCO" title="UNESCO">UNESCO</a> headquarters, nuclear physicist <a href="/wiki/J._Robert_Oppenheimer" title="J. Robert Oppenheimer">J. Robert Oppenheimer</a> summarized his <a href="/wiki/Einstein%E2%80%93Oppenheimer_relationship" title="Einstein–Oppenheimer relationship">impression of Einstein</a> as a person: "He was almost wholly without sophistication and wholly without worldliness&#160;... There was always with him a wonderful purity at once childlike and profoundly stubborn."<sup id="cite_ref-aJHxn_216-0" class="reference"><a href="#cite_note-aJHxn-216">&#91;213&#93;</a></sup>
</p><p>Einstein bequeathed his personal archives, library, and intellectual assets to the <a href="/wiki/Hebrew_University_of_Jerusalem" title="Hebrew University of Jerusalem">Hebrew University of Jerusalem</a> in Israel.<sup id="cite_ref-217" class="reference"><a href="#cite_note-217">&#91;214&#93;</a></sup>
</p>
<h2><span class="mw-headline" id="Scientific_career">Scientific career</span></h2>
<p>Throughout his life, Einstein published hundreds of books and articles.<sup id="cite_ref-Bio_20-2" class="reference"><a href="#cite_note-Bio-20">&#91;19&#93;</a></sup><sup id="cite_ref-Paul_Arthur_Schilpp,_editor_1951_730–746_218-0" class="reference"><a href="#cite_note-Paul_Arthur_Schilpp,_editor_1951_730–746-218">&#91;215&#93;</a></sup> He published more than 300 scientific papers and 150 non-scientific ones.<sup id="cite_ref-Nobel_15-1" class="reference"><a href="#cite_note-Nobel-15">&#91;14&#93;</a></sup><sup id="cite_ref-Paul_Arthur_Schilpp,_editor_1951_730–746_218-1" class="reference"><a href="#cite_note-Paul_Arthur_Schilpp,_editor_1951_730–746-218">&#91;215&#93;</a></sup> On 5 December 2014, universities and archives announced the release of Einstein\'s papers, comprising more than 30,000 unique documents.<sup id="cite_ref-FOOTNOTEStachel_et_al.2008_219-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008-219">&#91;216&#93;</a></sup><sup id="cite_ref-NYT-20141204-DB_220-0" class="reference"><a href="#cite_note-NYT-20141204-DB-220">&#91;217&#93;</a></sup> Einstein\'s intellectual achievements and originality have made the word "Einstein" synonymous with "genius".<sup id="cite_ref-wordnetweb.princeton.edu_19-1" class="reference"><a href="#cite_note-wordnetweb.princeton.edu-19">&#91;18&#93;</a></sup> In addition to the work he did by himself he also collaborated with other scientists on additional projects including the <a href="/wiki/Bose%E2%80%93Einstein_statistics" title="Bose–Einstein statistics">Bose–Einstein statistics</a>, the <a href="/wiki/Einstein_refrigerator" title="Einstein refrigerator">Einstein refrigerator</a> and others.<sup id="cite_ref-Instituut-Lorentz_221-0" class="reference"><a href="#cite_note-Instituut-Lorentz-221">&#91;218&#93;</a></sup><sup id="cite_ref-e5xd8_222-0" class="reference"><a href="#cite_note-e5xd8-222">&#91;219&#93;</a></sup>
</p>
<h3><span id="1905_.E2.80.93_Annus_Mirabilis_papers"></span><span class="mw-headline" id="1905_–_Annus_Mirabilis_papers">1905 – <i>Annus Mirabilis</i> papers</span></h3>
<p>The <a href="/wiki/Annus_mirabilis_papers" title="Annus mirabilis papers"><i>Annus Mirabilis</i> papers</a> are four articles pertaining to the photoelectric effect (which gave rise to <a href="/wiki/Quantum_mechanics" title="Quantum mechanics">quantum theory</a>), <a href="/wiki/Brownian_motion" title="Brownian motion">Brownian motion</a>, the <a href="/wiki/Special_theory_of_relativity" class="mw-redirect" title="Special theory of relativity">special theory of relativity</a>, and <a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence"><i>E</i>&#160;=&#160;<i>mc</i><sup>2</sup></a> that Einstein published in the <i>Annalen der Physik</i> scientific journal in 1905. These four works contributed substantially to the foundation of <a href="/wiki/History_of_physics#Modern_physics" title="History of physics">modern physics</a> and changed views on <a href="/wiki/Space" title="Space">space</a>, time, and <a href="/wiki/Matter" title="Matter">matter</a>. The four papers are:
</p>
<table class="wikitable">

<tbody><tr>
<th>Title <small>(translated)</small></th>
<th><small>Area of focus</small></th>
<th>Received</th>
<th>Published</th>
<th>Significance
</th></tr>
<tr>
<td>"On a Heuristic Viewpoint Concerning the Production and Transformation of Light"<sup id="cite_ref-FOOTNOTEEinstein1905a_223-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905a-223">&#91;220&#93;</a></sup></td>
<td>Photoelectric effect</td>
<td>18 March</td>
<td>9 June</td>
<td>Resolved an unsolved puzzle by suggesting that energy is exchanged only in discrete amounts (<a href="/wiki/Quantum" title="Quantum">quanta</a>).<sup id="cite_ref-1Jhcb_224-0" class="reference"><a href="#cite_note-1Jhcb-224">&#91;221&#93;</a></sup> This idea was pivotal to the early development of quantum theory.<sup id="cite_ref-oJBvd_225-0" class="reference"><a href="#cite_note-oJBvd-225">&#91;222&#93;</a></sup>
</td></tr>
<tr>
<td>"On the Motion of Small Particles Suspended in a Stationary Liquid, as Required by the Molecular Kinetic Theory of Heat"<sup id="cite_ref-FOOTNOTEEinstein1905c_226-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905c-226">&#91;223&#93;</a></sup></td>
<td><a href="/wiki/Brownian_motion" title="Brownian motion">Brownian motion</a></td>
<td>11 May</td>
<td>18 July</td>
<td>Explained empirical evidence for the <a href="/wiki/Atomic_theory" class="mw-redirect" title="Atomic theory">atomic theory</a>, supporting the application of <a href="/wiki/Statistical_physics" class="mw-redirect" title="Statistical physics">statistical physics</a>.
</td></tr>
<tr>
<td>"On the Electrodynamics of Moving Bodies"<sup id="cite_ref-FOOTNOTEEinstein1905d_227-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905d-227">&#91;224&#93;</a></sup></td>
<td><a href="/wiki/Special_relativity" title="Special relativity">Special relativity</a></td>
<td>30 June</td>
<td>26&#160;September</td>
<td>Reconciled Maxwell\'s equations for electricity and magnetism with the laws of mechanics by introducing changes to mechanics, resulting from analysis based on empirical evidence that the speed of light is independent of the motion of the observer.<sup id="cite_ref-RhZ8x_228-0" class="reference"><a href="#cite_note-RhZ8x-228">&#91;225&#93;</a></sup> Discredited the concept of a "<a href="/wiki/Luminiferous_ether" class="mw-redirect" title="Luminiferous ether">luminiferous ether</a>".<sup id="cite_ref-lhfJ9_229-0" class="reference"><a href="#cite_note-lhfJ9-229">&#91;226&#93;</a></sup>
</td></tr>
<tr>
<td>"Does the Inertia of a Body Depend Upon Its Energy Content?"<sup id="cite_ref-FOOTNOTEEinstein1905e_230-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905e-230">&#91;227&#93;</a></sup></td>
<td><a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence"><span class="nowrap">Matter–energy</span> equivalence</a></td>
<td>27&#160;September</td>
<td>21 November</td>
<td>Equivalence of matter and energy, <i>E</i>&#160;=&#160;<i>mc</i><sup>2</sup>, the existence of "<a href="/wiki/Rest_energy" class="mw-redirect" title="Rest energy">rest energy</a>", and the basis of nuclear energy.
</td></tr></tbody></table>
<h3><span class="mw-headline" id="Statistical_mechanics">Statistical mechanics</span></h3>
<h4><span class="mw-headline" id="Thermodynamic_fluctuations_and_statistical_physics">Thermodynamic fluctuations and statistical physics</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main articles: <a href="/wiki/Statistical_mechanics" title="Statistical mechanics">Statistical mechanics</a>, <a href="/wiki/Thermal_fluctuations" title="Thermal fluctuations">thermal fluctuations</a>, and <a href="/wiki/Statistical_physics" class="mw-redirect" title="Statistical physics">statistical physics</a></div>
<p>Einstein\'s first paper<sup id="cite_ref-FOOTNOTEEinstein1901_81-1" class="reference"><a href="#cite_note-FOOTNOTEEinstein1901-81">&#91;79&#93;</a></sup><sup id="cite_ref-PubList_231-0" class="reference"><a href="#cite_note-PubList-231">&#91;228&#93;</a></sup> submitted in 1900 to <i>Annalen der Physik</i> was on <a href="/wiki/Capillary_attraction" class="mw-redirect" title="Capillary attraction">capillary attraction</a>. It was published in 1901 with the title "Folgerungen aus den Capillaritätserscheinungen", which translates as "Conclusions from the capillarity phenomena". Two papers he published in 1902–1903 (thermodynamics) attempted to interpret <a href="/wiki/Atom" title="Atom">atomic</a> phenomena from a statistical point of view. These papers were the foundation for the 1905 paper on Brownian motion, which showed that Brownian movement can be construed as firm evidence that molecules exist. His research in 1903 and 1904 was mainly concerned with the effect of finite atomic size on diffusion phenomena.<sup id="cite_ref-PubList_231-1" class="reference"><a href="#cite_note-PubList-231">&#91;228&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Theory_of_critical_opalescence">Theory of critical opalescence</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Critical_opalescence" title="Critical opalescence">Critical opalescence</a></div>
<p>Einstein returned to the problem of thermodynamic fluctuations, giving a treatment of the density variations in a fluid at its critical point. Ordinarily the density fluctuations are controlled by the second derivative of the free energy with respect to the density. At the critical point, this derivative is zero, leading to large fluctuations. The effect of density fluctuations is that light of all wavelengths is scattered, making the fluid look milky white. Einstein relates this to <a href="/wiki/Rayleigh_scattering" title="Rayleigh scattering">Rayleigh scattering</a>, which is what happens when the fluctuation size is much smaller than the wavelength, and which explains why the sky is blue.<sup id="cite_ref-L2N73_232-0" class="reference"><a href="#cite_note-L2N73-232">&#91;229&#93;</a></sup> Einstein quantitatively derived critical opalescence from a treatment of density fluctuations, and demonstrated how both the effect and Rayleigh scattering originate from the atomistic constitution of matter.
</p>
<h3><span class="mw-headline" id="Special_relativity">Special relativity</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/History_of_special_relativity" title="History of special relativity">History of special relativity</a></div>
<p>Einstein\'s "<span title="German-language text"><i lang="de">Zur Elektrodynamik bewegter Körper</i></span>"<sup id="cite_ref-FOOTNOTEEinstein1905d_227-1" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905d-227">&#91;224&#93;</a></sup> ("On the Electrodynamics of Moving Bodies") was received on 30 June 1905 and published 26 September of that same year. It reconciled conflicts between <a href="/wiki/Maxwell%27s_equations" title="Maxwell&#39;s equations">Maxwell\'s equations</a> (the laws of electricity and magnetism) and the laws of Newtonian mechanics by introducing changes to the laws of mechanics.<sup id="cite_ref-FOOTNOTEFölsing1997178–198_233-0" class="reference"><a href="#cite_note-FOOTNOTEFölsing1997178–198-233">&#91;230&#93;</a></sup> Observationally, the effects of these changes are most apparent at high speeds (where objects are moving at speeds close to the <a href="/wiki/Speed_of_light" title="Speed of light">speed of light</a>). The theory developed in this paper later became known as Einstein\'s special theory of relativity.
</p><p>This paper predicted that, when measured in the frame of a relatively moving observer, a clock carried by a moving body would appear to <a href="/wiki/Time_dilation" title="Time dilation">slow down</a>, and the body itself would <a href="/wiki/Length_contraction" title="Length contraction">contract</a> in its direction of motion. This paper also argued that the idea of a <a href="/wiki/Luminiferous_aether" title="Luminiferous aether">luminiferous aether</a>—one of the leading theoretical entities in physics at the time—was superfluous.<sup id="cite_ref-aBfxO_234-0" class="reference"><a href="#cite_note-aBfxO-234">&#91;note 4&#93;</a></sup>
</p><p>In his paper on <a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence">mass–energy equivalence</a>, Einstein produced <i>E</i>&#160;=&#160;<i>mc</i><sup>2</sup> as a consequence of his special relativity equations.<sup id="cite_ref-FOOTNOTEStachel2002vi,_15,_90,_131,_&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA215_215&#93;_235-0" class="reference"><a href="#cite_note-FOOTNOTEStachel2002vi,_15,_90,_131,_[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA215_215]-235">&#91;231&#93;</a></sup> Einstein\'s 1905 work on relativity remained controversial for many years, but was accepted by leading physicists, starting with <a href="/wiki/Max_Planck" title="Max Planck">Max Planck</a>.<sup id="cite_ref-sBl2q_236-0" class="reference"><a href="#cite_note-sBl2q-236">&#91;note 5&#93;</a></sup><sup id="cite_ref-FOOTNOTEPais1982382–386_237-0" class="reference"><a href="#cite_note-FOOTNOTEPais1982382–386-237">&#91;232&#93;</a></sup>
</p><p>Einstein originally framed special relativity in terms of <a href="/wiki/Kinematics" title="Kinematics">kinematics</a> (the study of moving bodies). In 1908, <a href="/wiki/Hermann_Minkowski" title="Hermann Minkowski">Hermann Minkowski</a> reinterpreted special relativity in geometric terms as a theory of <a href="/wiki/Spacetime" title="Spacetime">spacetime</a>. Einstein adopted Minkowski\'s formalism in his 1915 <a href="/wiki/General_theory_of_relativity" class="mw-redirect" title="General theory of relativity">general theory of relativity</a>.<sup id="cite_ref-FOOTNOTEPais1982151–152_238-0" class="reference"><a href="#cite_note-FOOTNOTEPais1982151–152-238">&#91;233&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="General_relativity">General relativity</span></h3>
<h4><span class="mw-headline" id="General_relativity_and_the_equivalence_principle">General relativity and the equivalence principle</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/History_of_general_relativity" title="History of general relativity">History of general relativity</a></div>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">See also: <a href="/wiki/Theory_of_relativity" title="Theory of relativity">Theory of relativity</a> and <a href="/wiki/Einstein_field_equations" title="Einstein field equations">Einstein field equations</a></div>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:1919_eclipse_positive.jpg" class="mw-file-description"><img alt="Black circle covering the sun, rays visible around it, in a dark sky." src="//upload.wikimedia.org/wikipedia/commons/thumb/3/37/1919_eclipse_positive.jpg/170px-1919_eclipse_positive.jpg" decoding="async" width="170" height="185" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/3/37/1919_eclipse_positive.jpg/255px-1919_eclipse_positive.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/3/37/1919_eclipse_positive.jpg/340px-1919_eclipse_positive.jpg 2x" data-file-width="490" data-file-height="533" /></a><figcaption><a href="/wiki/Arthur_Stanley_Eddington" class="mw-redirect" title="Arthur Stanley Eddington">Eddington</a>\'s photograph of a <a href="/wiki/Solar_eclipse" title="Solar eclipse">solar eclipse</a></figcaption></figure>
<p><a href="/wiki/General_relativity" title="General relativity">General relativity</a> (GR) is a <a href="/wiki/Theory_of_gravitation" class="mw-redirect" title="Theory of gravitation">theory of gravitation</a> that was developed by Einstein between 1907 and 1915. According to it, the observed gravitational attraction between masses results from the warping of <a href="/wiki/Spacetime" title="Spacetime">spacetime</a> by those masses. General relativity has developed into an essential tool in modern <a href="/wiki/Astrophysics" title="Astrophysics">astrophysics</a>; it provides the foundation for the current understanding of <a href="/wiki/Black_holes" class="mw-redirect" title="Black holes">black holes</a>, regions of space where gravitational attraction is so strong that not even light can escape.<sup id="cite_ref-239" class="reference"><a href="#cite_note-239">&#91;234&#93;</a></sup>
</p><p>As Einstein later said, the reason for the development of general relativity was that the preference of inertial motions within <a href="/wiki/Special_relativity" title="Special relativity">special relativity</a> was unsatisfactory, while a theory which from the outset prefers no state of motion (even accelerated ones) should appear more satisfactory.<sup id="cite_ref-FOOTNOTEEinstein1923_240-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1923-240">&#91;235&#93;</a></sup> Consequently, in 1907 he published an article on acceleration under special relativity. In that article titled "On the Relativity Principle and the Conclusions Drawn from It", he argued that <a href="/wiki/Free_fall" title="Free fall">free fall</a> is really inertial motion, and that for a free-falling observer the rules of special relativity must apply. This argument is called the <a href="/wiki/Equivalence_principle" title="Equivalence principle">equivalence principle</a>. In the same article, Einstein also predicted the phenomena of <a href="/wiki/Gravitational_time_dilation" title="Gravitational time dilation">gravitational time dilation</a>, <a href="/wiki/Gravitational_redshift" title="Gravitational redshift">gravitational redshift</a> and <a href="/wiki/Gravitational_lensing" class="mw-redirect" title="Gravitational lensing">gravitational lensing</a>.<sup id="cite_ref-FOOTNOTEPais1982179–183_241-0" class="reference"><a href="#cite_note-FOOTNOTEPais1982179–183-241">&#91;236&#93;</a></sup><sup id="cite_ref-FOOTNOTEStachel_et_al.2008273–274vol._2:_The_Swiss_Years:_Writings,_1900–1909_242-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008273–274vol._2:_The_Swiss_Years:_Writings,_1900–1909-242">&#91;237&#93;</a></sup>
</p><p>In 1911, Einstein published another article "On the Influence of Gravitation on the Propagation of Light" expanding on the 1907 article, in which he estimated the amount of deflection of light by massive bodies. Thus, the theoretical prediction of general relativity could for the first time be tested experimentally.<sup id="cite_ref-FOOTNOTEPais1982194–195_243-0" class="reference"><a href="#cite_note-FOOTNOTEPais1982194–195-243">&#91;238&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Gravitational_waves">Gravitational waves</span></h4>
<p>In 1916, Einstein predicted <a href="/wiki/Gravitational_wave" title="Gravitational wave">gravitational waves</a>,<sup id="cite_ref-FOOTNOTEEinstein1916_244-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1916-244">&#91;239&#93;</a></sup><sup id="cite_ref-FOOTNOTEEinstein1918_245-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1918-245">&#91;240&#93;</a></sup> ripples in the <a href="/wiki/Curvature" title="Curvature">curvature</a> of spacetime which propagate as <a href="/wiki/Wave" title="Wave">waves</a>, traveling outward from the source, transporting energy as gravitational radiation. The existence of gravitational waves is possible under general relativity due to its <a href="/wiki/Lorentz_invariance" class="mw-redirect" title="Lorentz invariance">Lorentz invariance</a> which brings the concept of a finite speed of propagation of the physical interactions of gravity with it. By contrast, gravitational waves cannot exist in the <a href="/wiki/Newton%27s_law_of_universal_gravitation" title="Newton&#39;s law of universal gravitation">Newtonian theory of gravitation</a>, which postulates that the physical interactions of gravity propagate at infinite speed.
</p><p>The first, indirect, detection of gravitational waves came in the 1970s through observation of a pair of closely orbiting <a href="/wiki/Neutron_stars" class="mw-redirect" title="Neutron stars">neutron stars</a>, <a href="/wiki/PSR_B1913%2B16" class="mw-redirect" title="PSR B1913+16">PSR B1913+16</a>.<sup id="cite_ref-natgeo_246-0" class="reference"><a href="#cite_note-natgeo-246">&#91;241&#93;</a></sup> The explanation for the decay in their orbital period was that they were emitting gravitational waves.<sup id="cite_ref-natgeo_246-1" class="reference"><a href="#cite_note-natgeo-246">&#91;241&#93;</a></sup><sup id="cite_ref-Tf1T0_247-0" class="reference"><a href="#cite_note-Tf1T0-247">&#91;242&#93;</a></sup> Einstein\'s prediction was confirmed on 11 February 2016, when researchers at <a href="/wiki/LIGO" title="LIGO">LIGO</a> published the <a href="/wiki/First_observation_of_gravitational_waves" title="First observation of gravitational waves">first observation of gravitational waves</a>,<sup id="cite_ref-PRL-20160211_248-0" class="reference"><a href="#cite_note-PRL-20160211-248">&#91;243&#93;</a></sup> detected on Earth on 14 September 2015, nearly one hundred years after the prediction.<sup id="cite_ref-natgeo_246-2" class="reference"><a href="#cite_note-natgeo-246">&#91;241&#93;</a></sup><sup id="cite_ref-CO6kH_249-0" class="reference"><a href="#cite_note-CO6kH-249">&#91;244&#93;</a></sup><sup id="cite_ref-oSmHb_250-0" class="reference"><a href="#cite_note-oSmHb-250">&#91;245&#93;</a></sup><sup id="cite_ref-hkKSp_251-0" class="reference"><a href="#cite_note-hkKSp-251">&#91;246&#93;</a></sup><sup id="cite_ref-38Msx_252-0" class="reference"><a href="#cite_note-38Msx-252">&#91;247&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Hole_argument_and_Entwurf_theory">Hole argument and Entwurf theory</span></h4>
<p>While developing general relativity, Einstein became confused about the <a href="/wiki/Gauge_invariance" class="mw-redirect" title="Gauge invariance">gauge invariance</a> in the theory. He formulated an argument that led him to conclude that a general relativistic field theory is impossible. He gave up looking for fully generally covariant tensor equations and searched for equations that would be invariant under general linear transformations only.<sup id="cite_ref-253" class="reference"><a href="#cite_note-253">&#91;248&#93;</a></sup>
</p><p>In June 1913, the Entwurf (\'draft\') theory was the result of these investigations. As its name suggests, it was a sketch of a theory, less elegant and more difficult than general relativity, with the equations of motion supplemented by additional gauge fixing conditions. After more than two years of intensive work, Einstein realized that the <a href="/wiki/Hole_argument" title="Hole argument">hole argument</a> was mistaken<sup id="cite_ref-sOA9t_254-0" class="reference"><a href="#cite_note-sOA9t-254">&#91;249&#93;</a></sup> and abandoned the theory in November 1915.
</p>
<h4><span class="mw-headline" id="Physical_cosmology">Physical cosmology</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Physical_cosmology" title="Physical cosmology">Physical cosmology</a></div>
<figure class="mw-default-size mw-halign-right" typeof="mw:File/Thumb"><a href="/wiki/File:MillikanLemaitreEinstein.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/c/c6/MillikanLemaitreEinstein.jpg/220px-MillikanLemaitreEinstein.jpg" decoding="async" width="220" height="179" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/c/c6/MillikanLemaitreEinstein.jpg/330px-MillikanLemaitreEinstein.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/c/c6/MillikanLemaitreEinstein.jpg/440px-MillikanLemaitreEinstein.jpg 2x" data-file-width="703" data-file-height="573" /></a><figcaption><a href="/wiki/Robert_Andrews_Millikan" title="Robert Andrews Millikan">Robert A. Millikan</a>, <a href="/wiki/Georges_Lema%C3%AEtre" title="Georges Lemaître">Georges Lemaître</a>, and Einstein at the <a href="/wiki/California_Institute_of_Technology" title="California Institute of Technology">California Institute of Technology</a> in January 1933</figcaption></figure>
<p>In 1917, Einstein applied the general theory of relativity to the structure of the universe as a whole.<sup id="cite_ref-FOOTNOTEEinstein1917a_255-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1917a-255">&#91;250&#93;</a></sup> He discovered that the general field equations predicted a universe that was dynamic, either contracting or expanding. As observational evidence for a dynamic universe was lacking at the time, Einstein introduced a new term, the <a href="/wiki/Cosmological_constant" title="Cosmological constant">cosmological constant</a>, into the field equations, in order to allow the theory to predict a static universe. The modified field equations predicted a static universe of closed curvature, in accordance with Einstein\'s understanding of <a href="/wiki/Mach%27s_principle" title="Mach&#39;s principle">Mach\'s principle</a> in these years. This model became known as the Einstein World or <a href="/wiki/Einstein%27s_static_universe" title="Einstein&#39;s static universe">Einstein\'s static universe</a>.<sup id="cite_ref-FOOTNOTEPais1994285–286_256-0" class="reference"><a href="#cite_note-FOOTNOTEPais1994285–286-256">&#91;251&#93;</a></sup><sup id="cite_ref-iJwuX_257-0" class="reference"><a href="#cite_note-iJwuX-257">&#91;252&#93;</a></sup>
</p><p>Following the discovery of the recession of the galaxies by <a href="/wiki/Edwin_Hubble" title="Edwin Hubble">Edwin Hubble</a> in 1929, Einstein abandoned his static model of the universe, and proposed two dynamic models of the cosmos, the <a href="/wiki/Friedmann%E2%80%93Einstein_universe" title="Friedmann–Einstein universe">Friedmann–Einstein universe</a> of 1931<sup id="cite_ref-FOOTNOTEEinstein1931_258-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1931-258">&#91;253&#93;</a></sup><sup id="cite_ref-cor-2013_259-0" class="reference"><a href="#cite_note-cor-2013-259">&#91;254&#93;</a></sup> and the <a href="/wiki/Einstein%E2%80%93de_Sitter_universe" title="Einstein–de Sitter universe">Einstein–de Sitter universe</a> of 1932.<sup id="cite_ref-FOOTNOTEEinsteinde_Sitter1932_260-0" class="reference"><a href="#cite_note-FOOTNOTEEinsteinde_Sitter1932-260">&#91;255&#93;</a></sup><sup id="cite_ref-J9Tqu_261-0" class="reference"><a href="#cite_note-J9Tqu-261">&#91;256&#93;</a></sup> In each of these models, Einstein discarded the cosmological constant, claiming that it was "in any case theoretically unsatisfactory".<sup id="cite_ref-FOOTNOTEEinstein1931_258-1" class="reference"><a href="#cite_note-FOOTNOTEEinstein1931-258">&#91;253&#93;</a></sup><sup id="cite_ref-cor-2013_259-1" class="reference"><a href="#cite_note-cor-2013-259">&#91;254&#93;</a></sup><sup id="cite_ref-sxfvo_262-0" class="reference"><a href="#cite_note-sxfvo-262">&#91;257&#93;</a></sup>
</p><p>In many Einstein biographies, it is claimed that Einstein referred to the cosmological constant in later years as his "biggest blunder", based on a letter <a href="/wiki/George_Gamow" title="George Gamow">George Gamow</a> claimed to have received from him. The astrophysicist <a href="/wiki/Mario_Livio" title="Mario Livio">Mario Livio</a> has cast doubt on this claim.<sup id="cite_ref-qmmVf_263-0" class="reference"><a href="#cite_note-qmmVf-263">&#91;258&#93;</a></sup>
</p><p>In late 2013, a team led by the Irish physicist <a href="/wiki/Cormac_O%27Raifeartaigh" title="Cormac O&#39;Raifeartaigh">Cormac O\'Raifeartaigh</a> discovered evidence that, shortly after learning of Hubble\'s observations of the recession of the galaxies, Einstein considered a <a href="/wiki/Steady-state_model" title="Steady-state model">steady-state model</a> of the universe.<sup id="cite_ref-Tq53z_264-0" class="reference"><a href="#cite_note-Tq53z-264">&#91;259&#93;</a></sup><sup id="cite_ref-8pfEk_265-0" class="reference"><a href="#cite_note-8pfEk-265">&#91;260&#93;</a></sup> In a hitherto overlooked manuscript, apparently written in early 1931, Einstein explored a model of the expanding universe in which the density of matter remains constant due to a continuous creation of matter, a process that he associated with the cosmological constant.<sup id="cite_ref-cor-steady-state_266-0" class="reference"><a href="#cite_note-cor-steady-state-266">&#91;261&#93;</a></sup><sup id="cite_ref-Einstein&#39;s_aborted_model_267-0" class="reference"><a href="#cite_note-Einstein&#39;s_aborted_model-267">&#91;262&#93;</a></sup> As he stated in the paper, "In what follows, I would like to draw attention to a solution to equation (1) that can account for Hubbel\'s [<i>sic</i>] facts, and in which the density is constant over time" ... "If one considers a physically bounded volume, particles of matter will be continually leaving it. For the density to remain constant, new particles of matter must be continually formed in the volume from space."
</p><p>It thus appears that Einstein considered a <a href="/wiki/Steady-state_model" title="Steady-state model">steady-state model</a> of the expanding universe many years before Hoyle, Bondi and Gold.<sup id="cite_ref-ILjYQ_268-0" class="reference"><a href="#cite_note-ILjYQ-268">&#91;263&#93;</a></sup><sup id="cite_ref-ThZb0_269-0" class="reference"><a href="#cite_note-ThZb0-269">&#91;264&#93;</a></sup> However, Einstein\'s steady-state model contained a fundamental flaw and he quickly abandoned the idea.<sup id="cite_ref-cor-steady-state_266-1" class="reference"><a href="#cite_note-cor-steady-state-266">&#91;261&#93;</a></sup><sup id="cite_ref-Einstein&#39;s_aborted_model_267-1" class="reference"><a href="#cite_note-Einstein&#39;s_aborted_model-267">&#91;262&#93;</a></sup><sup id="cite_ref-7ShC9_270-0" class="reference"><a href="#cite_note-7ShC9-270">&#91;265&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Energy_momentum_pseudotensor">Energy momentum pseudotensor</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Stress%E2%80%93energy%E2%80%93momentum_pseudotensor" title="Stress–energy–momentum pseudotensor">Stress–energy–momentum pseudotensor</a></div>
<p>General relativity includes a dynamical spacetime, so it is difficult to see how to identify the conserved energy and momentum. <a href="/wiki/Noether%27s_theorem" title="Noether&#39;s theorem">Noether\'s theorem</a> allows these quantities to be determined from a <a href="/wiki/Lagrangian_(field_theory)" title="Lagrangian (field theory)">Lagrangian</a> with <a href="/wiki/Translation_invariance" class="mw-redirect" title="Translation invariance">translation invariance</a>, but <a href="/wiki/General_covariance" title="General covariance">general covariance</a> makes translation invariance into something of a <a href="/wiki/Gauge_symmetry" class="mw-redirect" title="Gauge symmetry">gauge symmetry</a>. The energy and momentum derived within general relativity by <a href="/wiki/Emmy_Noether" title="Emmy Noether">Noether</a>\'s prescriptions do not make a real tensor for this reason.<sup id="cite_ref-271" class="reference"><a href="#cite_note-271">&#91;266&#93;</a></sup>
</p><p>Einstein argued that this is true for a fundamental reason: the gravitational field could be made to vanish by a choice of coordinates. He maintained that the non-covariant energy momentum pseudotensor was, in fact, the best description of the energy momentum distribution in a gravitational field. While the use of non-covariant objects like pseudotensors was criticized by <a href="/wiki/Erwin_Schr%C3%B6dinger" title="Erwin Schrödinger">Erwin Schrödinger</a> and others, Einstein\'s approach has been echoed by physicists including <a href="/wiki/Lev_Landau" title="Lev Landau">Lev Landau</a> and <a href="/wiki/Evgeny_Lifshitz" title="Evgeny Lifshitz">Evgeny Lifshitz</a>.<sup id="cite_ref-272" class="reference"><a href="#cite_note-272">&#91;267&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Wormholes">Wormholes</span></h4>
<p>In 1935, Einstein collaborated with <a href="/wiki/Nathan_Rosen" title="Nathan Rosen">Nathan Rosen</a> to produce a model of a <a href="/wiki/Wormhole" title="Wormhole">wormhole</a>, often called <a href="/wiki/Einstein%E2%80%93Rosen_bridges" class="mw-redirect" title="Einstein–Rosen bridges">Einstein–Rosen bridges</a>.<sup id="cite_ref-FOOTNOTEEinsteinRosen1935_273-0" class="reference"><a href="#cite_note-FOOTNOTEEinsteinRosen1935-273">&#91;268&#93;</a></sup><sup id="cite_ref-QNjpt_274-0" class="reference"><a href="#cite_note-QNjpt-274">&#91;269&#93;</a></sup> His motivation was to model elementary particles with charge as a solution of gravitational field equations, in line with the program outlined in the paper "Do Gravitational Fields play an Important Role in the Constitution of the Elementary Particles?". These solutions cut and pasted <a href="/wiki/Schwarzschild_black_hole" class="mw-redirect" title="Schwarzschild black hole">Schwarzschild black holes</a> to make a bridge between two patches. Because these solutions included spacetime curvature without the presence of a physical body, Einstein and Rosen suggested that they could provide the beginnings of a theory that avoided the notion of point particles. However, it was later found that Einstein–Rosen bridges are not stable.<sup id="cite_ref-ja7FY_275-0" class="reference"><a href="#cite_note-ja7FY-275">&#91;270&#93;</a></sup>
</p>
<h4><span id="Einstein.E2.80.93Cartan_theory"></span><span class="mw-headline" id="Einstein–Cartan_theory">Einstein–Cartan theory</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Einstein%E2%80%93Cartan_theory" title="Einstein–Cartan theory">Einstein–Cartan theory</a></div>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_photo_1920.jpg" class="mw-file-description"><img alt="Einstein, sitting at a table, looks up from the papers he is reading and into the camera." src="//upload.wikimedia.org/wikipedia/commons/thumb/1/10/Albert_Einstein_photo_1920.jpg/170px-Albert_Einstein_photo_1920.jpg" decoding="async" width="170" height="249" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/1/10/Albert_Einstein_photo_1920.jpg/255px-Albert_Einstein_photo_1920.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/1/10/Albert_Einstein_photo_1920.jpg/340px-Albert_Einstein_photo_1920.jpg 2x" data-file-width="3744" data-file-height="5480" /></a><figcaption>Einstein at his office, <a href="/wiki/University_of_Berlin" class="mw-redirect" title="University of Berlin">University of Berlin</a>, 1920</figcaption></figure><p>In order to incorporate spinning point particles into general relativity, the affine connection needed to be generalized to include an antisymmetric part, called the <a href="/wiki/Torsion_tensor" title="Torsion tensor">torsion</a>. This modification was made by Einstein and Cartan in the 1920s.
</p><h4><span class="mw-headline" id="Equations_of_motion">Equations of motion</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Einstein%E2%80%93Infeld%E2%80%93Hoffmann_equations" title="Einstein–Infeld–Hoffmann equations">Einstein–Infeld–Hoffmann equations</a></div>
<p>In general relativity, gravitational force is reimagined as curvature of <a href="/wiki/Spacetime" title="Spacetime">spacetime</a>. A curved path like an orbit is not the result of a force deflecting a body from an ideal straight-line path, but rather the body\'s attempt to fall freely through a background that is itself curved by the presence of other masses. A remark by <a href="/wiki/John_Archibald_Wheeler" title="John Archibald Wheeler">John Archibald Wheeler</a> that has become proverbial among physicists summarizes the theory: "Spacetime tells matter how to move; matter tells spacetime how to curve."<sup id="cite_ref-Wheeler_276-0" class="reference"><a href="#cite_note-Wheeler-276">&#91;271&#93;</a></sup><sup id="cite_ref-277" class="reference"><a href="#cite_note-277">&#91;272&#93;</a></sup> The <a href="/wiki/Einstein_field_equations" title="Einstein field equations">Einstein field equations</a> cover the latter aspect of the theory, relating the curvature of spacetime to the distribution of matter and energy. The <a href="/wiki/Geodesic_equation" class="mw-redirect" title="Geodesic equation">geodesic equation</a> covers the former aspect, stating that freely falling bodies follow <a href="/wiki/Geodesics_in_general_relativity" title="Geodesics in general relativity">lines that are as straight as possible in a curved spacetime</a>. Einstein regarded this as an "independent fundamental assumption" that had to be postulated in addition to the field equations in order to complete the theory. Believing this to be a shortcoming in how general relativity was originally presented, he wished to derive it from the field equations themselves. Since the equations of general relativity are non-linear, a lump of energy made out of pure gravitational fields, like a black hole, would move on a trajectory which is determined by the Einstein field equations themselves, not by a new law. Accordingly, Einstein proposed that the field equations would determine the path of a singular solution, like a black hole, to be a geodesic. Both physicists and philosophers have often repeated the assertion that the geodesic equation can be obtained from applying the field equations to the motion of a <a href="/wiki/Gravitational_singularity" title="Gravitational singularity">gravitational singularity</a>, but this claim remains disputed.<sup id="cite_ref-278" class="reference"><a href="#cite_note-278">&#91;273&#93;</a></sup><sup id="cite_ref-279" class="reference"><a href="#cite_note-279">&#91;274&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="Old_quantum_theory">Old quantum theory</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Old_quantum_theory" title="Old quantum theory">Old quantum theory</a></div>
<h4><span class="mw-headline" id="Photons_and_energy_quanta">Photons and energy quanta</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Photoelectric_effect_in_a_solid_-_diagram.svg" class="mw-file-description"><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/a/a6/Photoelectric_effect_in_a_solid_-_diagram.svg/220px-Photoelectric_effect_in_a_solid_-_diagram.svg.png" decoding="async" width="220" height="220" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/a/a6/Photoelectric_effect_in_a_solid_-_diagram.svg/330px-Photoelectric_effect_in_a_solid_-_diagram.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/a/a6/Photoelectric_effect_in_a_solid_-_diagram.svg/440px-Photoelectric_effect_in_a_solid_-_diagram.svg.png 2x" data-file-width="364" data-file-height="364" /></a><figcaption>The photoelectric effect. Incoming photons on the left strike a metal plate (bottom), and eject electrons, depicted as flying off to the right.</figcaption></figure>
<p>In a 1905 paper,<sup id="cite_ref-FOOTNOTEEinstein1905a_223-1" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905a-223">&#91;220&#93;</a></sup> Einstein postulated that light itself consists of localized particles (<i><a href="/wiki/Quantum" title="Quantum">quanta</a></i>). Einstein\'s light quanta were nearly universally rejected by all physicists, including Max Planck and Niels Bohr. This idea only became universally accepted in 1919, with <a href="/wiki/Robert_Millikan" class="mw-redirect" title="Robert Millikan">Robert Millikan</a>\'s detailed experiments on the photoelectric effect, and with the measurement of <a href="/wiki/Compton_scattering" title="Compton scattering">Compton scattering</a>.
</p><p>Einstein concluded that each wave of frequency <i>f</i> is associated with a collection of photons with energy <i>hf</i> each, where <i>h</i> is the <a href="/wiki/Planck_constant" title="Planck constant">Planck constant</a>. He did not say much more, because he was not sure how the particles were related to the wave. But he did suggest that this idea would explain certain experimental results, notably the photoelectric effect.<sup id="cite_ref-FOOTNOTEEinstein1905a_223-2" class="reference"><a href="#cite_note-FOOTNOTEEinstein1905a-223">&#91;220&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Quantized_atomic_vibrations">Quantized atomic vibrations</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Einstein_solid" title="Einstein solid">Einstein solid</a></div>
<p>In 1907, Einstein proposed a model of matter where each atom in a lattice structure is an independent harmonic oscillator. In the Einstein model, each atom oscillates independently—a series of equally spaced quantized states for each oscillator. Einstein was aware that getting the frequency of the actual oscillations would be difficult, but he nevertheless proposed this theory because it was a particularly clear demonstration that quantum mechanics could solve the specific heat problem in classical mechanics. <a href="/wiki/Peter_Debye" title="Peter Debye">Peter Debye</a> refined this model.<sup id="cite_ref-ixm32_280-0" class="reference"><a href="#cite_note-ixm32-280">&#91;275&#93;</a></sup>
</p>
<h4><span id="Bose.E2.80.93Einstein_statistics"></span><span class="mw-headline" id="Bose–Einstein_statistics">Bose–Einstein statistics</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Bose%E2%80%93Einstein_statistics" title="Bose–Einstein statistics">Bose–Einstein statistics</a></div>
<p>In 1924, Einstein received a description of a <a href="/wiki/Statistical_mechanics" title="Statistical mechanics">statistical</a> model from Indian physicist <a href="/wiki/Satyendra_Nath_Bose" title="Satyendra Nath Bose">Satyendra Nath Bose</a>, based on a counting method that assumed that light could be understood as a gas of indistinguishable particles. Einstein noted that Bose\'s statistics applied to some atoms as well as to the proposed light particles, and submitted his translation of Bose\'s paper to the <i><a href="/wiki/Zeitschrift_f%C3%BCr_Physik" title="Zeitschrift für Physik">Zeitschrift für Physik</a></i>. Einstein also published his own articles describing the model and its implications, among them the <a href="/wiki/Bose%E2%80%93Einstein_condensate" title="Bose–Einstein condensate">Bose–Einstein condensate</a> phenomenon that some particulates should appear at very low temperatures.<sup id="cite_ref-FOOTNOTEEinstein1924_281-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1924-281">&#91;276&#93;</a></sup> It was not until 1995 that the first such condensate was produced experimentally by <a href="/wiki/Eric_Allin_Cornell" title="Eric Allin Cornell">Eric Allin Cornell</a> and <a href="/wiki/Carl_Wieman" title="Carl Wieman">Carl Wieman</a> using <a href="/wiki/Ultracold_atom" title="Ultracold atom">ultra-cooling</a> equipment built at the <a href="/wiki/NIST" class="mw-redirect" title="NIST">NIST</a>–<a href="/wiki/JILA" title="JILA">JILA</a> laboratory at the <a href="/wiki/University_of_Colorado_at_Boulder" class="mw-redirect" title="University of Colorado at Boulder">University of Colorado at Boulder</a>.<sup id="cite_ref-nlagl_282-0" class="reference"><a href="#cite_note-nlagl-282">&#91;277&#93;</a></sup> Bose–Einstein statistics are now used to describe the behaviors of any assembly of <a href="/wiki/Boson" title="Boson">bosons</a>. Einstein\'s sketches for this project may be seen in the Einstein Archive in the library of the Leiden University.<sup id="cite_ref-Instituut-Lorentz_221-1" class="reference"><a href="#cite_note-Instituut-Lorentz-221">&#91;218&#93;</a></sup>
</p>
<h4><span id="Wave.E2.80.93particle_duality"></span><span class="mw-headline" id="Wave–particle_duality">Wave–particle duality</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_1921_(re-cropped).jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/4/49/Albert_Einstein_1921_%28re-cropped%29.jpg/170px-Albert_Einstein_1921_%28re-cropped%29.jpg" decoding="async" width="170" height="243" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/4/49/Albert_Einstein_1921_%28re-cropped%29.jpg/255px-Albert_Einstein_1921_%28re-cropped%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/4/49/Albert_Einstein_1921_%28re-cropped%29.jpg/340px-Albert_Einstein_1921_%28re-cropped%29.jpg 2x" data-file-width="1784" data-file-height="2552" /></a><figcaption>Einstein in 1921, photo by Harris &amp; Ewing Studio</figcaption></figure>
<p>Although the patent office promoted Einstein to Technical Examiner Second Class in 1906, he had not given up on academia. In 1908, he became a <i><a href="/wiki/Privatdozent" title="Privatdozent">Privatdozent</a></i> at the University of Bern.<sup id="cite_ref-FOOTNOTEPais1982522_283-0" class="reference"><a href="#cite_note-FOOTNOTEPais1982522-283">&#91;278&#93;</a></sup> In "<i>Über die Entwicklung unserer Anschauungen über das Wesen und die Konstitution der Strahlung</i>" ("<a href="https://en.wikisource.org/wiki/Translation:The_Development_of_Our_Views_on_the_Composition_and_Essence_of_Radiation" class="extiw" title="s:Translation:The Development of Our Views on the Composition and Essence of Radiation">The Development of our Views on the Composition and Essence of Radiation</a>"), on the <a href="/wiki/Quantization_(physics)" title="Quantization (physics)">quantization</a> of light, and in an earlier 1909 paper, Einstein showed that Max Planck\'s energy quanta must have well-defined <a href="/wiki/Momentum" title="Momentum">momenta</a> and act in some respects as independent, <a href="/wiki/Point_particle" title="Point particle">point-like particles</a>. This paper introduced the <i>photon</i> concept (although the name <i>photon</i> was introduced later by <a href="/wiki/Gilbert_N._Lewis" title="Gilbert N. Lewis">Gilbert N. Lewis</a> in 1926) and inspired the notion of <a href="/wiki/Wave%E2%80%93particle_duality" title="Wave–particle duality">wave–particle duality</a> in quantum mechanics. Einstein saw this wave–particle duality in radiation as concrete evidence for his conviction that physics needed a new, unified foundation.
</p>
<h4><span class="mw-headline" id="Zero-point_energy">Zero-point energy</span></h4>
<p>In a series of works completed from 1911 to 1913, Planck reformulated his 1900 quantum theory and introduced the idea of <a href="/wiki/Zero-point_energy" title="Zero-point energy">zero-point energy</a> in his "second quantum theory". Soon, this idea attracted the attention of Einstein and his assistant <a href="/wiki/Otto_Stern" title="Otto Stern">Otto Stern</a>. Assuming the energy of rotating diatomic molecules contains zero-point energy, they then compared the theoretical specific heat of hydrogen gas with the experimental data. The numbers matched nicely. However, after publishing the findings, they promptly withdrew their support, because they no longer had confidence in the correctness of the idea of zero-point energy.<sup id="cite_ref-FOOTNOTEStachel_et_al.2008270ffvol._4:_The_Swiss_Years:_Writings,_1912–1914_284-0" class="reference"><a href="#cite_note-FOOTNOTEStachel_et_al.2008270ffvol._4:_The_Swiss_Years:_Writings,_1912–1914-284">&#91;279&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Stimulated_emission">Stimulated emission</span></h4>
<p>In 1917, at the height of his work on relativity, Einstein published an article in <i>Physikalische Zeitschrift</i> that proposed the possibility of <a href="/wiki/Stimulated_emission" title="Stimulated emission">stimulated emission</a>, the physical process that makes possible the <a href="/wiki/Maser" title="Maser">maser</a> and the <a href="/wiki/Laser" title="Laser">laser</a>.<sup id="cite_ref-FOOTNOTEEinstein1917b_285-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1917b-285">&#91;280&#93;</a></sup>
This article showed that the statistics of absorption and emission of light would only be consistent with Planck\'s distribution law if the emission of light into a mode with n photons would be enhanced statistically compared to the emission of light into an empty mode. This paper was enormously influential in the later development of quantum mechanics, because it was the first paper to show that the statistics of atomic transitions had simple laws.<sup id="cite_ref-286" class="reference"><a href="#cite_note-286">&#91;281&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Matter_waves">Matter waves</span></h4>
<p>Einstein discovered <a href="/wiki/Louis_de_Broglie" title="Louis de Broglie">Louis de Broglie</a>\'s work and supported his ideas, which were received skeptically at first. In another major paper from this era, Einstein observed that <a href="/wiki/De_Broglie_waves" class="mw-redirect" title="De Broglie waves">de Broglie waves</a> could explain the <a href="/wiki/Bohr-Sommerfeld_quantization" class="mw-redirect" title="Bohr-Sommerfeld quantization">quantization rules of Bohr and Sommerfeld</a>. This paper would inspire Schrödinger\'s work of 1926.<sup id="cite_ref-287" class="reference"><a href="#cite_note-287">&#91;282&#93;</a></sup><sup id="cite_ref-288" class="reference"><a href="#cite_note-288">&#91;283&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="Quantum_mechanics">Quantum mechanics</span></h3>
<h4><span id="Einstein.27s_objections_to_quantum_mechanics"></span><span class="mw-headline" id="Einstein\'s_objections_to_quantum_mechanics">Einstein\'s objections to quantum mechanics</span></h4>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:NYT_May_4,_1935.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/a/a0/NYT_May_4%2C_1935.jpg/170px-NYT_May_4%2C_1935.jpg" decoding="async" width="170" height="203" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/a/a0/NYT_May_4%2C_1935.jpg/255px-NYT_May_4%2C_1935.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/a/a0/NYT_May_4%2C_1935.jpg/340px-NYT_May_4%2C_1935.jpg 2x" data-file-width="569" data-file-height="680" /></a><figcaption>Newspaper headline on 4 May 1935</figcaption></figure>
<p>Einstein played a major role in developing quantum theory, beginning with his 1905 paper on the photoelectric effect. However, he became displeased with modern quantum mechanics as it had evolved after 1925, despite its acceptance by other physicists. He was skeptical that the randomness of quantum mechanics was fundamental rather than the result of determinism, stating that God "is not playing at dice".<sup id="cite_ref-zZ2hS_289-0" class="reference"><a href="#cite_note-zZ2hS-289">&#91;284&#93;</a></sup> Until the end of his life, he continued to maintain that quantum mechanics was incomplete.<sup id="cite_ref-yzZtL_290-0" class="reference"><a href="#cite_note-yzZtL-290">&#91;285&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Bohr_versus_Einstein">Bohr versus Einstein</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Bohr%E2%80%93Einstein_debates" title="Bohr–Einstein debates">Bohr–Einstein debates</a></div>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg" class="mw-file-description"><img alt="Two men sitting, looking relaxed. A dark-haired Bohr is talking while Einstein looks skeptical." src="//upload.wikimedia.org/wikipedia/commons/thumb/4/43/Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg/170px-Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg" decoding="async" width="170" height="138" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/4/43/Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg/255px-Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/4/43/Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg/340px-Niels_Bohr_Albert_Einstein4_by_Ehrenfest_cr.jpg 2x" data-file-width="1912" data-file-height="1548" /></a><figcaption>Einstein and <a href="/wiki/Niels_Bohr" title="Niels Bohr">Niels Bohr</a>, 1925</figcaption></figure><p> The Bohr–Einstein debates were a series of public disputes about quantum mechanics between Einstein and <a href="/wiki/Niels_Bohr" title="Niels Bohr">Niels Bohr</a>, who were two of its founders. Their debates are remembered because of their importance to the <a href="/wiki/Philosophy_of_science" title="Philosophy of science">philosophy of science</a>.<sup id="cite_ref-Bohr1949_291-0" class="reference"><a href="#cite_note-Bohr1949-291">&#91;286&#93;</a></sup><sup id="cite_ref-FOOTNOTEEinstein1969_292-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1969-292">&#91;287&#93;</a></sup><sup id="cite_ref-293" class="reference"><a href="#cite_note-293">&#91;288&#93;</a></sup> Their debates would influence later <a href="/wiki/Interpretations_of_quantum_mechanics" title="Interpretations of quantum mechanics">interpretations of quantum mechanics</a>.
</p><h4><span id="Einstein.E2.80.93Podolsky.E2.80.93Rosen_paradox"></span><span class="mw-headline" id="Einstein–Podolsky–Rosen_paradox">Einstein–Podolsky–Rosen paradox</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/EPR_paradox" class="mw-redirect" title="EPR paradox">EPR paradox</a></div>
<p>Einstein never fully accepted quantum mechanics. While he recognized that it made correct predictions, he believed a more fundamental description of nature must be possible. Over the years he presented multiple arguments to this effect, but the one he preferred most dated to a debate with Bohr in 1930. Einstein suggested a <a href="/wiki/Einstein%27s_thought_experiments" title="Einstein&#39;s thought experiments">thought experiment</a> in which two objects are allowed to interact and then moved apart a great distance from each other. The quantum-mechanical description of the two objects is a mathematical entity known as a <a href="/wiki/Wavefunction" class="mw-redirect" title="Wavefunction">wavefunction</a>. If the wavefunction that describes the two objects before their interaction is given, then the <a href="/wiki/Schr%C3%B6dinger_equation" title="Schrödinger equation">Schrödinger equation</a> provides the wavefunction that describes them after their interaction. But because of what would later be called <a href="/wiki/Quantum_entanglement" title="Quantum entanglement">quantum entanglement</a>, measuring one object would lead to an instantaneous change of the wavefunction describing the other object, no matter how far away it is. Moreover, the choice of which measurement to perform upon the first object would affect what wavefunction could result for the second object. Einstein reasoned that no influence could propagate from the first object to the second instantaneously fast. Indeed, he argued, physics depends on being able to tell one thing apart from another, and such instantaneous influences would call that into question. Because the true "physical condition" of the second object could not be immediately altered by an action done to the first, Einstein concluded, the wavefunction could not be that true physical condition, only an incomplete description of it.<sup id="cite_ref-FOOTNOTEHoward1990_294-0" class="reference"><a href="#cite_note-FOOTNOTEHoward1990-294">&#91;289&#93;</a></sup><sup id="cite_ref-FOOTNOTEHarriganSpekkens2010_295-0" class="reference"><a href="#cite_note-FOOTNOTEHarriganSpekkens2010-295">&#91;290&#93;</a></sup>
</p><p>A more famous version of this argument came in 1935, when Einstein published a paper with <a href="/wiki/Boris_Podolsky" title="Boris Podolsky">Boris Podolsky</a> and <a href="/wiki/Nathan_Rosen" title="Nathan Rosen">Nathan Rosen</a> that laid out what would become known as the <a href="/wiki/EPR_paradox" class="mw-redirect" title="EPR paradox">EPR paradox</a>.<sup id="cite_ref-FOOTNOTEEinsteinPodolskyRosen1935_296-0" class="reference"><a href="#cite_note-FOOTNOTEEinsteinPodolskyRosen1935-296">&#91;291&#93;</a></sup> In this thought experiment, two particles interact in such a way that the wavefunction describing them is entangled. Then, no matter how far the two particles were separated, a precise position measurement on one particle would imply the ability to predict, perfectly, the result of measuring the position of the other particle. Likewise, a precise momentum measurement of one particle would result in an equally precise prediction for of the momentum of the other particle, without needing to disturb the other particle in any way. They argued that no action taken on the first particle could instantaneously affect the other, since this would involve information being transmitted faster than light, which is forbidden by the <a href="/wiki/Theory_of_relativity" title="Theory of relativity">theory of relativity</a>. They invoked a principle, later known as the "EPR criterion of reality", positing that: "If, without in any way disturbing a system, we can predict with certainty (i.e., with <a href="/wiki/Probability" title="Probability">probability</a> equal to unity) the value of a physical quantity, then there exists an element of reality corresponding to that quantity." From this, they inferred that the second particle must have a definite value of both position and of momentum prior to either quantity being measured. But quantum mechanics considers these two observables <a href="/wiki/Observable#Incompatibility_of_observables_in_quantum_mechanics" title="Observable">incompatible</a> and thus does not associate simultaneous values for both to any system. Einstein, Podolsky, and Rosen therefore concluded that quantum theory does not provide a complete description of reality.<sup id="cite_ref-FOOTNOTEPeres2002_297-0" class="reference"><a href="#cite_note-FOOTNOTEPeres2002-297">&#91;292&#93;</a></sup>
</p><p>In 1964, <a href="/wiki/John_Stewart_Bell" title="John Stewart Bell">John Stewart Bell</a> carried the analysis of quantum entanglement much further. He deduced that if measurements are performed independently on the two separated particles of an entangled pair, then the assumption that the outcomes depend upon hidden variables within each half implies a mathematical constraint on how the outcomes on the two measurements are correlated. This constraint would later be called a <a href="/wiki/Bell_inequality" class="mw-redirect" title="Bell inequality">Bell inequality</a>. Bell then showed that quantum physics predicts correlations that violate this inequality. Consequently, the only way that hidden variables could explain the predictions of quantum physics is if they are "nonlocal", which is to say that somehow the two particles are able to interact instantaneously no matter how widely they ever become separated.<sup id="cite_ref-FOOTNOTEMermin1993_298-0" class="reference"><a href="#cite_note-FOOTNOTEMermin1993-298">&#91;293&#93;</a></sup><sup id="cite_ref-FOOTNOTEPenrose2007_299-0" class="reference"><a href="#cite_note-FOOTNOTEPenrose2007-299">&#91;294&#93;</a></sup> Bell argued that because an explanation of quantum phenomena in terms of hidden variables would require nonlocality, the EPR paradox "is resolved in the way which Einstein would have liked least".<sup id="cite_ref-FOOTNOTEBell1966_300-0" class="reference"><a href="#cite_note-FOOTNOTEBell1966-300">&#91;295&#93;</a></sup>
</p><p>Despite this, and although Einstein personally found the argument in the EPR paper overly complicated,<sup id="cite_ref-FOOTNOTEHoward1990_294-1" class="reference"><a href="#cite_note-FOOTNOTEHoward1990-294">&#91;289&#93;</a></sup><sup id="cite_ref-FOOTNOTEHarriganSpekkens2010_295-1" class="reference"><a href="#cite_note-FOOTNOTEHarriganSpekkens2010-295">&#91;290&#93;</a></sup> that paper became among the most influential papers published in <i><a href="/wiki/Physical_Review" title="Physical Review">Physical Review</a></i>. It is considered a centerpiece of the development of <a href="/wiki/Quantum_information_theory" class="mw-redirect" title="Quantum information theory">quantum information theory</a>.<sup id="cite_ref-FOOTNOTEFine2017_301-0" class="reference"><a href="#cite_note-FOOTNOTEFine2017-301">&#91;296&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="Unified_field_theory">Unified field theory</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Classical_unified_field_theories" title="Classical unified field theories">Classical unified field theories</a></div>
<p>Encouraged by his success with general relativity, Einstein sought an even more ambitious geometrical theory that would treat gravitation and electromagnetism as aspects of a single entity. In 1950, he described his <a href="/wiki/Unified_field_theory" title="Unified field theory">unified field theory</a> in a <i><a href="/wiki/Scientific_American" title="Scientific American">Scientific American</a></i> article titled "On the Generalized Theory of Gravitation".<sup id="cite_ref-FOOTNOTEEinstein1950_302-0" class="reference"><a href="#cite_note-FOOTNOTEEinstein1950-302">&#91;297&#93;</a></sup> His attempt to find the most fundamental laws of nature won him praise but not success: a particularly conspicuous blemish of his model was that it did not accommodate the <a href="/wiki/Strong_nuclear_force" class="mw-redirect" title="Strong nuclear force">strong</a> and <a href="/wiki/Weak_nuclear_force" class="mw-redirect" title="Weak nuclear force">weak nuclear forces</a>, neither of which was well understood until many years after his death. Although most researchers now believe that Einstein\'s approach to unifying physics was mistaken, his goal of a <a href="/wiki/Theory_of_everything" title="Theory of everything">theory of everything</a> is one to which his successors still aspire.<sup id="cite_ref-303" class="reference"><a href="#cite_note-303">&#91;298&#93;</a></sup>
</p>
<h3><span class="mw-headline" id="Other_investigations">Other investigations</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Einstein%27s_unsuccessful_investigations" title="Einstein&#39;s unsuccessful investigations">Einstein\'s unsuccessful investigations</a></div>
<p>Einstein conducted other investigations that were unsuccessful and abandoned. These pertain to <a href="/wiki/Force" title="Force">force</a>, <a href="/wiki/Superconductivity" title="Superconductivity">superconductivity</a>, and other research.
</p>
<h3><span class="mw-headline" id="Collaboration_with_other_scientists">Collaboration with other scientists</span></h3>
<figure class="mw-default-size" typeof="mw:File/Thumb"><a href="/wiki/File:Solvay_conference_1927.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/6/6e/Solvay_conference_1927.jpg/220px-Solvay_conference_1927.jpg" decoding="async" width="220" height="159" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/6/6e/Solvay_conference_1927.jpg/330px-Solvay_conference_1927.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/6/6e/Solvay_conference_1927.jpg/440px-Solvay_conference_1927.jpg 2x" data-file-width="3000" data-file-height="2171" /></a><figcaption>The 1927 <a href="/wiki/Solvay_Conference" title="Solvay Conference">Solvay Conference</a> in Brussels, a gathering of the world\'s top physicists. Einstein is in the center.</figcaption></figure>
<p>In addition to longtime collaborators <a href="/wiki/Leopold_Infeld" title="Leopold Infeld">Leopold Infeld</a>, <a href="/wiki/Nathan_Rosen" title="Nathan Rosen">Nathan Rosen</a>, <a href="/wiki/Peter_Bergmann" title="Peter Bergmann">Peter Bergmann</a> and others, Einstein also had some one-shot collaborations with various scientists.
</p>
<h4><span id="Einstein.E2.80.93de_Haas_experiment"></span><span class="mw-headline" id="Einstein–de_Haas_experiment">Einstein–de Haas experiment</span></h4>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Einstein%E2%80%93de_Haas_effect" title="Einstein–de Haas effect">Einstein–de Haas effect</a></div>
<p>In 1908, <a href="/wiki/Owen_Willans_Richardson" title="Owen Willans Richardson">Owen Willans Richardson</a> predicted that a change in the <a href="/wiki/Magnetic_moment" title="Magnetic moment">magnetic moment</a> of a free body will cause this body to rotate. This effect is a consequence of the <a href="/wiki/Conservation_of_angular_momentum" class="mw-redirect" title="Conservation of angular momentum">conservation of angular momentum</a> and is strong enough to be observable in <a href="/wiki/Ferromagnetic_materials" class="mw-redirect" title="Ferromagnetic materials">ferromagnetic materials</a>.<sup id="cite_ref-Richardson-1908_304-0" class="reference"><a href="#cite_note-Richardson-1908-304">&#91;299&#93;</a></sup> Einstein and <a href="/wiki/Wander_Johannes_de_Haas" title="Wander Johannes de Haas">Wander Johannes de Haas</a> published two papers in 1915 claiming the first experimental observation of the effect.<sup id="cite_ref-EdH-1-1915_305-0" class="reference"><a href="#cite_note-EdH-1-1915-305">&#91;300&#93;</a></sup><sup id="cite_ref-EdH-2-1915_306-0" class="reference"><a href="#cite_note-EdH-2-1915-306">&#91;301&#93;</a></sup> Measurements of this kind demonstrate that the phenomenon of <a href="/wiki/Magnetization" title="Magnetization">magnetization</a> is caused by the alignment (<a href="/wiki/Spin_polarization" title="Spin polarization">polarization</a>) of the <a href="/wiki/Angular_momenta" class="mw-redirect" title="Angular momenta">angular momenta</a> of the <a href="/wiki/Electron" title="Electron">electrons</a> in the material along the axis of magnetization. These measurements also allow the separation of the two contributions to the magnetization: that which is associated with the <a href="/wiki/Spin_(physics)" title="Spin (physics)">spin</a> and with the orbital motion of the electrons. The Einstein-de Haas experiment is the only experiment concived, realized and published by Albert Einstein himself.
</p><p>A complete original version of the Einstein-de Haas experimental equipment was donated by <a href="/wiki/Geertruida_de_Haas-Lorentz" title="Geertruida de Haas-Lorentz">Geertruida de Haas-Lorentz</a>, wife of de Haas and daughter of Lorentz, to the <a href="/wiki/Amp%C3%A8re_Museum" title="Ampère Museum">Ampère Museum</a> in Lyon France in 1961 where it is currently on display. It was lost among the museum\'s holdings and was rediscovered in 2023.<sup id="cite_ref-307" class="reference"><a href="#cite_note-307">&#91;302&#93;</a></sup><sup id="cite_ref-308" class="reference"><a href="#cite_note-308">&#91;303&#93;</a></sup>
</p>
<h4><span class="mw-headline" id="Einstein_as_an_inventor">Einstein as an inventor</span></h4>
<p>In 1926, Einstein and his former student Leó Szilárd co-invented (and in 1930, patented) the <a href="/wiki/Einstein_refrigerator" title="Einstein refrigerator">Einstein refrigerator</a>. This <a href="/wiki/Absorption_refrigerator" title="Absorption refrigerator">absorption refrigerator</a> was then revolutionary for having no moving parts and using only heat as an input.<sup id="cite_ref-Goettling_309-0" class="reference"><a href="#cite_note-Goettling-309">&#91;304&#93;</a></sup> On 11 November 1930, <span><a rel="nofollow" class="external text" href="https://patents.google.com/patent/US1781541">U.S. patent 1,781,541</a></span> was awarded to Einstein and Leó Szilárd for the refrigerator. Their invention was not immediately put into commercial production, but the most promising of their patents were acquired by the Swedish company <a href="/wiki/Electrolux" title="Electrolux">Electrolux</a>.<sup id="cite_ref-311" class="reference"><a href="#cite_note-311">&#91;note 6&#93;</a></sup>
</p><p>Einstein also invented an electromagnetic pump,<sup id="cite_ref-patents.google.com_312-0" class="reference"><a href="#cite_note-patents.google.com-312">&#91;306&#93;</a></sup> sound reproduction device,<sup id="cite_ref-313" class="reference"><a href="#cite_note-313">&#91;307&#93;</a></sup> and several other household devices.<sup id="cite_ref-314" class="reference"><a href="#cite_note-314">&#91;308&#93;</a></sup>
</p>
<h2><span class="mw-headline" id="Non-scientific_legacy">Non-scientific legacy</span></h2>
<figure class="mw-default-size mw-halign-left" typeof="mw:File/Thumb"><a href="/wiki/File:Einstein-Oslofjord_(cropped).jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/6/61/Einstein-Oslofjord_%28cropped%29.jpg/220px-Einstein-Oslofjord_%28cropped%29.jpg" decoding="async" width="220" height="169" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/6/61/Einstein-Oslofjord_%28cropped%29.jpg/330px-Einstein-Oslofjord_%28cropped%29.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/6/61/Einstein-Oslofjord_%28cropped%29.jpg/440px-Einstein-Oslofjord_%28cropped%29.jpg 2x" data-file-width="906" data-file-height="698" /></a><figcaption>Left-right: <a href="/wiki/Heinrich_Jacob_Goldschmidt" title="Heinrich Jacob Goldschmidt">Heinrich Goldschmidt</a>, Einstein, <a href="/wiki/Ole_Colbj%C3%B8rnsen" title="Ole Colbjørnsen">Ole Colbjørnsen</a>, <a href="/wiki/J%C3%B8rgen_Vogt" title="Jørgen Vogt">Jørgen Vogt</a>, and Ilse Einstein at a picnic in Oslo in 1920.</figcaption></figure>
<p>While traveling, Einstein wrote daily to his wife Elsa and adopted stepdaughters Margot and Ilse. The letters were included in the papers bequeathed to the <a href="/wiki/Hebrew_University_of_Jerusalem" title="Hebrew University of Jerusalem">Hebrew University of Jerusalem</a>. Margot Einstein permitted the personal letters to be made available to the public, but requested that it not be done until twenty years after her death (she died in 1986<sup id="cite_ref-margot-obituary_315-0" class="reference"><a href="#cite_note-margot-obituary-315">&#91;309&#93;</a></sup>). Barbara Wolff, of the Hebrew University\'s <a href="/wiki/Albert_Einstein_Archives" title="Albert Einstein Archives">Albert Einstein Archives</a>, told the <a href="/wiki/BBC" title="BBC">BBC</a> that there are about 3,500 pages of private correspondence written between 1912 and 1955.<sup id="cite_ref-letters-love_316-0" class="reference"><a href="#cite_note-letters-love-316">&#91;310&#93;</a></sup>
</p><p>Einstein\'s <a href="/wiki/Right_of_publicity" class="mw-redirect" title="Right of publicity">right of publicity</a> was litigated in 2015 in a federal district court in California. Although the court initially held that the right had expired,<sup id="cite_ref-casetext-hebrew-university_317-0" class="reference"><a href="#cite_note-casetext-hebrew-university-317">&#91;311&#93;</a></sup> that ruling was immediately appealed, and the decision was later vacated in its entirety. The underlying claims between the parties in that lawsuit were ultimately settled. The right is enforceable, and the Hebrew University of Jerusalem is the exclusive representative of that right.<sup id="cite_ref-pacermonitor-hebrew-university_318-0" class="reference"><a href="#cite_note-pacermonitor-hebrew-university-318">&#91;312&#93;</a></sup> <a href="/wiki/Branded_Entertainment_Network" class="mw-redirect" title="Branded Entertainment Network">Corbis</a>, successor to The Roger Richman Agency, licenses the <a href="/wiki/Trademark" title="Trademark">use of his name and associated imagery</a>, as agent for the university.<sup id="cite_ref-einstein.biz_319-0" class="reference"><a href="#cite_note-einstein.biz-319">&#91;313&#93;</a></sup>
</p><p><a href="/wiki/Mount_Einstein" title="Mount Einstein">Mount Einstein</a> in the <a href="/wiki/Chugach_Mountains" title="Chugach Mountains">Chugach Mountains</a> of <a href="/wiki/Alaska" title="Alaska">Alaska</a> was named in 1955.
</p><p>Mount Einstein in New Zealand\'s <a href="/wiki/Paparoa_Range" title="Paparoa Range">Paparoa Range</a> was named after him in 1970 by the <a href="/wiki/Department_of_Scientific_and_Industrial_Research_(New_Zealand)" title="Department of Scientific and Industrial Research (New Zealand)">Department of Scientific and Industrial Research</a>.<sup id="cite_ref-320" class="reference"><a href="#cite_note-320">&#91;314&#93;</a></sup>
</p>
<h2><span class="mw-headline" id="In_popular_culture">In popular culture</span></h2>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/Albert_Einstein_in_popular_culture" title="Albert Einstein in popular culture">Albert Einstein in popular culture</a></div>
<figure typeof="mw:File/Thumb"><a href="/wiki/File:Albert_Einstein_sticks_his_tongue_1951.jpg" class="mw-file-description"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/5/5a/Albert_Einstein_sticks_his_tongue_1951.jpg/189px-Albert_Einstein_sticks_his_tongue_1951.jpg" decoding="async" width="189" height="224" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/5/5a/Albert_Einstein_sticks_his_tongue_1951.jpg/284px-Albert_Einstein_sticks_his_tongue_1951.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/5/5a/Albert_Einstein_sticks_his_tongue_1951.jpg/379px-Albert_Einstein_sticks_his_tongue_1951.jpg 2x" data-file-width="1514" data-file-height="1789" /></a><figcaption>The famous image of Einstein taken by <a href="/wiki/International_News_Service" title="International News Service">International News</a> photographer <a href="/wiki/Arthur_Sasse" title="Arthur Sasse">Arthur Sasse</a> in 1951</figcaption></figure>
<p>Einstein became one of the most famous <a href="/wiki/Scientific_celebrity" title="Scientific celebrity">scientific celebrities</a> after the confirmation of his general theory of relativity in 1919.<sup id="cite_ref-321" class="reference"><a href="#cite_note-321">&#91;315&#93;</a></sup><sup id="cite_ref-322" class="reference"><a href="#cite_note-322">&#91;316&#93;</a></sup><sup id="cite_ref-323" class="reference"><a href="#cite_note-323">&#91;317&#93;</a></sup> Although most of the public had little understanding of his work, he was widely recognized and admired. In the period before World War II, <i><a href="/wiki/The_New_Yorker" title="The New Yorker">The New Yorker</a></i> published a vignette in their "The Talk of the Town" feature saying that Einstein was so well known in America that he would be stopped on the street by people wanting him to explain "that theory". Eventually he came to cope with unwanted enquirers by pretending to be someone else: "Pardon me, sorry! Always I am mistaken for Professor Einstein."<sup id="cite_ref-disguise_324-0" class="reference"><a href="#cite_note-disguise-324">&#91;318&#93;</a></sup>
</p><p>Einstein has been the subject of or inspiration for many novels, films, plays, and works of music.<sup id="cite_ref-orchestra_325-0" class="reference"><a href="#cite_note-orchestra-325">&#91;319&#93;</a></sup> He is a favorite model for depictions of <a href="/wiki/Absent-minded_professor" title="Absent-minded professor">absent-minded professors</a>; his expressive face and distinctive hairstyle have been widely copied and exaggerated. <i><a href="/wiki/Time_(magazine)" title="Time (magazine)">Time</a></i> magazine\'s Frederic Golden wrote that Einstein was "a cartoonist\'s dream come true".<sup id="cite_ref-slqbwn_326-0" class="reference"><a href="#cite_note-slqbwn-326">&#91;320&#93;</a></sup>
</p><p>Many popular <a href="/wiki/Quotations" class="mw-redirect" title="Quotations">quotations</a> are often <a href="/wiki/False_attribution" title="False attribution">misattributed</a> to him.<sup id="cite_ref-fake-quotes_327-0" class="reference"><a href="#cite_note-fake-quotes-327">&#91;321&#93;</a></sup><sup id="cite_ref-humiliate-atheist_328-0" class="reference"><a href="#cite_note-humiliate-atheist-328">&#91;322&#93;</a></sup>
</p>
<h2><span class="mw-headline" id="Awards_and_honors">Awards and honors</span></h2>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Main article: <a href="/wiki/List_of_awards_and_honors_received_by_Albert_Einstein" title="List of awards and honors received by Albert Einstein">List of awards and honors received by Albert Einstein</a></div>
<p>Einstein received numerous awards and honors, and in 1922, he was awarded the 1921 <a href="/wiki/Nobel_Prize_in_Physics" title="Nobel Prize in Physics">Nobel Prize in Physics</a> "for his services to Theoretical Physics, and especially for his discovery of the law of the photoelectric effect". None of the nominations in 1921 met the criteria set by <a href="/wiki/Alfred_Nobel" title="Alfred Nobel">Alfred Nobel</a>, so the 1921 prize was carried forward and awarded to Einstein in 1922.<sup id="cite_ref-Nobel_Prize_8-2" class="reference"><a href="#cite_note-Nobel_Prize-8">&#91;7&#93;</a></sup>
</p><p><a href="/wiki/Einsteinium" title="Einsteinium">Einsteinium</a>, a synthetic chemical element, was named in his honor in 1955, a few months after his death.<sup id="cite_ref-329" class="reference"><a href="#cite_note-329">&#91;323&#93;</a></sup>
</p>
<h2><span class="mw-headline" id="Publications">Publications</span></h2>
<h3><span class="mw-headline" id="Scientific">Scientific</span></h3>
<dl><dd><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1033289096"><div role="note" class="hatnote navigation-not-searchable">Further information: <a href="/wiki/List_of_scientific_publications_by_Albert_Einstein" title="List of scientific publications by Albert Einstein">List of scientific publications by Albert Einstein</a></div></dd></dl>
<style data-mw-deduplicate="TemplateStyles:r1184024115">.mw-parser-output .div-col{margin-top:0.3em;column-width:30em}.mw-parser-output .div-col-small{font-size:90%}.mw-parser-output .div-col-rules{column-rule:1px solid #aaa}.mw-parser-output .div-col dl,.mw-parser-output .div-col ol,.mw-parser-output .div-col ul{margin-top:0}.mw-parser-output .div-col li,.mw-parser-output .div-col dd{page-break-inside:avoid;break-inside:avoid-column}</style><div class="div-col" style="column-width: 35em;">
<ul><li><style data-mw-deduplicate="TemplateStyles:r1215172403">.mw-parser-output cite.citation{font-style:inherit;word-wrap:break-word}.mw-parser-output .citation q{quotes:"\\"""\\"""\'""\'"}.mw-parser-output .citation:target{background-color:rgba(0,127,255,0.133)}.mw-parser-output .id-lock-free.id-lock-free a{background:url("//upload.wikimedia.org/wikipedia/commons/6/65/Lock-green.svg")right 0.1em center/9px no-repeat}body:not(.skin-timeless):not(.skin-minerva) .mw-parser-output .id-lock-free a{background-size:contain}.mw-parser-output .id-lock-limited.id-lock-limited a,.mw-parser-output .id-lock-registration.id-lock-registration a{background:url("//upload.wikimedia.org/wikipedia/commons/d/d6/Lock-gray-alt-2.svg")right 0.1em center/9px no-repeat}body:not(.skin-timeless):not(.skin-minerva) .mw-parser-output .id-lock-limited a,body:not(.skin-timeless):not(.skin-minerva) .mw-parser-output .id-lock-registration a{background-size:contain}.mw-parser-output .id-lock-subscription.id-lock-subscription a{background:url("//upload.wikimedia.org/wikipedia/commons/a/aa/Lock-red-alt-2.svg")right 0.1em center/9px no-repeat}body:not(.skin-timeless):not(.skin-minerva) .mw-parser-output .id-lock-subscription a{background-size:contain}.mw-parser-output .cs1-ws-icon a{background:url("//upload.wikimedia.org/wikipedia/commons/4/4c/Wikisource-logo.svg")right 0.1em center/12px no-repeat}body:not(.skin-timeless):not(.skin-minerva) .mw-parser-output .cs1-ws-icon a{background-size:contain}.mw-parser-output .cs1-code{color:inherit;background:inherit;border:none;padding:inherit}.mw-parser-output .cs1-hidden-error{display:none;color:#d33}.mw-parser-output .cs1-visible-error{color:#d33}.mw-parser-output .cs1-maint{display:none;color:#2C882D;margin-left:0.3em}.mw-parser-output .cs1-format{font-size:95%}.mw-parser-output .cs1-kern-left{padding-left:0.2em}.mw-parser-output .cs1-kern-right{padding-right:0.2em}.mw-parser-output .citation .mw-selflink{font-weight:inherit}html.skin-theme-clientpref-night .mw-parser-output .cs1-maint{color:#18911F}html.skin-theme-clientpref-night .mw-parser-output .cs1-visible-error,html.skin-theme-clientpref-night .mw-parser-output .cs1-hidden-error{color:#f8a397}@media(prefers-color-scheme:dark){html.skin-theme-clientpref-os .mw-parser-output .cs1-visible-error,html.skin-theme-clientpref-os .mw-parser-output .cs1-hidden-error{color:#f8a397}html.skin-theme-clientpref-os .mw-parser-output .cs1-maint{color:#18911F}}</style><cite id="CITEREFEinstein1901" class="citation journal cs1 cs1-prop-location-test cs1-prop-long-vol cs1-prop-foreign-lang-source">Einstein, Albert (1901) [Completed 13 December 1900 and manuscript received 16 December 1900].  Written at Zurich, Switzerland. <a href="/wiki/Paul_Karl_Ludwig_Drude" class="mw-redirect" title="Paul Karl Ludwig Drude">Paul Karl Ludwig Drude</a> (ed.). <a rel="nofollow" class="external text" href="https://zenodo.org/record/1423995">"Folgerungen aus den Capillaritätserscheinungen"</a> &#91;Conclusions Drawn from the Phenomena of Capillarity&#93;. <i><a href="/wiki/Annalen_der_Physik" title="Annalen der Physik">Annalen der Physik</a></i>. Vierte Folge (in German). 4 (all series: 309) (3). Leipzig, Germany: Verlag von Johann Ambrosius Barth (published 1 March 1901): 513–523. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1901AnP...309..513E">1901AnP...309..513E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1002%2Fandp.19013090306">10.1002/andp.19013090306</a> &#8211; via Wiley Online Library, Hoboken, New Jersey, US (March 2006).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Annalen+der+Physik&amp;rft.atitle=Folgerungen+aus+den+Capillarit%C3%A4tserscheinungen&amp;rft.volume=4+%28all+series%3A+309%29&amp;rft.issue=3&amp;rft.pages=513-523&amp;rft.date=1901&amp;rft_id=info%3Adoi%2F10.1002%2Fandp.19013090306&amp;rft_id=info%3Abibcode%2F1901AnP...309..513E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Fzenodo.org%2Frecord%2F1423995&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1905a" class="citation journal cs1 cs1-prop-location-test cs1-prop-long-vol cs1-prop-foreign-lang-source">Einstein, Albert (1905a) [Completed 17 March 1905 and submitted 18 March 1905].  Written at Berne, Switzerland. <a href="/wiki/Paul_Karl_Ludwig_Drude" class="mw-redirect" title="Paul Karl Ludwig Drude">Paul Karl Ludwig Drude</a> (ed.). <a rel="nofollow" class="external text" href="http://www.physik.uni-augsburg.de/annalen/history/einstein-papers/1905_17_132-148.pdf">"Über einen die Erzeugung und Verwandlung des Lichtes betreffenden heuristischen Gesichtspunkt"</a> &#91;On a Heuristic Viewpoint Concerning the Production and Transformation of Light&#93; <span class="cs1-format">(PDF)</span>. <i><a href="/wiki/Annalen_der_Physik" title="Annalen der Physik">Annalen der Physik</a></i>. Vierte Folge (in German). 17 (all series: 322) (6). Leipzig, Germany: Verlag von Johann Ambrosius Barth (published 9 June 1905): 132–148. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1905AnP...322..132E">1905AnP...322..132E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1002%2Fandp.19053220607">10.1002/andp.19053220607</a> &#8211; via Wiley Online Library, Hoboken, New Jersey, US (10 March 2006).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Annalen+der+Physik&amp;rft.atitle=%C3%9Cber+einen+die+Erzeugung+und+Verwandlung+des+Lichtes+betreffenden+heuristischen+Gesichtspunkt&amp;rft.volume=17+%28all+series%3A+322%29&amp;rft.issue=6&amp;rft.pages=132-148&amp;rft.date=1905&amp;rft_id=info%3Adoi%2F10.1002%2Fandp.19053220607&amp;rft_id=info%3Abibcode%2F1905AnP...322..132E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fwww.physik.uni-augsburg.de%2Fannalen%2Fhistory%2Feinstein-papers%2F1905_17_132-148.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1905b" class="citation thesis cs1 cs1-prop-foreign-lang-source">Einstein, Albert (1905b) [Completed 30 April 1905]. <a rel="nofollow" class="external text" href="http://e-collection.library.ethz.ch/eserv/eth:30378/eth-30378-01.pdf"><i>Eine neue Bestimmung der Moleküldimensionen</i></a> &#91;<i>A new determination of molecular dimensions</i>&#93; <span class="cs1-format">(PDF)</span>. <i>Dissertationen <a href="/wiki/Universit%C3%A4t_Z%C3%BCrich" class="mw-redirect" title="Universität Zürich">Universität Zürich</a></i> (PhD Thesis) (in German). Berne, Switzerland: Wyss Buchdruckerei (published 20 July 1905). <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.3929%2Fethz-a-000565688">10.3929/ethz-a-000565688</a>. <a href="/wiki/Hdl_(identifier)" class="mw-redirect" title="Hdl (identifier)">hdl</a>:<a rel="nofollow" class="external text" href="https://hdl.handle.net/20.500.11850%2F139872">20.500.11850/139872</a> &#8211; via <a href="/wiki/ETH" class="mw-redirect" title="ETH">ETH</a> Bibliothek, Zürich (2008).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Adissertation&amp;rft.title=Eine+neue+Bestimmung+der+Molek%C3%BCldimensionen&amp;rft.inst=Wyss+Buchdruckerei&amp;rft.date=1905&amp;rft_id=info%3Ahdl%2F20.500.11850%2F139872&amp;rft_id=info%3Adoi%2F10.3929%2Fethz-a-000565688&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fe-collection.library.ethz.ch%2Feserv%2Feth%3A30378%2Feth-30378-01.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1905c" class="citation journal cs1 cs1-prop-location-test cs1-prop-long-vol cs1-prop-foreign-lang-source">Einstein, Albert (1905c) [Manuscript received: 11 May 1905].  Written at Berne, Switzerland. <a href="/wiki/Paul_Karl_Ludwig_Drude" class="mw-redirect" title="Paul Karl Ludwig Drude">Paul Karl Ludwig Drude</a> (ed.). <a rel="nofollow" class="external text" href="http://sedici.unlp.edu.ar/handle/10915/2785">"Über die von der molekularkinetischen Theorie der Wärme geforderte Bewegung von in ruhenden Flüssigkeiten suspendierten Teilchen"</a> &#91;On the Motion&#160;– Required by the Molecular Kinetic Theory of Heat&#160;– of Small Particles Suspended in a Stationary Liquid&#93;. <i><a href="/wiki/Annalen_der_Physik" title="Annalen der Physik">Annalen der Physik</a></i>. Vierte Folge (in German). 17 (all series: 322) (8). Leipzig, Germany: Verlag von Johann Ambrosius Barth (published 18 July 1905): 549–560. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1905AnP...322..549E">1905AnP...322..549E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1002%2Fandp.19053220806">10.1002/andp.19053220806</a></span>. <a href="/wiki/Hdl_(identifier)" class="mw-redirect" title="Hdl (identifier)">hdl</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://hdl.handle.net/10915%2F2785">10915/2785</a></span> &#8211; via Wiley Online Library, Hoboken, New Jersey, US (10 March 2006).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Annalen+der+Physik&amp;rft.atitle=%C3%9Cber+die+von+der+molekularkinetischen+Theorie+der+W%C3%A4rme+geforderte+Bewegung+von+in+ruhenden+Fl%C3%BCssigkeiten+suspendierten+Teilchen&amp;rft.volume=17+%28all+series%3A+322%29&amp;rft.issue=8&amp;rft.pages=549-560&amp;rft.date=1905&amp;rft_id=info%3Ahdl%2F10915%2F2785&amp;rft_id=info%3Adoi%2F10.1002%2Fandp.19053220806&amp;rft_id=info%3Abibcode%2F1905AnP...322..549E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fsedici.unlp.edu.ar%2Fhandle%2F10915%2F2785&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1905d" class="citation journal cs1 cs1-prop-location-test cs1-prop-long-vol cs1-prop-foreign-lang-source">Einstein, Albert (1905d) [Manuscript received 30 June 1905].  Written at Berne, Switzerland. <a href="/wiki/Paul_Karl_Ludwig_Drude" class="mw-redirect" title="Paul Karl Ludwig Drude">Paul Karl Ludwig Drude</a> (ed.). <a rel="nofollow" class="external text" href="http://sedici.unlp.edu.ar/handle/10915/2786">"Zur Elektrodynamik bewegter Körper"</a> &#91;On the Electrodynamics of Moving Bodies&#93;. <i><a href="/wiki/Annalen_der_Physik" title="Annalen der Physik">Annalen der Physik</a></i> (Submitted manuscript). Vierte Folge (in German). 17 (all series: 322) (10). Leipzig, Germany: Verlag von Johann Ambrosius Barth (published 26 September 1905): 891–921. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1905AnP...322..891E">1905AnP...322..891E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1002%2Fandp.19053221004">10.1002/andp.19053221004</a>. <a href="/wiki/Hdl_(identifier)" class="mw-redirect" title="Hdl (identifier)">hdl</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://hdl.handle.net/10915%2F2786">10915/2786</a></span> &#8211; via Wiley Online Library, Hoboken, New Jersey, US (10 March 2006).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Annalen+der+Physik&amp;rft.atitle=Zur+Elektrodynamik+bewegter+K%C3%B6rper&amp;rft.volume=17+%28all+series%3A+322%29&amp;rft.issue=10&amp;rft.pages=891-921&amp;rft.date=1905&amp;rft_id=info%3Ahdl%2F10915%2F2786&amp;rft_id=info%3Adoi%2F10.1002%2Fandp.19053221004&amp;rft_id=info%3Abibcode%2F1905AnP...322..891E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fsedici.unlp.edu.ar%2Fhandle%2F10915%2F2786&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1905e" class="citation journal cs1 cs1-prop-location-test cs1-prop-long-vol cs1-prop-foreign-lang-source">Einstein, Albert (1905e) [Manuscript received 27 September 1905].  Written at Berne, Switzerland. <a href="/wiki/Paul_Karl_Ludwig_Drude" class="mw-redirect" title="Paul Karl Ludwig Drude">Paul Karl Ludwig Drude</a> (ed.). <a rel="nofollow" class="external text" href="https://zenodo.org/record/1424057">"Ist die Trägheit eines Körpers von seinem Energieinhalt abhängig?"</a> &#91;Does the Inertia of a Body Depend Upon Its Energy Content?&#93;. <i><a href="/wiki/Annalen_der_Physik" title="Annalen der Physik">Annalen der Physik</a></i>. Vierte Folge (in German). 18 (all series: 323) (13). Leipzig, Germany: Verlag von Johann Ambrosius Barth (published 21 November 1905): 639–641. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1905AnP...323..639E">1905AnP...323..639E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1002%2Fandp.19053231314">10.1002/andp.19053231314</a></span> &#8211; via Wiley Online Library, Hoboken, New Jersey, US (10 March 2006).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Annalen+der+Physik&amp;rft.atitle=Ist+die+Tr%C3%A4gheit+eines+K%C3%B6rpers+von+seinem+Energieinhalt+abh%C3%A4ngig%3F&amp;rft.volume=18+%28all+series%3A+323%29&amp;rft.issue=13&amp;rft.pages=639-641&amp;rft.date=1905&amp;rft_id=info%3Adoi%2F10.1002%2Fandp.19053231314&amp;rft_id=info%3Abibcode%2F1905AnP...323..639E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Fzenodo.org%2Frecord%2F1424057&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1915" class="citation journal cs1 cs1-prop-foreign-lang-source">Einstein, Albert (1915) [Completed 25 November 1915]. <a rel="nofollow" class="external text" href="http://echo.mpiwg-berlin.mpg.de/MPIWG:ZZB2HK6W">"Die Feldgleichungen der Gravitation"</a> &#91;The Field Equations of Gravitation&#93; <span class="cs1-format">(Online page images)</span>. <i>Sitzungsberichte 1915</i> (in German). Berlin, Germany: <a href="/wiki/Prussian_Academy_of_Sciences" title="Prussian Academy of Sciences">Königlich Preussische Akademie der Wissenschaften</a> (published 2 December 1915): 844–847 &#8211; via ECHO, Cultural Heritage Online, <a href="/wiki/Max_Planck_Institute" class="mw-redirect" title="Max Planck Institute">Max Planck Institute</a> for the History of Science.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Sitzungsberichte+1915&amp;rft.atitle=Die+Feldgleichungen+der+Gravitation&amp;rft.pages=844-847&amp;rft.date=1915&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fecho.mpiwg-berlin.mpg.de%2FMPIWG%3AZZB2HK6W&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1916" class="citation journal cs1">Einstein, Albert (1916) [Issued 29 June 1916]. <a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1916SPAW.......688E">"Näherungsweise Integration der Feldgleichungen der Gravitation"</a> &#91;Approximate integration of the field equations of gravitation&#93; <span class="cs1-format">(Online page images)</span>. <i>Sitzungsberichte 1916</i>. Berlin, Germany: <a href="/wiki/Prussian_Academy_of_Sciences" title="Prussian Academy of Sciences">Königlich Preussische Akademie der Wissenschaften</a>: 688–696. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1916SPAW.......688E">1916SPAW.......688E</a><span class="reference-accessdate">. Retrieved <span class="nowrap">24 January</span> 2022</span> &#8211; via SAO/NASA Astrophysics Data System (ADS).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Sitzungsberichte+1916&amp;rft.atitle=N%C3%A4herungsweise+Integration+der+Feldgleichungen+der+Gravitation&amp;rft.pages=688-696&amp;rft.date=1916&amp;rft_id=info%3Abibcode%2F1916SPAW.......688E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Fui.adsabs.harvard.edu%2Fabs%2F1916SPAW.......688E&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1917a" class="citation journal cs1 cs1-prop-foreign-lang-source">Einstein, Albert (1917a). <a rel="nofollow" class="external text" href="http://echo.mpiwg-berlin.mpg.de/MPIWG:H428RSAN">"Kosmologische Betrachtungen zur allgemeinen Relativitätstheorie"</a> &#91;Cosmological Considerations in the General Theory of Relativity&#93; <span class="cs1-format">(Online page images)</span>. <i>Sitzungsberichte 1917</i> (in German). <a href="/wiki/Prussian_Academy_of_Sciences" title="Prussian Academy of Sciences">Königlich Preussische Akademie der Wissenschaften</a>, Berlin.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Sitzungsberichte+1917&amp;rft.atitle=Kosmologische+Betrachtungen+zur+allgemeinen+Relativit%C3%A4tstheorie&amp;rft.date=1917&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fecho.mpiwg-berlin.mpg.de%2FMPIWG%3AH428RSAN&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1917b" class="citation journal cs1 cs1-prop-foreign-lang-source">Einstein, Albert (1917b). "Zur Quantentheorie der Strahlung" &#91;On the Quantum Mechanics of Radiation&#93;. <i>Physikalische Zeitschrift</i> (in German). <b>18</b>: 121–128. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1917PhyZ...18..121E">1917PhyZ...18..121E</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physikalische+Zeitschrift&amp;rft.atitle=Zur+Quantentheorie+der+Strahlung&amp;rft.volume=18&amp;rft.pages=121-128&amp;rft.date=1917&amp;rft_id=info%3Abibcode%2F1917PhyZ...18..121E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1918" class="citation journal cs1">Einstein, Albert (31 January 1918). <a rel="nofollow" class="external text" href="https://echo.mpiwg-berlin.mpg.de/ECHOdocuView?url=/permanent/echo/einstein/sitzungsberichte/W7ZU8V1E/index.meta">"Über Gravitationswellen"</a> &#91;About gravitational waves&#93;. <i>Sitzungsberichte der Königlich Preussischen Akademie der Wissenschaften Berlin</i>: 154–167. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1918SPAW.......154E">1918SPAW.......154E</a><span class="reference-accessdate">. Retrieved <span class="nowrap">14 November</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Sitzungsberichte+der+K%C3%B6niglich+Preussischen+Akademie+der+Wissenschaften+Berlin&amp;rft.atitle=%C3%9Cber+Gravitationswellen&amp;rft.pages=154-167&amp;rft.date=1918-01-31&amp;rft_id=info%3Abibcode%2F1918SPAW.......154E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Fecho.mpiwg-berlin.mpg.de%2FECHOdocuView%3Furl%3D%2Fpermanent%2Fecho%2Feinstein%2Fsitzungsberichte%2FW7ZU8V1E%2Findex.meta&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1923" class="citation speech cs1 cs1-prop-location-test cs1-prop-foreign-lang-source">Einstein, Albert (1923) [First published 1923, in English 1967].  Written at Gothenburg. <a rel="nofollow" class="external text" href="https://www.nobelprize.org/nobel_prizes/physics/laureates/1921/einstein-lecture.html"><i>Grundgedanken und Probleme der Relativitätstheorie</i></a> &#91;<i>Fundamental Ideas and Problems of the Theory of Relativity</i>&#93; (Speech). Lecture delivered to the Nordic Assembly of Naturalists at Gothenburg, 11 July 1923. <i>Nobel Lectures, Physics 1901–1921</i> (in German and English). Stockholm: Nobelprice.org (published 3 February 2015) &#8211; via Nobel Media AB 2014.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Grundgedanken+und+Probleme+der+Relativit%C3%A4tstheorie&amp;rft.place=Stockholm&amp;rft.pub=Nobelprice.org&amp;rft.date=1923&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Fwww.nobelprize.org%2Fnobel_prizes%2Fphysics%2Flaureates%2F1921%2Feinstein-lecture.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1924" class="citation journal cs1 cs1-prop-foreign-lang-source">Einstein, Albert (1924) [Published 10 July 1924]. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20161014072015/http://echo.mpiwg-berlin.mpg.de/ECHOdocuView?url=%2Fpermanent%2Fecho%2Feinstein%2Fsitzungsberichte%2FPG8B073X%2Findex.meta">"Quantentheorie des einatomigen idealen Gases"</a> &#91;Quantum theory of monatomic ideal gases&#93;. <i>Sitzungsberichte der Preussischen Akademie der Wissenschaften, Physikalisch-Mathematische Klasse</i> (in German): 261–267. Archived from <a rel="nofollow" class="external text" href="http://echo.mpiwg-berlin.mpg.de/MPIWG:DRQK5WYB">the original</a> <span class="cs1-format">(Online page images)</span> on 14 October 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">26 February</span> 2015</span> &#8211; via ECHO, Cultural Heritage Online, <a href="/wiki/Max_Planck_Institute" class="mw-redirect" title="Max Planck Institute">Max Planck Institute</a> for the History of Science.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Sitzungsberichte+der+Preussischen+Akademie+der+Wissenschaften%2C+Physikalisch-Mathematische+Klasse&amp;rft.atitle=Quantentheorie+des+einatomigen+idealen+Gases&amp;rft.pages=261-267&amp;rft.date=1924&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fecho.mpiwg-berlin.mpg.de%2FMPIWG%3ADRQK5WYB&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> First of a series of papers on this topic.</li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1926" class="citation journal cs1 cs1-prop-location-test cs1-prop-foreign-lang-source">Einstein, Albert (12 March 1926) [Cover Date 1 March 1926].  Written at Berlin. "Die Ursache der Mäanderbildung der Flußläufe und des sogenannten Baerschen Gesetzes" &#91;On <a href="/wiki/Baer%27s_law" class="mw-redirect" title="Baer&#39;s law">Baer\'s law</a> and <a href="/wiki/Meander" title="Meander">meanders</a> in the courses of rivers&#93;. <i>Die Naturwissenschaften</i> (in German). <b>14</b> (11). Heidelberg, Germany: 223–224. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1926NW.....14..223E">1926NW.....14..223E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1007%2FBF01510300">10.1007/BF01510300</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/1432-1904">1432-1904</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:39899416">39899416</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Die+Naturwissenschaften&amp;rft.atitle=Die+Ursache+der+M%C3%A4anderbildung+der+Flu%C3%9Fl%C3%A4ufe+und+des+sogenannten+Baerschen+Gesetzes&amp;rft.volume=14&amp;rft.issue=11&amp;rft.pages=223-224&amp;rft.date=1926-03-12&amp;rft_id=info%3Adoi%2F10.1007%2FBF01510300&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A39899416%23id-name%3DS2CID&amp;rft.issn=1432-1904&amp;rft_id=info%3Abibcode%2F1926NW.....14..223E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1926b" class="citation book cs1 cs1-prop-location-test">Einstein, Albert (1926b).  Written at Berne, Switzerland. Fürth, R. (ed.). <a rel="nofollow" class="external text" href="http://www.pitt.edu/~jdnorton/lectures/Rotman_Summer_School_2013/Einstein_1905_docs/Einstein_Dissertation_English.pdf"><i>Investigations on the Theory of the Brownian Movement</i></a> <span class="cs1-format">(PDF)</span>. Translated by Cowper, A. D. US: Dover Publications (published 1956). <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-60796-285-4" title="Special:BookSources/978-1-60796-285-4"><bdi>978-1-60796-285-4</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">4 January</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Investigations+on+the+Theory+of+the+Brownian+Movement&amp;rft.place=US&amp;rft.pub=Dover+Publications&amp;rft.date=1926&amp;rft.isbn=978-1-60796-285-4&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fwww.pitt.edu%2F~jdnorton%2Flectures%2FRotman_Summer_School_2013%2FEinstein_1905_docs%2FEinstein_Dissertation_English.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1931" class="citation journal cs1">Einstein, Albert (1931). "Zum kosmologischen Problem der allgemeinen Relativitätstheorie" &#91;On the cosmological problem of the general theory of relativity&#93;. <i>Sonderasugabe aus den Sitzungsb. König. Preuss. Akad.</i>: 235–237.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Sonderasugabe+aus+den+Sitzungsb.+K%C3%B6nig.+Preuss.+Akad.&amp;rft.atitle=Zum+kosmologischen+Problem+der+allgemeinen+Relativit%C3%A4tstheorie&amp;rft.pages=235-237&amp;rft.date=1931&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinsteinde_Sitter1932" class="citation journal cs1">Einstein, A.; de Sitter, W. (1932). <a rel="nofollow" class="external text" href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC1076193">"On the relation between the expansion and the mean density of the universe"</a>. <i>Proceedings of the National Academy of Sciences</i>. <b>18</b> (3): 213–214. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1932PNAS...18..213E">1932PNAS...18..213E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1073%2Fpnas.18.3.213">10.1073/pnas.18.3.213</a></span>. <a href="/wiki/PMC_(identifier)" class="mw-redirect" title="PMC (identifier)">PMC</a>&#160;<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC1076193">1076193</a></span>. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/16587663">16587663</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Proceedings+of+the+National+Academy+of+Sciences&amp;rft.atitle=On+the+relation+between+the+expansion+and+the+mean+density+of+the+universe&amp;rft.volume=18&amp;rft.issue=3&amp;rft.pages=213-214&amp;rft.date=1932&amp;rft_id=https%3A%2F%2Fwww.ncbi.nlm.nih.gov%2Fpmc%2Farticles%2FPMC1076193%23id-name%3DPMC&amp;rft_id=info%3Apmid%2F16587663&amp;rft_id=info%3Adoi%2F10.1073%2Fpnas.18.3.213&amp;rft_id=info%3Abibcode%2F1932PNAS...18..213E&amp;rft.aulast=Einstein&amp;rft.aufirst=A.&amp;rft.au=de+Sitter%2C+W.&amp;rft_id=https%3A%2F%2Fwww.ncbi.nlm.nih.gov%2Fpmc%2Farticles%2FPMC1076193&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinsteinRosen1935" class="citation journal cs1">Einstein, Albert; Rosen, Nathan (1935). <a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FPhysRev.48.73">"The Particle Problem in the General Theory of Relativity"</a>. <i><a href="/wiki/Physical_Review" title="Physical Review">Physical Review</a></i>. <b>48</b> (1): 73. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1935PhRv...48...73E">1935PhRv...48...73E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FPhysRev.48.73">10.1103/PhysRev.48.73</a></span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physical+Review&amp;rft.atitle=The+Particle+Problem+in+the+General+Theory+of+Relativity&amp;rft.volume=48&amp;rft.issue=1&amp;rft.pages=73&amp;rft.date=1935&amp;rft_id=info%3Adoi%2F10.1103%2FPhysRev.48.73&amp;rft_id=info%3Abibcode%2F1935PhRv...48...73E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft.au=Rosen%2C+Nathan&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1103%252FPhysRev.48.73&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinsteinPodolskyRosen1935" class="citation journal cs1">Einstein, Albert; Podolsky, Boris; Rosen, Nathan (15 May 1935) [Received 25 March 1935]. <a rel="nofollow" class="external text" href="https://cds.cern.ch/record/405662">"Can Quantum-Mechanical Description of Physical Reality Be Considered Complete?"</a>. <i>Physical Review</i> (Submitted manuscript). <b>47</b> (10): 777–780. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1935PhRv...47..777E">1935PhRv...47..777E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FPhysRev.47.777">10.1103/PhysRev.47.777</a></span> &#8211; via APS Journals.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physical+Review&amp;rft.atitle=Can+Quantum-Mechanical+Description+of+Physical+Reality+Be+Considered+Complete%3F&amp;rft.volume=47&amp;rft.issue=10&amp;rft.pages=777-780&amp;rft.date=1935-05-15&amp;rft_id=info%3Adoi%2F10.1103%2FPhysRev.47.777&amp;rft_id=info%3Abibcode%2F1935PhRv...47..777E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft.au=Podolsky%2C+Boris&amp;rft.au=Rosen%2C+Nathan&amp;rft_id=https%3A%2F%2Fcds.cern.ch%2Frecord%2F405662&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1950" class="citation journal cs1">Einstein, Albert (1950). "On the Generalized Theory of Gravitation". <i>Scientific American</i>. <b>CLXXXII</b> (4): 13–17. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1950SciAm.182d..13E">1950SciAm.182d..13E</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1038%2Fscientificamerican0450-13">10.1038/scientificamerican0450-13</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Scientific+American&amp;rft.atitle=On+the+Generalized+Theory+of+Gravitation&amp;rft.volume=CLXXXII&amp;rft.issue=4&amp;rft.pages=13-17&amp;rft.date=1950&amp;rft_id=info%3Adoi%2F10.1038%2Fscientificamerican0450-13&amp;rft_id=info%3Abibcode%2F1950SciAm.182d..13E&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1954" class="citation book cs1">Einstein, Albert (1954). <a rel="nofollow" class="external text" href="https://archive.org/details/ideasopinions00eins"><i>Ideas and Opinions</i></a>. New York: Crown Publishers. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-517-00393-0" title="Special:BookSources/978-0-517-00393-0"><bdi>978-0-517-00393-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Ideas+and+Opinions&amp;rft.place=New+York&amp;rft.pub=Crown+Publishers&amp;rft.date=1954&amp;rft.isbn=978-0-517-00393-0&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Fideasopinions00eins&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span><br /><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1995" class="citation book cs1">&#8212;&#8212;&#8212;&#8212;&#8212;&#8212; (1995) [1954]. <a rel="nofollow" class="external text" href="https://books.google.com/books?id=9fJkBqwDD3sC"><i>Ideas and Opinions</i></a>. New York: Three Rivers Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-517-88440-9" title="Special:BookSources/978-0-517-88440-9"><bdi>978-0-517-88440-9</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Ideas+and+Opinions&amp;rft.place=New+York&amp;rft.pub=Three+Rivers+Press&amp;rft.date=1995&amp;rft.isbn=978-0-517-88440-9&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3D9fJkBqwDD3sC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1969" class="citation book cs1 cs1-prop-foreign-lang-source">Einstein, Albert (1969). <i>Albert Einstein, Hedwig und Max Born: Briefwechsel 1916–1955</i> (in German). Commented by Max Born; Preface by Bertrand Russell; Foreword by Werner Heisenberg. Munich: Nymphenburger Verlagshandlung. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-3-88682-005-4" title="Special:BookSources/978-3-88682-005-4"><bdi>978-3-88682-005-4</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein%2C+Hedwig+und+Max+Born%3A+Briefwechsel+1916%E2%80%931955&amp;rft.place=Munich&amp;rft.pub=Nymphenburger+Verlagshandlung&amp;rft.date=1969&amp;rft.isbn=978-3-88682-005-4&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> A reprint of this book was published by Edition Erbrich in 1982, <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-3-88682-005-4" title="Special:BookSources/978-3-88682-005-4">978-3-88682-005-4</a>.</li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFStachel_et_al.2008" class="citation book cs1"><a href="/wiki/John_Stachel" title="John Stachel">Stachel, John</a>; Martin J. Klein; A. J. Kox; Michel Janssen; R. Schulmann; Diana Komos Buchwald; et&#160;al., eds. (21 July 2008) [Published between 1987 and 2006]. <a rel="nofollow" class="external text" href="https://einsteinpapers.press.princeton.edu/"><i>The Collected Papers of Albert Einstein</i></a>. Vol.&#160;1–10. <a href="/wiki/Princeton_University_Press" title="Princeton University Press">Princeton University Press</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Collected+Papers+of+Albert+Einstein&amp;rft.pub=Princeton+University+Press&amp;rft.date=2008-07-21&amp;rft_id=https%3A%2F%2Feinsteinpapers.press.princeton.edu%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> Further information about the volumes published so far can be found on the webpages of the Einstein Papers Project<sup id="cite_ref-330" class="reference"><a href="#cite_note-330">&#91;324&#93;</a></sup> and on the Princeton University Press Einstein Page.<sup id="cite_ref-331" class="reference"><a href="#cite_note-331">&#91;325&#93;</a></sup></li></ul>
</div>
<h3><span class="mw-headline" id="Others">Others</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1184024115"><div class="div-col" style="column-width: 35em;">
<ul><li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1948" class="citation news cs1">Einstein, Albert; et&#160;al. (4 December 1948). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20071217113044/http://phys4.harvard.edu/~wilson/NYTimes1948.html">"To the editors of <i>The New York Times</i>"</a>. <i><a href="/wiki/The_New_York_Times" title="The New York Times">The New York Times</a></i>. Melville, New York. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-7354-0359-8" title="Special:BookSources/978-0-7354-0359-8"><bdi>978-0-7354-0359-8</bdi></a>. Archived from <a rel="nofollow" class="external text" href="http://phys4.harvard.edu/~wilson/NYTimes1948.html">the original</a> on 17 December 2007<span class="reference-accessdate">. Retrieved <span class="nowrap">25 May</span> 2006</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=To+the+editors+of+The+New+York+Times&amp;rft.date=1948-12-04&amp;rft.isbn=978-0-7354-0359-8&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fphys4.harvard.edu%2F~wilson%2FNYTimes1948.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1949" class="citation journal cs1">Einstein, Albert (May 1949). Sweezy, Paul; Huberman, Leo (eds.). <a rel="nofollow" class="external text" href="http://monthlyreview.org/2009/05/01/why-socialism/">"Why Socialism?"</a>. <i><a href="/wiki/Monthly_Review" title="Monthly Review">Monthly Review</a></i>. <b>1</b> (1): 9–15. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.14452%2FMR-001-01-1949-05_3">10.14452/MR-001-01-1949-05_3</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Monthly+Review&amp;rft.atitle=Why+Socialism%3F&amp;rft.volume=1&amp;rft.issue=1&amp;rft.pages=9-15&amp;rft.date=1949-05&amp;rft_id=info%3Adoi%2F10.14452%2FMR-001-01-1949-05_3&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fmonthlyreview.org%2F2009%2F05%2F01%2Fwhy-socialism%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span><br /><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein2009" class="citation web cs1">&#8212;&#8212;&#8212;&#8212;&#8212;&#8212; (May 2009) [May 1949]. <a rel="nofollow" class="external text" href="http://www.monthlyreview.org/598einst.htm">"Why Socialism? (Reprise)"</a>. <i><a href="/wiki/Monthly_Review" title="Monthly Review">Monthly Review</a></i>. New York: Monthly Review Foundation. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20060111081948/http://www.monthlyreview.org/598einst.htm">Archived</a> from the original on 11 January 2006<span class="reference-accessdate">. Retrieved <span class="nowrap">16 January</span> 2006</span> &#8211; via MonthlyReview.org.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Monthly+Review&amp;rft.atitle=Why+Socialism%3F+%28Reprise%29&amp;rft.date=2009-05&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fwww.monthlyreview.org%2F598einst.htm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li>Einstein, Albert (September 1960). <a rel="nofollow" class="external text" href="https://archive.org/download/gandhiwieldsweap00shar/gandhiwieldsweap00shar.pdf">Foreword to <i>Gandhi Wields the Weapon of Moral Power: Three Case Histories</i>.</a> Introduction by Bharatan Kumarappa. Ahmedabad: Navajivan Publishing House. pp. v–vi. <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><a href="/wiki/OCLC_(identifier)" class="mw-redirect" title="OCLC (identifier)">OCLC</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/oclc/2325889">2325889</a>. Foreword originally written in April 1953.</li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1979" class="citation book cs1">Einstein, Albert (1979). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/autobiographical1979eins"><i>Autobiographical Notes</i></a></span>. Paul Arthur Schilpp (Centennial&#160;ed.). Chicago: Open Court. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-87548-352-8" title="Special:BookSources/978-0-87548-352-8"><bdi>978-0-87548-352-8</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Autobiographical+Notes&amp;rft.place=Chicago&amp;rft.edition=Centennial&amp;rft.pub=Open+Court&amp;rft.date=1979&amp;rft.isbn=978-0-87548-352-8&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Fautobiographical1979eins&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>. The <i>chasing a light beam</i> thought experiment is described on pages 48–51.</li></ul>
</div>
<h2><span class="mw-headline" id="See_also">See also</span></h2>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1184024115"><div class="div-col" style="column-width: 25em;">
<ul><li><a href="/wiki/Bern_Historical_Museum" title="Bern Historical Museum">Bern Historical Museum</a> (Einstein Museum)</li>
<li><a href="/wiki/Einstein_notation" title="Einstein notation">Einstein notation</a></li>
<li><a href="/wiki/Frist_Campus_Center" title="Frist Campus Center">Frist Campus Center</a> at <a href="/wiki/Princeton_University" title="Princeton University">Princeton University</a>&#160;&#8211;&#32; room 302 is associated with Einstein. The center was once the Palmer Physical Laboratory.</li>
<li><a href="/wiki/Heinrich_Burkhardt" title="Heinrich Burkhardt">Heinrich Burkhardt</a></li>
<li><a href="/wiki/Heinrich_Zangger" title="Heinrich Zangger">Heinrich Zangger</a></li>
<li><a href="/wiki/History_of_gravitational_theory" title="History of gravitational theory">History of gravitational theory</a></li>
<li><a href="/wiki/List_of_coupled_cousins" title="List of coupled cousins">List of coupled cousins</a></li>
<li><a href="/wiki/List_of_German_inventors_and_discoverers" title="List of German inventors and discoverers">List of German inventors and discoverers</a></li>
<li><a href="/wiki/List_of_Jewish_Nobel_laureates" title="List of Jewish Nobel laureates">List of Jewish Nobel laureates</a></li>
<li><a href="/wiki/List_of_peace_activists" title="List of peace activists">List of peace activists</a></li>
<li><a href="/wiki/Relativity_priority_dispute" title="Relativity priority dispute">Relativity priority dispute</a></li>
<li><a href="/wiki/Sticky_bead_argument" title="Sticky bead argument">Sticky bead argument</a></li></ul>
</div>
<h2><span class="mw-headline" id="Notes">Notes</span></h2>
<style data-mw-deduplicate="TemplateStyles:r1217336898">.mw-parser-output .reflist{font-size:90%;margin-bottom:0.5em;list-style-type:decimal}.mw-parser-output .reflist .references{font-size:100%;margin-bottom:0;list-style-type:inherit}.mw-parser-output .reflist-columns-2{column-width:30em}.mw-parser-output .reflist-columns-3{column-width:25em}.mw-parser-output .reflist-columns{margin-top:0.3em}.mw-parser-output .reflist-columns ol{margin-top:0}.mw-parser-output .reflist-columns li{page-break-inside:avoid;break-inside:avoid-column}.mw-parser-output .reflist-upper-alpha{list-style-type:upper-alpha}.mw-parser-output .reflist-upper-roman{list-style-type:upper-roman}.mw-parser-output .reflist-lower-alpha{list-style-type:lower-alpha}.mw-parser-output .reflist-lower-greek{list-style-type:lower-greek}.mw-parser-output .reflist-lower-roman{list-style-type:lower-roman}</style><div class="reflist">
<div class="mw-references-wrap"><ol class="references">
<li id="cite_note-GEcitizen-4"><span class="mw-cite-backlink">^ <a href="#cite_ref-GEcitizen_4-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-GEcitizen_4-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-GEcitizen_4-2"><sup><i><b>c</b></i></sup></a> <a href="#cite_ref-GEcitizen_4-3"><sup><i><b>d</b></i></sup></a> <a href="#cite_ref-GEcitizen_4-4"><sup><i><b>e</b></i></sup></a></span> <span class="reference-text">Until 1913, German citizenship was acquired through citizenship in a constituent state (whose requirements varied); from 1913, uniform citizenship requirements were <a href="/wiki/Constitution_of_the_German_Empire#Citizenship" title="Constitution of the German Empire">set at the national level</a>.</span>
</li>
<li id="cite_note-MaturaScore-34"><span class="mw-cite-backlink"><b><a href="#cite_ref-MaturaScore_34-0">^</a></b></span> <span class="reference-text">Einstein\'s scores on his <i><a href="/wiki/Matura" title="Matura">Matura</a></i> certificate: German 5; French 3; Italian 5; History 6; Geography 4; Algebra 6; Geometry 6; Descriptive Geometry 6; Physics 6; Chemistry 5; Natural History 5; Art Drawing 4; Technical Drawing 4.<br /><a href="/wiki/Grading_systems_by_country#Switzerland" title="Grading systems by country">Scale</a>: 6 = very good, 5 = good, 4 = sufficient, 3 = insufficient, 2 = poor, 1 = very poor.</span>
</li>
<li id="cite_note-gnriE-146"><span class="mw-cite-backlink"><b><a href="#cite_ref-gnriE_146-0">^</a></b></span> <span class="reference-text">"Their leaders in Germany have not driven out her cut-throats and her blackguards. She has chosen the cream of her culture and has suppressed it. She has even turned upon her most glorious citizen, Albert Einstein, who is the supreme example of the selfless intellectual...The man, who, beyond all others, approximates a citizen of the world, is without a home. How proud we must be to offer him temporary shelter."</span>
</li>
<li id="cite_note-aBfxO-234"><span class="mw-cite-backlink"><b><a href="#cite_ref-aBfxO_234-0">^</a></b></span> <span class="reference-text">In <a href="https://en.wikisource.org/wiki/Translation:On_the_Electrodynamics_of_Moving_Bodies" class="extiw" title="s:Translation:On the Electrodynamics of Moving Bodies">his paper</a>, Einstein wrote: "The introduction of a \'luminiferous æther\' will be proved to be superfluous in so far, as according to the conceptions which will be developed, we shall introduce neither a \'space absolutely at rest\' endowed with special properties, nor shall we associate a velocity-vector with a point in which electro-magnetic processes take place."</span>
</li>
<li id="cite_note-sBl2q-236"><span class="mw-cite-backlink"><b><a href="#cite_ref-sBl2q_236-0">^</a></b></span> <span class="reference-text">For a discussion of the reception of relativity theory around the world, and the different controversies it encountered, see the articles in <a href="#CITEREFGlick1987">Glick (1987)</a>.</span>
</li>
<li id="cite_note-311"><span class="mw-cite-backlink"><b><a href="#cite_ref-311">^</a></b></span> <span class="reference-text">In September 2008 it was reported that Malcolm McCulloch of Oxford University was heading a three-year project to develop more robust appliances that could be used in locales lacking electricity, and that his team had completed a prototype Einstein refrigerator. He was quoted as saying that improving the design and changing the types of gases used might allow the design\'s efficiency to be quadrupled.<sup id="cite_ref-310" class="reference"><a href="#cite_note-310">&#91;305&#93;</a></sup></span>
</li>
</ol></div></div>
<h2><span class="mw-headline" id="References">References</span></h2>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1217336898"><div class="reflist">
<div class="mw-references-wrap mw-references-columns"><ol class="references">
<li id="cite_note-frs-1"><span class="mw-cite-backlink">^ <a href="#cite_ref-frs_1-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-frs_1-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-frs_1-2"><sup><i><b>c</b></i></sup></a> <a href="#cite_ref-frs_1-3"><sup><i><b>d</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWhittaker1955" class="citation journal cs1"><a href="/wiki/E._T._Whittaker" title="E. T. Whittaker">Whittaker, E.</a> (1 November 1955). <a rel="nofollow" class="external text" href="https://doi.org/10.1098%2Frsbm.1955.0005">"Albert Einstein. 1879–1955"</a>. <i><a href="/wiki/Biographical_Memoirs_of_Fellows_of_the_Royal_Society" title="Biographical Memoirs of Fellows of the Royal Society">Biographical Memoirs of Fellows of the Royal Society</a></i>. <b>1</b>: 37–67. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1098%2Frsbm.1955.0005">10.1098/rsbm.1955.0005</a></span>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/769242">769242</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Biographical+Memoirs+of+Fellows+of+the+Royal+Society&amp;rft.atitle=Albert+Einstein.+1879%E2%80%931955&amp;rft.volume=1&amp;rft.pages=37-67&amp;rft.date=1955-11-01&amp;rft_id=info%3Adoi%2F10.1098%2Frsbm.1955.0005&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F769242%23id-name%3DJSTOR&amp;rft.aulast=Whittaker&amp;rft.aufirst=E.&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1098%252Frsbm.1955.0005&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-2"><span class="mw-cite-backlink"><b><a href="#cite_ref-2">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://ras.ac.uk/sites/default/files/2021-03/Gold%20Medal%202021.pdf">"The Gold Medal"</a> <span class="cs1-format">(PDF)</span>. <a href="/wiki/Royal_Astronomical_Society" title="Royal Astronomical Society">Royal Astronomical Society</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20211220130005/https://ras.ac.uk/sites/default/files/2021-03/Gold%20Medal%202021.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 20 December 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">20 December</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=The+Gold+Medal&amp;rft.pub=Royal+Astronomical+Society&amp;rft_id=https%3A%2F%2Fras.ac.uk%2Fsites%2Fdefault%2Ffiles%2F2021-03%2FGold%2520Medal%25202021.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-3"><span class="mw-cite-backlink"><b><a href="#cite_ref-3">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.nasonline.org/member-directory/deceased-members/20001817.html">"Membership directory"</a>. <a href="/wiki/National_Academy_of_Sciences" title="National Academy of Sciences">National Academy of Sciences</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20211220080311/http://www.nasonline.org/member-directory/deceased-members/20001817.html">Archived</a> from the original on 20 December 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">20 December</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Membership+directory&amp;rft.pub=National+Academy+of+Sciences&amp;rft_id=http%3A%2F%2Fwww.nasonline.org%2Fmember-directory%2Fdeceased-members%2F20001817.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-NDxay-5"><span class="mw-cite-backlink"><b><a href="#cite_ref-NDxay_5-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWells2008" class="citation book cs1"><a href="/wiki/John_C._Wells" title="John C. Wells">Wells, John</a> (3 April 2008). <i>Longman Pronunciation Dictionary</i> (3rd&#160;ed.). Pearson Longman. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-4058-8118-0" title="Special:BookSources/978-1-4058-8118-0"><bdi>978-1-4058-8118-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Longman+Pronunciation+Dictionary&amp;rft.edition=3rd&amp;rft.pub=Pearson+Longman&amp;rft.date=2008-04-03&amp;rft.isbn=978-1-4058-8118-0&amp;rft.aulast=Wells&amp;rft.aufirst=John&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-YangHamilton2010-6"><span class="mw-cite-backlink"><b><a href="#cite_ref-YangHamilton2010_6-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFYangHamilton2010" class="citation book cs1">Yang, Fujia; Hamilton, Joseph H. (2010). <i>Modern Atomic and Nuclear Physics</i>. World Scientific. p.&#160;274. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-981-4277-16-7" title="Special:BookSources/978-981-4277-16-7"><bdi>978-981-4277-16-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Modern+Atomic+and+Nuclear+Physics&amp;rft.pages=274&amp;rft.pub=World+Scientific&amp;rft.date=2010&amp;rft.isbn=978-981-4277-16-7&amp;rft.aulast=Yang&amp;rft.aufirst=Fujia&amp;rft.au=Hamilton%2C+Joseph+H.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-LnLVo-7"><span class="mw-cite-backlink"><b><a href="#cite_ref-LnLVo_7-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBodanis2000" class="citation book cs1">Bodanis, David (2000). <i>E&#160;=&#160;mc<sup>2</sup>: A Biography of the World\'s Most Famous Equation</i>. New York: Walker.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=E+%3D+mc%3Csup%3E2%3C%2Fsup%3E%3A+A+Biography+of+the+World%27s+Most+Famous+Equation&amp;rft.place=New+York&amp;rft.pub=Walker&amp;rft.date=2000&amp;rft.aulast=Bodanis&amp;rft.aufirst=David&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Nobel_Prize-8"><span class="mw-cite-backlink">^ <a href="#cite_ref-Nobel_Prize_8-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Nobel_Prize_8-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-Nobel_Prize_8-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.nobelprize.org/nobel_prizes/physics/laureates/1921/">"The Nobel Prize in Physics 1921"</a>. Nobel Prize. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20180703190346/https://www.nobelprize.org/nobel_prizes/physics/laureates/1921/">Archived</a> from the original on 3 July 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">11 July</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=The+Nobel+Prize+in+Physics+1921&amp;rft.pub=Nobel+Prize&amp;rft_id=https%3A%2F%2Fwww.nobelprize.org%2Fnobel_prizes%2Fphysics%2Flaureates%2F1921%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-xZQWt-9"><span class="mw-cite-backlink"><b><a href="#cite_ref-xZQWt_9-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHoward2014" class="citation journal cs1">Howard, Don A., ed. (2014) [First published 11 February 2004]. <a rel="nofollow" class="external text" href="http://plato.stanford.edu/entries/einstein-philscience/#IntWasEinEpiOpp">"Einstein\'s Philosophy of Science"</a>. <i>Stanford Encyclopedia of Philosophy</i>. The Metaphysics Research Lab, Center for the Study of Language and Information (CSLI), Stanford University. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210413170244/https://plato.stanford.edu/entries/einstein-philscience/#IntWasEinEpiOpp">Archived</a> from the original on 13 April 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">4 February</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Stanford+Encyclopedia+of+Philosophy&amp;rft.atitle=Einstein%27s+Philosophy+of+Science&amp;rft.date=2014&amp;rft_id=http%3A%2F%2Fplato.stanford.edu%2Fentries%2Feinstein-philscience%2F%23IntWasEinEpiOpp&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-3UiiT-10"><span class="mw-cite-backlink"><b><a href="#cite_ref-3UiiT_10-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHoward2005" class="citation journal cs1">Howard, Don A. (December 2005). <a rel="nofollow" class="external text" href="http://www3.nd.edu/~dhoward1/vol58no12p34_40.pdf">"Albert Einstein as a Philosopher of Science"</a> <span class="cs1-format">(PDF)</span>. <i>Physics Today</i>. <b>58</b> (12): 34–40. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2005PhT....58l..34H">2005PhT....58l..34H</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1063%2F1.2169442">10.1063/1.2169442</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:170769196">170769196</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150828054601/http://www3.nd.edu/~dhoward1/vol58no12p34_40.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 28 August 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">8 March</span> 2015</span> &#8211; via University of Notre Dame, Notre Dame, IN, author\'s personal webpage.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics+Today&amp;rft.atitle=Albert+Einstein+as+a+Philosopher+of+Science&amp;rft.volume=58&amp;rft.issue=12&amp;rft.pages=34-40&amp;rft.date=2005-12&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A170769196%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1063%2F1.2169442&amp;rft_id=info%3Abibcode%2F2005PhT....58l..34H&amp;rft.aulast=Howard&amp;rft.aufirst=Don+A.&amp;rft_id=http%3A%2F%2Fwww3.nd.edu%2F~dhoward1%2Fvol58no12p34_40.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-zE9Bz-11"><span class="mw-cite-backlink"><b><a href="#cite_ref-zE9Bz_11-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLevenson2017" class="citation journal cs1">Levenson, Thomas (9 June 2017). <a rel="nofollow" class="external text" href="https://www.theatlantic.com/science/archive/2017/06/einstein-germany-and-the-bomb/528534/">"The Scientist and the Fascist"</a>. <i>The Atlantic</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190512133141/https://www.theatlantic.com/science/archive/2017/06/einstein-germany-and-the-bomb/528534/">Archived</a> from the original on 12 May 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">23 August</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Atlantic&amp;rft.atitle=The+Scientist+and+the+Fascist&amp;rft.date=2017-06-09&amp;rft.aulast=Levenson&amp;rft.aufirst=Thomas&amp;rft_id=https%3A%2F%2Fwww.theatlantic.com%2Fscience%2Farchive%2F2017%2F06%2Feinstein-germany-and-the-bomb%2F528534%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-BoyerDubofsky2001-12"><span class="mw-cite-backlink"><b><a href="#cite_ref-BoyerDubofsky2001_12-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPaul_S._BoyerMelvyn_Dubofsky2001" class="citation book cs1">Paul S. Boyer; Melvyn Dubofsky (2001). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/oxfordcompaniont00paul_0"><i>The Oxford Companion to United States History</i></a></span>. Oxford University Press. p.&#160;<a rel="nofollow" class="external text" href="https://archive.org/details/oxfordcompaniont00paul_0/page/218">218</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-19-508209-8" title="Special:BookSources/978-0-19-508209-8"><bdi>978-0-19-508209-8</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Oxford+Companion+to+United+States+History&amp;rft.pages=218&amp;rft.pub=Oxford+University+Press&amp;rft.date=2001&amp;rft.isbn=978-0-19-508209-8&amp;rft.au=Paul+S.+Boyer&amp;rft.au=Melvyn+Dubofsky&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Foxfordcompaniont00paul_0&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-13"><span class="mw-cite-backlink"><b><a href="#cite_ref-13">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://wiseinternational.org/nuclear-monitor/802/albert-einstein-nuclear-weapons">"Albert Einstein on nuclear weapons | Wise International"</a>. <i>wiseinternational.org</i><span class="reference-accessdate">. Retrieved <span class="nowrap">23 October</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=wiseinternational.org&amp;rft.atitle=Albert+Einstein+on+nuclear+weapons+%7C+Wise+International&amp;rft_id=https%3A%2F%2Fwiseinternational.org%2Fnuclear-monitor%2F802%2Falbert-einstein-nuclear-weapons&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEGalison2000377-14"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEGalison2000377_14-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEGalison2000377_14-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFGalison2000">Galison (2000)</a>, p.&#160;377.</span>
</li>
<li id="cite_note-Nobel-15"><span class="mw-cite-backlink">^ <a href="#cite_ref-Nobel_15-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Nobel_15-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20120516052710/https://www.nobelprize.org/nobel_prizes/physics/laureates/2011/advanced-physicsprize2011.pdf">"Scientific Background on the Nobel Prize in Physics 2011. The accelerating universe"</a> <span class="cs1-format">(PDF)</span>. Nobel Media AB. p.&#160;2. Archived from <a rel="nofollow" class="external text" href="https://www.nobelprize.org/nobel_prizes/physics/laureates/2011/advanced-physicsprize2011.pdf">the original</a> <span class="cs1-format">(PDF)</span> on 16 May 2012<span class="reference-accessdate">. Retrieved <span class="nowrap">4 January</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Scientific+Background+on+the+Nobel+Prize+in+Physics+2011.+The+accelerating+universe&amp;rft.pages=2&amp;rft.pub=Nobel+Media+AB&amp;rft_id=https%3A%2F%2Fwww.nobelprize.org%2Fnobel_prizes%2Fphysics%2Flaureates%2F2011%2Fadvanced-physicsprize2011.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-NYT-20151124-16"><span class="mw-cite-backlink"><b><a href="#cite_ref-NYT-20151124_16-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFOverbye2015" class="citation news cs1"><a href="/wiki/Dennis_Overbye" title="Dennis Overbye">Overbye, Dennis</a> (24 November 2015). <a rel="nofollow" class="external text" href="https://ghostarchive.org/archive/20220101/https://www.nytimes.com/2015/11/24/science/a-century-ago-einsteins-theory-of-relativity-changed-everything.html">"A Century Ago, Einstein\'s Theory of Relativity Changed Everything"</a>. <i><a href="/wiki/The_New_York_Times" title="The New York Times">The New York Times</a></i>. Archived from <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://www.nytimes.com/2015/11/24/science/a-century-ago-einsteins-theory-of-relativity-changed-everything.html">the original</a></span> on 1 January 2022<span class="reference-accessdate">. Retrieved <span class="nowrap">24 November</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=A+Century+Ago%2C+Einstein%27s+Theory+of+Relativity+Changed+Everything&amp;rft.date=2015-11-24&amp;rft.aulast=Overbye&amp;rft.aufirst=Dennis&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F2015%2F11%2F24%2Fscience%2Fa-century-ago-einsteins-theory-of-relativity-changed-everything.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-17"><span class="mw-cite-backlink"><b><a href="#cite_ref-17">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRobinson2018" class="citation journal cs1">Robinson, Andrew (30 April 2018). <a rel="nofollow" class="external text" href="https://www.nature.com/articles/d41586-018-05004-4">"Did Einstein really say that?"</a>. <i><a href="/wiki/Nature_(journal)" title="Nature (journal)">Nature</a></i>. <b>557</b> (30): 30. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2018Natur.557...30R">2018Natur.557...30R</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1038%2Fd41586-018-05004-4">10.1038/d41586-018-05004-4</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:14013938">14013938</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20201109033021/https://www.nature.com/articles/d41586-018-05004-4">Archived</a> from the original on 9 November 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">21 February</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Nature&amp;rft.atitle=Did+Einstein+really+say+that%3F&amp;rft.volume=557&amp;rft.issue=30&amp;rft.pages=30&amp;rft.date=2018-04-30&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A14013938%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1038%2Fd41586-018-05004-4&amp;rft_id=info%3Abibcode%2F2018Natur.557...30R&amp;rft.aulast=Robinson&amp;rft.aufirst=Andrew&amp;rft_id=https%3A%2F%2Fwww.nature.com%2Farticles%2Fd41586-018-05004-4&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-18"><span class="mw-cite-backlink"><b><a href="#cite_ref-18">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://physicsworld.com/a/physics-past-present-future/">"Physics: past, present, future"</a>. <i>Physics World</i>. 6 December 1999<span class="reference-accessdate">. Retrieved <span class="nowrap">1 August</span> 2023</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Physics+World&amp;rft.atitle=Physics%3A+past%2C+present%2C+future&amp;rft.date=1999-12-06&amp;rft_id=https%3A%2F%2Fphysicsworld.com%2Fa%2Fphysics-past-present-future%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-wordnetweb.princeton.edu-19"><span class="mw-cite-backlink">^ <a href="#cite_ref-wordnetweb.princeton.edu_19-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-wordnetweb.princeton.edu_19-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://wordnetweb.princeton.edu/perl/webwn?s=Einstein">"Result of WordNet Search for Einstein"</a>. 3.1. The Trustees of Princeton University. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150828054753/http://wordnetweb.princeton.edu/perl/webwn?s=Einstein">Archived</a> from the original on 28 August 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">4 January</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Result+of+WordNet+Search+for+Einstein&amp;rft.series=3.1&amp;rft.pub=The+Trustees+of+Princeton+University&amp;rft_id=http%3A%2F%2Fwordnetweb.princeton.edu%2Fperl%2Fwebwn%3Fs%3DEinstein&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Bio-20"><span class="mw-cite-backlink">^ <a href="#cite_ref-Bio_20-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Bio_20-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-Bio_20-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://nobelprize.org/nobel_prizes/physics/laureates/1921/einstein-bio.html">"Albert Einstein&#160;– Biography"</a>. <a href="/wiki/Nobel_Foundation" title="Nobel Foundation">Nobel Foundation</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20070306133522/http://nobelprize.org/nobel_prizes/physics/laureates/1921/einstein-bio.html">Archived</a> from the original on 6 March 2007<span class="reference-accessdate">. Retrieved <span class="nowrap">7 March</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein+%E2%80%93+Biography&amp;rft.pub=Nobel+Foundation&amp;rft_id=http%3A%2F%2Fnobelprize.org%2Fnobel_prizes%2Fphysics%2Flaureates%2F1921%2Feinstein-bio.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-21"><span class="mw-cite-backlink"><b><a href="#cite_ref-21">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.jewishvirtuallibrary.org/albert-einstein">"Albert Einstein (1879–1955)"</a>. Jewisth Virtual Library. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170309071447/https://www.jewishvirtuallibrary.org/albert-einstein">Archived</a> from the original on 9 March 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">13 February</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein+%281879%E2%80%931955%29&amp;rft.pub=Jewisth+Virtual+Library&amp;rft_id=https%3A%2F%2Fwww.jewishvirtuallibrary.org%2Falbert-einstein&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-22"><span class="mw-cite-backlink"><b><a href="#cite_ref-22">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFIsaacson2009" class="citation journal cs1">Isaacson, Walter (2009). <a rel="nofollow" class="external text" href="https://www.theatlantic.com/magazine/archive/2009/12/how-einstein-divided-americas-jews/307763/">"How Einstein Divided America\'s Jews"</a>. <i>The Atlantic</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210126013637/https://www.theatlantic.com/magazine/archive/2009/12/how-einstein-divided-americas-jews/307763/">Archived</a> from the original on 26 January 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">13 February</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Atlantic&amp;rft.atitle=How+Einstein+Divided+America%27s+Jews&amp;rft.date=2009&amp;rft.aulast=Isaacson&amp;rft.aufirst=Walter&amp;rft_id=https%3A%2F%2Fwww.theatlantic.com%2Fmagazine%2Farchive%2F2009%2F12%2Fhow-einstein-divided-americas-jews%2F307763%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEStachel2002&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA59_59–61&#93;-23"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel2002[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA59_59–61]_23-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel2002">Stachel (2002)</a>, pp.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=OAsQ_hFjhrAC&amp;pg=PA59">59–61</a>.</span>
</li>
<li id="cite_note-EQyag-24"><span class="mw-cite-backlink"><b><a href="#cite_ref-EQyag_24-0">^</a></b></span> <span class="reference-text">Barry R. Parker (2003). <i>Einstein: The Passions of a Scientist</i>, Prometheus Books, p. 31</span>
</li>
<li id="cite_note-25"><span class="mw-cite-backlink"><b><a href="#cite_ref-25">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFUniversity_of_Pavia" class="citation web cs1">University of Pavia. <a rel="nofollow" class="external text" href="http://musei.unipv.eu/msu/our-museums/historical-figures/albert-einstein/">"Einstein, Albert"</a>. <i>Museo per la Storia dell\'Università di Pavia</i>. University of Pavia<span class="reference-accessdate">. Retrieved <span class="nowrap">7 January</span> 2023</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Museo+per+la+Storia+dell%27Universit%C3%A0+di+Pavia&amp;rft.atitle=Einstein%2C+Albert&amp;rft.au=University+of+Pavia&amp;rft_id=http%3A%2F%2Fmusei.unipv.eu%2Fmsu%2Four-museums%2Fhistorical-figures%2Falbert-einstein%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEFölsing199730–31-26"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing199730–31_26-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, pp.&#160;30–31.</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._5-27"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._5_27-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>, vol. 1 (1987), doc. 5.</span>
</li>
<li id="cite_note-1RgTv-28"><span class="mw-cite-backlink"><b><a href="#cite_ref-1RgTv_28-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMehra2001" class="citation book cs1">Mehra, Jagdish (2001). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=o1XVCgAAQBAJ&amp;pg=PA1">"Albert Einstein\'s "First Paper"<span class="cs1-kern-right"></span>"</a>. <a rel="nofollow" class="external text" href="https://books.google.com/books?id=o1XVCgAAQBAJ"><i>Golden Age Of Theoretical Physics, The (Boxed Set Of 2 Vols)</i></a>. World Scientific. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-981-4492-85-0" title="Special:BookSources/978-981-4492-85-0"><bdi>978-981-4492-85-0</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">5 January</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Albert+Einstein%27s+%22First+Paper%22&amp;rft.btitle=Golden+Age+Of+Theoretical+Physics%2C+The+%28Boxed+Set+Of+2+Vols%29&amp;rft.pub=World+Scientific&amp;rft.date=2001&amp;rft.isbn=978-981-4492-85-0&amp;rft.aulast=Mehra&amp;rft.aufirst=Jagdish&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3Do1XVCgAAQBAJ%26pg%3DPA1&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FVfDU-29"><span class="mw-cite-backlink"><b><a href="#cite_ref-FVfDU_29-0">^</a></b></span> <span class="reference-text"><i>The Three-body Problem from Pythagoras to Hawking</i>, Mauri Valtonen, Joanna Anosova, Konstantin Kholshevnikov, Aleksandr Mylläri, Victor Orlov, Kiyotaka Tanikawa, (Springer 2016), p. 43, Simon and Schuster, 2008</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson200716-30"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEIsaacson200716_30-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson200716_30-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;16.</span>
</li>
<li id="cite_note-31"><span class="mw-cite-backlink"><b><a href="#cite_ref-31">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBloom2012" class="citation book cs1">Bloom, Howard (2012). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=xlEupJb4ojIC"><i>The God Problem: How a Godless Cosmos Creates</i></a> (illustrated&#160;ed.). Prometheus Books. p.&#160;294. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-61614-552-1" title="Special:BookSources/978-1-61614-552-1"><bdi>978-1-61614-552-1</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">8 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+God+Problem%3A+How+a+Godless+Cosmos+Creates&amp;rft.pages=294&amp;rft.edition=illustrated&amp;rft.pub=Prometheus+Books&amp;rft.date=2012&amp;rft.isbn=978-1-61614-552-1&amp;rft.aulast=Bloom&amp;rft.aufirst=Howard&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DxlEupJb4ojIC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBloom2012" class="citation book cs1">Bloom, Howard (30 August 2012). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=xlEupJb4ojIC&amp;pg=PT294"><i>Extract of page 294</i></a>. Prometheus Books. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-61614-552-1" title="Special:BookSources/978-1-61614-552-1"><bdi>978-1-61614-552-1</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">8 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Extract+of+page+294&amp;rft.pub=Prometheus+Books&amp;rft.date=2012-08-30&amp;rft.isbn=978-1-61614-552-1&amp;rft.aulast=Bloom&amp;rft.aufirst=Howard&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DxlEupJb4ojIC%26pg%3DPT294&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson200717-32"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEIsaacson200717_32-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson200717_32-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson200717_32-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;17.</span>
</li>
<li id="cite_note-FOOTNOTECalapriceLipscombe20058-33"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalapriceLipscombe20058_33-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalapriceLipscombe2005">Calaprice &amp; Lipscombe (2005)</a>, p.&#160;8.</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_p._11-35"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_p._11_35-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>, vol. 1 (1987), p. 11.</span>
</li>
<li id="cite_note-FOOTNOTEFölsing199736–37-36"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing199736–37_36-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, pp.&#160;36–37.</span>
</li>
<li id="cite_note-b250-37"><span class="mw-cite-backlink"><b><a href="#cite_ref-b250_37-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHunziker2015" class="citation journal cs1">Hunziker, Herbert (2015). "Albert Einstein\'s Magic Mountain: An Aarau Education*". <i>Physics in Perspective</i>. <b>17</b> (1): 55–69. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2015PhP....17...55H">2015PhP....17...55H</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1007%2Fs00016-014-0153-5">10.1007/s00016-014-0153-5</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/1422-6944">1422-6944</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics+in+Perspective&amp;rft.atitle=Albert+Einstein%27s+Magic+Mountain%3A+An+Aarau+Education%2A&amp;rft.volume=17&amp;rft.issue=1&amp;rft.pages=55-69&amp;rft.date=2015&amp;rft.issn=1422-6944&amp;rft_id=info%3Adoi%2F10.1007%2Fs00016-014-0153-5&amp;rft_id=info%3Abibcode%2F2015PhP....17...55H&amp;rft.aulast=Hunziker&amp;rft.aufirst=Herbert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> ref for: <a href="/wiki/Old_Cantonal_School_Aarau" title="Old Cantonal School Aarau">Old Cantonal School Aarau</a></span>
</li>
<li id="cite_note-FOOTNOTEHighfieldCarter199321,_31,_56–57-38"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEHighfieldCarter199321,_31,_56–57_38-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEHighfieldCarter199321,_31,_56–57_38-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFHighfieldCarter1993">Highfield &amp; Carter (1993)</a>, pp.&#160;21, 31, 56–57.</span>
</li>
<li id="cite_note-FOOTNOTEFölsing199740-39"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing199740_39-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, p.&#160;40.</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_docs._21–27-40"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_docs._21–27_40-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>, vol. 1 (1987), docs. 21–27.</span>
</li>
<li id="cite_note-mileva-41"><span class="mw-cite-backlink">^ <a href="#cite_ref-mileva_41-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-mileva_41-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-mileva_41-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGagnon2016" class="citation web cs1">Gagnon, Pauline (19 December 2016). <a rel="nofollow" class="external text" href="https://blogs.scientificamerican.com/guest-blog/the-forgotten-life-of-einsteins-first-wife/">"The Forgotten Life of Einstein\'s First Wife"</a>. <i>Scientific American Blog Network</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20201017222145/https://blogs.scientificamerican.com/guest-blog/the-forgotten-life-of-einsteins-first-wife/">Archived</a> from the original on 17 October 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">17 October</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Scientific+American+Blog+Network&amp;rft.atitle=The+Forgotten+Life+of+Einstein%27s+First+Wife&amp;rft.date=2016-12-19&amp;rft.aulast=Gagnon&amp;rft.aufirst=Pauline&amp;rft_id=https%3A%2F%2Fblogs.scientificamerican.com%2Fguest-blog%2Fthe-forgotten-life-of-einsteins-first-wife%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-7HA7H-42"><span class="mw-cite-backlink"><b><a href="#cite_ref-7HA7H_42-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFTroemel-Ploetz,_D.1990" class="citation journal cs1">Troemel-Ploetz, D. (1990). "Mileva Einstein-Marić: The Woman Who Did Einstein\'s Mathematics". <i>Women\'s Studies International Forum</i>. <b>13</b> (5): 415–432. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1016%2F0277-5395%2890%2990094-e">10.1016/0277-5395(90)90094-e</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Women%27s+Studies+International+Forum&amp;rft.atitle=Mileva+Einstein-Mari%C4%87%3A+The+Woman+Who+Did+Einstein%27s+Mathematics&amp;rft.volume=13&amp;rft.issue=5&amp;rft.pages=415-432&amp;rft.date=1990&amp;rft_id=info%3Adoi%2F10.1016%2F0277-5395%2890%2990094-e&amp;rft.au=Troemel-Ploetz%2C+D.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-1zJdH-43"><span class="mw-cite-backlink"><b><a href="#cite_ref-1zJdH_43-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWalker,_Evan_Harris1989" class="citation journal cs1">Walker, Evan Harris (February 1989). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20120119093653/http://philosci40.unibe.ch/lehre/winter99/einstein/Walker_Stachel.pdf">"Did Einstein Espouse his Spouse\'s Ideas?"</a> <span class="cs1-format">(PDF)</span>. <i>Physics Today</i>. <b>42</b> (2): 9–13. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1989PhT....42b...9W">1989PhT....42b...9W</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1063%2F1.2810898">10.1063/1.2810898</a>. Archived from <a rel="nofollow" class="external text" href="http://philosci40.unibe.ch/lehre/winter99/einstein/Walker_Stachel.pdf">the original</a> <span class="cs1-format">(PDF)</span> on 19 January 2012<span class="reference-accessdate">. Retrieved <span class="nowrap">19 October</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics+Today&amp;rft.atitle=Did+Einstein+Espouse+his+Spouse%27s+Ideas%3F&amp;rft.volume=42&amp;rft.issue=2&amp;rft.pages=9-13&amp;rft.date=1989-02&amp;rft_id=info%3Adoi%2F10.1063%2F1.2810898&amp;rft_id=info%3Abibcode%2F1989PhT....42b...9W&amp;rft.au=Walker%2C+Evan+Harris&amp;rft_id=http%3A%2F%2Fphilosci40.unibe.ch%2Flehre%2Fwinter99%2Feinstein%2FWalker_Stachel.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEPais19941–29-44"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais19941–29_44-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1994">Pais (1994)</a>, pp.&#160;1–29.</span>
</li>
<li id="cite_note-xKrMG-45"><span class="mw-cite-backlink"><b><a href="#cite_ref-xKrMG_45-0">^</a></b></span> <span class="reference-text">Holton, G., <i>Einstein, History, and Other Passions</i>, Harvard University Press, 1996, pp. 177–193.</span>
</li>
<li id="cite_note-FOOTNOTEStachel2002&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA49_49–56&#93;-46"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel2002[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA49_49–56]_46-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel2002">Stachel (2002)</a>, pp.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=OAsQ_hFjhrAC&amp;pg=PA49">49–56</a>.</span>
</li>
<li id="cite_note-dUxMl-47"><span class="mw-cite-backlink"><b><a href="#cite_ref-dUxMl_47-0">^</a></b></span> <span class="reference-text">Martinez, A. A., "Handling evidence in history: the case of Einstein\'s wife", <i>School Science Review</i>, 86 (316), March 2005, pp. 49–56. <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20110811141225/https://webspace.utexas.edu/aam829/1/m/Maric_files/EvidenceMaric.pdf">"PDF"</a> <span class="cs1-format">(PDF)</span>. Archived from <a rel="nofollow" class="external text" href="https://webspace.utexas.edu/aam829/1/m/Maric_files/EvidenceMaric.pdf">the original</a> <span class="cs1-format">(PDF)</span> on 11 August 2011<span class="reference-accessdate">. Retrieved <span class="nowrap">11 August</span> 2011</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=PDF&amp;rft_id=https%3A%2F%2Fwebspace.utexas.edu%2Faam829%2F1%2Fm%2FMaric_files%2FEvidenceMaric.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-HBMes-48"><span class="mw-cite-backlink"><b><a href="#cite_ref-HBMes_48-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRennSchulmann2000" class="citation book cs1">Renn, Jürgen; Schulmann, Robert, eds. (16 November 2000). <a rel="nofollow" class="external text" href="https://press.princeton.edu/books/paperback/9780691088860/albert-einstein-mileva-maric"><i>Albert Einstein, Mileva Maric: The Love Letters</i></a>. Translated by Smith, Shawn. <a href="/wiki/Princeton_University_Press" title="Princeton University Press">Princeton University Press</a>. pp.&#160;73–74, 78. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-08886-0" title="Special:BookSources/978-0-691-08886-0"><bdi>978-0-691-08886-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein%2C+Mileva+Maric%3A+The+Love+Letters&amp;rft.pages=73-74%2C+78&amp;rft.pub=Princeton+University+Press&amp;rft.date=2000-11-16&amp;rft.isbn=978-0-691-08886-0&amp;rft_id=https%3A%2F%2Fpress.princeton.edu%2Fbooks%2Fpaperback%2F9780691088860%2Falbert-einstein-mileva-maric&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTECalapriceLipscombe200522–23-49"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalapriceLipscombe200522–23_49-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalapriceLipscombe2005">Calaprice &amp; Lipscombe (2005)</a>, pp.&#160;22–23.</span>
</li>
<li id="cite_note-MlQLY-50"><span class="mw-cite-backlink"><b><a href="#cite_ref-MlQLY_50-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWüthrich2015" class="citation news cs1 cs1-prop-foreign-lang-source">Wüthrich, Urs (11 April 2015). <a rel="nofollow" class="external text" href="http://www.bernerzeitung.ch/region/bern/Die-Liebesbriefe-des-untreuen-Einstein/story/11875058">"Die Liebesbriefe des untreuen Einstein"</a> &#91;The love letters of the unfaithful Einstein&#93;. <i>BZ Berner Zeitung</i> (in German). Bern, Switzerland. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150416075918/http://www.bernerzeitung.ch/region/bern/Die-Liebesbriefe-des-untreuen-Einstein/story/11875058">Archived</a> from the original on 16 April 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">11 April</span> 2015</span>. <q>Ich denke in innigster Liebe an Dich in jeder freien Minute und bin so unglücklich, wie nur ein Mensch es sein kann.</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=BZ+Berner+Zeitung&amp;rft.atitle=Die+Liebesbriefe+des+untreuen+Einstein&amp;rft.date=2015-04-11&amp;rft.aulast=W%C3%BCthrich&amp;rft.aufirst=Urs&amp;rft_id=http%3A%2F%2Fwww.bernerzeitung.ch%2Fregion%2Fbern%2FDie-Liebesbriefe-des-untreuen-Einstein%2Fstory%2F11875058&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTECalapriceLipscombe2005&#91;httpsbooksgooglecombooksid5eWh2O_3OAQCpgPA50_50&#93;-51"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalapriceLipscombe2005[httpsbooksgooglecombooksid5eWh2O_3OAQCpgPA50_50]_51-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalapriceLipscombe2005">Calaprice &amp; Lipscombe (2005)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=5eWh2O_3OAQC&amp;pg=PA50">50</a>.</span>
</li>
<li id="cite_note-dh-52"><span class="mw-cite-backlink">^ <a href="#cite_ref-dh_52-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-dh_52-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-dh_52-2"><sup><i><b>c</b></i></sup></a> <a href="#cite_ref-dh_52-3"><sup><i><b>d</b></i></sup></a> <a href="#cite_ref-dh_52-4"><sup><i><b>e</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHoffmann2013" class="citation book cs1">Hoffmann, Dieter (2013). <i>Einstein\'s Berlin: In the footsteps of a genius</i>. Baltimore: The Johns Hopkins University Press. pp.&#160;2–9, 28. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-4214-1040-1" title="Special:BookSources/978-1-4214-1040-1"><bdi>978-1-4214-1040-1</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%27s+Berlin%3A+In+the+footsteps+of+a+genius&amp;rft.place=Baltimore&amp;rft.pages=2-9%2C+28&amp;rft.pub=The+Johns+Hopkins+University+Press&amp;rft.date=2013&amp;rft.isbn=978-1-4214-1040-1&amp;rft.aulast=Hoffmann&amp;rft.aufirst=Dieter&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEStachel1966-53"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel1966_53-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel1966">Stachel (1966)</a>.</span>
</li>
<li id="cite_note-54"><span class="mw-cite-backlink"><b><a href="#cite_ref-54">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFSmith1996" class="citation news cs1">Smith, Dinitia (6 November 1996). <a rel="nofollow" class="external text" href="https://www.nytimes.com/1996/11/06/arts/dark-side-of-einstein-emerges-in-his-letters.html">"Dark Side of Einstein Emerges in His Letters"</a>. <i>The New York Times</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210105092333/https://www.nytimes.com/1996/11/06/arts/dark-side-of-einstein-emerges-in-his-letters.html">Archived</a> from the original on 5 January 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">17 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Dark+Side+of+Einstein+Emerges+in+His+Letters&amp;rft.date=1996-11-06&amp;rft.aulast=Smith&amp;rft.aufirst=Dinitia&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F1996%2F11%2F06%2Farts%2Fdark-side-of-einstein-emerges-in-his-letters.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEStachel2002&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA50_50&#93;-55"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel2002[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA50_50]_55-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel2002">Stachel (2002)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=OAsQ_hFjhrAC&amp;pg=PA50">50</a>.</span>
</li>
<li id="cite_note-56"><span class="mw-cite-backlink"><b><a href="#cite_ref-56">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://einsteinpapers.press.princeton.edu/vol9-trans/28">"Volume 9: The Berlin Years: Correspondence, January 1919 – April 1920 (English translation supplement) page 6"</a>. <i>einsteinpapers.press.princeton.edu</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20211004033245/https://einsteinpapers.press.princeton.edu/vol9-trans/28">Archived</a> from the original on 4 October 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">4 October</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=einsteinpapers.press.princeton.edu&amp;rft.atitle=Volume+9%3A+The+Berlin+Years%3A+Correspondence%2C+January+1919+%E2%80%93+April+1920+%28English+translation+supplement%29+page+6&amp;rft_id=https%3A%2F%2Feinsteinpapers.press.princeton.edu%2Fvol9-trans%2F28&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007&quot;Main_characters&quot;,_front_matter-57"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007&quot;Main_characters&quot;,_front_matter_57-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, "Main characters", front matter.</span>
</li>
<li id="cite_note-FOOTNOTECalapriceKennefickSchulmann201562-58"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalapriceKennefickSchulmann201562_58-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalapriceKennefickSchulmann2015">Calaprice, Kennefick &amp; Schulmann (2015)</a>, p.&#160;62.</span>
</li>
<li id="cite_note-59"><span class="mw-cite-backlink"><b><a href="#cite_ref-59">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHighfield2006" class="citation web cs1">Highfield, Roger (10 July 2006). <span class="id-lock-subscription" title="Paid subscription required"><a rel="nofollow" class="external text" href="https://www.telegraph.co.uk/news/worldnews/northamerica/usa/1523626/Einsteins-theory-of-fidelity.html">"Einstein\'s theory of fidelity"</a></span>. <i>The Daily Telegraph</i>. <a rel="nofollow" class="external text" href="https://ghostarchive.org/archive/20220110/https://www.telegraph.co.uk/news/worldnews/northamerica/usa/1523626/Einsteins-theory-of-fidelity.html">Archived</a> from the original on 10 January 2022.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=The+Daily+Telegraph&amp;rft.atitle=Einstein%27s+theory+of+fidelity&amp;rft.date=2006-07-10&amp;rft.aulast=Highfield&amp;rft.aufirst=Roger&amp;rft_id=https%3A%2F%2Fwww.telegraph.co.uk%2Fnews%2Fworldnews%2Fnorthamerica%2Fusa%2F1523626%2FEinsteins-theory-of-fidelity.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-60"><span class="mw-cite-backlink"><b><a href="#cite_ref-60">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFOverbye2017" class="citation news cs1">Overbye, Dennis (17 April 2017). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170418100011/https://www.nytimes.com/2017/04/17/science/albert-einstein-genius-national-geographic-channel.html">"<span class="cs1-kern-left"></span>\'Genius\' Unravels the Mysteries of Einstein\'s Universe"</a>. <i>The New York Times</i>. Archived from <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://www.nytimes.com/2017/04/17/science/albert-einstein-genius-national-geographic-channel.html">the original</a></span> on 18 April 2017.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=%27Genius%27+Unravels+the+Mysteries+of+Einstein%27s+Universe&amp;rft.date=2017-04-17&amp;rft.aulast=Overbye&amp;rft.aufirst=Dennis&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F2017%2F04%2F17%2Fscience%2Falbert-einstein-genius-national-geographic-channel.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-61"><span class="mw-cite-backlink"><b><a href="#cite_ref-61">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.natgeotv.com/za/special/genius-albert-einsteins-theory-of-infidelity">"Genius Albert Einstein\'s Theory of Infidelity"</a>. NatGeo TV. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200923010851/https://www.natgeotv.com/za/special/genius-albert-einsteins-theory-of-infidelity">Archived</a> from the original on 23 September 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">9 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Genius+Albert+Einstein%27s+Theory+of+Infidelity&amp;rft.pub=NatGeo+TV&amp;rft_id=https%3A%2F%2Fwww.natgeotv.com%2Fza%2Fspecial%2Fgenius-albert-einsteins-theory-of-infidelity&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-62"><span class="mw-cite-backlink"><b><a href="#cite_ref-62">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="https://www.jpost.com/health-and-science/getting-up-close-and-personal-with-einstein">"Getting up close and personal with Einstein"</a>. <i>The Jerusalem Post &#124; JPost.com</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200923001654/https://www.jpost.com/Health-and-Science/Getting-up-close-and-personal-with-Einstein">Archived</a> from the original on 23 September 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">29 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Jerusalem+Post+%26%23124%3B+JPost.com&amp;rft.atitle=Getting+up+close+and+personal+with+Einstein&amp;rft_id=https%3A%2F%2Fwww.jpost.com%2Fhealth-and-science%2Fgetting-up-close-and-personal-with-einstein&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEHighfieldCarter1993216-63"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEHighfieldCarter1993216_63-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFHighfieldCarter1993">Highfield &amp; Carter (1993)</a>, p.&#160;216.</span>
</li>
<li id="cite_note-64"><span class="mw-cite-backlink"><b><a href="#cite_ref-64">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.hindustantimes.com/india/einstein-secret-love-affairs-out/story-QVSHrfMYJzCRcIlbBCJKAM.html">"Einstein secret love affairs out!"</a>. <i>Hindustan Times</i>. 13 July 2006. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200923115250/https://www.hindustantimes.com/india/einstein-secret-love-affairs-out/story-QVSHrfMYJzCRcIlbBCJKAM.html">Archived</a> from the original on 23 September 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">17 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Hindustan+Times&amp;rft.atitle=Einstein+secret+love+affairs+out%21&amp;rft.date=2006-07-13&amp;rft_id=https%3A%2F%2Fwww.hindustantimes.com%2Findia%2Feinstein-secret-love-affairs-out%2Fstory-QVSHrfMYJzCRcIlbBCJKAM.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-65"><span class="mw-cite-backlink"><b><a href="#cite_ref-65">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGraydon2023" class="citation book cs1">Graydon, Samuel (14 November 2023). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=PRSsEAAAQBAJ&amp;dq=Margarete+Lebach&amp;pg=PA199"><i>Einstein in Time and Space: A Life in 99 Particles</i></a> (1&#160;ed.). New York: Simon and Schuster. p.&#160;199. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-9821-8512-1" title="Special:BookSources/978-1-9821-8512-1"><bdi>978-1-9821-8512-1</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+in+Time+and+Space%3A+A+Life+in+99+Particles&amp;rft.place=New+York&amp;rft.pages=199&amp;rft.edition=1&amp;rft.pub=Simon+and+Schuster&amp;rft.date=2023-11-14&amp;rft.isbn=978-1-9821-8512-1&amp;rft.aulast=Graydon&amp;rft.aufirst=Samuel&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DPRSsEAAAQBAJ%26dq%3DMargarete%2BLebach%26pg%3DPA199&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-66"><span class="mw-cite-backlink"><b><a href="#cite_ref-66">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.nbcnews.com/id/13804030/ns/technology_and_science-science/t/new-letters-shed-light-einsteins-love-life/">"New letters shed light on Einstein\'s love life"</a>. NBC News. 11 July 2006. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200222022647/http://www.nbcnews.com/id/13804030/ns/technology_and_science-science/t/new-letters-shed-light-einsteins-love-life">Archived</a> from the original on 22 February 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">15 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=New+letters+shed+light+on+Einstein%27s+love+life&amp;rft.pub=NBC+News&amp;rft.date=2006-07-11&amp;rft_id=http%3A%2F%2Fwww.nbcnews.com%2Fid%2F13804030%2Fns%2Ftechnology_and_science-science%2Ft%2Fnew-letters-shed-light-einsteins-love-life%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-67"><span class="mw-cite-backlink"><b><a href="#cite_ref-67">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="https://economictimes.indiatimes.com/magazines/panache/albert-einstein-may-have-had-the-iq-but-he-needed-to-work-on-his-eq/articleshow/64849211.cms?from=mdr">"Albert Einstein may have had the IQ, but he needed to work on his EQ"</a>. <i>The Economic Times</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210208134808/https://economictimes.indiatimes.com/magazines/panache/albert-einstein-may-have-had-the-iq-but-he-needed-to-work-on-his-eq/articleshow/64849211.cms?from=mdr">Archived</a> from the original on 8 February 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">15 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Economic+Times&amp;rft.atitle=Albert+Einstein+may+have+had+the+IQ%2C+but+he+needed+to+work+on+his+EQ&amp;rft_id=https%3A%2F%2Feconomictimes.indiatimes.com%2Fmagazines%2Fpanache%2Falbert-einstein-may-have-had-the-iq-but-he-needed-to-work-on-his-eq%2Farticleshow%2F64849211.cms%3Ffrom%3Dmdr&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-68"><span class="mw-cite-backlink"><b><a href="#cite_ref-68">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPogrebin1998" class="citation news cs1">Pogrebin, Robin (1 June 1998). <a rel="nofollow" class="external text" href="https://www.nytimes.com/1998/06/01/us/love-letters-by-einstein-at-auction.html">"Love Letters By Einstein at Auction"</a>. <i>The New York Times</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20201107053956/https://www.nytimes.com/1998/06/01/us/love-letters-by-einstein-at-auction.html">Archived</a> from the original on 7 November 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">10 August</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Love+Letters+By+Einstein+at+Auction&amp;rft.date=1998-06-01&amp;rft.aulast=Pogrebin&amp;rft.aufirst=Robin&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F1998%2F06%2F01%2Fus%2Flove-letters-by-einstein-at-auction.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-69"><span class="mw-cite-backlink"><b><a href="#cite_ref-69">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.independent.co.uk/news/einsteins-letters-show-affair-with-spy-1162418.html">"Einstein\'s letters show affair with spy"</a>. <i>The Independent</i>. 2 June 1998. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20201116013010/https://www.independent.co.uk/news/einsteins-letters-show-affair-with-spy-1162418.html">Archived</a> from the original on 16 November 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">10 November</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=The+Independent&amp;rft.atitle=Einstein%27s+letters+show+affair+with+spy&amp;rft.date=1998-06-02&amp;rft_id=https%3A%2F%2Fwww.independent.co.uk%2Fnews%2Feinsteins-letters-show-affair-with-spy-1162418.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Robinson2015a-70"><span class="mw-cite-backlink"><b><a href="#cite_ref-Robinson2015a_70-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRobinson2015" class="citation book cs1"><a href="/wiki/Walter_Isaacson" title="Walter Isaacson">Robinson, Andrew</a> (2015). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=Px4_CQAAQBAJ&amp;pg=PA144"><i>Einstein: A Hundred Years of Relativity</i></a>. Princeton University Press. pp.&#160;143–145. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-16989-7" title="Special:BookSources/978-0-691-16989-7"><bdi>978-0-691-16989-7</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">19 July</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%3A+A+Hundred+Years+of+Relativity&amp;rft.pages=143-145&amp;rft.pub=Princeton+University+Press&amp;rft.date=2015&amp;rft.isbn=978-0-691-16989-7&amp;rft.aulast=Robinson&amp;rft.aufirst=Andrew&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DPx4_CQAAQBAJ%26pg%3DPA144&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTENeffe2007&#91;httpsarchiveorgdetailseinsteinbiograph00neffpage203_203&#93;-71"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTENeffe2007[httpsarchiveorgdetailseinsteinbiograph00neffpage203_203]_71-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFNeffe2007">Neffe (2007)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://archive.org/details/einsteinbiograph00neff/page/203">203</a>.</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._67-72"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008vol._1_(1987),_doc._67_72-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>, vol. 1 (1987), doc. 67.</span>
</li>
<li id="cite_note-FOOTNOTEFölsing199782-73"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing199782_73-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, p.&#160;82.</span>
</li>
<li id="cite_note-ODY5p-74"><span class="mw-cite-backlink"><b><a href="#cite_ref-ODY5p_74-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFJ._J._O&#39;ConnorE._F._Robertson2010" class="citation web cs1">J. J. O\'Connor; E. F. Robertson (May 2010). <a rel="nofollow" class="external text" href="http://www-history.mcs.st-and.ac.uk/Biographies/Grossmann.html">"Grossmann biography"</a>. <i>MacTutor</i>. School of Mathematics and Statistics, University of St Andrews, Scotland. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150910072254/http://www-history.mcs.st-and.ac.uk/Biographies/Grossmann.html">Archived</a> from the original on 10 September 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">27 March</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=MacTutor&amp;rft.atitle=Grossmann+biography&amp;rft.date=2010-05&amp;rft.au=J.+J.+O%27Connor&amp;rft.au=E.+F.+Robertson&amp;rft_id=http%3A%2F%2Fwww-history.mcs.st-and.ac.uk%2FBiographies%2FGrossmann.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson200763-75"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson200763_75-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;63.</span>
</li>
<li id="cite_note-MeZPN-76"><span class="mw-cite-backlink"><b><a href="#cite_ref-MeZPN_76-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20160830195148/https://www.ipi.ch/en/about-us/einstein/einstein-at-the-patent-office.html">"Einstein at the patent office"</a> (official website). Berne, Switzerland: Swiss Federal Institute of Intellectual Property, IGE/IPI. 6 February 2014. Archived from <a rel="nofollow" class="external text" href="https://www.ipi.ch/en/about-us/einstein/einstein-at-the-patent-office.html">the original</a> on 30 August 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">9 September</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein+at+the+patent+office&amp;rft.place=Berne%2C+Switzerland&amp;rft.pub=Swiss+Federal+Institute+of+Intellectual+Property%2C+IGE%2FIPI&amp;rft.date=2014-02-06&amp;rft_id=https%3A%2F%2Fwww.ipi.ch%2Fen%2Fabout-us%2Feinstein%2Feinstein-at-the-patent-office.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-IGEFAQ-77"><span class="mw-cite-backlink">^ <a href="#cite_ref-IGEFAQ_77-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-IGEFAQ_77-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.ige.ch/en/about-us/the-history-of-the-ipi/einstein/faq">"FAQ about Einstein and the Institute"</a> (official website). Berne, Switzerland: Swiss Federal Institute of Intellectual Property, IGE/IPI. 27 May 2014. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210612105555/https://www.ige.ch/en/about-us/the-history-of-the-ipi/einstein/faq">Archived</a> from the original on 12 June 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">27 March</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=FAQ+about+Einstein+and+the+Institute&amp;rft.place=Berne%2C+Switzerland&amp;rft.pub=Swiss+Federal+Institute+of+Intellectual+Property%2C+IGE%2FIPI&amp;rft.date=2014-05-27&amp;rft_id=https%3A%2F%2Fwww.ige.ch%2Fen%2Fabout-us%2Fthe-history-of-the-ipi%2Feinstein%2Ffaq&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEGalison2000370-78"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEGalison2000370_78-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFGalison2000">Galison (2000)</a>, p.&#160;370.</span>
</li>
<li id="cite_note-FOOTNOTEHighfieldCarter199396–98-79"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEHighfieldCarter199396–98_79-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFHighfieldCarter1993">Highfield &amp; Carter (1993)</a>, pp.&#160;96–98.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson200779–84-80"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson200779–84_80-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, pp.&#160;79–84.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1901-81"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEEinstein1901_81-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEEinstein1901_81-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFEinstein1901">Einstein (1901)</a>.</span>
</li>
<li id="cite_note-82"><span class="mw-cite-backlink"><b><a href="#cite_ref-82">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMurrellGrobert2002" class="citation journal cs1">Murrell, J. N.; Grobert, N. (January 2002). "The centenary of Einstein\'s first scientific paper". <i>Notes and Records of the Royal Society of London</i>. <b>56</b> (1): 89–94. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1098%2Frsnr.2002.0169">10.1098/rsnr.2002.0169</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/532124">532124</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Notes+and+Records+of+the+Royal+Society+of+London&amp;rft.atitle=The+centenary+of+Einstein%27s+first+scientific+paper&amp;rft.volume=56&amp;rft.issue=1&amp;rft.pages=89-94&amp;rft.date=2002-01&amp;rft_id=info%3Adoi%2F10.1098%2Frsnr.2002.0169&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F532124%23id-name%3DJSTOR&amp;rft.aulast=Murrell&amp;rft.aufirst=J.+N.&amp;rft.au=Grobert%2C+N.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;-83"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;_83-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEEinstein1905b&quot;Meinem_Freunde_Herr_Dr._Marcel_Grossmann_gewidmet_(Dedicated_to_my_friend,_Dr._Marcel_Grossmann)&quot;_83-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFEinstein1905b">Einstein (1905b)</a>, "Meinem Freunde Herr Dr. Marcel Grossmann gewidmet (Dedicated to my friend, Dr. Marcel Grossmann)".</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1926bchap._&quot;A_New_Determination_of_Molecular_Dimensions&quot;-84"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1926bchap._&quot;A_New_Determination_of_Molecular_Dimensions&quot;_84-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1926b">Einstein (1926b)</a>, chap. "A New Determination of Molecular Dimensions".</span>
</li>
<li id="cite_note-85"><span class="mw-cite-backlink"><b><a href="#cite_ref-85">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMehra2001" class="citation book cs1">Mehra, Jagdish (28 February 2001). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=o1XVCgAAQBAJ"><i>Golden Age Of Theoretical Physics, The (Boxed Set Of 2 Vols)</i></a>. World Scientific. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-981-4492-85-0" title="Special:BookSources/978-981-4492-85-0"><bdi>978-981-4492-85-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Golden+Age+Of+Theoretical+Physics%2C+The+%28Boxed+Set+Of+2+Vols%29&amp;rft.pub=World+Scientific&amp;rft.date=2001-02-28&amp;rft.isbn=978-981-4492-85-0&amp;rft.aulast=Mehra&amp;rft.aufirst=Jagdish&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3Do1XVCgAAQBAJ&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-86"><span class="mw-cite-backlink"><b><a href="#cite_ref-86">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMay2017" class="citation book cs1">May, Andrew (2017). Clegg, Brian (ed.). <i>Albert Einstein, in 30-Second Physics: The 50 most fundamental concepts in physics, each explained in half a minute</i>. London: Ivy Press. pp.&#160;108–109. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-78240-514-6" title="Special:BookSources/978-1-78240-514-6"><bdi>978-1-78240-514-6</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein%2C+in+30-Second+Physics%3A+The+50+most+fundamental+concepts+in+physics%2C+each+explained+in+half+a+minute&amp;rft.place=London&amp;rft.pages=108-109&amp;rft.pub=Ivy+Press&amp;rft.date=2017&amp;rft.isbn=978-1-78240-514-6&amp;rft.aulast=May&amp;rft.aufirst=Andrew&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-bG2yp-87"><span class="mw-cite-backlink"><b><a href="#cite_ref-bG2yp_87-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1 cs1-prop-foreign-lang-source"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20140821032129/http://www.library.ethz.ch/en/Resources/Digital-library/Einstein-Online/Associate-Professor-at-the-Universiy-of-Zurich-und-professor-in-Prague-1909-1912">"Associate Professor at the University of Zurich und professor in Prague (1909–1912)"</a> (digital library). Einstein Online (in German and English). Bern, Switzerland: ETH-Bibliothek Zurich, ETH Zurich, www.ethz.ch. 2014. Archived from <a rel="nofollow" class="external text" href="http://www.library.ethz.ch/en/Resources/Digital-library/Einstein-Online/Associate-Professor-at-the-Universiy-of-Zurich-und-professor-in-Prague-1909-1912">the original</a> on 21 August 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">17 August</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Associate+Professor+at+the+University+of+Zurich+und+professor+in+Prague+%281909%E2%80%931912%29&amp;rft.place=Bern%2C+Switzerland&amp;rft.series=Einstein+Online&amp;rft.pub=ETH-Bibliothek+Zurich%2C+ETH+Zurich%2C+www.ethz.ch&amp;rft.date=2014&amp;rft_id=http%3A%2F%2Fwww.library.ethz.ch%2Fen%2FResources%2FDigital-library%2FEinstein-Online%2FAssociate-Professor-at-the-Universiy-of-Zurich-und-professor-in-Prague-1909-1912&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007164-88"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007164_88-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;164.</span>
</li>
<li id="cite_note-Itl8r-89"><span class="mw-cite-backlink"><b><a href="#cite_ref-Itl8r_89-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFvon_Hirschhausen,_Ulrike2007" class="citation web cs1">von Hirschhausen, Ulrike (2007). <a rel="nofollow" class="external text" href="http://econstor.eu/bitstream/10419/49610/1/569197996.pdf">"Von imperialer Inklusion zur nationalen Exklusion:Staatsbürgerschaft in Österreich- Ungarn 1867–1923"</a> <span class="cs1-format">(PDF)</span> (WZB Discussion Paper). ZKD&#160;&#8211;&#32; Veröffentlichungsreihe der Forschungsgruppe, "Zivilgesellschaft, Citizenship und politische Mobilisierung in Europa" Schwerpunkt Zivilgesellschaft, Konflikte und Demokratie, Wissenschaftszentrum Berlin für Sozialforschung. Berlin, Germany: WZB Social Science Research Center Berlin. p.&#160;8. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/1860-4315">1860-4315</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150909200726/http://econstor.eu/bitstream/10419/49610/1/569197996.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 9 September 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">4 August</span> 2015</span>. <q>Eine weitere Diskontinuität bestand viertens darin, dass die Bestimmungen der österreichischen Staatsbürgerschaft, die in den ersten Dritteln des Jahrhunderts auch auf Ungarn angewandt worden waren, seit 1867 nur noch für die cisleithanische Reichshälfte galten. Ungarn entwickelte hingegen jetzt eine eige-ne Staatsbürgerschaft.</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Von+imperialer+Inklusion+zur+nationalen+Exklusion%3AStaatsb%C3%BCrgerschaft+in+%C3%96sterreich-+Ungarn+1867%E2%80%931923&amp;rft.place=Berlin%2C+Germany&amp;rft.series=ZKD+%26ndash%3B%26%2332%3B+Ver%C3%B6ffentlichungsreihe+der+Forschungsgruppe%2C+%22Zivilgesellschaft%2C+Citizenship+und+politische+Mobilisierung+in+Europa%22+Schwerpunkt+Zivilgesellschaft%2C+Konflikte+und+Demokratie%2C+Wissenschaftszentrum+Berlin+f%C3%BCr+Sozialforschung&amp;rft.pages=8&amp;rft.pub=WZB+Social+Science+Research+Center+Berlin&amp;rft.date=2007&amp;rft.issn=1860-4315&amp;rft.au=von+Hirschhausen%2C+Ulrike&amp;rft_id=http%3A%2F%2Feconstor.eu%2Fbitstream%2F10419%2F49610%2F1%2F569197996.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-90"><span class="mw-cite-backlink"><b><a href="#cite_ref-90">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLyth2019" class="citation book cs1">Lyth, David (31 January 2019). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=pRaGDwAAQBAJ&amp;dq=%22Einstein%22+%22Prague%22+%22Eleven%22&amp;pg=PA122"><i>The Road to Einstein\'s Relativity: Following in the Footsteps of the Giants</i></a>. CRC Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-429-68268-1" title="Special:BookSources/978-0-429-68268-1"><bdi>978-0-429-68268-1</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Road+to+Einstein%27s+Relativity%3A+Following+in+the+Footsteps+of+the+Giants&amp;rft.pub=CRC+Press&amp;rft.date=2019-01-31&amp;rft.isbn=978-0-429-68268-1&amp;rft.aulast=Lyth&amp;rft.aufirst=David&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DpRaGDwAAQBAJ%26dq%3D%2522Einstein%2522%2B%2522Prague%2522%2B%2522Eleven%2522%26pg%3DPA122&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-hXQin-91"><span class="mw-cite-backlink"><b><a href="#cite_ref-hXQin_91-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1 cs1-prop-foreign-lang-source"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20140821032349/http://www.library.ethz.ch/en/Resources/Digital-library/Einstein-Online/Professor-at-the-ETH-Zurich-1912-1914">"Professor at the ETH Zurich (1912–1914)"</a> (digital library). Einstein Online (in German and English). Zurich, Switzerland: ETH-Bibliothek Zurich, ETH Zürich, www.ethz.ch. 2014. Archived from <a rel="nofollow" class="external text" href="http://www.library.ethz.ch/en/Resources/Digital-library/Einstein-Online/Professor-at-the-ETH-Zurich-1912-1914">the original</a> on 21 August 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">17 August</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Professor+at+the+ETH+Zurich+%281912%E2%80%931914%29&amp;rft.place=Zurich%2C+Switzerland&amp;rft.series=Einstein+Online&amp;rft.pub=ETH-Bibliothek+Zurich%2C+ETH+Z%C3%BCrich%2C+www.ethz.ch&amp;rft.date=2014&amp;rft_id=http%3A%2F%2Fwww.library.ethz.ch%2Fen%2FResources%2FDigital-library%2FEinstein-Online%2FProfessor-at-the-ETH-Zurich-1912-1914&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEStachel2002534-92"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEStachel2002534_92-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEStachel2002534_92-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFStachel2002">Stachel (2002)</a>, p.&#160;534.</span>
</li>
<li id="cite_note-jstor.org-93"><span class="mw-cite-backlink">^ <a href="#cite_ref-jstor.org_93-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-jstor.org_93-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.jstor.org/stable/1687520">"Albert Einstein: His Influence on Physics, Philosophy and Politics JL Heilbron – 1982, Published by: American Association for the Advancement of Science <i>via</i> JSTOR"</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/1687520">1687520</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20211122130724/https://www.jstor.org/stable/1687520">Archived</a> from the original on 22 November 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">22 November</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein%3A+His+Influence+on+Physics%2C+Philosophy+and+Politics+JL+Heilbron+%E2%80%93+1982%2C+Published+by%3A+American+Association+for+the+Advancement+of+Science+via+JSTOR&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F1687520%23id-name%3DJSTOR&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F1687520&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEScheideler2002333-94"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEScheideler2002333_94-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFScheideler2002">Scheideler (2002)</a>, p.&#160;333.</span>
</li>
<li id="cite_note-FOOTNOTEWeinstein201518–19-95"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEWeinstein201518–19_95-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFWeinstein2015">Weinstein (2015)</a>, pp.&#160;18–19.</span>
</li>
<li id="cite_note-FOOTNOTECalapriceLipscombe2005&#91;httpsbooksgooglecombooksid5eWh2O_3OAQCpgPR19_&quot;Timeline&quot;,_p._xix&#93;-96"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalapriceLipscombe2005[httpsbooksgooglecombooksid5eWh2O_3OAQCpgPR19_&quot;Timeline&quot;,_p._xix]_96-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalapriceLipscombe2005">Calaprice &amp; Lipscombe (2005)</a>, <a rel="nofollow" class="external text" href="https://books.google.com/books?id=5eWh2O_3OAQC&amp;pg=PR19">"Timeline", p. xix</a>.</span>
</li>
<li id="cite_note-EXcH6-97"><span class="mw-cite-backlink"><b><a href="#cite_ref-EXcH6_97-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20170131021344/https://www.mpg.de/dossier/einstein/in-berlin">"Director in the attic"</a>. Max-Planck-Gesellschaft, München. Archived from <a rel="nofollow" class="external text" href="https://www.mpg.de/dossier/einstein/in-berlin">the original</a> on 31 January 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">9 July</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Director+in+the+attic&amp;rft.pub=Max-Planck-Gesellschaft%2C+M%C3%BCnchen&amp;rft_id=https%3A%2F%2Fwww.mpg.de%2Fdossier%2Feinstein%2Fin-berlin&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-3gcYy-98"><span class="mw-cite-backlink"><b><a href="#cite_ref-3gcYy_98-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.dwc.knaw.nl/biografie/pmknaw/?pagetype=authorDetail&amp;aId=PE00000116">"Albert Einstein (1879–1955)"</a>. Royal Netherlands Academy of Arts and Sciences. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150923225403/http://www.dwc.knaw.nl/biografie/pmknaw/?pagetype=authorDetail&amp;aId=PE00000116">Archived</a> from the original on 23 September 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">21 July</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein+%281879%E2%80%931955%29&amp;rft.pub=Royal+Netherlands+Academy+of+Arts+and+Sciences&amp;rft_id=http%3A%2F%2Fwww.dwc.knaw.nl%2Fbiografie%2Fpmknaw%2F%3Fpagetype%3DauthorDetail%26aId%3DPE00000116&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-99"><span class="mw-cite-backlink"><b><a href="#cite_ref-99">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.amacad.org/person/albert-einstein">"Albert Einstein"</a>. <i>American Academy of Arts &amp; Sciences</i>. 9 February 2023<span class="reference-accessdate">. Retrieved <span class="nowrap">13 July</span> 2023</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=American+Academy+of+Arts+%26+Sciences&amp;rft.atitle=Albert+Einstein&amp;rft.date=2023-02-09&amp;rft_id=https%3A%2F%2Fwww.amacad.org%2Fperson%2Falbert-einstein&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-100"><span class="mw-cite-backlink"><b><a href="#cite_ref-100">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://search.amphilsoc.org/memhist/search?creator=Albert+Einstein&amp;title=&amp;subject=&amp;subdiv=&amp;mem=&amp;year=&amp;year-max=&amp;dead=&amp;keyword=&amp;smode=advanced">"APS Member History"</a>. <i>search.amphilsoc.org</i><span class="reference-accessdate">. Retrieved <span class="nowrap">13 July</span> 2023</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=search.amphilsoc.org&amp;rft.atitle=APS+Member+History&amp;rft_id=https%3A%2F%2Fsearch.amphilsoc.org%2Fmemhist%2Fsearch%3Fcreator%3DAlbert%2BEinstein%26title%3D%26subject%3D%26subdiv%3D%26mem%3D%26year%3D%26year-max%3D%26dead%3D%26keyword%3D%26smode%3Dadvanced&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-NYTimes_19191125-101"><span class="mw-cite-backlink"><b><a href="#cite_ref-NYTimes_19191125_101-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><span class="id-lock-subscription" title="Paid subscription required"><a rel="nofollow" class="external text" href="https://newspaperarchive.com/new-york-times-nov-25-1919-p-17/">"A New Physics, Based on Einstein"</a></span>. <i>The New York Times</i>. 25 November 1919. p.&#160;17. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190608033600/https://newspaperarchive.com/new-york-times-nov-25-1919-p-17/">Archived</a> from the original on 8 June 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">8 June</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=A+New+Physics%2C+Based+on+Einstein&amp;rft.pages=17&amp;rft.date=1919-11-25&amp;rft_id=https%3A%2F%2Fnewspaperarchive.com%2Fnew-york-times-nov-25-1919-p-17%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-102"><span class="mw-cite-backlink"><b><a href="#cite_ref-102">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWeinberg1972" class="citation book cs1">Weinberg, Steven (1972). <i>Gravitation and Cosmology: Principles and applications of the general theory of relativity</i>. John Wiley &amp; Sons, Inc. pp.&#160;19–20. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/9788126517558" title="Special:BookSources/9788126517558"><bdi>9788126517558</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Gravitation+and+Cosmology%3A+Principles+and+applications+of+the+general+theory+of+relativity&amp;rft.pages=19-20&amp;rft.pub=John+Wiley+%26+Sons%2C+Inc.&amp;rft.date=1972&amp;rft.isbn=9788126517558&amp;rft.aulast=Weinberg&amp;rft.aufirst=Steven&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Eddington-103"><span class="mw-cite-backlink"><b><a href="#cite_ref-Eddington_103-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFAndrzej2003" class="citation journal cs1">Andrzej, Stasiak (2003). <a rel="nofollow" class="external text" href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC1315907">"Myths in science"</a>. <i>EMBO Reports</i>. <b>4</b> (3): 236. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1038%2Fsj.embor.embor779">10.1038/sj.embor.embor779</a></span>. <a href="/wiki/PMC_(identifier)" class="mw-redirect" title="PMC (identifier)">PMC</a>&#160;<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC1315907">1315907</a></span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=EMBO+Reports&amp;rft.atitle=Myths+in+science&amp;rft.volume=4&amp;rft.issue=3&amp;rft.pages=236&amp;rft.date=2003&amp;rft_id=https%3A%2F%2Fwww.ncbi.nlm.nih.gov%2Fpmc%2Farticles%2FPMC1315907%23id-name%3DPMC&amp;rft_id=info%3Adoi%2F10.1038%2Fsj.embor.embor779&amp;rft.aulast=Andrzej&amp;rft.aufirst=Stasiak&amp;rft_id=https%3A%2F%2Fwww.ncbi.nlm.nih.gov%2Fpmc%2Farticles%2FPMC1315907&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-104"><span class="mw-cite-backlink"><b><a href="#cite_ref-104">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFrancis2017" class="citation web cs1">Francis, Matthew (3 March 2017). <a rel="nofollow" class="external text" href="https://www.smithsonianmag.com/science-nature/how-celebrity-scientist-albert-einstein-used-fame-denounce-american-racism-180962356/">"How Albert Einstein Used His Fame to Denounce American Racism"</a>. Smithsonian Magazine.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=How+Albert+Einstein+Used+His+Fame+to+Denounce+American+Racism&amp;rft.pub=Smithsonian+Magazine&amp;rft.date=2017-03-03&amp;rft.aulast=Francis&amp;rft.aufirst=Matthew&amp;rft_id=https%3A%2F%2Fwww.smithsonianmag.com%2Fscience-nature%2Fhow-celebrity-scientist-albert-einstein-used-fame-denounce-american-racism-180962356%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-105"><span class="mw-cite-backlink"><b><a href="#cite_ref-105">^</a></b></span> <span class="reference-text">Falk, Dan, <i><a rel="nofollow" class="external text" href="https://www.smithsonianmag.com/history/one-hundred-years-ago-einstein-was-given-heros-welcome-americas-jews-180977386/">One Hundred Years Ago, Einstein Was Given a Hero\'s Welcome by America\'s Jews</a> <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210403140031/https://www.smithsonianmag.com/history/one-hundred-years-ago-einstein-was-given-heros-welcome-americas-jews-180977386/">Archived</a> 3 April 2021 at the <a href="/wiki/Wayback_Machine" title="Wayback Machine">Wayback Machine</a></i>, Smithsonian, 2 April 2021</span>
</li>
<li id="cite_note-FOOTNOTEHoffmann1972145–148-106"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEHoffmann1972145–148_106-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFHoffmann1972">Hoffmann (1972)</a>, pp.&#160;145–148.</span>
</li>
<li id="cite_note-FOOTNOTEFölsing1997499–508-107"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing1997499–508_107-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, pp.&#160;499–508.</span>
</li>
<li id="cite_note-7gwHd-108"><span class="mw-cite-backlink"><b><a href="#cite_ref-7gwHd_108-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20200225121713/http://www.einsteinsworld.com/news-new-york-herald-tribune-1931-as-einstein-sees-america.htm">"As Einstein Sees American"</a>. Archived from <a rel="nofollow" class="external text" href="http://www.einsteinsworld.com/News-New-York-Herald-Tribune-1931-As-Einstein-Sees-America.htm">the original</a> on 25 February 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">25 May</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=As+Einstein+Sees+American&amp;rft_id=http%3A%2F%2Fwww.einsteinsworld.com%2FNews-New-York-Herald-Tribune-1931-As-Einstein-Sees-America.htm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>, <i>Einstein\'s World</i>, a 1931 reprint with minor changes, of his 1921 essay.</span>
</li>
<li id="cite_note-FOOTNOTEHolton198420-109"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEHolton198420_109-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFHolton1984">Holton (1984)</a>, p.&#160;20.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007307–308-110"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007307–308_110-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, pp.&#160;307–308.</span>
</li>
<li id="cite_note-38YkY-111"><span class="mw-cite-backlink"><b><a href="#cite_ref-38YkY_111-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFlood2018" class="citation news cs1">Flood, Alison (12 June 2018). <a rel="nofollow" class="external text" href="https://www.theguardian.com/books/2018/jun/12/einsteins-travel-diaries-reveal-shocking-xenophobia">"Einstein\'s travel diaries reveal \'shocking\' xenophobia"</a>. <i><a href="/wiki/The_Guardian" title="The Guardian">The Guardian</a></i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190117005146/https://www.theguardian.com/books/2018/jun/12/einsteins-travel-diaries-reveal-shocking-xenophobia">Archived</a> from the original on 17 January 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">13 June</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Guardian&amp;rft.atitle=Einstein%27s+travel+diaries+reveal+%27shocking%27+xenophobia&amp;rft.date=2018-06-12&amp;rft.aulast=Flood&amp;rft.aufirst=Alison&amp;rft_id=https%3A%2F%2Fwww.theguardian.com%2Fbooks%2F2018%2Fjun%2F12%2Feinsteins-travel-diaries-reveal-shocking-xenophobia&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-112"><span class="mw-cite-backlink"><b><a href="#cite_ref-112">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFKatz" class="citation web cs1">Katz, Brigit. <a rel="nofollow" class="external text" href="https://www.smithsonianmag.com/smart-news/einsteins-travel-diaries-reveal-his-deeply-troubling-views-race-180969387/">"Einstein\'s Travel Diaries Reveal His Deeply Troubling Views on Race"</a>. <i>Smithsonian Magazine</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20201225201826/https://www.smithsonianmag.com/smart-news/einsteins-travel-diaries-reveal-his-deeply-troubling-views-race-180969387/">Archived</a> from the original on 25 December 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">3 January</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Smithsonian+Magazine&amp;rft.atitle=Einstein%27s+Travel+Diaries+Reveal+His+Deeply+Troubling+Views+on+Race&amp;rft.aulast=Katz&amp;rft.aufirst=Brigit&amp;rft_id=https%3A%2F%2Fwww.smithsonianmag.com%2Fsmart-news%2Feinsteins-travel-diaries-reveal-his-deeply-troubling-views-race-180969387%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007308-113"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007308_113-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;308.</span>
</li>
<li id="cite_note-oxak7-114"><span class="mw-cite-backlink"><b><a href="#cite_ref-oxak7_114-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.nobelprize.org/nobel_prizes/physics/laureates/1921/einstein-speech.html">"The Nobel Prize in Physics 1921: Albert Einstein. Banquet Speech by R. Nadolny (in German)"</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170612114023/http://www.nobelprize.org/nobel_prizes/physics/laureates/1921/einstein-speech.html">Archived</a> from the original on 12 June 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">13 June</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=The+Nobel+Prize+in+Physics+1921%3A+Albert+Einstein.+Banquet+Speech+by+R.+Nadolny+%28in+German%29.&amp;rft_id=https%3A%2F%2Fwww.nobelprize.org%2Fnobel_prizes%2Fphysics%2Flaureates%2F1921%2Feinstein-speech.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> Retrieved 9 December 2015 via Nobelprize.org</span>
</li>
<li id="cite_note-w74nv-115"><span class="mw-cite-backlink"><b><a href="#cite_ref-w74nv_115-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMontes-Santiago2017" class="citation journal cs1">Montes-Santiago, J. (16 July 2017). "[The meeting of Einstein with Cajal (Madrid, 1923): a lost tide of fortune]". <i>Revista de Neurología</i>. <b>43</b> (2): 113–117. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0210-0010">0210-0010</a>. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/16838259">16838259</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Revista+de+Neurolog%C3%ADa&amp;rft.atitle=%5BThe+meeting+of+Einstein+with+Cajal+%28Madrid%2C+1923%29%3A+a+lost+tide+of+fortune%5D&amp;rft.volume=43&amp;rft.issue=2&amp;rft.pages=113-117&amp;rft.date=2017-07-16&amp;rft_id=info%3Apmid%2F16838259&amp;rft.issn=0210-0010&amp;rft.aulast=Montes-Santiago&amp;rft.aufirst=J.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Q5hgx-116"><span class="mw-cite-backlink"><b><a href="#cite_ref-Q5hgx_116-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGrandjean2018" class="citation book cs1 cs1-prop-foreign-lang-source">Grandjean, Martin (2018). <a rel="nofollow" class="external text" href="https://tel.archives-ouvertes.fr/tel-01853903/document"><i>Les réseaux de la coopération intellectuelle. La Société des Nations comme actrice des échanges scientifiques et culturels dans l\'entre-deux-guerres</i></a> &#91;<i>The Networks of Intellectual Cooperation. The League of Nations as an Actor of the Scientific and Cultural Exchanges in the Inter-War Period</i>&#93; (in French). Lausanne: Université de Lausanne. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20180912022034/https://tel.archives-ouvertes.fr/tel-01853903/document">Archived</a> from the original on 12 September 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">18 September</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Les+r%C3%A9seaux+de+la+coop%C3%A9ration+intellectuelle.+La+Soci%C3%A9t%C3%A9+des+Nations+comme+actrice+des+%C3%A9changes+scientifiques+et+culturels+dans+l%27entre-deux-guerres&amp;rft.place=Lausanne&amp;rft.pub=Universit%C3%A9+de+Lausanne&amp;rft.date=2018&amp;rft.aulast=Grandjean&amp;rft.aufirst=Martin&amp;rft_id=https%3A%2F%2Ftel.archives-ouvertes.fr%2Ftel-01853903%2Fdocument&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> pp. 296–302</span>
</li>
<li id="cite_note-vNNnX-117"><span class="mw-cite-backlink"><b><a href="#cite_ref-vNNnX_117-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGrandjean2017" class="citation journal cs1">Grandjean, Martin (2017). "Analisi e visualizzazioni delle reti in storia. L\'esempio della cooperazione intellettuale della Società delle Nazioni". <i>Memoria e Ricerca</i> (2): 371–393. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.14647%2F87204">10.14647/87204</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Memoria+e+Ricerca&amp;rft.atitle=Analisi+e+visualizzazioni+delle+reti+in+storia.+L%27esempio+della+cooperazione+intellettuale+della+Societ%C3%A0+delle+Nazioni&amp;rft.issue=2&amp;rft.pages=371-393&amp;rft.date=2017&amp;rft_id=info%3Adoi%2F10.14647%2F87204&amp;rft.aulast=Grandjean&amp;rft.aufirst=Martin&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> See also: <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMartin_Grandjean2017" class="citation journal cs1">Martin Grandjean (2017). <a rel="nofollow" class="external text" href="https://halshs.archives-ouvertes.fr/halshs-01610098v2">"French version"</a>. <i>Memoria e Ricerca</i> (2): 371–393. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.14647%2F87204">10.14647/87204</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20171107004313/https://halshs.archives-ouvertes.fr/halshs-01610098v2">Archived</a> from the original on 7 November 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">1 December</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Memoria+e+Ricerca&amp;rft.atitle=French+version&amp;rft.issue=2&amp;rft.pages=371-393&amp;rft.date=2017&amp;rft_id=info%3Adoi%2F10.14647%2F87204&amp;rft.au=Martin+Grandjean&amp;rft_id=https%3A%2F%2Fhalshs.archives-ouvertes.fr%2Fhalshs-01610098v2&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> (PDF) and <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.martingrandjean.ch/complex-structures-and-international-organizations/">"English summary"</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20171102034717/http://www.martingrandjean.ch/complex-structures-and-international-organizations/">Archived</a> from the original on 2 November 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">1 December</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=English+summary&amp;rft_id=http%3A%2F%2Fwww.martingrandjean.ch%2Fcomplex-structures-and-international-organizations%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>.</span>
</li>
<li id="cite_note-e9Xyh-118"><span class="mw-cite-backlink"><b><a href="#cite_ref-e9Xyh_118-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFShine2018" class="citation journal cs1">Shine, Cormac (2018). "Papal Diplomacy by Proxy? Catholic Internationalism at the League of Nations\' International Committee on Intellectual Cooperation". <i><a href="/wiki/The_Journal_of_Ecclesiastical_History" title="The Journal of Ecclesiastical History">The Journal of Ecclesiastical History</a></i>. <b>69</b> (4): 785–805. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1017%2FS0022046917002731">10.1017/S0022046917002731</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Journal+of+Ecclesiastical+History&amp;rft.atitle=Papal+Diplomacy+by+Proxy%3F+Catholic+Internationalism+at+the+League+of+Nations%27+International+Committee+on+Intellectual+Cooperation&amp;rft.volume=69&amp;rft.issue=4&amp;rft.pages=785-805&amp;rft.date=2018&amp;rft_id=info%3Adoi%2F10.1017%2FS0022046917002731&amp;rft.aulast=Shine&amp;rft.aufirst=Cormac&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-119"><span class="mw-cite-backlink"><b><a href="#cite_ref-119">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation journal cs1"><a rel="nofollow" class="external text" href="https://www.jstor.org/stable/1651869">"The Committee on Intellectual Cooperation of the League of Nations"</a>. <i>Science</i>. <b>64</b> (1649). American Association for the Advancement of Science: 132–133. 6 August 1926. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1126%2Fscience.64.1649.132.b">10.1126/science.64.1649.132.b</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/1651869">1651869</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:239778182">239778182</a><span class="reference-accessdate">. Retrieved <span class="nowrap">30 May</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Science&amp;rft.atitle=The+Committee+on+Intellectual+Cooperation+of+the+League+of+Nations&amp;rft.volume=64&amp;rft.issue=1649&amp;rft.pages=132-133&amp;rft.date=1926-08-06&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A239778182%23id-name%3DS2CID&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F1651869%23id-name%3DJSTOR&amp;rft_id=info%3Adoi%2F10.1126%2Fscience.64.1649.132.b&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F1651869&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-120"><span class="mw-cite-backlink"><b><a href="#cite_ref-120">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFTolmasquim2012" class="citation book cs1">Tolmasquim, Alfredo Tiomno (2012). "Science and Ideology in Einstein\'s Visit to South America in 1925". In Lehner, Christoph; Renn, Jürgen; Schemmel, Matthias (eds.). <i>Einstein and the Changing Worldviews of Physics</i>. pp.&#160;117–133. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1007%2F978-0-8176-4940-1_6">10.1007/978-0-8176-4940-1_6</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-8176-4939-5" title="Special:BookSources/978-0-8176-4939-5"><bdi>978-0-8176-4939-5</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Science+and+Ideology+in+Einstein%27s+Visit+to+South+America+in+1925&amp;rft.btitle=Einstein+and+the+Changing+Worldviews+of+Physics&amp;rft.pages=117-133&amp;rft.date=2012&amp;rft_id=info%3Adoi%2F10.1007%2F978-0-8176-4940-1_6&amp;rft.isbn=978-0-8176-4939-5&amp;rft.aulast=Tolmasquim&amp;rft.aufirst=Alfredo+Tiomno&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-121"><span class="mw-cite-backlink"><b><a href="#cite_ref-121">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGanguiOrtiz2008" class="citation journal cs1">Gangui, Alejandro; Ortiz, Eduardo L. (2008). "Einstein\'s Unpublished Opening Lecture for His Course on Relativity Theory in Argentina, 1925". <i>Science in Context</i>. <b>21</b> (3): 435–450. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/0903.2064">0903.2064</a></span>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1017%2FS0269889708001853">10.1017/S0269889708001853</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:54920641">54920641</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Science+in+Context&amp;rft.atitle=Einstein%27s+Unpublished+Opening+Lecture+for+His+Course+on+Relativity+Theory+in+Argentina%2C+1925&amp;rft.volume=21&amp;rft.issue=3&amp;rft.pages=435-450&amp;rft.date=2008&amp;rft_id=info%3Aarxiv%2F0903.2064&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A54920641%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1017%2FS0269889708001853&amp;rft.aulast=Gangui&amp;rft.aufirst=Alejandro&amp;rft.au=Ortiz%2C+Eduardo+L.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-122"><span class="mw-cite-backlink"><b><a href="#cite_ref-122">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGanguiOrtiz2016" class="citation arxiv cs1">Gangui, Alejandro; Ortiz, Eduardo L. (2016). "The scientific impact of Einstein\'s visit to Argentina, in 1925". <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1603.03792">1603.03792</a></span> [<a rel="nofollow" class="external text" href="https://arxiv.org/archive/physics.hist-ph">physics.hist-ph</a>].</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=preprint&amp;rft.jtitle=arXiv&amp;rft.atitle=The+scientific+impact+of+Einstein%27s+visit+to+Argentina%2C+in+1925&amp;rft.date=2016&amp;rft_id=info%3Aarxiv%2F1603.03792&amp;rft.aulast=Gangui&amp;rft.aufirst=Alejandro&amp;rft.au=Ortiz%2C+Eduardo+L.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007368-123"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007368_123-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;368.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007370-124"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEIsaacson2007370_124-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007370_124-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007370_124-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;370.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007373-125"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007373_125-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;373.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007374-126"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEIsaacson2007374_126-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007374_126-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;374.</span>
</li>
<li id="cite_note-FOOTNOTEChaplin1964320-127"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEChaplin1964320_127-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFChaplin1964">Chaplin (1964)</a>, p.&#160;320.</span>
</li>
<li id="cite_note-FOOTNOTEChaplin1964322-128"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEChaplin1964322_128-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFChaplin1964">Chaplin (1964)</a>, p.&#160;322.</span>
</li>
<li id="cite_note-FOOTNOTEFölsing1997659-129"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing1997659_129-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, p.&#160;659.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007404-130"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007404_130-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;404.</span>
</li>
<li id="cite_note-131"><span class="mw-cite-backlink"><b><a href="#cite_ref-131">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://newspapers.ushmm.org/events/albert-einstein-quits-germany-renounces-citizenship">"Albert Einstein Quits Germany, Renounces Citizenship"</a>. <i>History Unfolded: US Newspapers and the Holocaust</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210417085304/https://newspapers.ushmm.org/events/albert-einstein-quits-germany-renounces-citizenship">Archived</a> from the original on 17 April 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">14 March</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=History+Unfolded%3A+US+Newspapers+and+the+Holocaust&amp;rft.atitle=Albert+Einstein+Quits+Germany%2C+Renounces+Citizenship&amp;rft_id=https%3A%2F%2Fnewspapers.ushmm.org%2Fevents%2Falbert-einstein-quits-germany-renounces-citizenship&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007407–410-132"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEIsaacson2007407–410_132-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007407–410_132-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007407–410_132-2"><sup><i><b>c</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007407–410_132-3"><sup><i><b>d</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007407–410_132-4"><sup><i><b>e</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, pp.&#160;407–410.</span>
</li>
<li id="cite_note-el4GB-133"><span class="mw-cite-backlink"><b><a href="#cite_ref-el4GB_133-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRichard_Kroehling1991" class="citation web cs1">Richard Kroehling (July 1991). <a rel="nofollow" class="external text" href="http://www.pbs.org/wnet/americanmasters/albert-einstein-how-i-see-the-world/585/">"Albert Einstein: How I See the World"</a>. <i>American Masters</i>. PBS. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20111114020538/http://www.pbs.org/wnet/americanmasters/episodes/albert-einstein/how-i-see-the-world/585/">Archived</a> from the original on 14 November 2011<span class="reference-accessdate">. Retrieved <span class="nowrap">29 May</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=American+Masters&amp;rft.atitle=Albert+Einstein%3A+How+I+See+the+World&amp;rft.date=1991-07&amp;rft.au=Richard+Kroehling&amp;rft_id=http%3A%2F%2Fwww.pbs.org%2Fwnet%2Famericanmasters%2Falbert-einstein-how-i-see-the-world%2F585%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEHolton1984-134"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEHolton1984_134-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFHolton1984">Holton (1984)</a>.</span>
</li>
<li id="cite_note-Jerome-135"><span class="mw-cite-backlink">^ <a href="#cite_ref-Jerome_135-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Jerome_135-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFred_JeromeRodger_Taylor2006" class="citation book cs1">Fred Jerome; Rodger Taylor (2006). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=4d79VQdOfFUC&amp;pg=PR10"><i>Einstein on Race and Racism</i></a>. Rutgers University Press. p.&#160;10. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-8135-3952-2" title="Special:BookSources/978-0-8135-3952-2"><bdi>978-0-8135-3952-2</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">18 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+on+Race+and+Racism&amp;rft.pages=10&amp;rft.pub=Rutgers+University+Press&amp;rft.date=2006&amp;rft.isbn=978-0-8135-3952-2&amp;rft.au=Fred+Jerome&amp;rft.au=Rodger+Taylor&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3D4d79VQdOfFUC%26pg%3DPR10&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1954197-136"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1954197_136-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1954">Einstein (1954)</a>, p.&#160;197.</span>
</li>
<li id="cite_note-Albert_Hall-137"><span class="mw-cite-backlink">^ <a href="#cite_ref-Albert_Hall_137-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Albert_Hall_137-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFKeyte2013" class="citation web cs1">Keyte, Suzanne (9 October 2013). <a rel="nofollow" class="external text" href="https://www.royalalberthall.com/about-the-hall/news/2013/october/3-october-1933-albert-einstein-speaks-at-the-hall/">"3 October 1933 – Albert Einstein presents his final speech given in Europe, at the Royal Albert Hall"</a>. <i>Royal Albert Hall</i><span class="reference-accessdate">. Retrieved <span class="nowrap">20 June</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Royal+Albert+Hall&amp;rft.atitle=3+October+1933+%E2%80%93+Albert+Einstein+presents+his+final+speech+given+in+Europe%2C+at+the+Royal+Albert+Hall&amp;rft.date=2013-10-09&amp;rft.aulast=Keyte&amp;rft.aufirst=Suzanne&amp;rft_id=https%3A%2F%2Fwww.royalalberthall.com%2Fabout-the-hall%2Fnews%2F2013%2Foctober%2F3-october-1933-albert-einstein-speaks-at-the-hall%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-138"><span class="mw-cite-backlink"><b><a href="#cite_ref-138">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRobinson2019" class="citation book cs1"><a href="/wiki/W._Andrew_Robinson" title="W. Andrew Robinson">Robinson, Andrew</a> (2019). <i><a href="/wiki/Einstein_on_the_Run" title="Einstein on the Run">Einstein on the Run</a></i>. <a href="/wiki/Yale_University_Press" title="Yale University Press">Yale University Press</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-300-23476-3" title="Special:BookSources/978-0-300-23476-3"><bdi>978-0-300-23476-3</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+on+the+Run&amp;rft.pub=Yale+University+Press&amp;rft.date=2019&amp;rft.isbn=978-0-300-23476-3&amp;rft.aulast=Robinson&amp;rft.aufirst=Andrew&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007422-139"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007422_139-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;422.</span>
</li>
<li id="cite_note-3zIp7-140"><span class="mw-cite-backlink"><b><a href="#cite_ref-3zIp7_140-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://collection.sciencemuseum.org.uk/objects/co8223551/professor-einstein-with-commander-locker-lampson-gelatin-silver-print-photograph">"Professor Einstein with Commander Locker-Lampson"</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170906091509/http://collection.sciencemuseum.org.uk/objects/co8223551/professor-einstein-with-commander-locker-lampson-gelatin-silver-print-photograph">Archived</a> from the original on 6 September 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">2 June</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Professor+Einstein+with+Commander+Locker-Lampson&amp;rft_id=http%3A%2F%2Fcollection.sciencemuseum.org.uk%2Fobjects%2Fco8223551%2Fprofessor-einstein-with-commander-locker-lampson-gelatin-silver-print-photograph&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>, ScienceMuseum.org, UK</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007419–420-141"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007419–420_141-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, pp.&#160;419–420.</span>
</li>
<li id="cite_note-Gilbert-142"><span class="mw-cite-backlink">^ <a href="#cite_ref-Gilbert_142-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Gilbert_142-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text">Gilbert, Martin. <i>Churchill and the Jews</i>, Henry Holt and Company, N.Y. (2007) pp. 101, 176</span>
</li>
<li id="cite_note-aDu8s-143"><span class="mw-cite-backlink"><b><a href="#cite_ref-aDu8s_143-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFReisman2006" class="citation web cs1">Reisman, Arnold (20 November 2006). <a rel="nofollow" class="external text" href="http://hnn.us/article/31946">"What a Freshly Discovered Einstein Letter Says About Turkey Today"</a>. History News Network, George Mason University. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20140417075103/http://hnn.us/article/31946">Archived</a> from the original on 17 April 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">2 June</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=What+a+Freshly+Discovered+Einstein+Letter+Says+About+Turkey+Today&amp;rft.pub=History+News+Network%2C+George+Mason+University&amp;rft.date=2006-11-20&amp;rft.aulast=Reisman&amp;rft.aufirst=Arnold&amp;rft_id=http%3A%2F%2Fhnn.us%2Farticle%2F31946&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEClark1971-144"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEClark1971_144-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEClark1971_144-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-FOOTNOTEClark1971_144-2"><sup><i><b>c</b></i></sup></a> <a href="#cite_ref-FOOTNOTEClark1971_144-3"><sup><i><b>d</b></i></sup></a> <a href="#cite_ref-FOOTNOTEClark1971_144-4"><sup><i><b>e</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFClark1971">Clark (1971)</a>.</span>
</li>
<li id="cite_note-AP-145"><span class="mw-cite-backlink"><b><a href="#cite_ref-AP_145-0">^</a></b></span> <span class="reference-text">"Denunciation of German Policy is a Stirring Event", Associated Press, 27 July 1933</span>
</li>
<li id="cite_note-Guardian-147"><span class="mw-cite-backlink"><b><a href="#cite_ref-Guardian_147-0">^</a></b></span> <span class="reference-text">"Stateless Jews: The Exiles from Germany, Nationality Plan", <i>The Guardian</i> (UK) 27 July 1933</span>
</li>
<li id="cite_note-FOOTNOTEFölsing1997649,_678-148"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing1997649,_678_148-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, pp.&#160;649, 678.</span>
</li>
<li id="cite_note-Arntzenius2011-149"><span class="mw-cite-backlink">^ <a href="#cite_ref-Arntzenius2011_149-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Arntzenius2011_149-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFArntzenius2011" class="citation book cs1">Arntzenius, Linda G. (2011). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=zHHguITir80C&amp;pg=PA19"><i>Institute for Advanced Study</i></a>. Arcadia Publishing. p.&#160;19. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-7385-7409-7" title="Special:BookSources/978-0-7385-7409-7"><bdi>978-0-7385-7409-7</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">18 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Institute+for+Advanced+Study&amp;rft.pages=19&amp;rft.pub=Arcadia+Publishing&amp;rft.date=2011&amp;rft.isbn=978-0-7385-7409-7&amp;rft.aulast=Arntzenius&amp;rft.aufirst=Linda+G.&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DzHHguITir80C%26pg%3DPA19&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FFt5E-150"><span class="mw-cite-backlink"><b><a href="#cite_ref-FFt5E_150-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.oxfordchabad.org/templates/articlecco_cdo/aid/457396/jewish/Albert-Einstein.htm">"Oxford Jewish Personalities"</a>. Oxford Chabad Society. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20160112172707/http://www.oxfordchabad.org/templates/articlecco_cdo/aid/457396/jewish/Albert-Einstein.htm">Archived</a> from the original on 12 January 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">7 March</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Oxford+Jewish+Personalities&amp;rft.pub=Oxford+Chabad+Society&amp;rft_id=http%3A%2F%2Fwww.oxfordchabad.org%2Ftemplates%2Farticlecco_cdo%2Faid%2F457396%2Fjewish%2FAlbert-Einstein.htm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-v8v06-151"><span class="mw-cite-backlink"><b><a href="#cite_ref-v8v06_151-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="http://www.oxfordtimes.co.uk/leisure/history_heritage/9617968.How_Einstein_fled_from_the_Nazis_to_an_Oxford_college/">"How Einstein fled from the Nazis to an Oxford college"</a>. <i>The Oxford Times</i>. 2012. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150402094400/http://www.oxfordtimes.co.uk/leisure/history_heritage/9617968.How_Einstein_fled_from_the_Nazis_to_an_Oxford_college/">Archived</a> from the original on 2 April 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">7 March</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Oxford+Times&amp;rft.atitle=How+Einstein+fled+from+the+Nazis+to+an+Oxford+college&amp;rft.date=2012&amp;rft_id=http%3A%2F%2Fwww.oxfordtimes.co.uk%2Fleisure%2Fhistory_heritage%2F9617968.How_Einstein_fled_from_the_Nazis_to_an_Oxford_college%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEFölsing1997686–687-152"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing1997686–687_152-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, pp.&#160;686–687.</span>
</li>
<li id="cite_note-mzNc5-153"><span class="mw-cite-backlink"><b><a href="#cite_ref-mzNc5_153-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.ias.edu/people/einstein/in-brief">"In Brief"</a>. Institute for Advanced Study. 10 September 2009. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20100329064405/http://www.ias.edu/people/einstein/in-brief">Archived</a> from the original on 29 March 2010<span class="reference-accessdate">. Retrieved <span class="nowrap">4 March</span> 2010</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=In+Brief&amp;rft.pub=Institute+for+Advanced+Study&amp;rft.date=2009-09-10&amp;rft_id=http%3A%2F%2Fwww.ias.edu%2Fpeople%2Feinstein%2Fin-brief&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-154"><span class="mw-cite-backlink"><b><a href="#cite_ref-154">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWeyl2013" class="citation book cs1">Weyl, Hermann (2013). Pesic, Peter (ed.). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=Dd-vAAAAQBAJ"><i>Levels of Infinity: Selected Writings on Mathematics and Philosophy</i></a>. Dover Publications. p.&#160;5. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/9780486266930" title="Special:BookSources/9780486266930"><bdi>9780486266930</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">30 May</span> 2022</span>. <q>By 1933, Weyl... left for the newly-founded Institute for Advanced Studies at Princeton, where his colleagues included Einstein, Kurt Gödel, and John von Neumann.</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Levels+of+Infinity%3A+Selected+Writings+on+Mathematics+and+Philosophy&amp;rft.pages=5&amp;rft.pub=Dover+Publications&amp;rft.date=2013&amp;rft.isbn=9780486266930&amp;rft.aulast=Weyl&amp;rft.aufirst=Hermann&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DDd-vAAAAQBAJ&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007630-155"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007630_155-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;630.</span>
</li>
<li id="cite_note-o4fkQ-156"><span class="mw-cite-backlink"><b><a href="#cite_ref-o4fkQ_156-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGosling2010" class="citation web cs1">Gosling, F. G. (2010). <a rel="nofollow" class="external text" href="http://energy.gov/management/downloads/gosling-manhattan-project-making-atomic-bomb">"The Manhattan Project: Making the Atomic Bomb"</a>. U.S. Department of Energy, History Division. p.&#160;vii. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150613145416/http://energy.gov/management/downloads/gosling-manhattan-project-making-atomic-bomb">Archived</a> from the original on 13 June 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">7 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=The+Manhattan+Project%3A+Making+the+Atomic+Bomb&amp;rft.pages=vii&amp;rft.pub=U.S.+Department+of+Energy%2C+History+Division&amp;rft.date=2010&amp;rft.aulast=Gosling&amp;rft.aufirst=F.+G.&amp;rft_id=http%3A%2F%2Fenergy.gov%2Fmanagement%2Fdownloads%2Fgosling-manhattan-project-making-atomic-bomb&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-pRqWK-157"><span class="mw-cite-backlink"><b><a href="#cite_ref-pRqWK_157-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLanouetteSilard1992" class="citation book cs1">Lanouette, William; Silard, Bela (1992). <a rel="nofollow" class="external text" href="https://archive.org/details/geniusinshadowsa00lano/page/198"><i>Genius in the Shadows: A Biography of Leo Szilárd: The Man Behind The Bomb</i></a>. New York: Charles Scribner\'s Sons. pp.&#160;<a rel="nofollow" class="external text" href="https://archive.org/details/geniusinshadowsa00lano/page/198">198–200</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-684-19011-2" title="Special:BookSources/978-0-684-19011-2"><bdi>978-0-684-19011-2</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Genius+in+the+Shadows%3A+A+Biography+of+Leo+Szil%C3%A1rd%3A+The+Man+Behind+The+Bomb&amp;rft.place=New+York&amp;rft.pages=198-200&amp;rft.pub=Charles+Scribner%27s+Sons&amp;rft.date=1992&amp;rft.isbn=978-0-684-19011-2&amp;rft.aulast=Lanouette&amp;rft.aufirst=William&amp;rft.au=Silard%2C+Bela&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Fgeniusinshadowsa00lano%2Fpage%2F198&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-4Z68g-158"><span class="mw-cite-backlink"><b><a href="#cite_ref-4Z68g_158-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDiehlMoltz2008" class="citation book cs1">Diehl, Sarah J.; Moltz, James Clay (2008). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=3PN-NEfl_U0C&amp;pg=PA218"><i>Nuclear Weapons and Nonproliferation: A Reference Handbook</i></a>. ABC-CLIO. p.&#160;218. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-59884-071-1" title="Special:BookSources/978-1-59884-071-1"><bdi>978-1-59884-071-1</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">7 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Nuclear+Weapons+and+Nonproliferation%3A+A+Reference+Handbook&amp;rft.pages=218&amp;rft.pub=ABC-CLIO&amp;rft.date=2008&amp;rft.isbn=978-1-59884-071-1&amp;rft.aulast=Diehl&amp;rft.aufirst=Sarah+J.&amp;rft.au=Moltz%2C+James+Clay&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3D3PN-NEfl_U0C%26pg%3DPA218&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-eZym8-159"><span class="mw-cite-backlink"><b><a href="#cite_ref-eZym8_159-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHewlettAnderson1962" class="citation book cs1">Hewlett, Richard G.; Anderson, Oscar E. (1962). <a rel="nofollow" class="external text" href="https://www.governmentattic.org/5docs/TheNewWorld1939-1946.pdf"><i>The New World, 1939–1946</i></a> <span class="cs1-format">(PDF)</span>. University Park: Pennsylvania State University Press. pp.&#160;15–16. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-520-07186-5" title="Special:BookSources/978-0-520-07186-5"><bdi>978-0-520-07186-5</bdi></a>. <a href="/wiki/OCLC_(identifier)" class="mw-redirect" title="OCLC (identifier)">OCLC</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/oclc/637004643">637004643</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190926065049/https://www.governmentattic.org/5docs/TheNewWorld1939-1946.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 26 September 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">7 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+New+World%2C+1939%E2%80%931946&amp;rft.place=University+Park&amp;rft.pages=15-16&amp;rft.pub=Pennsylvania+State+University+Press&amp;rft.date=1962&amp;rft_id=info%3Aoclcnum%2F637004643&amp;rft.isbn=978-0-520-07186-5&amp;rft.aulast=Hewlett&amp;rft.aufirst=Richard+G.&amp;rft.au=Anderson%2C+Oscar+E.&amp;rft_id=https%3A%2F%2Fwww.governmentattic.org%2F5docs%2FTheNewWorld1939-1946.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-z73PK-160"><span class="mw-cite-backlink"><b><a href="#cite_ref-z73PK_160-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein1952" class="citation web cs1">Einstein, Albert (1952). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150828230457/http://www.atomicarchive.com/Docs/Hiroshima/EinsteinResponse.shtml">"On My Participation in the Atom Bomb Project"</a>. Archived from <a rel="nofollow" class="external text" href="http://www.atomicarchive.com/Docs/Hiroshima/EinsteinResponse.shtml">the original</a> on 28 August 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">7 June</span> 2015</span> &#8211; via atomicarchive.org.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=On+My+Participation+in+the+Atom+Bomb+Project&amp;rft.date=1952&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft_id=http%3A%2F%2Fwww.atomicarchive.com%2FDocs%2FHiroshima%2FEinsteinResponse.shtml&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEClark1971752-161"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEClark1971752_161-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFClark1971">Clark (1971)</a>, p.&#160;752.</span>
</li>
<li id="cite_note-162"><span class="mw-cite-backlink"><b><a href="#cite_ref-162">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinsteinRussell1955" class="citation book cs1">Einstein, Albert; Russell, Bertrand (9 July 1955). <a rel="nofollow" class="external text" href="https://pugwash.org/1955/07/09/statement-manifesto/"><i>The Russell-Einstein Manifesto</i></a>. London. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200301114337/https://pugwash.org/1955/07/09/statement-manifesto/">Archived</a> from the original on 1 March 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">9 June</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Russell-Einstein+Manifesto&amp;rft.place=London&amp;rft.date=1955-07-09&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rft.au=Russell%2C+Bertrand&amp;rft_id=https%3A%2F%2Fpugwash.org%2F1955%2F07%2F09%2Fstatement-manifesto%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span><span class="cs1-maint citation-comment"><code class="cs1-code">{{<a href="/wiki/Template:Cite_book" title="Template:Cite book">cite book</a>}}</code>:  CS1 maint: location missing publisher (<a href="/wiki/Category:CS1_maint:_location_missing_publisher" title="Category:CS1 maint: location missing publisher">link</a>)</span></span>
</li>
<li id="cite_note-163"><span class="mw-cite-backlink"><b><a href="#cite_ref-163">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBoyko" class="citation book cs1">Boyko, Hugo. <a rel="nofollow" class="external text" href="https://www.worldacademy.org/files/publications/Science%20and%20the%20Future%20of%20Mankind.pdf"><i>Science and the Future of Mankind</i></a> <span class="cs1-format">(PDF)</span>. Indiana University Press. p.&#160;377.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Science+and+the+Future+of+Mankind&amp;rft.pages=377&amp;rft.pub=Indiana+University+Press&amp;rft.aulast=Boyko&amp;rft.aufirst=Hugo&amp;rft_id=https%3A%2F%2Fwww.worldacademy.org%2Ffiles%2Fpublications%2FScience%2520and%2520the%2520Future%2520of%2520Mankind.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007432-164"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007432_164-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;432.</span>
</li>
<li id="cite_note-smithsonianmag-165"><span class="mw-cite-backlink">^ <a href="#cite_ref-smithsonianmag_165-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-smithsonianmag_165-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFrancis2017" class="citation news cs1">Francis, Matthew (3 March 2017). <a rel="nofollow" class="external text" href="https://www.smithsonianmag.com/science-nature/how-celebrity-scientist-albert-einstein-used-fame-denounce-american-racism-180962356">"How Albert Einstein Used His Fame to Denounce American Racism"</a>. <i>Smithsonian Magazine</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210211150143/https://www.smithsonianmag.com/science-nature/how-celebrity-scientist-albert-einstein-used-fame-denounce-american-racism-180962356/">Archived</a> from the original on 11 February 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">10 February</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Smithsonian+Magazine&amp;rft.atitle=How+Albert+Einstein+Used+His+Fame+to+Denounce+American+Racism&amp;rft.date=2017-03-03&amp;rft.aulast=Francis&amp;rft.aufirst=Matthew&amp;rft_id=https%3A%2F%2Fwww.smithsonianmag.com%2Fscience-nature%2Fhow-celebrity-scientist-albert-einstein-used-fame-denounce-american-racism-180962356&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTECalaprice2005148–149-166"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalaprice2005148–149_166-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalaprice2005">Calaprice (2005)</a>, pp.&#160;148–149.</span>
</li>
<li id="cite_note-FOOTNOTERobeson2002565-167"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTERobeson2002565_167-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFRobeson2002">Robeson (2002)</a>, p.&#160;565.</span>
</li>
<li id="cite_note-civil-168"><span class="mw-cite-backlink">^ <a href="#cite_ref-civil_168-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-civil_168-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://news.harvard.edu/gazette/story/2007/04/albert-einstein-civil-rights-activist/">"Albert Einstein, Civil Rights activist"</a>. 12 April 2007. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20180302182248/https://news.harvard.edu/gazette/story/2007/04/albert-einstein-civil-rights-activist/">Archived</a> from the original on 2 March 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">8 June</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein%2C+Civil+Rights+activist&amp;rft.date=2007-04-12&amp;rft_id=http%3A%2F%2Fnews.harvard.edu%2Fgazette%2Fstory%2F2007%2F04%2Falbert-einstein-civil-rights-activist%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>, <i>Harvard Gazette</i>, 12 April 2007</span>
</li>
<li id="cite_note-Jerome_Isis-169"><span class="mw-cite-backlink"><b><a href="#cite_ref-Jerome_Isis_169-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFJerome2004" class="citation journal cs1">Jerome, Fred (December 2004). "Einstein, Race, and the Myth of the Cultural Icon". <i>Isis</i>. <b>95</b> (4): 627–639. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2004Isis...95..627J">2004Isis...95..627J</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1086%2F430653">10.1086/430653</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/10.1086/430653">10.1086/430653</a>. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/16011298">16011298</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:24738716">24738716</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Isis&amp;rft.atitle=Einstein%2C+Race%2C+and+the+Myth+of+the+Cultural+Icon&amp;rft.volume=95&amp;rft.issue=4&amp;rft.pages=627-639&amp;rft.date=2004-12&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A24738716%23id-name%3DS2CID&amp;rft_id=info%3Abibcode%2F2004Isis...95..627J&amp;rft_id=info%3Apmid%2F16011298&amp;rft_id=info%3Adoi%2F10.1086%2F430653&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F10.1086%2F430653%23id-name%3DJSTOR&amp;rft.aulast=Jerome&amp;rft.aufirst=Fred&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-170"><span class="mw-cite-backlink"><b><a href="#cite_ref-170">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFTobies2012" class="citation book cs1">Tobies, Renate (2012). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=EDm0eQqFUQ4C&amp;pg=PA116"><i>Iris Runge - A Life at the Crossroads of Mathematics, Science, and Industry</i></a>. Basel: Birkhèauser. p.&#160;116. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-3034802512" title="Special:BookSources/978-3034802512"><bdi>978-3034802512</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Iris+Runge+-+A+Life+at+the+Crossroads+of+Mathematics%2C+Science%2C+and+Industry&amp;rft.place=Basel&amp;rft.pages=116&amp;rft.pub=Birkh%C3%A8auser&amp;rft.date=2012&amp;rft.isbn=978-3034802512&amp;rft.aulast=Tobies&amp;rft.aufirst=Renate&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DEDm0eQqFUQ4C%26pg%3DPA116&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-171"><span class="mw-cite-backlink"><b><a href="#cite_ref-171">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGimbel2015" class="citation book cs1">Gimbel, Steven (2015). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=HvTOBwAAQBAJ&amp;pg=PA111"><i>Einstein - His Space and Times</i></a>. New Haven: Yale University Press. p.&#160;111. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0300196719" title="Special:BookSources/978-0300196719"><bdi>978-0300196719</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+-+His+Space+and+Times&amp;rft.place=New+Haven&amp;rft.pages=111&amp;rft.pub=Yale+University+Press&amp;rft.date=2015&amp;rft.isbn=978-0300196719&amp;rft.aulast=Gimbel&amp;rft.aufirst=Steven&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DHvTOBwAAQBAJ%26pg%3DPA111&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1949-172"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1949_172-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1949">Einstein (1949)</a>.</span>
</li>
<li id="cite_note-LXsUJ-173"><span class="mw-cite-backlink"><b><a href="#cite_ref-LXsUJ_173-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRoweSchulmann2007a" class="citation web cs1">Rowe, David E.; Schulmann, Robert (8 June 2007a). David A., Walsh (ed.). <a rel="nofollow" class="external text" href="http://hnn.us/articles/39445.html">"What Were Einstein\'s Politics?"</a>. <i><a href="/wiki/History_News_Network" title="History News Network">History News Network</a></i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190203065834/http://hnn.us/articles/39445.html">Archived</a> from the original on 3 February 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">29 July</span> 2012</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=History+News+Network&amp;rft.atitle=What+Were+Einstein%27s+Politics%3F&amp;rft.date=2007-06-08&amp;rft.aulast=Rowe&amp;rft.aufirst=David+E.&amp;rft.au=Schulmann%2C+Robert&amp;rft_id=http%3A%2F%2Fhnn.us%2Farticles%2F39445.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTERoweSchulmann2013&#91;httpsbooksgooglecombooksid_X1dAAAAQBAJpg413_412,_413&#93;-174"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTERoweSchulmann2013[httpsbooksgooglecombooksid_X1dAAAAQBAJpg413_412,_413]_174-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFRoweSchulmann2013">Rowe &amp; Schulmann (2013)</a>, pp.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=_X1dAAAAQBAJ&amp;pg=413">412, 413</a>.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007487,_494,_550-175"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007487,_494,_550_175-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, pp.&#160;487, 494, 550.</span>
</li>
<li id="cite_note-176"><span class="mw-cite-backlink"><b><a href="#cite_ref-176">^</a></b></span> <span class="reference-text">Bulletin of the Atomic Scientists 4 (February 1948), No. 2 35–37: \'A Reply to the Soviet Scientists, December 1947\'</span>
</li>
<li id="cite_note-ixWWZ-177"><span class="mw-cite-backlink"><b><a href="#cite_ref-ixWWZ_177-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWaldrop2017" class="citation magazine cs1">Waldrop, Mitch (19 April 2017). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170526164434/http://news.nationalgeographic.com/2017/04/science-march-einstein-fbi-genius-science/">"Why the FBI Kept a 1,400-Page File on Einstein"</a>. <i>National Geographic</i>. Archived from <a rel="nofollow" class="external text" href="http://news.nationalgeographic.com/2017/04/science-march-einstein-fbi-genius-science/">the original</a> on 26 May 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">7 June</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=National+Geographic&amp;rft.atitle=Why+the+FBI+Kept+a+1%2C400-Page+File+on+Einstein&amp;rft.date=2017-04-19&amp;rft.aulast=Waldrop&amp;rft.aufirst=Mitch&amp;rft_id=http%3A%2F%2Fnews.nationalgeographic.com%2F2017%2F04%2Fscience-march-einstein-fbi-genius-science%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Albano-Müller-178"><span class="mw-cite-backlink"><b><a href="#cite_ref-Albano-Müller_178-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20120117104005/http://www.gandhiserve.org/streams/einstein.html">"Einstein on Gandhi (Einstein\'s letter to Gandhi&#160;&#8211;&#32; Courtesy:Saraswati Albano-Müller &amp; Notes by Einstein on Gandhi&#160;&#8211;&#32; Source: The Hebrew University of Jerusalem)"</a>. Gandhiserve.org. 18 October 1931. Archived from <a rel="nofollow" class="external text" href="http://www.gandhiserve.org/streams/einstein.html">the original</a> on 17 January 2012<span class="reference-accessdate">. Retrieved <span class="nowrap">24 January</span> 2012</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein+on+Gandhi+%28Einstein%27s+letter+to+Gandhi+%26ndash%3B%26%2332%3B+Courtesy%3ASaraswati+Albano-M%C3%BCller+%26+Notes+by+Einstein+on+Gandhi+%26ndash%3B%26%2332%3B+Source%3A+The+Hebrew+University+of+Jerusalem%29&amp;rft.pub=Gandhiserve.org&amp;rft.date=1931-10-18&amp;rft_id=http%3A%2F%2Fwww.gandhiserve.org%2Fstreams%2Feinstein.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-179"><span class="mw-cite-backlink"><b><a href="#cite_ref-179">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://streams.gandhiserve.org/einstein.html">"Einstein\'s letter and Gandhi\'s answer"</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20140609031152/http://streams.gandhiserve.org/einstein.html">Archived</a> from the original on 9 June 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">22 August</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein%27s+letter+and+Gandhi%27s+answer&amp;rft_id=http%3A%2F%2Fstreams.gandhiserve.org%2Feinstein.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>, gandhiserve.org</span>
</li>
<li id="cite_note-180"><span class="mw-cite-backlink"><b><a href="#cite_ref-180">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDennis_Overbye2005" class="citation news cs1">Dennis Overbye (25 January 2005). <a rel="nofollow" class="external text" href="https://www.nytimes.com/2005/01/25/science/brace-yourself-here-comes-einsteins-year.html">"Brace Yourself! Here Comes Einstein\'s Year"</a>. <i><a href="/wiki/The_New_York_Times" title="The New York Times">The New York Times</a></i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20201030232656/https://www.nytimes.com/2005/01/25/science/brace-yourself-here-comes-einsteins-year.html">Archived</a> from the original on 30 October 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">27 October</span> 2020</span>. <q>Hebrew University ... which he helped found</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Brace+Yourself%21+Here+Comes+Einstein%27s+Year&amp;rft.date=2005-01-25&amp;rft.au=Dennis+Overbye&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F2005%2F01%2F25%2Fscience%2Fbrace-yourself-here-comes-einsteins-year.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007290-181"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2007290_181-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;290.</span>
</li>
<li id="cite_note-FOOTNOTERoweSchulmann2007161-182"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTERoweSchulmann2007161_182-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFRoweSchulmann2007">Rowe &amp; Schulmann (2007)</a>, p.&#160;161.</span>
</li>
<li id="cite_note-FOOTNOTERoweSchulmann2007158-183"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTERoweSchulmann2007158_183-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFRoweSchulmann2007">Rowe &amp; Schulmann (2007)</a>, p.&#160;158.</span>
</li>
<li id="cite_note-184"><span class="mw-cite-backlink"><b><a href="#cite_ref-184">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinstein2013" class="citation book cs1">Einstein, Albert (10 November 2013). Rowe, David E.; Schulmann, Robert (eds.). <i>Einstein on Politics</i>. Princeton University Press. p.&#160;152. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0691160207" title="Special:BookSources/978-0691160207"><bdi>978-0691160207</bdi></a>. <q>I consider raising Jewish self-esteem essential, also in the interest of a natural coexistence with non-Jews. This was my major motive for joining the Zionist movement.</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+on+Politics&amp;rft.pages=152&amp;rft.pub=Princeton+University+Press&amp;rft.date=2013-11-10&amp;rft.isbn=978-0691160207&amp;rft.aulast=Einstein&amp;rft.aufirst=Albert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-:0-185"><span class="mw-cite-backlink">^ <a href="#cite_ref-:0_185-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-:0_185-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-:0_185-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFJerome2009" class="citation book cs1">Jerome, Fred (2009). <i>Einstein on Israel and Zionism</i> (1&#160;ed.). New York: St. Martin\'s Press. pp.&#160;156, 176, 182. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-312-36228-7" title="Special:BookSources/978-0-312-36228-7"><bdi>978-0-312-36228-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+on+Israel+and+Zionism&amp;rft.place=New+York&amp;rft.pages=156%2C+176%2C+182&amp;rft.edition=1&amp;rft.pub=St.+Martin%27s+Press&amp;rft.date=2009&amp;rft.isbn=978-0-312-36228-7&amp;rft.aulast=Jerome&amp;rft.aufirst=Fred&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Time-186"><span class="mw-cite-backlink"><b><a href="#cite_ref-Time_186-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation magazine cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20080518022224/http://www.time.com/time/magazine/article/0,9171,817454,00.html">"ISRAEL: Einstein Declines"</a>. <i><a href="/wiki/Time_(magazine)" title="Time (magazine)">Time</a></i>. 1 December 1952. Archived from <a rel="nofollow" class="external text" href="http://www.time.com/time/magazine/article/0,9171,817454,00.html">the original</a> on 18 May 2008<span class="reference-accessdate">. Retrieved <span class="nowrap">31 March</span> 2010</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Time&amp;rft.atitle=ISRAEL%3A+Einstein+Declines&amp;rft.date=1952-12-01&amp;rft_id=http%3A%2F%2Fwww.time.com%2Ftime%2Fmagazine%2Farticle%2F0%2C9171%2C817454%2C00.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Msb2q-187"><span class="mw-cite-backlink"><b><a href="#cite_ref-Msb2q_187-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRosenkranz2002" class="citation book cs1">Rosenkranz, Ze\'ev (6 November 2002). <i>The Einstein Scrapbook</i>. Baltimore, Maryland: <a href="/wiki/Johns_Hopkins_University_Press" title="Johns Hopkins University Press">Johns Hopkins University Press</a>. p.&#160;103. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-8018-7203-7" title="Special:BookSources/978-0-8018-7203-7"><bdi>978-0-8018-7203-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Einstein+Scrapbook&amp;rft.place=Baltimore%2C+Maryland&amp;rft.pages=103&amp;rft.pub=Johns+Hopkins+University+Press&amp;rft.date=2002-11-06&amp;rft.isbn=978-0-8018-7203-7&amp;rft.aulast=Rosenkranz&amp;rft.aufirst=Ze%27ev&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2007522-188"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEIsaacson2007522_188-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEIsaacson2007522_188-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFIsaacson2007">Isaacson (2007)</a>, p.&#160;522.</span>
</li>
<li id="cite_note-018QJ-189"><span class="mw-cite-backlink"><b><a href="#cite_ref-018QJ_189-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHitchens2007" class="citation book cs1"><a href="/wiki/Christopher_Hitchens" title="Christopher Hitchens">Hitchens, Christopher</a>, ed. (2007). "Selected Writings on Religion: Albert Einstein". <a href="/wiki/The_Portable_Atheist" title="The Portable Atheist"><i>The Portable Atheist: Essential Readings for the Nonbeliever</i></a>. Da Capo Press. p.&#160;155. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-306-81608-6" title="Special:BookSources/978-0-306-81608-6"><bdi>978-0-306-81608-6</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Selected+Writings+on+Religion%3A+Albert+Einstein&amp;rft.btitle=The+Portable+Atheist%3A+Essential+Readings+for+the+Nonbeliever&amp;rft.pages=155&amp;rft.pub=Da+Capo+Press&amp;rft.date=2007&amp;rft.isbn=978-0-306-81608-6&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2008&#91;httpsbooksgooglecombooksidG_iziBAPXtECpgPA325_325&#93;-190"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2008[httpsbooksgooglecombooksidG_iziBAPXtECpgPA325_325]_190-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2008">Isaacson (2008)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=G_iziBAPXtEC&amp;pg=PA325">325</a>.</span>
</li>
<li id="cite_note-FOOTNOTECalaprice2000218-191"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTECalaprice2000218_191-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTECalaprice2000218_191-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFCalaprice2000">Calaprice (2000)</a>, p.&#160;218.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2008&#91;httpsbooksgooglecombooksidcdxWNE7NY6QCpgPT390_390&#93;-192"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2008[httpsbooksgooglecombooksidcdxWNE7NY6QCpgPT390_390]_192-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2008">Isaacson (2008)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=cdxWNE7NY6QC&amp;pg=PT390">390</a>.</span>
</li>
<li id="cite_note-FOOTNOTECalaprice2010&#91;httpsbooksgooglecombooksidG_iziBAPXtECpgPA340_340&#93;-193"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTECalaprice2010[httpsbooksgooglecombooksidG_iziBAPXtECpgPA340_340]_193-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFCalaprice2010">Calaprice (2010)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=G_iziBAPXtEC&amp;pg=PA340">340</a>.</span>
</li>
<li id="cite_note-flickr2687-194"><span class="mw-cite-backlink"><b><a href="#cite_ref-flickr2687_194-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://farm3.static.flickr.com/2687/4496554935_0b573db853_o.jpg">"Letter to M. Berkowitz, 25 October 1950"</a><span class="reference-accessdate">. Retrieved <span class="nowrap">16 February</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Letter+to+M.+Berkowitz%2C+25+October+1950.&amp;rft_id=http%3A%2F%2Ffarm3.static.flickr.com%2F2687%2F4496554935_0b573db853_o.jpg&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> Einstein Archive 59–215.</span>
</li>
<li id="cite_note-FOOTNOTEIsaacson2008&#91;httpsbooksgooglecombooksidOzSJgdwk5esCpgPT461_461&#93;-195"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEIsaacson2008[httpsbooksgooglecombooksidOzSJgdwk5esCpgPT461_461]_195-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFIsaacson2008">Isaacson (2008)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=OzSJgdwk5esC&amp;pg=PT461">461</a>.</span>
</li>
<li id="cite_note-mKToJ-196"><span class="mw-cite-backlink"><b><a href="#cite_ref-mKToJ_196-0">^</a></b></span> <span class="reference-text">Dowbiggin, Ian (2003). <i>A Merciful End</i>. New York: Oxford University Press, <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDowbiggin2003" class="citation book cs1">Dowbiggin, Ian (9 January 2003). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=E1AKtIEIIvUC&amp;pg=PA41"><i>p. 41</i></a>. Oxford University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-19-803515-2" title="Special:BookSources/978-0-19-803515-2"><bdi>978-0-19-803515-2</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">26 March</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=p.+41.&amp;rft.pub=Oxford+University+Press&amp;rft.date=2003-01-09&amp;rft.isbn=978-0-19-803515-2&amp;rft.aulast=Dowbiggin&amp;rft.aufirst=Ian&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DE1AKtIEIIvUC%26pg%3DPA41&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1995&#91;httpsbooksgooglecombooksid9fJkBqwDD3sCpgPA62_62&#93;-197"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1995[httpsbooksgooglecombooksid9fJkBqwDD3sCpgPA62_62]_197-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1995">Einstein (1995)</a>, p.&#160;<a rel="nofollow" class="external text" href="https://books.google.com/books?id=9fJkBqwDD3sC&amp;pg=PA62">62</a>.</span>
</li>
<li id="cite_note-xI99y-198"><span class="mw-cite-backlink"><b><a href="#cite_ref-xI99y_198-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDvorsky2012" class="citation web cs1">Dvorsky, George (23 October 2012). <a rel="nofollow" class="external text" href="http://io9.com/5954119/einsteins-i-dont-believe-in-god-letter-has-sold-on-ebay--and-youre-not-going-to-believe-the-price">"Einstein\'s \'I don\'t believe in God\' letter has sold on eBay..."</a> <i>io9</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20151209103816/http://io9.com/5954119/einsteins-i-dont-believe-in-god-letter-has-sold-on-ebay--and-youre-not-going-to-believe-the-price">Archived</a> from the original on 9 December 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">23 April</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=io9&amp;rft.atitle=Einstein%27s+%27I+don%27t+believe+in+God%27+letter+has+sold+on+eBay...&amp;rft.date=2012-10-23&amp;rft.aulast=Dvorsky&amp;rft.aufirst=George&amp;rft_id=http%3A%2F%2Fio9.com%2F5954119%2Feinsteins-i-dont-believe-in-god-letter-has-sold-on-ebay--and-youre-not-going-to-believe-the-price&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-199"><span class="mw-cite-backlink"><b><a href="#cite_ref-199">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://ivu.org/history/northam20a/einstein.html">"Albert Einstein (1879–1955)"</a>. International Vegetarian Union.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein+%281879%E2%80%931955%29&amp;rft.pub=International+Vegetarian+Union&amp;rft_id=https%3A%2F%2Fivu.org%2Fhistory%2Fnortham20a%2Feinstein.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-200"><span class="mw-cite-backlink"><b><a href="#cite_ref-200">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://aretheyvegan.com/alberteinstein/">"Was Albert Einstein vegan?"</a>. <i>AreTheyVegan.com</i>. 27 March 2020.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=AreTheyVegan.com&amp;rft.atitle=Was+Albert+Einstein+vegan%3F&amp;rft.date=2020-03-27&amp;rft_id=https%3A%2F%2Faretheyvegan.com%2Falberteinstein%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-BQH5A-201"><span class="mw-cite-backlink"><b><a href="#cite_ref-BQH5A_201-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDuchen,_Jessica2011" class="citation news cs1">Duchen, Jessica (28 January 2011). <a rel="nofollow" class="external text" href="https://www.independent.co.uk/arts-entertainment/classical/features/the-relative-beauty-of-the-violin-2196313.html">"The relative beauty of the violin"</a>. <i><a href="/wiki/The_Independent" title="The Independent">The Independent</a></i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200722171721/https://www.independent.co.uk/arts-entertainment/classical/features/the-relative-beauty-of-the-violin-2196313.html">Archived</a> from the original on 22 July 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">23 August</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Independent&amp;rft.atitle=The+relative+beauty+of+the+violin&amp;rft.date=2011-01-28&amp;rft.au=Duchen%2C+Jessica&amp;rft_id=https%3A%2F%2Fwww.independent.co.uk%2Farts-entertainment%2Fclassical%2Ffeatures%2Fthe-relative-beauty-of-the-violin-2196313.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-aBOjz-202"><span class="mw-cite-backlink"><b><a href="#cite_ref-aBOjz_202-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20150828225916/http://www.pha.jhu.edu/einstein/stuff/einstein%26music.pdf">"Einstein and his love of music"</a> <span class="cs1-format">(PDF)</span>. <a href="/wiki/Physics_World" title="Physics World">Physics World</a>. January 2005. Archived from <a rel="nofollow" class="external text" href="http://www.pha.jhu.edu/einstein/stuff/einstein&amp;music.pdf">the original</a> <span class="cs1-format">(PDF)</span> on 28 August 2015.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=Einstein+and+his+love+of+music&amp;rft.date=2005-01&amp;rft_id=http%3A%2F%2Fwww.pha.jhu.edu%2Feinstein%2Fstuff%2Feinstein%26music.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Botstein-203"><span class="mw-cite-backlink">^ <a href="#cite_ref-Botstein_203-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Botstein_203-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-Botstein_203-2"><sup><i><b>c</b></i></sup></a> <a href="#cite_ref-Botstein_203-3"><sup><i><b>d</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPeter_GalisonGerald_James_HoltonSilvan_S._Schweber2008" class="citation book cs1"><a href="/wiki/Peter_Galison" title="Peter Galison">Peter Galison</a>; <a href="/wiki/Gerald_Holton" title="Gerald Holton">Gerald James Holton</a>; <a href="/wiki/Silvan_S._Schweber" title="Silvan S. Schweber">Silvan S. Schweber</a> (2008). <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://archive.org/details/einsteinforstcen00gali"><i>Einstein for the 21st Century: His Legacy in Science, Art, and Modern Culture</i></a></span>. Princeton University Press. pp.&#160;<a rel="nofollow" class="external text" href="https://archive.org/details/einsteinforstcen00gali/page/n181">161</a>–164. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-13520-5" title="Special:BookSources/978-0-691-13520-5"><bdi>978-0-691-13520-5</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+for+the+21st+Century%3A+His+Legacy+in+Science%2C+Art%2C+and+Modern+Culture&amp;rft.pages=161-164&amp;rft.pub=Princeton+University+Press&amp;rft.date=2008&amp;rft.isbn=978-0-691-13520-5&amp;rft.au=Peter+Galison&amp;rft.au=Gerald+James+Holton&amp;rft.au=Silvan+S.+Schweber&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinsteinforstcen00gali&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-kGuWC-204"><span class="mw-cite-backlink"><b><a href="#cite_ref-kGuWC_204-0">^</a></b></span> <span class="reference-text">Article "Alfred Einstein", in <i><a href="/wiki/The_New_Grove_Dictionary_of_Music_and_Musicians" title="The New Grove Dictionary of Music and Musicians">The New Grove Dictionary of Music and Musicians</a></i>, ed. <a href="/wiki/Stanley_Sadie" title="Stanley Sadie">Stanley Sadie</a>. 20 vol. London, Macmillan Publishers Ltd., 1980. <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-56159-174-9" title="Special:BookSources/978-1-56159-174-9">978-1-56159-174-9</a></span>
</li>
<li id="cite_note-OIn6p-205"><span class="mw-cite-backlink"><b><a href="#cite_ref-OIn6p_205-0">^</a></b></span> <span class="reference-text"><i>The Concise Edition of <a href="/wiki/Baker%27s_Biographical_Dictionary_of_Musicians" title="Baker&#39;s Biographical Dictionary of Musicians">Baker\'s Biographical Dictionary of Musicians</a></i>, 8th ed. Revised by <a href="/wiki/Nicolas_Slonimsky" title="Nicolas Slonimsky">Nicolas Slonimsky</a>. New York, Schirmer Books, 1993. <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-02-872416-4" title="Special:BookSources/978-0-02-872416-4">978-0-02-872416-4</a></span>
</li>
<li id="cite_note-Times-206"><span class="mw-cite-backlink"><b><a href="#cite_ref-Times_206-0">^</a></b></span> <span class="reference-text"><a rel="nofollow" class="external text" href="https://articles.latimes.com/1985-12-22/entertainment/ca-20526_1_life-estate">Cariaga, Daniel, "Not Taking It with You: A Tale of Two Estates", <i>Los Angeles Times</i></a> <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190121200008/http://articles.latimes.com/1985-12-22/entertainment/ca-20526_1_life-estate">Archived</a> 21 January 2019 at the <a href="/wiki/Wayback_Machine" title="Wayback Machine">Wayback Machine</a>, 22 December 1985. Retrieved April 2012.</span>
</li>
<li id="cite_note-RR-207"><span class="mw-cite-backlink"><b><a href="#cite_ref-RR_207-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.rrauction.com/albert_einstein_signed_photo_to_joseph_zoellner.cfm">"Relaxed Einstein signs for a fellow violinist before sailing to Germany for the last time"</a>. <i>RR Auction</i>. 2010. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20130524160226/http://www.rrauction.com/albert_einstein_signed_photo_to_joseph_zoellner.cfm">Archived</a> from the original on 24 May 2013<span class="reference-accessdate">. Retrieved <span class="nowrap">6 June</span> 2012</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=RR+Auction&amp;rft.atitle=Relaxed+Einstein+signs+for+a+fellow+violinist+before+sailing+to+Germany+for+the+last+time&amp;rft.date=2010&amp;rft_id=http%3A%2F%2Fwww.rrauction.com%2Falbert_einstein_signed_photo_to_joseph_zoellner.cfm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-BXLfp-208"><span class="mw-cite-backlink"><b><a href="#cite_ref-BXLfp_208-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.medscape.com/viewarticle/436253">"The Case of the Scientist with a Pulsating Mass"</a>. <i><a href="/wiki/Medscape" title="Medscape">Medscape</a></i>. 14 June 2002. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20090708043220/http://www.medscape.com/viewarticle/436253">Archived</a> from the original on 8 July 2009<span class="reference-accessdate">. Retrieved <span class="nowrap">11 June</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Medscape&amp;rft.atitle=The+Case+of+the+Scientist+with+a+Pulsating+Mass&amp;rft.date=2002-06-14&amp;rft_id=http%3A%2F%2Fwww.medscape.com%2Fviewarticle%2F436253&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-QN45b-209"><span class="mw-cite-backlink"><b><a href="#cite_ref-QN45b_209-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFAlbert_Einstein_Archives1955" class="citation web cs1">Albert Einstein Archives (April 1955). <a rel="nofollow" class="external text" href="http://alberteinstein.info/vufind1/Digital/EAR000020078#page/1/mode/1up">"Draft of projected Telecast Israel Independence Day, April 1955 (last statement ever written)"</a>. Einstein Archives Online. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20070313231657/http://www.alberteinstein.info/">Archived</a> from the original on 13 March 2007<span class="reference-accessdate">. Retrieved <span class="nowrap">14 March</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Draft+of+projected+Telecast+Israel+Independence+Day%2C+April+1955+%28last+statement+ever+written%29&amp;rft.pub=Einstein+Archives+Online&amp;rft.date=1955-04&amp;rft.au=Albert+Einstein+Archives&amp;rft_id=http%3A%2F%2Falberteinstein.info%2Fvufind1%2FDigital%2FEAR000020078%23page%2F1%2Fmode%2F1up&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-BhiNM-210"><span class="mw-cite-backlink"><b><a href="#cite_ref-BhiNM_210-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCohen,_J._R.Graver,_L._M.1995" class="citation journal cs1">Cohen, J. R.; Graver, L. M. (November 1995). "The ruptured abdominal aortic aneurysm of Albert Einstein". <i>Surgery, Gynecology &amp; Obstetrics</i>. <b>170</b> (5): 455–458. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/2183375">2183375</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Surgery%2C+Gynecology+%26+Obstetrics&amp;rft.atitle=The+ruptured+abdominal+aortic+aneurysm+of+Albert+Einstein&amp;rft.volume=170&amp;rft.issue=5&amp;rft.pages=455-458&amp;rft.date=1995-11&amp;rft_id=info%3Apmid%2F2183375&amp;rft.au=Cohen%2C+J.+R.&amp;rft.au=Graver%2C+L.+M.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-YUhsl-211"><span class="mw-cite-backlink"><b><a href="#cite_ref-YUhsl_211-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCosgrove,_Ben2014" class="citation magazine cs1">Cosgrove, Ben (14 March 2014). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20141112114029/http://time.com/3494553/the-day-albert-einstein-died-a-photographers-story/">"The Day Albert Einstein Died: A Photographer\'s Story"</a>. <i><a href="/wiki/Time_(magazine)" title="Time (magazine)">Time</a></i>. Archived from <a rel="nofollow" class="external text" href="http://time.com/3494553/the-day-albert-einstein-died-a-photographers-story/">the original</a> on 12 November 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">24 April</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Time&amp;rft.atitle=The+Day+Albert+Einstein+Died%3A+A+Photographer%27s+Story&amp;rft.date=2014-03-14&amp;rft.au=Cosgrove%2C+Ben&amp;rft_id=http%3A%2F%2Ftime.com%2F3494553%2Fthe-day-albert-einstein-died-a-photographers-story%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-MqyYW-212"><span class="mw-cite-backlink"><b><a href="#cite_ref-MqyYW_212-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="https://www.npr.org/templates/story/story.php?storyId=4602913">"The Long, Strange Journey of Einstein\'s Brain"</a>. <a href="/wiki/NPR" title="NPR">NPR</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190714011830/https://www.npr.org/templates/story/story.php?storyId=4602913">Archived</a> from the original on 14 July 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">3 October</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.atitle=The+Long%2C+Strange+Journey+of+Einstein%27s+Brain&amp;rft_id=https%3A%2F%2Fwww.npr.org%2Ftemplates%2Fstory%2Fstory.php%3FstoryId%3D4602913&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-213"><span class="mw-cite-backlink"><b><a href="#cite_ref-213">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCosgroveMorse2014" class="citation magazine cs1">Cosgrove, Benjamin; Morse, Ralph (14 March 2014). <a rel="nofollow" class="external text" href="https://www.life.com/history/the-day-albert-einstein-died-a-photographers-story/">"The Day Albert Einstein Died: A Photographer\'s Story"</a>. <i><a href="/wiki/Life_(magazine)" title="Life (magazine)">Life</a></i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210319004714/https://www.life.com/history/the-day-albert-einstein-died-a-photographers-story/">Archived</a> from the original on 19 March 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">10 March</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Life&amp;rft.atitle=The+Day+Albert+Einstein+Died%3A+A+Photographer%27s+Story&amp;rft.date=2014-03-14&amp;rft.aulast=Cosgrove&amp;rft.aufirst=Benjamin&amp;rft.au=Morse%2C+Ralph&amp;rft_id=https%3A%2F%2Fwww.life.com%2Fhistory%2Fthe-day-albert-einstein-died-a-photographers-story%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-GQrBZ-214"><span class="mw-cite-backlink"><b><a href="#cite_ref-GQrBZ_214-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFO&#39;ConnorRobertson1997" class="citation book cs1">O\'Connor, J. J.; Robertson, E.F. (1997). <a rel="nofollow" class="external text" href="http://www-history.mcs.st-andrews.ac.uk/Biographies/Einstein.html">"Albert Einstein"</a>. <i>The MacTutor History of Mathematics archive</i>. School of Mathematics and Statistics, University of St. Andrews. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20070213223549/http://www-history.mcs.st-andrews.ac.uk/Biographies/Einstein.html">Archived</a> from the original on 13 February 2007<span class="reference-accessdate">. Retrieved <span class="nowrap">11 March</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Albert+Einstein&amp;rft.btitle=The+MacTutor+History+of+Mathematics+archive&amp;rft.pub=School+of+Mathematics+and+Statistics%2C+University+of+St.+Andrews&amp;rft.date=1997&amp;rft.aulast=O%27Connor&amp;rft.aufirst=J.+J.&amp;rft.au=Robertson%2C+E.F.&amp;rft_id=http%3A%2F%2Fwww-history.mcs.st-andrews.ac.uk%2FBiographies%2FEinstein.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Obit-215"><span class="mw-cite-backlink"><b><a href="#cite_ref-Obit_215-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLate_City1955" class="citation news cs1 cs1-prop-location-test">Late City, ed. (18 April 1955).  Written at Princeton, NJ. <a rel="nofollow" class="external text" href="http://select.nytimes.com/gst/abstract.html?res=F60C1EFC3D55107A93CBA8178FD85F418585F9">"Dr. Albert Einstein Dies in Sleep at 76; World Mourns Loss of Great Scientist, Rupture of Aorta Causes Death, Body Cremated, Memorial Here Set"</a>. <i>The New York Times</i>. Vol.&#160;CIV, no.&#160;35, 514. New York (published 19 April 1955). p.&#160;1. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0362-4331">0362-4331</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20140525200758/http://select.nytimes.com/gst/abstract.html?res=F60C1EFC3D55107A93CBA8178FD85F418585F9">Archived</a> from the original on 25 May 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">24 May</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Dr.+Albert+Einstein+Dies+in+Sleep+at+76%3B+World+Mourns+Loss+of+Great+Scientist%2C+Rupture+of+Aorta+Causes+Death%2C+Body+Cremated%2C+Memorial+Here+Set&amp;rft.volume=CIV&amp;rft.issue=35%2C+514&amp;rft.pages=1&amp;rft.date=1955-04-18&amp;rft.issn=0362-4331&amp;rft_id=http%3A%2F%2Fselect.nytimes.com%2Fgst%2Fabstract.html%3Fres%3DF60C1EFC3D55107A93CBA8178FD85F418585F9&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-aJHxn-216"><span class="mw-cite-backlink"><b><a href="#cite_ref-aJHxn_216-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFOppenheimer1979" class="citation journal cs1"><a href="/wiki/J._Robert_Oppenheimer" title="J. Robert Oppenheimer">Oppenheimer, J. Robert</a> (March 1979). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=7goAAAAAMBAJ&amp;pg=PA38">"Oppenheimer on Einstein"</a>. <i><a href="/wiki/Bulletin_of_the_Atomic_Scientists" title="Bulletin of the Atomic Scientists">Bulletin of the Atomic Scientists</a></i>. <b>35</b> (3): 38. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1979BuAtS..35c..36O">1979BuAtS..35c..36O</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1080%2F00963402.1979.11458597">10.1080/00963402.1979.11458597</a><span class="reference-accessdate">. Retrieved <span class="nowrap">12 January</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Bulletin+of+the+Atomic+Scientists&amp;rft.atitle=Oppenheimer+on+Einstein&amp;rft.volume=35&amp;rft.issue=3&amp;rft.pages=38&amp;rft.date=1979-03&amp;rft_id=info%3Adoi%2F10.1080%2F00963402.1979.11458597&amp;rft_id=info%3Abibcode%2F1979BuAtS..35c..36O&amp;rft.aulast=Oppenheimer&amp;rft.aufirst=J.+Robert&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3D7goAAAAAMBAJ%26pg%3DPA38&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-217"><span class="mw-cite-backlink"><b><a href="#cite_ref-217">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFUnna2007" class="citation news cs1">Unna, Issachar (22 June 2007). <a rel="nofollow" class="external text" href="https://www.haaretz.com/1.4945718">"An Ongoing Power of Attraction"</a>. <i><a href="/wiki/Haaretz" title="Haaretz">Haaretz</a></i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210616043403/https://www.haaretz.com/1.4945718">Archived</a> from the original on 16 June 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">15 June</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Haaretz&amp;rft.atitle=An+Ongoing+Power+of+Attraction&amp;rft.date=2007-06-22&amp;rft.aulast=Unna&amp;rft.aufirst=Issachar&amp;rft_id=https%3A%2F%2Fwww.haaretz.com%2F1.4945718&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Paul_Arthur_Schilpp,_editor_1951_730–746-218"><span class="mw-cite-backlink">^ <a href="#cite_ref-Paul_Arthur_Schilpp,_editor_1951_730–746_218-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Paul_Arthur_Schilpp,_editor_1951_730–746_218-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPaul_Arthur_Schilpp1951" class="citation book cs1">Paul Arthur Schilpp, ed. (1951). <i>Albert Einstein: Philosopher-Scientist</i>. Vol.&#160;II. New York: Harper and Brothers Publishers (Harper Torchbook edition). pp.&#160;730–746.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein%3A+Philosopher-Scientist&amp;rft.place=New+York&amp;rft.pages=730-746&amp;rft.pub=Harper+and+Brothers+Publishers+%28Harper+Torchbook+edition%29&amp;rft.date=1951&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>. His non-scientific works include: <i>About Zionism: Speeches and Lectures by Professor Albert Einstein</i> (1930), "Why War?" (1933, co-authored by <a href="/wiki/Sigmund_Freud" title="Sigmund Freud">Sigmund Freud</a>), <i>The World As I See It</i> (1934), <i>Out of My Later Years</i> (1950), and a book on science for the general reader, <i><a href="/wiki/The_Evolution_of_Physics" title="The Evolution of Physics">The Evolution of Physics</a></i> (1938, co-authored by <a href="/wiki/Leopold_Infeld" title="Leopold Infeld">Leopold Infeld</a>).</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008-219"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008_219-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>.</span>
</li>
<li id="cite_note-NYT-20141204-DB-220"><span class="mw-cite-backlink"><b><a href="#cite_ref-NYT-20141204-DB_220-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFOverbye2014" class="citation news cs1"><a href="/wiki/Dennis_Overbye" title="Dennis Overbye">Overbye, Dennis</a> (4 December 2014). <a rel="nofollow" class="external text" href="https://ghostarchive.org/archive/20220101/https://www.nytimes.com/2014/12/05/science/huge-trove-of-albert-einstein-documents-becomes-available-online.html">"Thousands of Einstein Documents Are Now a Click Away"</a>. <i>The New York Times</i>. Archived from <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://www.nytimes.com/2014/12/05/science/huge-trove-of-albert-einstein-documents-becomes-available-online.html">the original</a></span> on 1 January 2022<span class="reference-accessdate">. Retrieved <span class="nowrap">4 January</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Thousands+of+Einstein+Documents+Are+Now+a+Click+Away&amp;rft.date=2014-12-04&amp;rft.aulast=Overbye&amp;rft.aufirst=Dennis&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F2014%2F12%2F05%2Fscience%2Fhuge-trove-of-albert-einstein-documents-becomes-available-online.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Instituut-Lorentz-221"><span class="mw-cite-backlink">^ <a href="#cite_ref-Instituut-Lorentz_221-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Instituut-Lorentz_221-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text">"<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://www.lorentz.leidenuniv.nl/history/Einstein_archive/">"Einstein archive at the Instituut-Lorentz"</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20150519023226/http://www.lorentz.leidenuniv.nl/history/Einstein_archive/">Archived</a> from the original on 19 May 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">21 August</span> 2005</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein+archive+at+the+Instituut-Lorentz&amp;rft_id=http%3A%2F%2Fwww.lorentz.leidenuniv.nl%2Fhistory%2FEinstein_archive%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>". <i>Instituut-Lorentz</i>. 2005. Retrieved 21 November 2005.</span>
</li>
<li id="cite_note-e5xd8-222"><span class="mw-cite-backlink"><b><a href="#cite_ref-e5xd8_222-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPietrow2019" class="citation journal cs1">Pietrow, Alexander G.M. (2019). "Investigations into the origin of Einstein\'s Sink". <i>Studium</i>. <b>11</b> (4): 260–268. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1905.09022">1905.09022</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2019Studi..11E...1P">2019Studi..11E...1P</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.18352%2Fstudium.10183">10.18352/studium.10183</a> (inactive 31 January 2024). <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:162168640">162168640</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Studium&amp;rft.atitle=Investigations+into+the+origin+of+Einstein%27s+Sink&amp;rft.volume=11&amp;rft.issue=4&amp;rft.pages=260-268&amp;rft.date=2019&amp;rft_id=info%3Aarxiv%2F1905.09022&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A162168640%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.18352%2Fstudium.10183&amp;rft_id=info%3Abibcode%2F2019Studi..11E...1P&amp;rft.aulast=Pietrow&amp;rft.aufirst=Alexander+G.M.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span><span class="cs1-maint citation-comment"><code class="cs1-code">{{<a href="/wiki/Template:Cite_journal" title="Template:Cite journal">cite journal</a>}}</code>:  CS1 maint: DOI inactive as of January 2024 (<a href="/wiki/Category:CS1_maint:_DOI_inactive_as_of_January_2024" title="Category:CS1 maint: DOI inactive as of January 2024">link</a>)</span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1905a-223"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEEinstein1905a_223-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEEinstein1905a_223-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-FOOTNOTEEinstein1905a_223-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFEinstein1905a">Einstein (1905a)</a>.</span>
</li>
<li id="cite_note-1Jhcb-224"><span class="mw-cite-backlink"><b><a href="#cite_ref-1Jhcb_224-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDas2003" class="citation book cs1">Das, Ashok (2003). <i>Lectures on quantum mechanics</i>. Hindustan Book Agency. p.&#160;59. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-81-85931-41-8" title="Special:BookSources/978-81-85931-41-8"><bdi>978-81-85931-41-8</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Lectures+on+quantum+mechanics&amp;rft.pages=59&amp;rft.pub=Hindustan+Book+Agency&amp;rft.date=2003&amp;rft.isbn=978-81-85931-41-8&amp;rft.aulast=Das&amp;rft.aufirst=Ashok&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-oJBvd-225"><span class="mw-cite-backlink"><b><a href="#cite_ref-oJBvd_225-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFSpielbergAnderson1995" class="citation book cs1">Spielberg, Nathan; Anderson, Bryon D. (1995). <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://archive.org/details/sevenideasthatsh00spie_874"><i>Seven ideas that shook the universe</i></a></span> (2nd&#160;ed.). John Wiley &amp; Sons. p.&#160;<a rel="nofollow" class="external text" href="https://archive.org/details/sevenideasthatsh00spie_874/page/n276">263</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-471-30606-1" title="Special:BookSources/978-0-471-30606-1"><bdi>978-0-471-30606-1</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Seven+ideas+that+shook+the+universe&amp;rft.pages=263&amp;rft.edition=2nd&amp;rft.pub=John+Wiley+%26+Sons&amp;rft.date=1995&amp;rft.isbn=978-0-471-30606-1&amp;rft.aulast=Spielberg&amp;rft.aufirst=Nathan&amp;rft.au=Anderson%2C+Bryon+D.&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Fsevenideasthatsh00spie_874&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1905c-226"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1905c_226-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1905c">Einstein (1905c)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1905d-227"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEEinstein1905d_227-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEEinstein1905d_227-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFEinstein1905d">Einstein (1905d)</a>.</span>
</li>
<li id="cite_note-RhZ8x-228"><span class="mw-cite-backlink"><b><a href="#cite_ref-RhZ8x_228-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMajor2007" class="citation book cs1">Major, Fouad G. (2007). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=tmdr6Wx_2PYC"><i>The quantum beat: principles and applications of atomic clocks</i></a> (2nd&#160;ed.). Springer. p.&#160;142. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-387-69533-4" title="Special:BookSources/978-0-387-69533-4"><bdi>978-0-387-69533-4</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">18 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+quantum+beat%3A+principles+and+applications+of+atomic+clocks&amp;rft.pages=142&amp;rft.edition=2nd&amp;rft.pub=Springer&amp;rft.date=2007&amp;rft.isbn=978-0-387-69533-4&amp;rft.aulast=Major&amp;rft.aufirst=Fouad+G.&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3Dtmdr6Wx_2PYC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-lhfJ9-229"><span class="mw-cite-backlink"><b><a href="#cite_ref-lhfJ9_229-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLindsayMargenau1981" class="citation book cs1">Lindsay, Robert Bruce; Margenau, Henry (1981). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=dwZltQAACAAJ"><i>Foundations of physics</i></a>. Ox Bow Press. p.&#160;330. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-918024-17-6" title="Special:BookSources/978-0-918024-17-6"><bdi>978-0-918024-17-6</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">18 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Foundations+of+physics&amp;rft.pages=330&amp;rft.pub=Ox+Bow+Press&amp;rft.date=1981&amp;rft.isbn=978-0-918024-17-6&amp;rft.aulast=Lindsay&amp;rft.aufirst=Robert+Bruce&amp;rft.au=Margenau%2C+Henry&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DdwZltQAACAAJ&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1905e-230"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1905e_230-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1905e">Einstein (1905e)</a>.</span>
</li>
<li id="cite_note-PubList-231"><span class="mw-cite-backlink">^ <a href="#cite_ref-PubList_231-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-PubList_231-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFKuepper" class="citation web cs1">Kuepper, Hans-Josef. <a rel="nofollow" class="external text" href="http://www.einstein-website.de/z_physics/wisspub-e.html">"List of Scientific Publications of Albert Einstein"</a>. Einstein-website.de. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20130508071317/http://www.einstein-website.de/z_physics/wisspub-e.html">Archived</a> from the original on 8 May 2013<span class="reference-accessdate">. Retrieved <span class="nowrap">3 April</span> 2011</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=List+of+Scientific+Publications+of+Albert+Einstein&amp;rft.pub=Einstein-website.de&amp;rft.aulast=Kuepper&amp;rft.aufirst=Hans-Josef&amp;rft_id=http%3A%2F%2Fwww.einstein-website.de%2Fz_physics%2Fwisspub-e.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-L2N73-232"><span class="mw-cite-backlink"><b><a href="#cite_ref-L2N73_232-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLevenson" class="citation web cs1">Levenson, Thomas. <a rel="nofollow" class="external text" href="https://www.pbs.org/wgbh/nova/einstein/genius/">"Genius Among Geniuses"</a>. <i>Einstein\'s Big Idea</i>. Boston: WBGH. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20181106193928/https://www.pbs.org/wgbh/nova/einstein/genius/">Archived</a> from the original on 6 November 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">20 June</span> 2015</span> &#8211; via NOVA by <a href="/wiki/Public_Broadcasting_Service" class="mw-redirect" title="Public Broadcasting Service">Public Broadcasting Service</a> (PBS).</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Einstein%27s+Big+Idea&amp;rft.atitle=Genius+Among+Geniuses&amp;rft.aulast=Levenson&amp;rft.aufirst=Thomas&amp;rft_id=https%3A%2F%2Fwww.pbs.org%2Fwgbh%2Fnova%2Feinstein%2Fgenius%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEFölsing1997178–198-233"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFölsing1997178–198_233-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFölsing1997">Fölsing (1997)</a>, pp.&#160;178–198.</span>
</li>
<li id="cite_note-FOOTNOTEStachel2002vi,_15,_90,_131,_&#91;httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA215_215&#93;-235"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel2002vi,_15,_90,_131,_[httpsbooksgooglecombooksidOAsQ_hFjhrACpgPA215_215]_235-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel2002">Stachel (2002)</a>, pp.&#160;vi, 15, 90, 131, <a rel="nofollow" class="external text" href="https://books.google.com/books?id=OAsQ_hFjhrAC&amp;pg=PA215">215</a>.</span>
</li>
<li id="cite_note-FOOTNOTEPais1982382–386-237"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais1982382–386_237-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1982">Pais (1982)</a>, pp.&#160;382–386.</span>
</li>
<li id="cite_note-FOOTNOTEPais1982151–152-238"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais1982151–152_238-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1982">Pais (1982)</a>, pp.&#160;151–152.</span>
</li>
<li id="cite_note-239"><span class="mw-cite-backlink"><b><a href="#cite_ref-239">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFraknoi2022" class="citation book cs1">Fraknoi, Andrew; et&#160;al. (2022). <a rel="nofollow" class="external text" href="https://openstax.org/details/books/astronomy-2e"><i>Astronomy 2e</i></a> (2e&#160;ed.). OpenStax. pp.&#160;800–815. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-951693-50-3" title="Special:BookSources/978-1-951693-50-3"><bdi>978-1-951693-50-3</bdi></a>. <a href="/wiki/OCLC_(identifier)" class="mw-redirect" title="OCLC (identifier)">OCLC</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/oclc/1322188620">1322188620</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Astronomy+2e&amp;rft.pages=800-815&amp;rft.edition=2e&amp;rft.pub=OpenStax&amp;rft.date=2022&amp;rft_id=info%3Aoclcnum%2F1322188620&amp;rft.isbn=978-1-951693-50-3&amp;rft.aulast=Fraknoi&amp;rft.aufirst=Andrew&amp;rft_id=https%3A%2F%2Fopenstax.org%2Fdetails%2Fbooks%2Fastronomy-2e&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1923-240"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1923_240-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1923">Einstein (1923)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEPais1982179–183-241"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais1982179–183_241-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1982">Pais (1982)</a>, pp.&#160;179–183.</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008273–274vol._2:_The_Swiss_Years:_Writings,_1900–1909-242"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008273–274vol._2:_The_Swiss_Years:_Writings,_1900–1909_242-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>, pp.&#160;273–274, vol. 2: The Swiss Years: Writings, 1900–1909.</span>
</li>
<li id="cite_note-FOOTNOTEPais1982194–195-243"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais1982194–195_243-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1982">Pais (1982)</a>, pp.&#160;194–195.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1916-244"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1916_244-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1916">Einstein (1916)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1918-245"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1918_245-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1918">Einstein (1918)</a>.</span>
</li>
<li id="cite_note-natgeo-246"><span class="mw-cite-backlink">^ <a href="#cite_ref-natgeo_246-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-natgeo_246-1"><sup><i><b>b</b></i></sup></a> <a href="#cite_ref-natgeo_246-2"><sup><i><b>c</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNadia_Drake2016" class="citation news cs1"><a href="/wiki/Nadia_Drake" title="Nadia Drake">Nadia Drake</a> (11 February 2016). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20160212083049/http://news.nationalgeographic.com/2016/02/160211-gravitational-waves-found-spacetime-science/">"Found! Gravitational Waves, or a Wrinkle in Spacetime"</a>. <i>National Geographic</i>. Archived from <a rel="nofollow" class="external text" href="http://news.nationalgeographic.com/2016/02/160211-gravitational-waves-found-spacetime-science/">the original</a> on 12 February 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">6 July</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=National+Geographic&amp;rft.atitle=Found%21+Gravitational+Waves%2C+or+a+Wrinkle+in+Spacetime&amp;rft.date=2016-02-11&amp;rft.au=Nadia+Drake&amp;rft_id=http%3A%2F%2Fnews.nationalgeographic.com%2F2016%2F02%2F160211-gravitational-waves-found-spacetime-science%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Tf1T0-247"><span class="mw-cite-backlink"><b><a href="#cite_ref-Tf1T0_247-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.nobelprize.org/nobel_prizes/physics/laureates/1993/press.html">"Gravity investigated with a binary pulsar-Press Release: The 1993 Nobel Prize in Physics"</a>. Nobel Foundation. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20180810182047/https://www.nobelprize.org/nobel_prizes/physics/laureates/1993/press.html">Archived</a> from the original on 10 August 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">6 July</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Gravity+investigated+with+a+binary+pulsar-Press+Release%3A+The+1993+Nobel+Prize+in+Physics&amp;rft.pub=Nobel+Foundation&amp;rft_id=https%3A%2F%2Fwww.nobelprize.org%2Fnobel_prizes%2Fphysics%2Flaureates%2F1993%2Fpress.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-PRL-20160211-248"><span class="mw-cite-backlink"><b><a href="#cite_ref-PRL-20160211_248-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFAbbott2016" class="citation journal cs1">Abbott, Benjamin P.; et&#160;al. (LIGO Scientific Collaboration and Virgo Collaboration) (2016). <a rel="nofollow" class="external text" href="https://www.ligo.caltech.edu/system/media_files/binaries/301/original/detection-science-summary.pdf">"Observation of Gravitational Waves from a Binary Black Hole Merger"</a> <span class="cs1-format">(PDF)</span>. <i><a href="/wiki/Phys._Rev._Lett." class="mw-redirect" title="Phys. Rev. Lett.">Phys. Rev. Lett.</a></i> <b>116</b> (6): 061102. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1602.03837">1602.03837</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2016PhRvL.116f1102A">2016PhRvL.116f1102A</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FPhysRevLett.116.061102">10.1103/PhysRevLett.116.061102</a>. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/26918975">26918975</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:124959784">124959784</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20160216132808/https://www.ligo.caltech.edu/system/media_files/binaries/301/original/detection-science-summary.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 16 February 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">6 July</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Phys.+Rev.+Lett.&amp;rft.atitle=Observation+of+Gravitational+Waves+from+a+Binary+Black+Hole+Merger&amp;rft.volume=116&amp;rft.issue=6&amp;rft.pages=061102&amp;rft.date=2016&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A124959784%23id-name%3DS2CID&amp;rft_id=info%3Abibcode%2F2016PhRvL.116f1102A&amp;rft_id=info%3Aarxiv%2F1602.03837&amp;rft_id=info%3Apmid%2F26918975&amp;rft_id=info%3Adoi%2F10.1103%2FPhysRevLett.116.061102&amp;rft.aulast=Abbott&amp;rft.aufirst=Benjamin+P.&amp;rft_id=https%3A%2F%2Fwww.ligo.caltech.edu%2Fsystem%2Fmedia_files%2Fbinaries%2F301%2Foriginal%2Fdetection-science-summary.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-CO6kH-249"><span class="mw-cite-backlink"><b><a href="#cite_ref-CO6kH_249-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://space.mit.edu/LIGO/more.html">"Gravitational Waves: Ripples in the fabric of space-time"</a>. LIGO | MIT. 11 February 2016. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20160219224900/http://space.mit.edu/LIGO/more.html">Archived</a> from the original on 19 February 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">12 February</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Gravitational+Waves%3A+Ripples+in+the+fabric+of+space-time&amp;rft.pub=LIGO+%7C+MIT&amp;rft.date=2016-02-11&amp;rft_id=http%3A%2F%2Fspace.mit.edu%2FLIGO%2Fmore.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-oSmHb-250"><span class="mw-cite-backlink"><b><a href="#cite_ref-oSmHb_250-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://news.mit.edu/2016/ligo-first-detection-gravitational-waves-0211">"Scientists make first direct detection of gravitational waves"</a>. <i>Jennifer Chu</i>. MIT News. 11 February 2016. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190407170726/http://news.mit.edu/2016/ligo-first-detection-gravitational-waves-0211">Archived</a> from the original on 7 April 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">12 February</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Jennifer+Chu&amp;rft.atitle=Scientists+make+first+direct+detection+of+gravitational+waves&amp;rft.date=2016-02-11&amp;rft_id=https%3A%2F%2Fnews.mit.edu%2F2016%2Fligo-first-detection-gravitational-waves-0211&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-hkKSp-251"><span class="mw-cite-backlink"><b><a href="#cite_ref-hkKSp_251-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGhosh2016" class="citation news cs1">Ghosh, Pallab (11 February 2016). <a rel="nofollow" class="external text" href="https://www.bbc.com/news/science-environment-35524440">"Einstein\'s gravitational waves \'seen\' from black holes"</a>. <i>BBC News</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20160211235836/https://www.bbc.com/news/science-environment-35524440">Archived</a> from the original on 11 February 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">12 February</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=BBC+News&amp;rft.atitle=Einstein%27s+gravitational+waves+%27seen%27+from+black+holes&amp;rft.date=2016-02-11&amp;rft.aulast=Ghosh&amp;rft.aufirst=Pallab&amp;rft_id=https%3A%2F%2Fwww.bbc.com%2Fnews%2Fscience-environment-35524440&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-38Msx-252"><span class="mw-cite-backlink"><b><a href="#cite_ref-38Msx_252-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFOverbye2016" class="citation news cs1">Overbye, Dennis (11 February 2016). <a rel="nofollow" class="external text" href="https://www.nytimes.com/2016/02/12/science/ligo-gravitational-waves-black-holes-einstein.html">"Gravitational Waves Detected, Confirming Einstein\'s Theory"</a>. <i>The New York Times</i>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0362-4331">0362-4331</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20160211165128/http://www.nytimes.com/2016/02/12/science/ligo-gravitational-waves-black-holes-einstein.html">Archived</a> from the original on 11 February 2016<span class="reference-accessdate">. Retrieved <span class="nowrap">12 February</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Gravitational+Waves+Detected%2C+Confirming+Einstein%27s+Theory&amp;rft.date=2016-02-11&amp;rft.issn=0362-4331&amp;rft.aulast=Overbye&amp;rft.aufirst=Dennis&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F2016%2F02%2F12%2Fscience%2Fligo-gravitational-waves-black-holes-einstein.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-253"><span class="mw-cite-backlink"><b><a href="#cite_ref-253">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNorton1984" class="citation journal cs1"><a href="/wiki/John_D._Norton" title="John D. Norton">Norton, John</a> (1984). <a rel="nofollow" class="external text" href="https://www.jstor.org/stable/27757535">"How Einstein Found His Field Equations: 1912–1915"</a>. <i>Historical Studies in the Physical Sciences</i>. <b>14</b> (2): 253–316. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.2307%2F27757535">10.2307/27757535</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0073-2672">0073-2672</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/27757535">27757535</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Historical+Studies+in+the+Physical+Sciences&amp;rft.atitle=How+Einstein+Found+His+Field+Equations%3A+1912%E2%80%931915&amp;rft.volume=14&amp;rft.issue=2&amp;rft.pages=253-316&amp;rft.date=1984&amp;rft.issn=0073-2672&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F27757535%23id-name%3DJSTOR&amp;rft_id=info%3Adoi%2F10.2307%2F27757535&amp;rft.aulast=Norton&amp;rft.aufirst=John&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F27757535&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-sOA9t-254"><span class="mw-cite-backlink"><b><a href="#cite_ref-sOA9t_254-0">^</a></b></span> <span class="reference-text">van Dongen, Jeroen (2010) <i>Einstein\'s Unification</i> Cambridge University Press, p. 23.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1917a-255"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1917a_255-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1917a">Einstein (1917a)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEPais1994285–286-256"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais1994285–286_256-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1994">Pais (1994)</a>, pp.&#160;285–286.</span>
</li>
<li id="cite_note-iJwuX-257"><span class="mw-cite-backlink"><b><a href="#cite_ref-iJwuX_257-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNorth1965" class="citation book cs1">North, J.D. (1965). <i>The Measure of the Universe: A History of Modern Cosmology</i>. New York: Dover. pp.&#160;81–83.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Measure+of+the+Universe%3A+A+History+of+Modern+Cosmology&amp;rft.place=New+York&amp;rft.pages=81-83&amp;rft.pub=Dover&amp;rft.date=1965&amp;rft.aulast=North&amp;rft.aufirst=J.D.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinstein1931-258"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEEinstein1931_258-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEEinstein1931_258-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFEinstein1931">Einstein (1931)</a>.</span>
</li>
<li id="cite_note-cor-2013-259"><span class="mw-cite-backlink">^ <a href="#cite_ref-cor-2013_259-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-cor-2013_259-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFO&#39;RaifeartaighMcCann2014" class="citation journal cs1">O\'Raifeartaigh, C; McCann, B (2014). <a rel="nofollow" class="external text" href="http://repository.wit.ie/2867/1/cosmic.pdf">"Einstein\'s cosmic model of 1931 revisited: An analysis and translation of a forgotten model of the universe"</a> <span class="cs1-format">(PDF)</span>. <i>The European Physical Journal H</i>. <b>39</b> (2014): 63–85. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1312.2192">1312.2192</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2014EPJH...39...63O">2014EPJH...39...63O</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1140%2Fepjh%2Fe2013-40038-x">10.1140/epjh/e2013-40038-x</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:53419239">53419239</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200929102551/https://repository.wit.ie/2867/1/cosmic.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 29 September 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">31 December</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+European+Physical+Journal+H&amp;rft.atitle=Einstein%27s+cosmic+model+of+1931+revisited%3A+An+analysis+and+translation+of+a+forgotten+model+of+the+universe&amp;rft.volume=39&amp;rft.issue=2014&amp;rft.pages=63-85&amp;rft.date=2014&amp;rft_id=info%3Aarxiv%2F1312.2192&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A53419239%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1140%2Fepjh%2Fe2013-40038-x&amp;rft_id=info%3Abibcode%2F2014EPJH...39...63O&amp;rft.aulast=O%27Raifeartaigh&amp;rft.aufirst=C&amp;rft.au=McCann%2C+B&amp;rft_id=http%3A%2F%2Frepository.wit.ie%2F2867%2F1%2Fcosmic.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinsteinde_Sitter1932-260"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinsteinde_Sitter1932_260-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinsteinde_Sitter1932">Einstein &amp; de Sitter (1932)</a>.</span>
</li>
<li id="cite_note-J9Tqu-261"><span class="mw-cite-backlink"><b><a href="#cite_ref-J9Tqu_261-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNussbaumer2014" class="citation journal cs1">Nussbaumer, Harry (2014). "Einstein\'s conversion from his static to an expanding universe". <i>Eur. Phys. J. H</i>. <b>39</b> (1): 37–62. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1311.2763">1311.2763</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2014EPJH...39...37N">2014EPJH...39...37N</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1140%2Fepjh%2Fe2013-40037-6">10.1140/epjh/e2013-40037-6</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:122011477">122011477</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Eur.+Phys.+J.+H&amp;rft.atitle=Einstein%27s+conversion+from+his+static+to+an+expanding+universe&amp;rft.volume=39&amp;rft.issue=1&amp;rft.pages=37-62&amp;rft.date=2014&amp;rft_id=info%3Aarxiv%2F1311.2763&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A122011477%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1140%2Fepjh%2Fe2013-40037-6&amp;rft_id=info%3Abibcode%2F2014EPJH...39...37N&amp;rft.aulast=Nussbaumer&amp;rft.aufirst=Harry&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-sxfvo-262"><span class="mw-cite-backlink"><b><a href="#cite_ref-sxfvo_262-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNussbaumer_and_Bieri2009" class="citation book cs1">Nussbaumer and Bieri (2009). <i>Discovering the Expanding Universe</i>. Cambridge: Cambridge University Press. pp.&#160;144–152.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Discovering+the+Expanding+Universe&amp;rft.place=Cambridge&amp;rft.pages=144-152&amp;rft.pub=Cambridge+University+Press&amp;rft.date=2009&amp;rft.au=Nussbaumer+and+Bieri&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-qmmVf-263"><span class="mw-cite-backlink"><b><a href="#cite_ref-qmmVf_263-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFZimmer2013" class="citation news cs1">Zimmer, Carl (9 June 2013). <a rel="nofollow" class="external text" href="https://ghostarchive.org/archive/20220101/https://www.nytimes.com/2013/06/09/books/review/brilliant-blunders-by-mario-livio.html">"The Genius of Getting It Wrong"</a>. <i>The New York Times</i>. Archived from <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://www.nytimes.com/2013/06/09/books/review/brilliant-blunders-by-mario-livio.html">the original</a></span> on 1 January 2022.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=The+Genius+of+Getting+It+Wrong&amp;rft.date=2013-06-09&amp;rft.aulast=Zimmer&amp;rft.aufirst=Carl&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F2013%2F06%2F09%2Fbooks%2Freview%2Fbrilliant-blunders-by-mario-livio.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Tq53z-264"><span class="mw-cite-backlink"><b><a href="#cite_ref-Tq53z_264-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCastelvecchi2014" class="citation journal cs1">Castelvecchi, Davide (2014). <a rel="nofollow" class="external text" href="https://doi.org/10.1038%2F506418a">"Einstein\'s lost theory uncovered"</a>. <i>Nature News &amp; Comment</i>. <b>506</b> (7489): 418–419. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2014Natur.506..418C">2014Natur.506..418C</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1038%2F506418a">10.1038/506418a</a></span>. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/24572403">24572403</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:205080245">205080245</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Nature+News+%26+Comment&amp;rft.atitle=Einstein%27s+lost+theory+uncovered&amp;rft.volume=506&amp;rft.issue=7489&amp;rft.pages=418-419&amp;rft.date=2014&amp;rft_id=info%3Adoi%2F10.1038%2F506418a&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A205080245%23id-name%3DS2CID&amp;rft_id=info%3Apmid%2F24572403&amp;rft_id=info%3Abibcode%2F2014Natur.506..418C&amp;rft.aulast=Castelvecchi&amp;rft.aufirst=Davide&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1038%252F506418a&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-8pfEk-265"><span class="mw-cite-backlink"><b><a href="#cite_ref-8pfEk_265-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://blogs.discovermagazine.com/outthere/2014/03/14/135th-birthday-einstein-still-full-surprises/">"On His 135th Birthday, Einstein is Still Full of Surprises"</a>. <i>Out There</i>. 14 March 2014. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20140318005847/http://blogs.discovermagazine.com/outthere/2014/03/14/135th-birthday-einstein-still-full-surprises/">Archived</a> from the original on 18 March 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">17 March</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Out+There&amp;rft.atitle=On+His+135th+Birthday%2C+Einstein+is+Still+Full+of+Surprises&amp;rft.date=2014-03-14&amp;rft_id=http%3A%2F%2Fblogs.discovermagazine.com%2Foutthere%2F2014%2F03%2F14%2F135th-birthday-einstein-still-full-surprises%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-cor-steady-state-266"><span class="mw-cite-backlink">^ <a href="#cite_ref-cor-steady-state_266-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-cor-steady-state_266-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFO&#39;RaifeartaighMcCannNahmMitton2014" class="citation journal cs1">O\'Raifeartaigh, C.; McCann, B.; Nahm, W.; Mitton, S. (2014). <a rel="nofollow" class="external text" href="http://repository.wit.ie/2866/1/cormac.pdf">"Einstein\'s steady-state theory: an abandoned model of the cosmos"</a> <span class="cs1-format">(PDF)</span>. <i>Eur. Phys. J. H</i>. <b>39</b> (3): 353–369. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1402.0132">1402.0132</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2014EPJH...39..353O">2014EPJH...39..353O</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1140%2Fepjh%2Fe2014-50011-x">10.1140/epjh/e2014-50011-x</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:38384067">38384067</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200929120033/https://repository.wit.ie/2866/1/cormac.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 29 September 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">31 December</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Eur.+Phys.+J.+H&amp;rft.atitle=Einstein%27s+steady-state+theory%3A+an+abandoned+model+of+the+cosmos&amp;rft.volume=39&amp;rft.issue=3&amp;rft.pages=353-369&amp;rft.date=2014&amp;rft_id=info%3Aarxiv%2F1402.0132&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A38384067%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1140%2Fepjh%2Fe2014-50011-x&amp;rft_id=info%3Abibcode%2F2014EPJH...39..353O&amp;rft.aulast=O%27Raifeartaigh&amp;rft.aufirst=C.&amp;rft.au=McCann%2C+B.&amp;rft.au=Nahm%2C+W.&amp;rft.au=Mitton%2C+S.&amp;rft_id=http%3A%2F%2Frepository.wit.ie%2F2866%2F1%2Fcormac.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Einstein&#39;s_aborted_model-267"><span class="mw-cite-backlink">^ <a href="#cite_ref-Einstein&#39;s_aborted_model_267-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-Einstein&#39;s_aborted_model_267-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNussbaumer2014" class="citation book cs1">Nussbaumer, Harry (2014). "Einstein\'s aborted attempt at a dynamic steady-state universe". <i>In memoriam Hilmar Duerbeck</i>. p.&#160;463. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1402.4099">1402.4099</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2014arXiv1402.4099N">2014arXiv1402.4099N</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-3-944913-56-8" title="Special:BookSources/978-3-944913-56-8"><bdi>978-3-944913-56-8</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Einstein%27s+aborted+attempt+at+a+dynamic+steady-state+universe&amp;rft.btitle=In+memoriam+Hilmar+Duerbeck&amp;rft.pages=463&amp;rft.date=2014&amp;rft_id=info%3Aarxiv%2F1402.4099&amp;rft_id=info%3Abibcode%2F2014arXiv1402.4099N&amp;rft.isbn=978-3-944913-56-8&amp;rft.aulast=Nussbaumer&amp;rft.aufirst=Harry&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-ILjYQ-268"><span class="mw-cite-backlink"><b><a href="#cite_ref-ILjYQ_268-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHoyle1948" class="citation journal cs1">Hoyle (1948). <a rel="nofollow" class="external text" href="https://doi.org/10.1093%2Fmnras%2F108.5.372">"A New Model for the Expanding Universe"</a>. <i>MNRAS</i>. <b>108</b> (5): 372. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1948MNRAS.108..372H">1948MNRAS.108..372H</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1093%2Fmnras%2F108.5.372">10.1093/mnras/108.5.372</a></span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=MNRAS&amp;rft.atitle=A+New+Model+for+the+Expanding+Universe&amp;rft.volume=108&amp;rft.issue=5&amp;rft.pages=372&amp;rft.date=1948&amp;rft_id=info%3Adoi%2F10.1093%2Fmnras%2F108.5.372&amp;rft_id=info%3Abibcode%2F1948MNRAS.108..372H&amp;rft.au=Hoyle&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1093%252Fmnras%252F108.5.372&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-ThZb0-269"><span class="mw-cite-backlink"><b><a href="#cite_ref-ThZb0_269-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBondiGold1948" class="citation journal cs1">Bondi; Gold (1948). <a rel="nofollow" class="external text" href="https://doi.org/10.1093%2Fmnras%2F108.3.252">"The Steady-State Theory of the Expanding Universe"</a>. <i>MNRAS</i>. <b>108</b> (3): 252. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1948MNRAS.108..252B">1948MNRAS.108..252B</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1093%2Fmnras%2F108.3.252">10.1093/mnras/108.3.252</a></span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=MNRAS&amp;rft.atitle=The+Steady-State+Theory+of+the+Expanding+Universe&amp;rft.volume=108&amp;rft.issue=3&amp;rft.pages=252&amp;rft.date=1948&amp;rft_id=info%3Adoi%2F10.1093%2Fmnras%2F108.3.252&amp;rft_id=info%3Abibcode%2F1948MNRAS.108..252B&amp;rft.au=Bondi&amp;rft.au=Gold&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1093%252Fmnras%252F108.3.252&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-7ShC9-270"><span class="mw-cite-backlink"><b><a href="#cite_ref-7ShC9_270-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFAmir_Aczel2014" class="citation web cs1">Amir Aczel (7 March 2014). <a rel="nofollow" class="external text" href="http://blogs.discovermagazine.com/crux/2014/03/07/einsteins-lost-theory-describes-a-universe-without-a-big-bang/">"Einstein\'s Lost Theory Describes a Universe Without a Big Bang"</a>. <i>The Crux</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20140319110251/http://blogs.discovermagazine.com/crux/2014/03/07/einsteins-lost-theory-describes-a-universe-without-a-big-bang/">Archived</a> from the original on 19 March 2014<span class="reference-accessdate">. Retrieved <span class="nowrap">17 March</span> 2014</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=The+Crux&amp;rft.atitle=Einstein%27s+Lost+Theory+Describes+a+Universe+Without+a+Big+Bang&amp;rft.date=2014-03-07&amp;rft.au=Amir+Aczel&amp;rft_id=http%3A%2F%2Fblogs.discovermagazine.com%2Fcrux%2F2014%2F03%2F07%2Feinsteins-lost-theory-describes-a-universe-without-a-big-bang%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-271"><span class="mw-cite-backlink"><b><a href="#cite_ref-271">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFByers1998" class="citation arxiv cs1"><a href="/wiki/Nina_Byers" title="Nina Byers">Byers, Nina</a> (23 September 1998). "E. Noether\'s Discovery of the Deep Connection Between Symmetries and Conservation Laws". <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/physics/9807044">physics/9807044</a></span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=preprint&amp;rft.jtitle=arXiv&amp;rft.atitle=E.+Noether%27s+Discovery+of+the+Deep+Connection+Between+Symmetries+and+Conservation+Laws&amp;rft.date=1998-09-23&amp;rft_id=info%3Aarxiv%2Fphysics%2F9807044&amp;rft.aulast=Byers&amp;rft.aufirst=Nina&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-272"><span class="mw-cite-backlink"><b><a href="#cite_ref-272">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGoldberg1958" class="citation journal cs1">Goldberg, J. N. (1958). "Conservation laws in general relativity". <i>Physical Review</i>. <b>111</b> (1): 315–320. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1958PhRv..111..315G">1958PhRv..111..315G</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FPhysRev.111.315">10.1103/PhysRev.111.315</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physical+Review&amp;rft.atitle=Conservation+laws+in+general+relativity&amp;rft.volume=111&amp;rft.issue=1&amp;rft.pages=315-320&amp;rft.date=1958&amp;rft_id=info%3Adoi%2F10.1103%2FPhysRev.111.315&amp;rft_id=info%3Abibcode%2F1958PhRv..111..315G&amp;rft.aulast=Goldberg&amp;rft.aufirst=J.+N.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEEinsteinRosen1935-273"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinsteinRosen1935_273-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinsteinRosen1935">Einstein &amp; Rosen (1935)</a>.</span>
</li>
<li id="cite_note-QNjpt-274"><span class="mw-cite-backlink"><b><a href="#cite_ref-QNjpt_274-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://journals.aps.org/general-relativity-centennial">"2015 – General Relativity\'s Centennial"</a>. <a href="/wiki/American_Physical_Society" title="American Physical Society">American Physical Society</a>. 2015. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20181115201857/https://journals.aps.org/general-relativity-centennial">Archived</a> from the original on 15 November 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">7 April</span> 2017</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=2015+%E2%80%93+General+Relativity%27s+Centennial&amp;rft.pub=American+Physical+Society&amp;rft.date=2015&amp;rft_id=https%3A%2F%2Fjournals.aps.org%2Fgeneral-relativity-centennial&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-ja7FY-275"><span class="mw-cite-backlink"><b><a href="#cite_ref-ja7FY_275-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLindley2005" class="citation journal cs1">Lindley, David (25 March 2005). "Focus: The Birth of Wormholes". <i>Physics</i>. <b>15</b>: 11. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2Fphysrevfocus.15.11">10.1103/physrevfocus.15.11</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics&amp;rft.atitle=Focus%3A+The+Birth+of+Wormholes&amp;rft.volume=15&amp;rft.pages=11&amp;rft.date=2005-03-25&amp;rft_id=info%3Adoi%2F10.1103%2Fphysrevfocus.15.11&amp;rft.aulast=Lindley&amp;rft.aufirst=David&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Wheeler-276"><span class="mw-cite-backlink"><b><a href="#cite_ref-Wheeler_276-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWheeler2010" class="citation book cs1"><a href="/wiki/John_Archibald_Wheeler" title="John Archibald Wheeler">Wheeler, John Archibald</a> (18 June 2010). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=zGFkK2tTXPsC&amp;pg=PA235"><i>Geons, Black Holes, and Quantum Foam: A Life in Physics</i></a>. W. W. Norton &amp; Company. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-393-07948-7" title="Special:BookSources/978-0-393-07948-7"><bdi>978-0-393-07948-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Geons%2C+Black+Holes%2C+and+Quantum+Foam%3A+A+Life+in+Physics&amp;rft.pub=W.+W.+Norton+%26+Company&amp;rft.date=2010-06-18&amp;rft.isbn=978-0-393-07948-7&amp;rft.aulast=Wheeler&amp;rft.aufirst=John+Archibald&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DzGFkK2tTXPsC%26pg%3DPA235&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-277"><span class="mw-cite-backlink"><b><a href="#cite_ref-277">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFKersting2019" class="citation journal cs1">Kersting, Magdalena (May 2019). <a rel="nofollow" class="external text" href="https://doi.org/10.1088%2F1361-6552%2Fab08f5">"Free fall in curved spacetime—how to visualise gravity in general relativity"</a>. <i><a href="/wiki/Physics_Education" title="Physics Education">Physics Education</a></i>. <b>54</b> (3): 035008. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2019PhyEd..54c5008K">2019PhyEd..54c5008K</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1088%2F1361-6552%2Fab08f5">10.1088/1361-6552/ab08f5</a></span>. <a href="/wiki/Hdl_(identifier)" class="mw-redirect" title="Hdl (identifier)">hdl</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://hdl.handle.net/10852%2F74677">10852/74677</a></span>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0031-9120">0031-9120</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:127471222">127471222</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics+Education&amp;rft.atitle=Free+fall+in+curved+spacetime%E2%80%94how+to+visualise+gravity+in+general+relativity&amp;rft.volume=54&amp;rft.issue=3&amp;rft.pages=035008&amp;rft.date=2019-05&amp;rft_id=info%3Ahdl%2F10852%2F74677&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A127471222%23id-name%3DS2CID&amp;rft_id=info%3Abibcode%2F2019PhyEd..54c5008K&amp;rft.issn=0031-9120&amp;rft_id=info%3Adoi%2F10.1088%2F1361-6552%2Fab08f5&amp;rft.aulast=Kersting&amp;rft.aufirst=Magdalena&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1088%252F1361-6552%252Fab08f5&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-278"><span class="mw-cite-backlink"><b><a href="#cite_ref-278">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFTamir2012" class="citation journal cs1">Tamir, M (2012). <a rel="nofollow" class="external text" href="http://philsci-archive.pitt.edu/9158/1/Tamir_-_Proving_the_Principle.pdf">"Proving the principle: Taking geodesic dynamics too seriously in Einstein\'s theory"</a> <span class="cs1-format">(PDF)</span>. <i>Studies in History and Philosophy of Modern Physics</i>. <b>43</b> (2): 137–154. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2012SHPMP..43..137T">2012SHPMP..43..137T</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1016%2Fj.shpsb.2011.12.002">10.1016/j.shpsb.2011.12.002</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Studies+in+History+and+Philosophy+of+Modern+Physics&amp;rft.atitle=Proving+the+principle%3A+Taking+geodesic+dynamics+too+seriously+in+Einstein%27s+theory&amp;rft.volume=43&amp;rft.issue=2&amp;rft.pages=137-154&amp;rft.date=2012&amp;rft_id=info%3Adoi%2F10.1016%2Fj.shpsb.2011.12.002&amp;rft_id=info%3Abibcode%2F2012SHPMP..43..137T&amp;rft.aulast=Tamir&amp;rft.aufirst=M&amp;rft_id=http%3A%2F%2Fphilsci-archive.pitt.edu%2F9158%2F1%2FTamir_-_Proving_the_Principle.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-279"><span class="mw-cite-backlink"><b><a href="#cite_ref-279">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMalament2012" class="citation book cs1"><a href="/wiki/David_Malament" title="David Malament">Malament, David</a> (2012). <a rel="nofollow" class="external text" href="http://philsci-archive.pitt.edu/5072/1/GeodesicLaw.pdf">"A Remark About the "Geodesic Principle" in General Relativity"</a> <span class="cs1-format">(PDF)</span>. In Frappier, M.; Brown, D.; DiSalle, R. (eds.). <i>Analysis and Interpretation in the Exact Sciences</i>. The Western Ontario Series in Philosophy of Science. Vol.&#160;78. Springer. pp.&#160;245–252. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1007%2F978-94-007-2582-9_14">10.1007/978-94-007-2582-9_14</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-94-007-2581-2" title="Special:BookSources/978-94-007-2581-2"><bdi>978-94-007-2581-2</bdi></a>. <q>Though the geodesic principle can be recovered as theorem in general relativity, it is not a consequence of Einstein\'s equation (or the conservation principle) alone. Other assumptions are needed to derive the theorems in question.</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=A+Remark+About+the+%22Geodesic+Principle%22+in+General+Relativity&amp;rft.btitle=Analysis+and+Interpretation+in+the+Exact+Sciences&amp;rft.series=The+Western+Ontario+Series+in+Philosophy+of+Science&amp;rft.pages=245-252&amp;rft.pub=Springer&amp;rft.date=2012&amp;rft_id=info%3Adoi%2F10.1007%2F978-94-007-2582-9_14&amp;rft.isbn=978-94-007-2581-2&amp;rft.aulast=Malament&amp;rft.aufirst=David&amp;rft_id=http%3A%2F%2Fphilsci-archive.pitt.edu%2F5072%2F1%2FGeodesicLaw.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-ixm32-280"><span class="mw-cite-backlink"><b><a href="#cite_ref-ixm32_280-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.osti.gov/accomplishments/nuggets/einstein/solidcolda.html">"Celebrating Einstein \'Solid Cold\'. U.S. DOE"</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170719091347/https://www.osti.gov/accomplishments/nuggets/einstein/solidcolda.html">Archived</a> from the original on 19 July 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">21 February</span> 2011</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Celebrating+Einstein+%27Solid+Cold%27.+U.S.+DOE.&amp;rft_id=http%3A%2F%2Fwww.osti.gov%2Faccomplishments%2Fnuggets%2Feinstein%2Fsolidcolda.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>, <a href="/wiki/Office_of_Scientific_and_Technical_Information" title="Office of Scientific and Technical Information">Office of Scientific and Technical Information</a>, 2011.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1924-281"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1924_281-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1924">Einstein (1924)</a>.</span>
</li>
<li id="cite_note-nlagl-282"><span class="mw-cite-backlink"><b><a href="#cite_ref-nlagl_282-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20070610080506/https://www.nist.gov/public_affairs/releases/n01-04.htm">"Cornell and Wieman Share 2001 Nobel Prize in Physics"</a>. 9 October 2001. Archived from <a rel="nofollow" class="external text" href="https://www.nist.gov/public_affairs/releases/n01-04.htm">the original</a> on 10 June 2007<span class="reference-accessdate">. Retrieved <span class="nowrap">11 June</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Cornell+and+Wieman+Share+2001+Nobel+Prize+in+Physics&amp;rft.date=2001-10-09&amp;rft_id=https%3A%2F%2Fwww.nist.gov%2Fpublic_affairs%2Freleases%2Fn01-04.htm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEPais1982522-283"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPais1982522_283-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPais1982">Pais (1982)</a>, p.&#160;522.</span>
</li>
<li id="cite_note-FOOTNOTEStachel_et_al.2008270ffvol._4:_The_Swiss_Years:_Writings,_1912–1914-284"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEStachel_et_al.2008270ffvol._4:_The_Swiss_Years:_Writings,_1912–1914_284-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFStachel_et_al.2008">Stachel et al. (2008)</a>, pp.&#160;270ff, vol. 4: The Swiss Years: Writings, 1912–1914.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1917b-285"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1917b_285-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1917b">Einstein (1917b)</a>.</span>
</li>
<li id="cite_note-286"><span class="mw-cite-backlink"><b><a href="#cite_ref-286">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFDuncanJanssen2019" class="citation book cs1">Duncan, Anthony; Janssen, Michel (2019). <a rel="nofollow" class="external text" href="https://www.worldcat.org/oclc/1119627546"><i>Constructing quantum mechanics. Volume 1, The scaffold&#160;: 1900–1923</i></a> (1st&#160;ed.). Oxford: Oxford University Press. pp.&#160;133–142. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-19-258422-9" title="Special:BookSources/978-0-19-258422-9"><bdi>978-0-19-258422-9</bdi></a>. <a href="/wiki/OCLC_(identifier)" class="mw-redirect" title="OCLC (identifier)">OCLC</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/oclc/1119627546">1119627546</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Constructing+quantum+mechanics.+Volume+1%2C+The+scaffold+%3A+1900%E2%80%931923&amp;rft.place=Oxford&amp;rft.pages=133-142&amp;rft.edition=1st&amp;rft.pub=Oxford+University+Press&amp;rft.date=2019&amp;rft_id=info%3Aoclcnum%2F1119627546&amp;rft.isbn=978-0-19-258422-9&amp;rft.aulast=Duncan&amp;rft.aufirst=Anthony&amp;rft.au=Janssen%2C+Michel&amp;rft_id=https%3A%2F%2Fwww.worldcat.org%2Foclc%2F1119627546&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-287"><span class="mw-cite-backlink"><b><a href="#cite_ref-287">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHanle1979" class="citation journal cs1">Hanle, Paul A. (July 1979). <a rel="nofollow" class="external text" href="https://pubs.aip.org/aapt/ajp/article/47/7/644-648/1051199">"The Schrödinger-Einstein correspondence and the sources of wave mechanics"</a>. <i>American Journal of Physics</i>. <b>47</b> (7): 644–648. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1979AmJPh..47..644H">1979AmJPh..47..644H</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1119%2F1.11950">10.1119/1.11950</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0002-9505">0002-9505</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=American+Journal+of+Physics&amp;rft.atitle=The+Schr%C3%B6dinger-Einstein+correspondence+and+the+sources+of+wave+mechanics&amp;rft.volume=47&amp;rft.issue=7&amp;rft.pages=644-648&amp;rft.date=1979-07&amp;rft.issn=0002-9505&amp;rft_id=info%3Adoi%2F10.1119%2F1.11950&amp;rft_id=info%3Abibcode%2F1979AmJPh..47..644H&amp;rft.aulast=Hanle&amp;rft.aufirst=Paul+A.&amp;rft_id=https%3A%2F%2Fpubs.aip.org%2Faapt%2Fajp%2Farticle%2F47%2F7%2F644-648%2F1051199&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-288"><span class="mw-cite-backlink"><b><a href="#cite_ref-288">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRamanForman1969" class="citation journal cs1">Raman, V. V.; Forman, Paul (1969). <a rel="nofollow" class="external text" href="https://www.jstor.org/stable/27757299">"Why Was It Schrödinger Who Developed de Broglie\'s Ideas?"</a>. <i>Historical Studies in the Physical Sciences</i>. <b>1</b>: 291–314. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.2307%2F27757299">10.2307/27757299</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/0073-2672">0073-2672</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/27757299">27757299</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Historical+Studies+in+the+Physical+Sciences&amp;rft.atitle=Why+Was+It+Schr%C3%B6dinger+Who+Developed+de+Broglie%27s+Ideas%3F&amp;rft.volume=1&amp;rft.pages=291-314&amp;rft.date=1969&amp;rft.issn=0073-2672&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F27757299%23id-name%3DJSTOR&amp;rft_id=info%3Adoi%2F10.2307%2F27757299&amp;rft.aulast=Raman&amp;rft.aufirst=V.+V.&amp;rft.au=Forman%2C+Paul&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F27757299&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-zZ2hS-289"><span class="mw-cite-backlink"><b><a href="#cite_ref-zZ2hS_289-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFAndrews2003" class="citation book cs1">Andrews, Robert (2003). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=VK0vR4fsaigC&amp;pg=PT499"><i>The New Penguin Dictionary of Modern Quotations</i></a>. Penguin UK. p.&#160;499. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-14-196531-4" title="Special:BookSources/978-0-14-196531-4"><bdi>978-0-14-196531-4</bdi></a><span class="reference-accessdate">. Retrieved <span class="nowrap">18 June</span> 2015</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+New+Penguin+Dictionary+of+Modern+Quotations&amp;rft.pages=499&amp;rft.pub=Penguin+UK&amp;rft.date=2003&amp;rft.isbn=978-0-14-196531-4&amp;rft.aulast=Andrews&amp;rft.aufirst=Robert&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DVK0vR4fsaigC%26pg%3DPT499&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-yzZtL-290"><span class="mw-cite-backlink"><b><a href="#cite_ref-yzZtL_290-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPais1979" class="citation journal cs1">Pais, Abraham (October 1979). <a rel="nofollow" class="external text" href="http://ursula.chem.yale.edu/~batista/classes/vvv/RevModPhys.51.863.pdf">"Einstein and the quantum theory"</a> <span class="cs1-format">(PDF)</span>. <i>Reviews of Modern Physics</i>. <b>51</b> (4): 863–914. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1979RvMP...51..863P">1979RvMP...51..863P</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FRevModPhys.51.863">10.1103/RevModPhys.51.863</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190829151347/http://ursula.chem.yale.edu/~batista/classes/vvv/RevModPhys.51.863.pdf">Archived</a> <span class="cs1-format">(PDF)</span> from the original on 29 August 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">18 November</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Reviews+of+Modern+Physics&amp;rft.atitle=Einstein+and+the+quantum+theory&amp;rft.volume=51&amp;rft.issue=4&amp;rft.pages=863-914&amp;rft.date=1979-10&amp;rft_id=info%3Adoi%2F10.1103%2FRevModPhys.51.863&amp;rft_id=info%3Abibcode%2F1979RvMP...51..863P&amp;rft.aulast=Pais&amp;rft.aufirst=Abraham&amp;rft_id=http%3A%2F%2Fursula.chem.yale.edu%2F~batista%2Fclasses%2Fvvv%2FRevModPhys.51.863.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Bohr1949-291"><span class="mw-cite-backlink"><b><a href="#cite_ref-Bohr1949_291-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBohr,_N." class="citation web cs1">Bohr, N. <a rel="nofollow" class="external text" href="https://www.marxists.org/reference/subject/philosophy/works/dk/bohr.htm">"Discussions with Einstein on Epistemological Problems in Atomic Physics"</a>. <i>The Value of Knowledge: A Miniature Library of Philosophy</i>. <a href="/wiki/Marxists_Internet_Archive" title="Marxists Internet Archive">Marxists Internet Archive</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20100913033345/http://www.marxists.org/reference/subject/philosophy/works/dk/bohr.htm">Archived</a> from the original on 13 September 2010<span class="reference-accessdate">. Retrieved <span class="nowrap">30 August</span> 2010</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=The+Value+of+Knowledge%3A+A+Miniature+Library+of+Philosophy&amp;rft.atitle=Discussions+with+Einstein+on+Epistemological+Problems+in+Atomic+Physics&amp;rft.au=Bohr%2C+N.&amp;rft_id=http%3A%2F%2Fwww.marxists.org%2Freference%2Fsubject%2Fphilosophy%2Fworks%2Fdk%2Fbohr.htm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> From Albert Einstein: Philosopher-Scientist (1949), publ. Cambridge University Press, 1949. Niels Bohr\'s report of conversations with Einstein.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1969-292"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1969_292-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1969">Einstein (1969)</a>.</span>
</li>
<li id="cite_note-293"><span class="mw-cite-backlink"><b><a href="#cite_ref-293">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFSchlosshauerKoflerZeilinger2013" class="citation journal cs1">Schlosshauer, Maximilian; Kofler, Johannes; Zeilinger, Anton (1 August 2013). "A snapshot of foundational attitudes toward quantum mechanics". <i>Studies in History and Philosophy of Science Part B: Studies in History and Philosophy of Modern Physics</i>. <b>44</b> (3): 222–230. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1301.1069">1301.1069</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2013SHPMP..44..222S">2013SHPMP..44..222S</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1016%2Fj.shpsb.2013.04.004">10.1016/j.shpsb.2013.04.004</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/1355-2198">1355-2198</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:55537196">55537196</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Studies+in+History+and+Philosophy+of+Science+Part+B%3A+Studies+in+History+and+Philosophy+of+Modern+Physics&amp;rft.atitle=A+snapshot+of+foundational+attitudes+toward+quantum+mechanics&amp;rft.volume=44&amp;rft.issue=3&amp;rft.pages=222-230&amp;rft.date=2013-08-01&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A55537196%23id-name%3DS2CID&amp;rft_id=info%3Abibcode%2F2013SHPMP..44..222S&amp;rft_id=info%3Aarxiv%2F1301.1069&amp;rft.issn=1355-2198&amp;rft_id=info%3Adoi%2F10.1016%2Fj.shpsb.2013.04.004&amp;rft.aulast=Schlosshauer&amp;rft.aufirst=Maximilian&amp;rft.au=Kofler%2C+Johannes&amp;rft.au=Zeilinger%2C+Anton&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-FOOTNOTEHoward1990-294"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEHoward1990_294-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEHoward1990_294-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFHoward1990">Howard (1990)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEHarriganSpekkens2010-295"><span class="mw-cite-backlink">^ <a href="#cite_ref-FOOTNOTEHarriganSpekkens2010_295-0"><sup><i><b>a</b></i></sup></a> <a href="#cite_ref-FOOTNOTEHarriganSpekkens2010_295-1"><sup><i><b>b</b></i></sup></a></span> <span class="reference-text"><a href="#CITEREFHarriganSpekkens2010">Harrigan &amp; Spekkens (2010)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEEinsteinPodolskyRosen1935-296"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinsteinPodolskyRosen1935_296-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinsteinPodolskyRosen1935">Einstein, Podolsky &amp; Rosen (1935)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEPeres2002-297"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPeres2002_297-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPeres2002">Peres (2002)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEMermin1993-298"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEMermin1993_298-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFMermin1993">Mermin (1993)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEPenrose2007-299"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEPenrose2007_299-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFPenrose2007">Penrose (2007)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEBell1966-300"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEBell1966_300-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFBell1966">Bell (1966)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEFine2017-301"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEFine2017_301-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFFine2017">Fine (2017)</a>.</span>
</li>
<li id="cite_note-FOOTNOTEEinstein1950-302"><span class="mw-cite-backlink"><b><a href="#cite_ref-FOOTNOTEEinstein1950_302-0">^</a></b></span> <span class="reference-text"><a href="#CITEREFEinstein1950">Einstein (1950)</a>.</span>
</li>
<li id="cite_note-303"><span class="mw-cite-backlink"><b><a href="#cite_ref-303">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGoenner2004" class="citation journal cs1">Goenner, Hubert F. M. (1 December 2004). <a rel="nofollow" class="external text" href="https://doi.org/10.12942/lrr-2004-2">"On the History of Unified Field Theories"</a>. <i>Living Reviews in Relativity</i>. <b>7</b> (1): 2. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2004LRR.....7....2G">2004LRR.....7....2G</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.12942%2Flrr-2004-2">10.12942/lrr-2004-2</a>. <a href="/wiki/ISSN_(identifier)" class="mw-redirect" title="ISSN (identifier)">ISSN</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/issn/1433-8351">1433-8351</a>. <a href="/wiki/PMC_(identifier)" class="mw-redirect" title="PMC (identifier)">PMC</a>&#160;<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5256024">5256024</a></span>. <a href="/wiki/PMID_(identifier)" class="mw-redirect" title="PMID (identifier)">PMID</a>&#160;<a rel="nofollow" class="external text" href="https://pubmed.ncbi.nlm.nih.gov/28179864">28179864</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Living+Reviews+in+Relativity&amp;rft.atitle=On+the+History+of+Unified+Field+Theories&amp;rft.volume=7&amp;rft.issue=1&amp;rft.pages=2&amp;rft.date=2004-12-01&amp;rft_id=https%3A%2F%2Fwww.ncbi.nlm.nih.gov%2Fpmc%2Farticles%2FPMC5256024%23id-name%3DPMC&amp;rft_id=info%3Abibcode%2F2004LRR.....7....2G&amp;rft_id=info%3Apmid%2F28179864&amp;rft_id=info%3Adoi%2F10.12942%2Flrr-2004-2&amp;rft.issn=1433-8351&amp;rft.aulast=Goenner&amp;rft.aufirst=Hubert+F.+M.&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.12942%2Flrr-2004-2&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Richardson-1908-304"><span class="mw-cite-backlink"><b><a href="#cite_ref-Richardson-1908_304-0">^</a></b></span> <span class="reference-text">
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRichardson1908" class="citation journal cs1">Richardson, O. W. (1908). <a rel="nofollow" class="external text" href="https://zenodo.org/record/1997325">"A Mechanical Effect Accompanying Magnetization"</a>. <i>Physical Review</i>. Series I. <b>26</b> (3): 248–253. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1908PhRvI..26..248R">1908PhRvI..26..248R</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FPhysRevSeriesI.26.248">10.1103/PhysRevSeriesI.26.248</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physical+Review&amp;rft.atitle=A+Mechanical+Effect+Accompanying+Magnetization&amp;rft.volume=26&amp;rft.issue=3&amp;rft.pages=248-253&amp;rft.date=1908&amp;rft_id=info%3Adoi%2F10.1103%2FPhysRevSeriesI.26.248&amp;rft_id=info%3Abibcode%2F1908PhRvI..26..248R&amp;rft.aulast=Richardson&amp;rft.aufirst=O.+W.&amp;rft_id=https%3A%2F%2Fzenodo.org%2Frecord%2F1997325&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-EdH-1-1915-305"><span class="mw-cite-backlink"><b><a href="#cite_ref-EdH-1-1915_305-0">^</a></b></span> <span class="reference-text">
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinsteinde_Haas1915" class="citation journal cs1 cs1-prop-foreign-lang-source">Einstein, A.; de Haas, W. J. (1915). "Experimenteller Nachweis der Ampereschen Molekularströme" &#91;Experimental Proof of Ampère\'s Molecular Currents&#93;. <i>Deutsche Physikalische Gesellschaft, Verhandlungen</i> (in German). <b>17</b>: 152–170.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Deutsche+Physikalische+Gesellschaft%2C+Verhandlungen&amp;rft.atitle=Experimenteller+Nachweis+der+Ampereschen+Molekularstr%C3%B6me&amp;rft.volume=17&amp;rft.pages=152-170&amp;rft.date=1915&amp;rft.aulast=Einstein&amp;rft.aufirst=A.&amp;rft.au=de+Haas%2C+W.+J.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-EdH-2-1915-306"><span class="mw-cite-backlink"><b><a href="#cite_ref-EdH-2-1915_306-0">^</a></b></span> <span class="reference-text">
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFEinsteinde_Haas1915" class="citation journal cs1">Einstein, A.; de Haas, W. J. (1915). <a rel="nofollow" class="external text" href="http://www.dwc.knaw.nl/DL/publications/PU00012546.pdf">"Experimental proof of the existence of Ampère\'s molecular currents"</a> <span class="cs1-format">(PDF)</span>. <i>Koninklijke Akademie van Wetenschappen te Amsterdam, Proceedings</i>. <b>18</b>: 696–711. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1915KNAB...18..696E">1915KNAB...18..696E</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Koninklijke+Akademie+van+Wetenschappen+te+Amsterdam%2C+Proceedings&amp;rft.atitle=Experimental+proof+of+the+existence+of+Amp%C3%A8re%27s+molecular+currents&amp;rft.volume=18&amp;rft.pages=696-711&amp;rft.date=1915&amp;rft_id=info%3Abibcode%2F1915KNAB...18..696E&amp;rft.aulast=Einstein&amp;rft.aufirst=A.&amp;rft.au=de+Haas%2C+W.+J.&amp;rft_id=http%3A%2F%2Fwww.dwc.knaw.nl%2FDL%2Fpublications%2FPU00012546.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-307"><span class="mw-cite-backlink"><b><a href="#cite_ref-307">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFSan_MiguelPallandre2024" class="citation journal cs1">San Miguel, Alfonso; Pallandre, Bernard (13 March 2024). <a rel="nofollow" class="external text" href="https://www.europhysicsnews.org/images/stories/news/epn_Einstein-de_Haas.pdf">"Revisiting the Einstein-de Haas experiment: the Ampère Museum\'s hidden treasure"</a> <span class="cs1-format">(PDF)</span>. <i>Europhysics News</i>: 12–14.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Europhysics+News&amp;rft.atitle=Revisiting+the+Einstein-de+Haas+experiment%3A+the+Amp%C3%A8re+Museum%27s+hidden+treasure&amp;rft.pages=12-14&amp;rft.date=2024-03-13&amp;rft.aulast=San+Miguel&amp;rft.aufirst=Alfonso&amp;rft.au=Pallandre%2C+Bernard&amp;rft_id=https%3A%2F%2Fwww.europhysicsnews.org%2Fimages%2Fstories%2Fnews%2Fepn_Einstein-de_Haas.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-308"><span class="mw-cite-backlink"><b><a href="#cite_ref-308">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFJohnston2024" class="citation web cs1">Johnston, Hamish (17 March 2024). <a rel="nofollow" class="external text" href="https://physicsworld.com/einsteins-only-experiment-is-found-in-french-museum/">"Einstein\'s only experiment is found in French museum"</a>. <i>Physics World</i><span class="reference-accessdate">. Retrieved <span class="nowrap">24 March</span> 2024</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Physics+World&amp;rft.atitle=Einstein%27s+only+experiment+is+found+in+French+museum&amp;rft.date=2024-03-17&amp;rft.aulast=Johnston&amp;rft.aufirst=Hamish&amp;rft_id=https%3A%2F%2Fphysicsworld.com%2Feinsteins-only-experiment-is-found-in-french-museum%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-Goettling-309"><span class="mw-cite-backlink"><b><a href="#cite_ref-Goettling_309-0">^</a></b></span> <span class="reference-text">Goettling, Gary. <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://web.archive.org/web/20050525082445/http://gtalumni.org/Publications/magazine/sum98/einsrefr.html">"Einstein\'s refrigerator"</a>. Archived from <a rel="nofollow" class="external text" href="http://gtalumni.org/Publications/magazine/sum98/einsrefr.html">the original</a> on 25 May 2005.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein%27s+refrigerator&amp;rft_id=http%3A%2F%2Fgtalumni.org%2FPublications%2Fmagazine%2Fsum98%2Feinsrefr.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span> <i>Georgia Tech Alumni Magazine</i>. 1998. Retrieved 12 November 2014. <a href="/wiki/Le%C3%B3_Szil%C3%A1rd" class="mw-redirect" title="Leó Szilárd">Leó Szilárd</a>, a Hungarian physicist who later worked on the Manhattan Project, is credited with the discovery of the <a href="/wiki/Chain_reaction" title="Chain reaction">chain reaction</a></span>
</li>
<li id="cite_note-310"><span class="mw-cite-backlink"><b><a href="#cite_ref-310">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFAlok2008" class="citation news cs1">Alok, Jha (21 September 2008). <a rel="nofollow" class="external text" href="https://www.theguardian.com/science/2008/sep/21/scienceofclimatechange.climatechange">"Einstein fridge design can help global cooling"</a>. <i>The Guardian</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20110124172925/http://www.guardian.co.uk/science/2008/sep/21/scienceofclimatechange.climatechange">Archived</a> from the original on 24 January 2011<span class="reference-accessdate">. Retrieved <span class="nowrap">22 February</span> 2011</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+Guardian&amp;rft.atitle=Einstein+fridge+design+can+help+global+cooling&amp;rft.date=2008-09-21&amp;rft.aulast=Alok&amp;rft.aufirst=Jha&amp;rft_id=https%3A%2F%2Fwww.theguardian.com%2Fscience%2F2008%2Fsep%2F21%2Fscienceofclimatechange.climatechange&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-patents.google.com-312"><span class="mw-cite-backlink"><b><a href="#cite_ref-patents.google.com_312-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://patents.google.com/patent/GB303065A/en?oq=GB303065">"Electrodynamic movement of fluid metals particularly for refrigerating machines"</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Electrodynamic+movement+of+fluid+metals+particularly+for+refrigerating+machines&amp;rft_id=https%3A%2F%2Fpatents.google.com%2Fpatent%2FGB303065A%2Fen%3Foq%3DGB303065&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-313"><span class="mw-cite-backlink"><b><a href="#cite_ref-313">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://patents.google.com/patent/DE590783C/en">"Device, in particular for sound reproduction devices, in which changes in electrical current through magnetostriction cause movements of a magnetic body"</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Device%2C+in+particular+for+sound+reproduction+devices%2C+in+which+changes+in+electrical+current+through+magnetostriction+cause+movements+of+a+magnetic+body&amp;rft_id=https%3A%2F%2Fpatents.google.com%2Fpatent%2FDE590783C%2Fen&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-314"><span class="mw-cite-backlink"><b><a href="#cite_ref-314">^</a></b></span> <span class="reference-text">Albert Einstein\'s patents. 2006. World Pat Inf. 28/2, 159–65. M. Trainer. doi: 10.1016/j.wpi.2005.10.012</span>
</li>
<li id="cite_note-margot-obituary-315"><span class="mw-cite-backlink"><b><a href="#cite_ref-margot-obituary_315-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="https://www.nytimes.com/1986/07/12/obituaries/margot-einstein-86-is-dead-stepdaughter-of-physicist.html">"Obituary"</a>. <i>The New York Times</i>. 12 July 1986. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170910002303/http://www.nytimes.com/1986/07/12/obituaries/margot-einstein-86-is-dead-stepdaughter-of-physicist.html">Archived</a> from the original on 10 September 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">3 April</span> 2011</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Times&amp;rft.atitle=Obituary&amp;rft.date=1986-07-12&amp;rft_id=https%3A%2F%2Fwww.nytimes.com%2F1986%2F07%2F12%2Fobituaries%2Fmargot-einstein-86-is-dead-stepdaughter-of-physicist.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-letters-love-316"><span class="mw-cite-backlink"><b><a href="#cite_ref-letters-love_316-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="http://news.bbc.co.uk/2/hi/science/nature/5168002.stm">"Letters Reveal Einstein Love Life"</a>. <i><a href="/wiki/BBC_News" title="BBC News">BBC News</a></i>. 11 July 2006. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20190502100238/http://news.bbc.co.uk/2/hi/science/nature/5168002.stm">Archived</a> from the original on 2 May 2019<span class="reference-accessdate">. Retrieved <span class="nowrap">14 March</span> 2007</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=BBC+News&amp;rft.atitle=Letters+Reveal+Einstein+Love+Life&amp;rft.date=2006-07-11&amp;rft_id=http%3A%2F%2Fnews.bbc.co.uk%2F2%2Fhi%2Fscience%2Fnature%2F5168002.stm&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-casetext-hebrew-university-317"><span class="mw-cite-backlink"><b><a href="#cite_ref-casetext-hebrew-university_317-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://casetext.com/case/hebrew-univ-of-jerusalem-v-gen-motors-llc">"United States District Court, Central District of California, Case No. CV10–03790 AHM (JCx)"</a>. 15 October 2012. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200121133844/https://casetext.com/case/hebrew-univ-of-jerusalem-v-gen-motors-llc">Archived</a> from the original on 21 January 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">24 November</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=United+States+District+Court%2C+Central+District+of+California%2C+Case+No.+CV10%E2%80%9303790+AHM+%28JCx%29&amp;rft.date=2012-10-15&amp;rft_id=https%3A%2F%2Fcasetext.com%2Fcase%2Fhebrew-univ-of-jerusalem-v-gen-motors-llc&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-pacermonitor-hebrew-university-318"><span class="mw-cite-backlink"><b><a href="#cite_ref-pacermonitor-hebrew-university_318-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.pacermonitor.com/public/case/944657/The_Hebrew_University_of_Jerusalem_v_General_Motors_LLC">"United States District Court, Central District of California, Case No.: CV-10-3790-AB (JCx)"</a>. 15 January 2015. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200725030614/https://www.pacermonitor.com/public/case/944657/The_Hebrew_University_of_Jerusalem_v_General_Motors_LLC">Archived</a> from the original on 25 July 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">24 November</span> 2019</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=United+States+District+Court%2C+Central+District+of+California%2C+Case+No.%3A+CV-10-3790-AB+%28JCx%29&amp;rft.date=2015-01-15&amp;rft_id=https%3A%2F%2Fwww.pacermonitor.com%2Fpublic%2Fcase%2F944657%2FThe_Hebrew_University_of_Jerusalem_v_General_Motors_LLC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-einstein.biz-319"><span class="mw-cite-backlink"><b><a href="#cite_ref-einstein.biz_319-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://einstein.biz/">"Einstein"</a>. Corbis Rights Representation. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20080819220424/http://einstein.biz/">Archived</a> from the original on 19 August 2008<span class="reference-accessdate">. Retrieved <span class="nowrap">8 August</span> 2008</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein&amp;rft.pub=Corbis+Rights+Representation&amp;rft_id=http%3A%2F%2Feinstein.biz%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-320"><span class="mw-cite-backlink"><b><a href="#cite_ref-320">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://gazetteer.linz.govt.nz/place/3694">"Place name detail: Mount Einstein"</a>. <i>New Zealand Gazetteer</i>. <a href="/wiki/New_Zealand_Geographic_Board" title="New Zealand Geographic Board">New Zealand Geographic Board</a><span class="reference-accessdate">. Retrieved <span class="nowrap">21 August</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=New+Zealand+Gazetteer&amp;rft.atitle=Place+name+detail%3A+Mount+Einstein&amp;rft_id=https%3A%2F%2Fgazetteer.linz.govt.nz%2Fplace%2F3694&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-321"><span class="mw-cite-backlink"><b><a href="#cite_ref-321">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHalpern2019" class="citation journal cs1"><a href="/wiki/Paul_Halpern" title="Paul Halpern">Halpern, Paul</a> (2019). <a rel="nofollow" class="external text" href="https://physicstoday.scitation.org/doi/10.1063/PT.3.4183">"Albert Einstein, celebrity scientist"</a>. <i><a href="/wiki/Physics_Today" title="Physics Today">Physics Today</a></i>. <b>72</b> (4): 38–45. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1063%2FPT.3.4183">10.1063/PT.3.4183</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:187603798">187603798</a>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210414011401/https://physicstoday.scitation.org/doi/10.1063/PT.3.4183">Archived</a> from the original on 14 April 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">21 February</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics+Today&amp;rft.atitle=Albert+Einstein%2C+celebrity+scientist&amp;rft.volume=72&amp;rft.issue=4&amp;rft.pages=38-45&amp;rft.date=2019&amp;rft_id=info%3Adoi%2F10.1063%2FPT.3.4183&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A187603798%23id-name%3DS2CID&amp;rft.aulast=Halpern&amp;rft.aufirst=Paul&amp;rft_id=https%3A%2F%2Fphysicstoday.scitation.org%2Fdoi%2F10.1063%2FPT.3.4183&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-322"><span class="mw-cite-backlink"><b><a href="#cite_ref-322">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFahy2015" class="citation magazine cs1">Fahy, Declan (2015). <a rel="nofollow" class="external text" href="https://skepticalinquirer.org/2015/07/a-brief-history-of-scientific-celebrity/">"A Brief History Of Scientific Celebrity"</a>. <i><a href="/wiki/Skeptical_Inquirer" title="Skeptical Inquirer">Skeptical Inquirer</a></i>. Vol.&#160;39, no.&#160;4. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20210510182647/https://skepticalinquirer.org/2015/07/a-brief-history-of-scientific-celebrity/">Archived</a> from the original on 10 May 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">21 February</span> 2021</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Skeptical+Inquirer&amp;rft.atitle=A+Brief+History+Of+Scientific+Celebrity&amp;rft.volume=39&amp;rft.issue=4&amp;rft.date=2015&amp;rft.aulast=Fahy&amp;rft.aufirst=Declan&amp;rft_id=https%3A%2F%2Fskepticalinquirer.org%2F2015%2F07%2Fa-brief-history-of-scientific-celebrity%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-323"><span class="mw-cite-backlink"><b><a href="#cite_ref-323">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMissner1985" class="citation journal cs1">Missner, Marshall (May 1985). "Why Einstein Became Famous in America". <i><a href="/wiki/Social_Studies_of_Science" title="Social Studies of Science">Social Studies of Science</a></i>. <b>15</b> (2): 267–291. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1177%2F030631285015002003">10.1177/030631285015002003</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/285389">285389</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:143398600">143398600</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Social+Studies+of+Science&amp;rft.atitle=Why+Einstein+Became+Famous+in+America&amp;rft.volume=15&amp;rft.issue=2&amp;rft.pages=267-291&amp;rft.date=1985-05&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A143398600%23id-name%3DS2CID&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F285389%23id-name%3DJSTOR&amp;rft_id=info%3Adoi%2F10.1177%2F030631285015002003&amp;rft.aulast=Missner&amp;rft.aufirst=Marshall&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-disguise-324"><span class="mw-cite-backlink"><b><a href="#cite_ref-disguise_324-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLibman1939" class="citation magazine cs1">Libman, E. (14 January 1939). <span class="id-lock-limited" title="Free access subject to limited trial, subscription normally required"><a rel="nofollow" class="external text" href="https://www.newyorker.com/magazine/1939/01/14/disguise-2">"Disguise"</a></span>. <i>The New Yorker</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20200725014949/https://www.newyorker.com/magazine/1939/01/14/disguise-2">Archived</a> from the original on 25 July 2020<span class="reference-accessdate">. Retrieved <span class="nowrap">15 April</span> 2020</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+Yorker&amp;rft.atitle=Disguise&amp;rft.date=1939-01-14&amp;rft.aulast=Libman&amp;rft.aufirst=E.&amp;rft_id=https%3A%2F%2Fwww.newyorker.com%2Fmagazine%2F1939%2F01%2F14%2Fdisguise-2&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-orchestra-325"><span class="mw-cite-backlink"><b><a href="#cite_ref-orchestra_325-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMcTee" class="citation web cs1">McTee, Cindy. <a rel="nofollow" class="external text" href="http://www.cindymctee.com/einsteins_dream.html">"Einstein\'s Dream for orchestra"</a>. Cindymctee.com. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20170418203004/http://cindymctee.com/einsteins_dream.html">Archived</a> from the original on 18 April 2017<span class="reference-accessdate">. Retrieved <span class="nowrap">17 July</span> 2010</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein%27s+Dream+for+orchestra&amp;rft.pub=Cindymctee.com&amp;rft.aulast=McTee&amp;rft.aufirst=Cindy&amp;rft_id=http%3A%2F%2Fwww.cindymctee.com%2Feinsteins_dream.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-slqbwn-326"><span class="mw-cite-backlink"><b><a href="#cite_ref-slqbwn_326-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGolden2000" class="citation news cs1">Golden, Frederic (3 January 2000). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20060221080452/http://www.time.com/time/time100/poc/magazine/albert_einstein5a.html">"Person of the Century: Albert Einstein"</a>. <i>Time</i>. Archived from <a rel="nofollow" class="external text" href="https://www.time.com/time/time100/poc/magazine/albert_einstein5a.html">the original</a> on 21 February 2006<span class="reference-accessdate">. Retrieved <span class="nowrap">25 February</span> 2006</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Time&amp;rft.atitle=Person+of+the+Century%3A+Albert+Einstein&amp;rft.date=2000-01-03&amp;rft.aulast=Golden&amp;rft.aufirst=Frederic&amp;rft_id=https%3A%2F%2Fwww.time.com%2Ftime%2Ftime100%2Fpoc%2Fmagazine%2Falbert_einstein5a.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-fake-quotes-327"><span class="mw-cite-backlink"><b><a href="#cite_ref-fake-quotes_327-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNovak2015" class="citation web cs1">Novak, Matt (16 May 2015). <a rel="nofollow" class="external text" href="https://www.gizmodo.com.au/2015/05/9-albert-einstein-quotes-that-are-totally-fake/">"9 Albert Einstein Quotes That Are Completely Fake"</a>. <i>Gizmodo</i>. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20180705004258/https://www.gizmodo.com.au/2015/05/9-albert-einstein-quotes-that-are-totally-fake/">Archived</a> from the original on 5 July 2018<span class="reference-accessdate">. Retrieved <span class="nowrap">4 May</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Gizmodo&amp;rft.atitle=9+Albert+Einstein+Quotes+That+Are+Completely+Fake&amp;rft.date=2015-05-16&amp;rft.aulast=Novak&amp;rft.aufirst=Matt&amp;rft_id=https%3A%2F%2Fwww.gizmodo.com.au%2F2015%2F05%2F9-albert-einstein-quotes-that-are-totally-fake%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-humiliate-atheist-328"><span class="mw-cite-backlink"><b><a href="#cite_ref-humiliate-atheist_328-0">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.snopes.com/fact-check/false-einstein-humiliates-professor/">"Did Albert Einstein Humiliate an Atheist Professor?"</a>. Snopes. 29 June 2004. <a rel="nofollow" class="external text" href="https://web.archive.org/web/20211104194315/https://www.snopes.com/fact-check/false-einstein-humiliates-professor/">Archived</a> from the original on 4 November 2021<span class="reference-accessdate">. Retrieved <span class="nowrap">4 May</span> 2018</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Did+Albert+Einstein+Humiliate+an+Atheist+Professor%3F&amp;rft.pub=Snopes&amp;rft.date=2004-06-29&amp;rft_id=https%3A%2F%2Fwww.snopes.com%2Ffact-check%2Ffalse-einstein-humiliates-professor%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-329"><span class="mw-cite-backlink"><b><a href="#cite_ref-329">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.rsc.org/periodic-table/element/99/einsteinium">"Einsteinium – Element"</a>. <i><a href="/wiki/Royal_Society_of_Chemistry" title="Royal Society of Chemistry">Royal Society of Chemistry</a></i><span class="reference-accessdate">. Retrieved <span class="nowrap">16 December</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=unknown&amp;rft.jtitle=Royal+Society+of+Chemistry&amp;rft.atitle=Einsteinium+%E2%80%93+Element&amp;rft_id=https%3A%2F%2Fwww.rsc.org%2Fperiodic-table%2Felement%2F99%2Feinsteinium&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-330"><span class="mw-cite-backlink"><b><a href="#cite_ref-330">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="https://www.einstein.caltech.edu/index.html">"Einstein Papers Project"</a>. California Institute of Technology<span class="reference-accessdate">. Retrieved <span class="nowrap">5 November</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Einstein+Papers+Project&amp;rft.pub=California+Institute+of+Technology&amp;rft_id=https%3A%2F%2Fwww.einstein.caltech.edu%2Findex.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
<li id="cite_note-331"><span class="mw-cite-backlink"><b><a href="#cite_ref-331">^</a></b></span> <span class="reference-text"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation web cs1"><a rel="nofollow" class="external text" href="http://press.princeton.edu/einstein/">"Albert Einstein"</a>. Princeton University Press<span class="reference-accessdate">. Retrieved <span class="nowrap">5 November</span> 2022</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=unknown&amp;rft.btitle=Albert+Einstein&amp;rft.pub=Princeton+University+Press&amp;rft_id=http%3A%2F%2Fpress.princeton.edu%2Feinstein%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></span>
</li>
</ol></div></div>
<h3><span class="mw-headline" id="Works_cited">Works cited</span></h3>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1184024115"><div class="div-col" style="column-width: 35em;">
<ul><li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBell1966" class="citation journal cs1">Bell, J. S. (1966). "On the problem of hidden variables in quantum mechanics". <i>Reviews of Modern Physics</i>. <b>38</b> (3): 447–452. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1966RvMP...38..447B">1966RvMP...38..447B</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2Frevmodphys.38.447">10.1103/revmodphys.38.447</a>. <a href="/wiki/OSTI_(identifier)" class="mw-redirect" title="OSTI (identifier)">OSTI</a>&#160;<a rel="nofollow" class="external text" href="https://www.osti.gov/biblio/1444158">1444158</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Reviews+of+Modern+Physics&amp;rft.atitle=On+the+problem+of+hidden+variables+in+quantum+mechanics&amp;rft.volume=38&amp;rft.issue=3&amp;rft.pages=447-452&amp;rft.date=1966&amp;rft_id=info%3Adoi%2F10.1103%2Frevmodphys.38.447&amp;rft_id=https%3A%2F%2Fwww.osti.gov%2Fbiblio%2F1444158%23id-name%3DOSTI&amp;rft_id=info%3Abibcode%2F1966RvMP...38..447B&amp;rft.aulast=Bell&amp;rft.aufirst=J.+S.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCalaprice2000" class="citation book cs1">Calaprice, Alice (2000). <i>The Expanded Quotable Einstein</i>. Princeton University Press.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Expanded+Quotable+Einstein&amp;rft.pub=Princeton+University+Press&amp;rft.date=2000&amp;rft.aulast=Calaprice&amp;rft.aufirst=Alice&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCalaprice2005" class="citation book cs1">Calaprice, Alice (2005). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20090622063213/http://press.princeton.edu/titles/7921.html"><i>The New Quotable Einstein</i></a>. Princeton University Press. Archived from <a rel="nofollow" class="external text" href="http://press.princeton.edu/titles/7921.html">the original</a> on 22 June 2009.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+New+Quotable+Einstein&amp;rft.pub=Princeton+University+Press&amp;rft.date=2005&amp;rft.aulast=Calaprice&amp;rft.aufirst=Alice&amp;rft_id=http%3A%2F%2Fpress.princeton.edu%2Ftitles%2F7921.html&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCalapriceLipscombe2005" class="citation book cs1">Calaprice, Alice; Lipscombe, Trevor (2005). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=5eWh2O_3OAQC"><i>Albert Einstein: A Biography</i></a>. Greenwood Publishing Group. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-313-33080-3" title="Special:BookSources/978-0-313-33080-3"><bdi>978-0-313-33080-3</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein%3A+A+Biography&amp;rft.pub=Greenwood+Publishing+Group&amp;rft.date=2005&amp;rft.isbn=978-0-313-33080-3&amp;rft.aulast=Calaprice&amp;rft.aufirst=Alice&amp;rft.au=Lipscombe%2C+Trevor&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3D5eWh2O_3OAQC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCalaprice2010" class="citation book cs1">Calaprice, Alice (2010). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=G_iziBAPXtEC"><i>The Ultimate Quotable Einstein</i></a>. Princeton University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-4008-3596-6" title="Special:BookSources/978-1-4008-3596-6"><bdi>978-1-4008-3596-6</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Ultimate+Quotable+Einstein&amp;rft.pub=Princeton+University+Press&amp;rft.date=2010&amp;rft.isbn=978-1-4008-3596-6&amp;rft.aulast=Calaprice&amp;rft.aufirst=Alice&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DG_iziBAPXtEC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFCalapriceKennefickSchulmann2015" class="citation book cs1">Calaprice, Alice; Kennefick, Daniel; Schulmann, Robert (2015). <i>An Einstein Encyclopedia</i>. Princeton University Press. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2016eien.book.....C">2016eien.book.....C</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=An+Einstein+Encyclopedia&amp;rft.pub=Princeton+University+Press&amp;rft.date=2015&amp;rft_id=info%3Abibcode%2F2016eien.book.....C&amp;rft.aulast=Calaprice&amp;rft.aufirst=Alice&amp;rft.au=Kennefick%2C+Daniel&amp;rft.au=Schulmann%2C+Robert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFChaplin1964" class="citation book cs1">Chaplin, Charles (1964). <i>Charles Chaplin: My Autobiography</i>. New York: Simon and Schuster.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Charles+Chaplin%3A+My+Autobiography&amp;rft.place=New+York&amp;rft.pub=Simon+and+Schuster&amp;rft.date=1964&amp;rft.aulast=Chaplin&amp;rft.aufirst=Charles&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFClark1971" class="citation book cs1"><a href="/wiki/Ronald_W._Clark" title="Ronald W. Clark">Clark, Ronald W.</a> (1971). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/einstein00rona"><i>Einstein: The Life and Times</i></a></span>. New York: Avon Books. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-380-44123-5" title="Special:BookSources/978-0-380-44123-5"><bdi>978-0-380-44123-5</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%3A+The+Life+and+Times&amp;rft.place=New+York&amp;rft.pub=Avon+Books&amp;rft.date=1971&amp;rft.isbn=978-0-380-44123-5&amp;rft.aulast=Clark&amp;rft.aufirst=Ronald+W.&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinstein00rona&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFölsing1997" class="citation book cs1">Fölsing, Albrecht (1997). <a rel="nofollow" class="external text" href="https://archive.org/details/alberteinsteinbi00fols"><i>Albert Einstein</i></a>. Translated by Osers, Ewald. Abridged by Ewald Osers. New York: Penguin Viking. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-670-85545-2" title="Special:BookSources/978-0-670-85545-2"><bdi>978-0-670-85545-2</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein&amp;rft.place=New+York&amp;rft.pub=Penguin+Viking&amp;rft.date=1997&amp;rft.isbn=978-0-670-85545-2&amp;rft.aulast=F%C3%B6lsing&amp;rft.aufirst=Albrecht&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Falberteinsteinbi00fols&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFFine2017" class="citation journal cs1">Fine, Arthur (2017). <a rel="nofollow" class="external text" href="https://plato.stanford.edu/entries/qt-epr/">"The Einstein-Podolsky-Rosen Argument in Quantum Theory"</a>. <i>Stanford Encyclopedia of Philosophy</i>. Metaphysics Research Lab, Stanford University.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Stanford+Encyclopedia+of+Philosophy&amp;rft.atitle=The+Einstein-Podolsky-Rosen+Argument+in+Quantum+Theory&amp;rft.date=2017&amp;rft.aulast=Fine&amp;rft.aufirst=Arthur&amp;rft_id=https%3A%2F%2Fplato.stanford.edu%2Fentries%2Fqt-epr%2F&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGalison2000" class="citation journal cs1">Galison, Peter (Winter 2000). "Einstein\'s Clocks: The Question of Time". <i>Critical Inquiry</i>. <b>26</b> (2): 355–389. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1086%2F448970">10.1086/448970</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/1344127">1344127</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:144484466">144484466</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Critical+Inquiry&amp;rft.atitle=Einstein%27s+Clocks%3A+The+Question+of+Time&amp;rft.ssn=winter&amp;rft.volume=26&amp;rft.issue=2&amp;rft.pages=355-389&amp;rft.date=2000&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A144484466%23id-name%3DS2CID&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F1344127%23id-name%3DJSTOR&amp;rft_id=info%3Adoi%2F10.1086%2F448970&amp;rft.aulast=Galison&amp;rft.aufirst=Peter&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGlick1987" class="citation book cs1">Glick, Thomas F., ed. (1987). <i>The Comparative Reception of Relativity</i>. Kluwer Academic Publishers. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-90-277-2498-4" title="Special:BookSources/978-90-277-2498-4"><bdi>978-90-277-2498-4</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Comparative+Reception+of+Relativity&amp;rft.pub=Kluwer+Academic+Publishers&amp;rft.date=1987&amp;rft.isbn=978-90-277-2498-4&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHarriganSpekkens2010" class="citation journal cs1">Harrigan, Nicholas; <a href="/wiki/Robert_Spekkens" title="Robert Spekkens">Spekkens, Robert W.</a> (2010). "Einstein, incompleteness, and the epistemic view of quantum states". <i><a href="/wiki/Foundations_of_Physics" title="Foundations of Physics">Foundations of Physics</a></i>. <b>40</b> (2): 125. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/0706.2661">0706.2661</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2010FoPh...40..125H">2010FoPh...40..125H</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1007%2Fs10701-009-9347-0">10.1007/s10701-009-9347-0</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:32755624">32755624</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Foundations+of+Physics&amp;rft.atitle=Einstein%2C+incompleteness%2C+and+the+epistemic+view+of+quantum+states&amp;rft.volume=40&amp;rft.issue=2&amp;rft.pages=125&amp;rft.date=2010&amp;rft_id=info%3Aarxiv%2F0706.2661&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A32755624%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1007%2Fs10701-009-9347-0&amp;rft_id=info%3Abibcode%2F2010FoPh...40..125H&amp;rft.aulast=Harrigan&amp;rft.aufirst=Nicholas&amp;rft.au=Spekkens%2C+Robert+W.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHighfieldCarter1993" class="citation book cs1"><a href="/wiki/Roger_Highfield" title="Roger Highfield">Highfield, Roger</a>; Carter, Paul (1993). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/privatelivesofal00high_1"><i>The Private Lives of Albert Einstein</i></a></span>. London: Faber and Faber. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-571-17170-5" title="Special:BookSources/978-0-571-17170-5"><bdi>978-0-571-17170-5</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Private+Lives+of+Albert+Einstein&amp;rft.place=London&amp;rft.pub=Faber+and+Faber&amp;rft.date=1993&amp;rft.isbn=978-0-571-17170-5&amp;rft.aulast=Highfield&amp;rft.aufirst=Roger&amp;rft.au=Carter%2C+Paul&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Fprivatelivesofal00high_1&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHoffmann1972" class="citation book cs1">Hoffmann, Banesh (1972). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/alberteinsteincr0000hoff_y3a8"><i>Albert Einstein: Creator and Rebel</i></a></span>. Collaboration with Helen Dukas. New York: Viking Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-670-11181-7" title="Special:BookSources/978-0-670-11181-7"><bdi>978-0-670-11181-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein%3A+Creator+and+Rebel&amp;rft.place=New+York&amp;rft.pub=Viking+Press&amp;rft.date=1972&amp;rft.isbn=978-0-670-11181-7&amp;rft.aulast=Hoffmann&amp;rft.aufirst=Banesh&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Falberteinsteincr0000hoff_y3a8&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHolton1984" class="citation journal cs1">Holton, Gerald (April 1984). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=prgDAAAAMBAJ&amp;pg=PA18">"The migration of physicists to the United States"</a>. <i>Bulletin of the Atomic Scientists</i>. <b>40</b> (4). Educational Foundation for Nuclear Science: 18–24. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1984BuAtS..40d..18H">1984BuAtS..40d..18H</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1080%2F00963402.1984.11459207">10.1080/00963402.1984.11459207</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Bulletin+of+the+Atomic+Scientists&amp;rft.atitle=The+migration+of+physicists+to+the+United+States&amp;rft.volume=40&amp;rft.issue=4&amp;rft.pages=18-24&amp;rft.date=1984-04&amp;rft_id=info%3Adoi%2F10.1080%2F00963402.1984.11459207&amp;rft_id=info%3Abibcode%2F1984BuAtS..40d..18H&amp;rft.aulast=Holton&amp;rft.aufirst=Gerald&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DprgDAAAAMBAJ%26pg%3DPA18&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFHoward1990" class="citation book cs1">Howard, D. (1990). "<span class="cs1-kern-left"></span>"Nicht Sein Kann was Nicht Sein Darf," or the Prehistory of EPR, 1909–1935: Einstein\'s Early Worries about the Quantum Mechanics of Composite Systems". <i>Sixty-Two Years of Uncertainty</i>. NATO ASI Series. Vol.&#160;226. Springer. pp.&#160;61–111. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1007%2F978-1-4684-8771-8_6">10.1007/978-1-4684-8771-8_6</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-4684-8773-2" title="Special:BookSources/978-1-4684-8773-2"><bdi>978-1-4684-8773-2</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=%22Nicht+Sein+Kann+was+Nicht+Sein+Darf%2C%22+or+the+Prehistory+of+EPR%2C+1909%E2%80%931935%3A+Einstein%27s+Early+Worries+about+the+Quantum+Mechanics+of+Composite+Systems&amp;rft.btitle=Sixty-Two+Years+of+Uncertainty&amp;rft.series=NATO+ASI+Series&amp;rft.pages=61-111&amp;rft.pub=Springer&amp;rft.date=1990&amp;rft_id=info%3Adoi%2F10.1007%2F978-1-4684-8771-8_6&amp;rft.isbn=978-1-4684-8773-2&amp;rft.aulast=Howard&amp;rft.aufirst=D.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFIsaacson2007" class="citation book cs1"><a href="/wiki/Walter_Isaacson" title="Walter Isaacson">Isaacson, Walter</a> (2007). <i>Einstein: His Life and Universe</i>. New York: Simon &amp; Schuster Paperbacks. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-7432-6473-0" title="Special:BookSources/978-0-7432-6473-0"><bdi>978-0-7432-6473-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%3A+His+Life+and+Universe&amp;rft.place=New+York&amp;rft.pub=Simon+%26+Schuster+Paperbacks&amp;rft.date=2007&amp;rft.isbn=978-0-7432-6473-0&amp;rft.aulast=Isaacson&amp;rft.aufirst=Walter&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFIsaacson2008" class="citation book cs1"><a href="/wiki/Walter_Isaacson" title="Walter Isaacson">Isaacson, Walter</a> (2008). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=OzSJgdwk5esC"><i>Einstein: His Life and Universe</i></a>. New York: Simon &amp; Schuster. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-84739-589-4" title="Special:BookSources/978-1-84739-589-4"><bdi>978-1-84739-589-4</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%3A+His+Life+and+Universe&amp;rft.place=New+York&amp;rft.pub=Simon+%26+Schuster&amp;rft.date=2008&amp;rft.isbn=978-1-84739-589-4&amp;rft.aulast=Isaacson&amp;rft.aufirst=Walter&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DOzSJgdwk5esC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMermin1993" class="citation journal cs1"><a href="/wiki/N._David_Mermin" title="N. David Mermin">Mermin, N. David</a> (July 1993). <a rel="nofollow" class="external text" href="http://cqi.inf.usi.ch/qic/Mermin1993.pdf">"Hidden Variables and the Two Theorems of John Bell"</a> <span class="cs1-format">(PDF)</span>. <i><a href="/wiki/Reviews_of_Modern_Physics" title="Reviews of Modern Physics">Reviews of Modern Physics</a></i>. <b>65</b> (3): 803–15. <a href="/wiki/ArXiv_(identifier)" class="mw-redirect" title="ArXiv (identifier)">arXiv</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://arxiv.org/abs/1802.10119">1802.10119</a></span>. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/1993RvMP...65..803M">1993RvMP...65..803M</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1103%2FRevModPhys.65.803">10.1103/RevModPhys.65.803</a>. <a href="/wiki/S2CID_(identifier)" class="mw-redirect" title="S2CID (identifier)">S2CID</a>&#160;<a rel="nofollow" class="external text" href="https://api.semanticscholar.org/CorpusID:119546199">119546199</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Reviews+of+Modern+Physics&amp;rft.atitle=Hidden+Variables+and+the+Two+Theorems+of+John+Bell&amp;rft.volume=65&amp;rft.issue=3&amp;rft.pages=803-15&amp;rft.date=1993-07&amp;rft_id=info%3Aarxiv%2F1802.10119&amp;rft_id=https%3A%2F%2Fapi.semanticscholar.org%2FCorpusID%3A119546199%23id-name%3DS2CID&amp;rft_id=info%3Adoi%2F10.1103%2FRevModPhys.65.803&amp;rft_id=info%3Abibcode%2F1993RvMP...65..803M&amp;rft.aulast=Mermin&amp;rft.aufirst=N.+David&amp;rft_id=http%3A%2F%2Fcqi.inf.usi.ch%2Fqic%2FMermin1993.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFNeffe2007" class="citation book cs1">Neffe, Jürgen (2007). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=B8K6n177ZwcC"><i>Einstein: A Biography</i></a>. Translated by Frisch, Shelley. <a href="/wiki/Farrar,_Straus_and_Giroux" title="Farrar, Straus and Giroux">Farrar, Straus and Giroux</a>. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-374-14664-1" title="Special:BookSources/978-0-374-14664-1"><bdi>978-0-374-14664-1</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%3A+A+Biography&amp;rft.pub=Farrar%2C+Straus+and+Giroux&amp;rft.date=2007&amp;rft.isbn=978-0-374-14664-1&amp;rft.aulast=Neffe&amp;rft.aufirst=J%C3%BCrgen&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DB8K6n177ZwcC&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPais1982" class="citation book cs1">Pais, Abraham (1982). <i><a href="/wiki/Subtle_is_the_Lord:_The_Science_and_the_Life_of_Albert_Einstein" class="mw-redirect" title="Subtle is the Lord: The Science and the Life of Albert Einstein">Subtle is the Lord: The Science and the Life of Albert Einstein</a></i>. Oxford University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-19-853907-0" title="Special:BookSources/978-0-19-853907-0"><bdi>978-0-19-853907-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Subtle+is+the+Lord%3A+The+Science+and+the+Life+of+Albert+Einstein&amp;rft.pub=Oxford+University+Press&amp;rft.date=1982&amp;rft.isbn=978-0-19-853907-0&amp;rft.aulast=Pais&amp;rft.aufirst=Abraham&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPais1994" class="citation book cs1">Pais, Abraham (1994). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/einsteinlivedher00pais"><i>Einstein Lived Here</i></a></span>. Oxford University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-19-280672-7" title="Special:BookSources/978-0-19-280672-7"><bdi>978-0-19-280672-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+Lived+Here&amp;rft.pub=Oxford+University+Press&amp;rft.date=1994&amp;rft.isbn=978-0-19-280672-7&amp;rft.aulast=Pais&amp;rft.aufirst=Abraham&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinsteinlivedher00pais&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPenrose2007" class="citation book cs1">Penrose, Roger (2007). <i>The Road to Reality</i>. Vintage Books. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-679-77631-4" title="Special:BookSources/978-0-679-77631-4"><bdi>978-0-679-77631-4</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+Road+to+Reality&amp;rft.pub=Vintage+Books&amp;rft.date=2007&amp;rft.isbn=978-0-679-77631-4&amp;rft.aulast=Penrose&amp;rft.aufirst=Roger&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFPeres2002" class="citation book cs1"><a href="/wiki/Asher_Peres" title="Asher Peres">Peres, Asher</a> (2002). <i>Quantum Theory: Concepts and Methods</i>. Kluwer. p.&#160;149.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Quantum+Theory%3A+Concepts+and+Methods&amp;rft.pages=149&amp;rft.pub=Kluwer&amp;rft.date=2002&amp;rft.aulast=Peres&amp;rft.aufirst=Asher&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRobeson2002" class="citation book cs1"><a href="/wiki/Paul_Robeson" title="Paul Robeson">Robeson, Paul</a> (2002). <i>Paul Robeson Speaks</i>. Citadel. p.&#160;333.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Paul+Robeson+Speaks&amp;rft.pages=333&amp;rft.pub=Citadel&amp;rft.date=2002&amp;rft.aulast=Robeson&amp;rft.aufirst=Paul&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRoweSchulmann2007" class="citation book cs1">Rowe, David E.; Schulmann, Robert, eds. (2007). <i>Einstein on Politics: His Private Thoughts and Public Stands on Nationalism, Zionism, War, Peace, and the Bomb</i>. Princeton University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-12094-2" title="Special:BookSources/978-0-691-12094-2"><bdi>978-0-691-12094-2</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+on+Politics%3A+His+Private+Thoughts+and+Public+Stands+on+Nationalism%2C+Zionism%2C+War%2C+Peace%2C+and+the+Bomb&amp;rft.pub=Princeton+University+Press&amp;rft.date=2007&amp;rft.isbn=978-0-691-12094-2&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRoweSchulmann2013" class="citation book cs1">Rowe, David E.; Schulmann, Robert, eds. (2013). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=_X1dAAAAQBAJ"><i>Einstein on Politics: His Private Thoughts and Public Stands on Nationalism, Zionism, War, Peace, and the Bomb</i></a>. Princeton University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-4008-4828-7" title="Special:BookSources/978-1-4008-4828-7"><bdi>978-1-4008-4828-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+on+Politics%3A+His+Private+Thoughts+and+Public+Stands+on+Nationalism%2C+Zionism%2C+War%2C+Peace%2C+and+the+Bomb&amp;rft.pub=Princeton+University+Press&amp;rft.date=2013&amp;rft.isbn=978-1-4008-4828-7&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3D_X1dAAAAQBAJ&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFScheideler2002" class="citation journal cs1">Scheideler, Britta (2002). "The Scientist as Moral Authority: Albert Einstein between Elitism and Democracy, 1914–1933". <i>Historical Studies in the Physical and Biological Sciences</i>. <b>32</b> (2): 319–346. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<a rel="nofollow" class="external text" href="https://doi.org/10.1525%2Fhsps.2002.32.2.319">10.1525/hsps.2002.32.2.319</a>. <a href="/wiki/JSTOR_(identifier)" class="mw-redirect" title="JSTOR (identifier)">JSTOR</a>&#160;<a rel="nofollow" class="external text" href="https://www.jstor.org/stable/10.1525/hsps.2002.32.2.319">10.1525/hsps.2002.32.2.319</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Historical+Studies+in+the+Physical+and+Biological+Sciences&amp;rft.atitle=The+Scientist+as+Moral+Authority%3A+Albert+Einstein+between+Elitism+and+Democracy%2C+1914%E2%80%931933&amp;rft.volume=32&amp;rft.issue=2&amp;rft.pages=319-346&amp;rft.date=2002&amp;rft_id=info%3Adoi%2F10.1525%2Fhsps.2002.32.2.319&amp;rft_id=https%3A%2F%2Fwww.jstor.org%2Fstable%2F10.1525%2Fhsps.2002.32.2.319%23id-name%3DJSTOR&amp;rft.aulast=Scheideler&amp;rft.aufirst=Britta&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFStachel1966" class="citation book cs1">Stachel, John J. (1966). <a rel="nofollow" class="external text" href="https://web.archive.org/web/20080307015425/http://philoscience.unibe.ch/lehre/winter99/einstein/Stachel1966.pdf"><i>Albert Einstein and Mileva Marić</i></a> <span class="cs1-format">(PDF)</span>. Archived from <a rel="nofollow" class="external text" href="http://philoscience.unibe.ch/lehre/winter99/einstein/Stachel1966.pdf">the original</a> <span class="cs1-format">(PDF)</span> on 7 March 2008<span class="reference-accessdate">. Retrieved <span class="nowrap">13 May</span> 2016</span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Albert+Einstein+and+Mileva+Mari%C4%87&amp;rft.date=1966&amp;rft.aulast=Stachel&amp;rft.aufirst=John+J.&amp;rft_id=http%3A%2F%2Fphiloscience.unibe.ch%2Flehre%2Fwinter99%2Feinstein%2FStachel1966.pdf&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFStachel2002" class="citation book cs1">Stachel, John J. (2002). <i>Einstein from \'B\' to \'Z\'<span></span></i>. Einstein Studies. Vol.&#160;9. Birkhäuser. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-8176-4143-6" title="Special:BookSources/978-0-8176-4143-6"><bdi>978-0-8176-4143-6</bdi></a>. <a href="/wiki/OCLC_(identifier)" class="mw-redirect" title="OCLC (identifier)">OCLC</a>&#160;<a rel="nofollow" class="external text" href="https://www.worldcat.org/oclc/237532460">237532460</a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+from+%27B%27+to+%27Z%27&amp;rft.series=Einstein+Studies&amp;rft.pub=Birkh%C3%A4user&amp;rft.date=2002&amp;rft_id=info%3Aoclcnum%2F237532460&amp;rft.isbn=978-0-8176-4143-6&amp;rft.aulast=Stachel&amp;rft.aufirst=John+J.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWeinstein2015" class="citation book cs1">Weinstein, G. (2015). <a rel="nofollow" class="external text" href="https://books.google.com/books?id=LQz5DAAAQBAJ"><i>General Relativity Conflict and Rivalries: Einstein\'s Polemics with Physicists</i></a>. Newcastle upon Tyne (UK): Cambridge Scholars Publishing. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-4438-8362-7" title="Special:BookSources/978-1-4438-8362-7"><bdi>978-1-4438-8362-7</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=General+Relativity+Conflict+and+Rivalries%3A+Einstein%27s+Polemics+with+Physicists&amp;rft.place=Newcastle+upon+Tyne+%28UK%29&amp;rft.pub=Cambridge+Scholars+Publishing&amp;rft.date=2015&amp;rft.isbn=978-1-4438-8362-7&amp;rft.aulast=Weinstein&amp;rft.aufirst=G.&amp;rft_id=https%3A%2F%2Fbooks.google.com%2Fbooks%3Fid%3DLQz5DAAAQBAJ&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li></ul>
</div>
<h2><span class="mw-headline" id="Further_reading">Further reading</span></h2>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1184024115"><div class="div-col" style="column-width: 35em;">
<ul><li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFBrian1996" class="citation book cs1">Brian, Denis (1996). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/einstein00deni"><i>Einstein: A Life</i></a></span>. New York: John Wiley.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%3A+A+Life&amp;rft.place=New+York&amp;rft.pub=John+Wiley&amp;rft.date=1996&amp;rft.aulast=Brian&amp;rft.aufirst=Denis&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinstein00deni&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFGordin2020" class="citation book cs1">Gordin, Michael D. (2020). <i>Einstein in Bohemia</i>. Princeton University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-17737-3" title="Special:BookSources/978-0-691-17737-3"><bdi>978-0-691-17737-3</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+in+Bohemia&amp;rft.pub=Princeton+University+Press&amp;rft.date=2020&amp;rft.isbn=978-0-691-17737-3&amp;rft.aulast=Gordin&amp;rft.aufirst=Michael+D.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFLindemann1922" class="citation encyclopaedia cs1"><a href="/wiki/Frederick_Alexander_Lindemann" class="mw-redirect" title="Frederick Alexander Lindemann">Lindemann, Frederick Alexander</a> (1922). <span class="cs1-ws-icon" title="s:1922 Encyclopædia Britannica/Einstein, Albert"><a class="external text" href="https://en.wikisource.org/wiki/1922_Encyclop%C3%A6dia_Britannica/Einstein,_Albert">"Einstein, Albert"&#160;</a></span>. In Chisholm, Hugh (ed.). <i><a href="/wiki/Encyclop%C3%A6dia_Britannica" title="Encyclopædia Britannica">Encyclopædia Britannica</a></i> (12th&#160;ed.). London &amp; New York: The Encyclopædia Britannica Company.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=bookitem&amp;rft.atitle=Einstein%2C+Albert&amp;rft.btitle=Encyclop%C3%A6dia+Britannica&amp;rft.place=London+%26+New+York&amp;rft.edition=12th&amp;rft.pub=The+Encyclop%C3%A6dia+Britannica+Company&amp;rft.date=1922&amp;rft.aulast=Lindemann&amp;rft.aufirst=Frederick+Alexander&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFMoring2004" class="citation book cs1">Moring, Gary (2004). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/completeidiotsgu00mori_0"><i>The complete idiot\'s guide to understanding Einstein</i></a></span> (1st&#160;ed.). Indianapolis, Indiana: Alpha books (Macmillan). <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-02-863180-6" title="Special:BookSources/978-0-02-863180-6"><bdi>978-0-02-863180-6</bdi></a>. <q>idiot\'s guide to Einstein.</q></cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=The+complete+idiot%27s+guide+to+understanding+Einstein&amp;rft.place=Indianapolis%2C+Indiana&amp;rft.edition=1st&amp;rft.pub=Alpha+books+%28Macmillan%29&amp;rft.date=2004&amp;rft.isbn=978-0-02-863180-6&amp;rft.aulast=Moring&amp;rft.aufirst=Gary&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Fcompleteidiotsgu00mori_0&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFOppenheimer1971" class="citation journal cs1"><a href="/wiki/J._Robert_Oppenheimer" title="J. Robert Oppenheimer">Oppenheimer, J. Robert</a> (1971). "On Albert Einstein". <i>Science and Synthesis: An International Colloquium Organized by Unesco on the Tenth Anniversary of the Death of Albert Einstein and Teilhard de Chardin</i>. Lecture delivered at the UNESCO House in Paris on 13 December 1965: 8–12, 208.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Science+and+Synthesis%3A+An+International+Colloquium+Organized+by+Unesco+on+the+Tenth+Anniversary+of+the+Death+of+Albert+Einstein+and+Teilhard+de+Chardin&amp;rft.atitle=On+Albert+Einstein&amp;rft.pages=8-12%2C+208&amp;rft.date=1971&amp;rft.aulast=Oppenheimer&amp;rft.aufirst=J.+Robert&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span>, or <link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite class="citation news cs1"><a rel="nofollow" class="external text" href="http://www.nybooks.com/articles/archives/1966/mar/17/on-albert-einstein/?pagination=false">"On Albert Einstein by Robert Oppenheimer"</a>. <i><a href="/wiki/The_New_York_Review_of_Books" title="The New York Review of Books">The New York Review of Books</a></i>. 17 March 1966.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=The+New+York+Review+of+Books&amp;rft.atitle=On+Albert+Einstein+by+Robert+Oppenheimer&amp;rft.date=1966-03-17&amp;rft_id=http%3A%2F%2Fwww.nybooks.com%2Farticles%2Farchives%2F1966%2Fmar%2F17%2Fon-albert-einstein%2F%3Fpagination%3Dfalse&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFParker2000" class="citation book cs1">Parker, Barry (2000). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/einsteinsbrainch00barr"><i>Einstein\'s Brainchild: Relativity Made Relatively Easy!</i></a></span>. Illustrated by Lori Scoffield-Beer. Prometheus Books. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-1-59102-522-1" title="Special:BookSources/978-1-59102-522-1"><bdi>978-1-59102-522-1</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%27s+Brainchild%3A+Relativity+Made+Relatively+Easy%21&amp;rft.pub=Prometheus+Books&amp;rft.date=2000&amp;rft.isbn=978-1-59102-522-1&amp;rft.aulast=Parker&amp;rft.aufirst=Barry&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinsteinsbrainch00barr&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFRogers2005" class="citation book cs1">Rogers, Donald W. (2005). <i>Einstein\'s "Other" Theory: The Planck-Bose-Einstein Theory of Heat Capacity</i>. Princeton University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-11826-0" title="Special:BookSources/978-0-691-11826-0"><bdi>978-0-691-11826-0</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein%27s+%22Other%22+Theory%3A+The+Planck-Bose-Einstein+Theory+of+Heat+Capacity&amp;rft.pub=Princeton+University+Press&amp;rft.date=2005&amp;rft.isbn=978-0-691-11826-0&amp;rft.aulast=Rogers&amp;rft.aufirst=Donald+W.&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFSchweber2008" class="citation book cs1"><a href="/wiki/Silvan_S._Schweber" title="Silvan S. Schweber">Schweber, Silvan S.</a> (2008). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/einsteinoppenhei00schw"><i>Einstein and Oppenheimer: The Meaning of Genius</i></a></span>. Harvard University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-674-02828-9" title="Special:BookSources/978-0-674-02828-9"><bdi>978-0-674-02828-9</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+and+Oppenheimer%3A+The+Meaning+of+Genius&amp;rft.pub=Harvard+University+Press&amp;rft.date=2008&amp;rft.isbn=978-0-674-02828-9&amp;rft.aulast=Schweber&amp;rft.aufirst=Silvan+S.&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinsteinoppenhei00schw&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFStone2013" class="citation book cs1">Stone, A. Douglas (2013). <span class="id-lock-registration" title="Free registration required"><a rel="nofollow" class="external text" href="https://archive.org/details/einsteinquantumq0000ston"><i>Einstein and the Quantum</i></a></span>. Princeton University Press. <a href="/wiki/ISBN_(identifier)" class="mw-redirect" title="ISBN (identifier)">ISBN</a>&#160;<a href="/wiki/Special:BookSources/978-0-691-13968-5" title="Special:BookSources/978-0-691-13968-5"><bdi>978-0-691-13968-5</bdi></a>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook&amp;rft.genre=book&amp;rft.btitle=Einstein+and+the+Quantum&amp;rft.pub=Princeton+University+Press&amp;rft.date=2013&amp;rft.isbn=978-0-691-13968-5&amp;rft.aulast=Stone&amp;rft.aufirst=A.+Douglas&amp;rft_id=https%3A%2F%2Farchive.org%2Fdetails%2Feinsteinquantumq0000ston&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li>
<li><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1215172403"><cite id="CITEREFWeinberg2005" class="citation journal cs1">Weinberg, Steven (2005). <a rel="nofollow" class="external text" href="https://doi.org/10.1063%2F1.2155755">"Einstein\'s mistakes"</a>. <i>Physics Today</i>. <b>58</b> (11): 31–35. <a href="/wiki/Bibcode_(identifier)" class="mw-redirect" title="Bibcode (identifier)">Bibcode</a>:<a rel="nofollow" class="external text" href="https://ui.adsabs.harvard.edu/abs/2005PhT....58k..31W">2005PhT....58k..31W</a>. <a href="/wiki/Doi_(identifier)" class="mw-redirect" title="Doi (identifier)">doi</a>:<span class="id-lock-free" title="Freely accessible"><a rel="nofollow" class="external text" href="https://doi.org/10.1063%2F1.2155755">10.1063/1.2155755</a></span>.</cite><span title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.genre=article&amp;rft.jtitle=Physics+Today&amp;rft.atitle=Einstein%27s+mistakes&amp;rft.volume=58&amp;rft.issue=11&amp;rft.pages=31-35&amp;rft.date=2005&amp;rft_id=info%3Adoi%2F10.1063%2F1.2155755&amp;rft_id=info%3Abibcode%2F2005PhT....58k..31W&amp;rft.aulast=Weinberg&amp;rft.aufirst=Steven&amp;rft_id=https%3A%2F%2Fdoi.org%2F10.1063%252F1.2155755&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AAlbert+Einstein" class="Z3988"></span></li></ul>
</div>
<h2><span class="mw-headline" id="External_links">External links</span></h2>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1217611005"><style data-mw-deduplicate="TemplateStyles:r1097092911">.mw-parser-output .sister-box .side-box-abovebelow{padding:0.75em 0;text-align:center}.mw-parser-output .sister-box .side-box-abovebelow>b{display:block}.mw-parser-output .sister-box .side-box-text>ul{border-top:1px solid #aaa;padding:0.75em 0;width:217px;margin:0 auto}.mw-parser-output .sister-box .side-box-text>ul>li{min-height:31px}.mw-parser-output .sister-logo{display:inline-block;width:31px;line-height:31px;vertical-align:middle;text-align:center}.mw-parser-output .sister-link{display:inline-block;margin-left:4px;width:182px;vertical-align:middle}</style><div role="navigation" aria-labelledby="sister-projects" class="side-box metadata side-box-right sister-box sistersitebox plainlinks"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409">
<div class="side-box-abovebelow">
<b>Albert Einstein</b>  at Wikipedia\'s <a href="/wiki/Wikipedia:Wikimedia_sister_projects" title="Wikipedia:Wikimedia sister projects"><span id="sister-projects">sister projects</span></a></div>
<div class="side-box-flex">
<div class="side-box-text plainlist"><ul><li><span class="sister-logo"><span class="mw-valign-middle" typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/en/thumb/4/4a/Commons-logo.svg/20px-Commons-logo.svg.png" decoding="async" width="20" height="27" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/4/4a/Commons-logo.svg/30px-Commons-logo.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/4/4a/Commons-logo.svg/40px-Commons-logo.svg.png 2x" data-file-width="1024" data-file-height="1376" /></span></span></span><span class="sister-link"><a href="https://commons.wikimedia.org/wiki/Albert_Einstein" class="extiw" title="c:Albert Einstein">Media</a> from Commons</span></li><li><span class="sister-logo"><span class="mw-valign-middle" typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/f/fa/Wikiquote-logo.svg/23px-Wikiquote-logo.svg.png" decoding="async" width="23" height="27" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/f/fa/Wikiquote-logo.svg/35px-Wikiquote-logo.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/f/fa/Wikiquote-logo.svg/46px-Wikiquote-logo.svg.png 2x" data-file-width="300" data-file-height="355" /></span></span></span><span class="sister-link"><a href="https://en.wikiquote.org/wiki/Albert_Einstein" class="extiw" title="q:Albert Einstein">Quotations</a> from Wikiquote</span></li><li><span class="sister-logo"><span class="mw-valign-middle" typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/4/4c/Wikisource-logo.svg/26px-Wikisource-logo.svg.png" decoding="async" width="26" height="27" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/4/4c/Wikisource-logo.svg/39px-Wikisource-logo.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/4/4c/Wikisource-logo.svg/51px-Wikisource-logo.svg.png 2x" data-file-width="410" data-file-height="430" /></span></span></span><span class="sister-link"><a href="https://en.wikisource.org/wiki/Author:Albert_Einstein" class="extiw" title="s:Author:Albert Einstein">Texts</a> from Wikisource</span></li></ul></div></div>
</div>
<link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1217611005"><div class="side-box metadata side-box-right"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1126788409">
<div class="side-box-flex">
<div class="side-box-image"><span class="noviewer" typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/3/32/Scholia_logo.svg/40px-Scholia_logo.svg.png" decoding="async" width="40" height="39" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/3/32/Scholia_logo.svg/60px-Scholia_logo.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/3/32/Scholia_logo.svg/80px-Scholia_logo.svg.png 2x" data-file-width="107" data-file-height="104" /></span></span></div>
<div class="side-box-text plainlist"><a href="https://www.wikidata.org/wiki/Wikidata:Scholia" class="extiw" title="d:Wikidata:Scholia">Scholia</a> has an <i>author</i> profile for <i><b><a href="https://iw.toolforge.org/scholia/author/Q937" class="extiw" title="toolforge:scholia/author/Q937">Albert Einstein</a></b></i>.</div></div>
</div>
<ul><li><a rel="nofollow" class="external text" href="https://curlie.org/Science/Physics/History/People/Einstein%2C_Albert/">Albert Einstein</a> at <a href="/wiki/Curlie" class="mw-redirect" title="Curlie">Curlie</a></li>
<li><a rel="nofollow" class="external text" href="https://www.gutenberg.org/ebooks/author/1630">Works by Albert Einstein</a> at <a href="/wiki/Project_Gutenberg" title="Project Gutenberg">Project Gutenberg</a></li>
<li><a rel="nofollow" class="external text" href="https://archive.org/search.php?query=%28%28subject%3A%22Einstein%2C%20Albert%22%20OR%20subject%3A%22Albert%20Einstein%22%20OR%20creator%3A%22Einstein%2C%20Albert%22%20OR%20creator%3A%22Albert%20Einstein%22%20OR%20creator%3A%22Einstein%2C%20A%2E%22%20OR%20title%3A%22Albert%20Einstein%22%20OR%20description%3A%22Einstein%2C%20Albert%22%20OR%20description%3A%22Albert%20Einstein%22%29%20OR%20%28%221879-1955%22%20AND%20Einstein%29%29%20AND%20%28-mediatype:software%29">Works by or about Albert Einstein</a> at <a href="/wiki/Internet_Archive" title="Internet Archive">Internet Archive</a></li>
<li><a rel="nofollow" class="external text" href="https://librivox.org/author/1035">Works by Albert Einstein</a> at <a href="/wiki/LibriVox" title="LibriVox">LibriVox</a> (public domain audiobooks) <span typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/2/21/Speaker_Icon.svg/15px-Speaker_Icon.svg.png" decoding="async" width="15" height="15" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/2/21/Speaker_Icon.svg/23px-Speaker_Icon.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/2/21/Speaker_Icon.svg/30px-Speaker_Icon.svg.png 2x" data-file-width="500" data-file-height="500" /></span></span></li>
<li><a rel="nofollow" class="external text" href="http://www.shapell.org/Collection/Jewish-Figures/Einstein-Albert">Einstein\'s Personal Correspondence: Religion, Politics, The Holocaust, and Philosophy</a> Shapell Manuscript Foundation</li>
<li><a rel="nofollow" class="external text" href="https://vault.fbi.gov/Albert%20Einstein">Federal Bureau of Investigation file on Albert Einstein</a></li>
<li><a rel="nofollow" class="external text" href="https://web.archive.org/web/20150828225916/http://www.pha.jhu.edu/einstein/stuff/einstein%26music.pdf">Einstein and his love of music</a>, <i><a href="/wiki/Physics_World" title="Physics World">Physics World</a></i></li>
<li><a rel="nofollow" class="external text" href="https://www.nobelprize.org/laureate/26">Albert Einstein</a> on Nobelprize.org <span class="mw-valign-text-top noprint" typeof="mw:File/Frameless"><a href="https://www.wikidata.org/wiki/Q937#P8024" title="Edit this at Wikidata"><img alt="Edit this at Wikidata" src="//upload.wikimedia.org/wikipedia/en/thumb/8/8a/OOjs_UI_icon_edit-ltr-progressive.svg/10px-OOjs_UI_icon_edit-ltr-progressive.svg.png" decoding="async" width="10" height="10" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/8/8a/OOjs_UI_icon_edit-ltr-progressive.svg/15px-OOjs_UI_icon_edit-ltr-progressive.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/8/8a/OOjs_UI_icon_edit-ltr-progressive.svg/20px-OOjs_UI_icon_edit-ltr-progressive.svg.png 2x" data-file-width="20" data-file-height="20" /></a></span> including the Nobel Lecture 11 July 1923 <i>Fundamental ideas and problems of the theory of relativity</i></li>
<li><a rel="nofollow" class="external text" href="http://www.alberteinstein.info/">Albert Einstein Archives Online (80,000+ Documents)</a> <a rel="nofollow" class="external text" href="https://web.archive.org/web/20110811112756/http://www.alberteinstein.info/">Archived</a> 11 August 2011 at the <a href="/wiki/Wayback_Machine" title="Wayback Machine">Wayback Machine</a> (<a rel="nofollow" class="external text" href="http://www.nbcnews.com/id/46785542">MSNBC, 19 March 2012</a>)</li>
<li><a rel="nofollow" class="external text" href="http://www.wdl.org/en/item/2745/">Einstein\'s declaration of intention for American citizenship</a> on the <a href="/wiki/World_Digital_Library" title="World Digital Library">World Digital Library</a></li>
<li><a rel="nofollow" class="external text" href="https://web.archive.org/web/20130929151059/http://archon.brandeis.edu/?p=collections%2Ffindingaid&amp;id=41">Albert Einstein Collection</a> at <a href="/wiki/Brandeis_University" title="Brandeis University">Brandeis University</a></li>
<li><a rel="nofollow" class="external text" href="http://einsteinpapers.press.princeton.edu/">The Collected Papers of Albert Einstein "Digital Einstein"</a> at <a href="/wiki/Princeton_University" title="Princeton University">Princeton University</a></li>
<li><a rel="nofollow" class="external text" href="http://purl.org/pressemappe20/folder/pe/004590">Newspaper clippings about Albert Einstein</a> in the <a href="/wiki/20th_Century_Press_Archives" title="20th Century Press Archives">20th Century Press Archives</a> of the <a href="/wiki/German_National_Library_of_Economics" title="German National Library of Economics">ZBW</a></li>
<li><a rel="nofollow" class="external text" href="https://www.ias.edu/scholars/einstein">Home page of Albert Einstein at The Institute for Advanced Study</a></li>
<li><a rel="nofollow" class="external text" href="https://albert.ias.edu/">Albert – The Digital Repository of the IAS</a>, which contains many digitized original documents and photographs</li>
<li><a rel="nofollow" class="external text" href="https://www.imdb.com/name/nm0251868/">Albert Einstein</a> at <a href="/wiki/IMDb_(identifier)" class="mw-redirect" title="IMDb (identifier)">IMDb</a></li></ul>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><style data-mw-deduplicate="TemplateStyles:r1061467846">.mw-parser-output .navbox{box-sizing:border-box;border:1px solid #a2a9b1;width:100%;clear:both;font-size:88%;text-align:center;padding:1px;margin:1em auto 0}.mw-parser-output .navbox .navbox{margin-top:0}.mw-parser-output .navbox+.navbox,.mw-parser-output .navbox+.navbox-styles+.navbox{margin-top:-1px}.mw-parser-output .navbox-inner,.mw-parser-output .navbox-subgroup{width:100%}.mw-parser-output .navbox-group,.mw-parser-output .navbox-title,.mw-parser-output .navbox-abovebelow{padding:0.25em 1em;line-height:1.5em;text-align:center}.mw-parser-output .navbox-group{white-space:nowrap;text-align:right}.mw-parser-output .navbox,.mw-parser-output .navbox-subgroup{background-color:#fdfdfd}.mw-parser-output .navbox-list{line-height:1.5em;border-color:#fdfdfd}.mw-parser-output .navbox-list-with-group{text-align:left;border-left-width:2px;border-left-style:solid}.mw-parser-output tr+tr>.navbox-abovebelow,.mw-parser-output tr+tr>.navbox-group,.mw-parser-output tr+tr>.navbox-image,.mw-parser-output tr+tr>.navbox-list{border-top:2px solid #fdfdfd}.mw-parser-output .navbox-title{background-color:#ccf}.mw-parser-output .navbox-abovebelow,.mw-parser-output .navbox-group,.mw-parser-output .navbox-subgroup .navbox-title{background-color:#ddf}.mw-parser-output .navbox-subgroup .navbox-group,.mw-parser-output .navbox-subgroup .navbox-abovebelow{background-color:#e6e6ff}.mw-parser-output .navbox-even{background-color:#f7f7f7}.mw-parser-output .navbox-odd{background-color:transparent}.mw-parser-output .navbox .hlist td dl,.mw-parser-output .navbox .hlist td ol,.mw-parser-output .navbox .hlist td ul,.mw-parser-output .navbox td.hlist dl,.mw-parser-output .navbox td.hlist ol,.mw-parser-output .navbox td.hlist ul{padding:0.125em 0}.mw-parser-output .navbox .navbar{display:block;font-size:100%}.mw-parser-output .navbox-title .navbar{float:left;text-align:left;margin-right:0.5em}</style></div><div role="navigation" class="navbox" aria-labelledby="Albert_Einstein" style="padding:3px"><table class="nowraplinks mw-collapsible expanded navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:Albert_Einstein" title="Template:Albert Einstein"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:Albert_Einstein" title="Template talk:Albert Einstein"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:Albert_Einstein" title="Special:EditPage/Template:Albert Einstein"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="Albert_Einstein" style="font-size:114%;margin:0 4em"><a class="mw-selflink selflink">Albert Einstein</a></div></th></tr><tr><th scope="row" class="navbox-group" style="width:1%">Physics</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Theory_of_relativity" title="Theory of relativity">Theory of relativity</a>
<ul><li><a href="/wiki/Special_relativity" title="Special relativity">Special relativity</a></li>
<li><a href="/wiki/General_relativity" title="General relativity">General relativity</a></li></ul></li>
<li><a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence">Mass–energy equivalence (E=mc<sup>2</sup>)</a></li>
<li><a href="/wiki/Brownian_motion" title="Brownian motion">Brownian motion</a></li>
<li><a href="/wiki/Photoelectric_effect" title="Photoelectric effect">Photoelectric effect</a></li>
<li><a href="/wiki/Einstein_coefficients" title="Einstein coefficients">Einstein coefficients</a></li>
<li><a href="/wiki/Einstein_solid" title="Einstein solid">Einstein solid</a></li>
<li><a href="/wiki/Equivalence_principle" title="Equivalence principle">Equivalence principle</a></li>
<li><a href="/wiki/Einstein_field_equations" title="Einstein field equations">Einstein field equations</a></li>
<li><a href="/wiki/Einstein_radius" title="Einstein radius">Einstein radius</a></li>
<li><a href="/wiki/Einstein_relation_(kinetic_theory)" title="Einstein relation (kinetic theory)">Einstein relation (kinetic theory)</a></li>
<li><a href="/wiki/Cosmological_constant" title="Cosmological constant">Cosmological constant</a></li>
<li><a href="/wiki/Bose%E2%80%93Einstein_condensate" title="Bose–Einstein condensate">Bose–Einstein condensate</a></li>
<li><a href="/wiki/Bose%E2%80%93Einstein_statistics" title="Bose–Einstein statistics">Bose–Einstein statistics</a></li>
<li><a href="/wiki/Bose%E2%80%93Einstein_correlations" title="Bose–Einstein correlations">Bose–Einstein correlations</a></li>
<li><a href="/wiki/Einstein%E2%80%93Cartan_theory" title="Einstein–Cartan theory">Einstein–Cartan theory</a></li>
<li><a href="/wiki/Einstein%E2%80%93Infeld%E2%80%93Hoffmann_equations" title="Einstein–Infeld–Hoffmann equations">Einstein–Infeld–Hoffmann equations</a></li>
<li><a href="/wiki/Einstein%E2%80%93de_Haas_effect" title="Einstein–de Haas effect">Einstein–de Haas effect</a></li>
<li><a href="/wiki/EPR_paradox" class="mw-redirect" title="EPR paradox">EPR paradox</a></li>
<li><a href="/wiki/Bohr%E2%80%93Einstein_debates" title="Bohr–Einstein debates">Bohr–Einstein debates</a></li>
<li><a href="/wiki/Teleparallelism" title="Teleparallelism">Teleparallelism</a></li>
<li><a href="/wiki/Einstein%27s_thought_experiments" title="Einstein&#39;s thought experiments">Thought experiments</a></li>
<li><a href="/wiki/Einstein%27s_unsuccessful_investigations" title="Einstein&#39;s unsuccessful investigations">Unsuccessful investigations</a></li>
<li><a href="/wiki/Wave%E2%80%93particle_duality" title="Wave–particle duality">Wave–particle duality</a></li>
<li><a href="/wiki/Gravitational_wave" title="Gravitational wave">Gravitational wave</a></li>
<li><a href="/wiki/Tea_leaf_paradox" title="Tea leaf paradox">Tea leaf paradox</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/List_of_scientific_publications_by_Albert_Einstein" title="List of scientific publications by Albert Einstein">Works</a></th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Annus_mirabilis_papers" title="Annus mirabilis papers"><i>Annus mirabilis</i> papers</a> (1905)</li>
<li>"<a href="/wiki/%C3%9Cber_die_von_der_molekularkinetischen_Theorie_der_W%C3%A4rme_geforderte_Bewegung_von_in_ruhenden_Fl%C3%BCssigkeiten_suspendierten_Teilchen" title="Über die von der molekularkinetischen Theorie der Wärme geforderte Bewegung von in ruhenden Flüssigkeiten suspendierten Teilchen">Investigations on the Theory of Brownian Movement</a>" (1905)</li>
<li><i><a href="/wiki/Relativity:_The_Special_and_the_General_Theory" title="Relativity: The Special and the General Theory">Relativity: The Special and the General Theory</a></i> (1916)</li>
<li><i><a href="/wiki/The_Meaning_of_Relativity" title="The Meaning of Relativity">The Meaning of Relativity</a></i> (1922)</li>
<li><i><a href="/wiki/The_World_as_I_See_It_(book)" title="The World as I See It (book)">The World as I See It</a></i> (1934)</li>
<li><i><a href="/wiki/The_Evolution_of_Physics" title="The Evolution of Physics">The Evolution of Physics</a></i> (1938)</li>
<li>"<a href="/wiki/Why_Socialism%3F" title="Why Socialism?">Why Socialism?</a>" (1949)</li>
<li><a href="/wiki/Russell%E2%80%93Einstein_Manifesto" title="Russell–Einstein Manifesto">Russell–Einstein Manifesto</a> (1955)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Albert_Einstein_in_popular_culture" title="Albert Einstein in popular culture">In popular<br />culture</a></th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><i><a href="/wiki/Die_Grundlagen_der_Einsteinschen_Relativit%C3%A4ts-Theorie" title="Die Grundlagen der Einsteinschen Relativitäts-Theorie">Die Grundlagen der Einsteinschen Relativitäts-Theorie</a></i> (1922 documentary)</li>
<li><i><a href="/wiki/The_Einstein_Theory_of_Relativity" title="The Einstein Theory of Relativity">The Einstein Theory of Relativity</a></i> (1923 documentary)</li>
<li><i><a href="/wiki/Relics:_Einstein%27s_Brain" title="Relics: Einstein&#39;s Brain">Relics: Einstein\'s Brain</a></i> (1994 documentary)</li>
<li><i><a href="/wiki/Insignificance_(film)" title="Insignificance (film)">Insignificance</a></i> (1985 film)</li>
<li><i><a href="/wiki/Picasso_at_the_Lapin_Agile" title="Picasso at the Lapin Agile">Picasso at the Lapin Agile</a></i> (1993 play)</li>
<li><i><a href="/wiki/I.Q._(film)" title="I.Q. (film)">I.Q.</a></i> (1994 film)</li>
<li><i><a href="/wiki/Einstein%27s_Gift" title="Einstein&#39;s Gift">Einstein\'s Gift</a></i> (2003 play)</li>
<li><i><a href="/wiki/Einstein_and_Eddington" title="Einstein and Eddington">Einstein and Eddington</a></i> (2008 TV film)</li>
<li><i><a href="/wiki/Genius_(American_TV_series)" title="Genius (American TV series)">Genius</a></i> (2017 series)</li>
<li><i><a href="/wiki/Oppenheimer_(film)" title="Oppenheimer (film)">Oppenheimer</a></i> (2023 film)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Prizes</th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Albert_Einstein_Award" title="Albert Einstein Award">Albert Einstein Award</a></li>
<li><a href="/wiki/Albert_Einstein_Medal" title="Albert Einstein Medal">Albert Einstein Medal</a></li>
<li><a href="/wiki/Kalinga_Prize" title="Kalinga Prize">Kalinga Prize</a></li>
<li><a href="/wiki/Albert_Einstein_Peace_Prize" title="Albert Einstein Peace Prize">Albert Einstein Peace Prize</a></li>
<li><a href="/wiki/Albert_Einstein_World_Award_of_Science" title="Albert Einstein World Award of Science">Albert Einstein World Award of Science</a></li>
<li><a href="/wiki/Einstein_Prize_for_Laser_Science" title="Einstein Prize for Laser Science">Einstein Prize for Laser Science</a></li>
<li><a href="/wiki/Einstein_Prize_(APS)" title="Einstein Prize (APS)">Einstein Prize (APS)</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Books about<br />Einstein</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><i><a href="/wiki/Albert_Einstein:_Creator_and_Rebel" title="Albert Einstein: Creator and Rebel">Albert Einstein: Creator and Rebel</a></i></li>
<li><i><a href="/wiki/Einstein_and_Religion" title="Einstein and Religion">Einstein and Religion</a></i></li>
<li><i><a href="/wiki/Einstein_for_Beginners" title="Einstein for Beginners">Einstein for Beginners</a></i></li>
<li><i><a href="/wiki/Einstein:_His_Life_and_Universe" title="Einstein: His Life and Universe">Einstein: His Life and Universe</a></i></li>
<li><i><a href="/wiki/Einstein%27s_Cosmos" title="Einstein&#39;s Cosmos">Einstein\'s Cosmos</a></i></li>
<li><i><a href="/wiki/I_Am_Albert_Einstein" title="I Am Albert Einstein">I Am Albert Einstein</a></i></li>
<li><i><a href="/wiki/Introducing_Relativity" title="Introducing Relativity">Introducing Relativity</a></i></li>
<li><i><a href="/wiki/Subtle_is_the_Lord" title="Subtle is the Lord">Subtle is the Lord</a></i></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Einstein_family" title="Einstein family">Family</a></th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Mileva_Mari%C4%87" title="Mileva Marić">Mileva Marić</a> (first wife)</li>
<li><a href="/wiki/Elsa_Einstein" title="Elsa Einstein">Elsa Einstein</a> (second wife; cousin)</li>
<li><a href="/wiki/Lieserl_Einstein" class="mw-redirect" title="Lieserl Einstein">Lieserl Einstein</a> (daughter)</li>
<li><a href="/wiki/Hans_Albert_Einstein" title="Hans Albert Einstein">Hans Albert Einstein</a> (son)</li>
<li><a href="/wiki/Pauline_Koch" class="mw-redirect" title="Pauline Koch">Pauline Koch</a> (mother)</li>
<li><a href="/wiki/Hermann_Einstein" class="mw-redirect" title="Hermann Einstein">Hermann Einstein</a> (father)</li>
<li><a href="/wiki/Maja_Einstein" class="mw-redirect" title="Maja Einstein">Maja Einstein</a> (sister)</li>
<li><a href="/wiki/Einstein_family#Eduard_&quot;Tete&quot;_Einstein_(Albert&#39;s_second_son)" title="Einstein family">Eduard Einstein</a> (son)</li>
<li><a href="/wiki/Murder_of_the_family_of_Robert_Einstein" title="Murder of the family of Robert Einstein">Robert Einstein</a> (cousin)</li>
<li><a href="/wiki/Bernhard_Caesar_Einstein" title="Bernhard Caesar Einstein">Bernhard Caesar Einstein</a> (grandson)</li>
<li><a href="/wiki/Evelyn_Einstein" title="Evelyn Einstein">Evelyn Einstein</a> (granddaughter)</li>
<li><a href="/wiki/Thomas_Martin_Einstein" class="mw-redirect" title="Thomas Martin Einstein">Thomas Martin Einstein</a> (great-grandson)</li>
<li><a href="/wiki/Siegbert_Einstein" title="Siegbert Einstein">Siegbert Einstein</a> (distant cousin)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Related</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/List_of_awards_and_honors_received_by_Albert_Einstein" title="List of awards and honors received by Albert Einstein">Awards and honors</a></li>
<li><a href="/wiki/Brain_of_Albert_Einstein" title="Brain of Albert Einstein">Brain</a></li>
<li><a href="/wiki/Albert_Einstein_House" title="Albert Einstein House">House</a></li>
<li><a href="/wiki/Albert_Einstein_Memorial" title="Albert Einstein Memorial">Memorial</a></li>
<li><a href="/wiki/Political_views_of_Albert_Einstein" title="Political views of Albert Einstein">Political views</a></li>
<li><a href="/wiki/Religious_and_philosophical_views_of_Albert_Einstein" title="Religious and philosophical views of Albert Einstein">Religious views</a></li>
<li><a href="/wiki/List_of_things_named_after_Albert_Einstein" title="List of things named after Albert Einstein">Things named after</a></li>
<li><a href="/wiki/Albert_Einstein_Archives" title="Albert Einstein Archives">Albert Einstein Archives</a></li>
<li><a href="/wiki/Einstein%27s_Blackboard" title="Einstein&#39;s Blackboard">Einstein\'s Blackboard</a></li>
<li><a href="/wiki/Einstein_Papers_Project" title="Einstein Papers Project">Einstein Papers Project</a></li>
<li><a href="/wiki/Einstein_refrigerator" title="Einstein refrigerator">Einstein refrigerator</a></li>
<li><a href="/wiki/Einsteinhaus" title="Einsteinhaus">Einsteinhaus</a></li>
<li><a href="/wiki/Einsteinium" title="Einsteinium">Einsteinium</a></li>
<li><a href="/wiki/Max_Talmey" title="Max Talmey">Max Talmey</a></li></ul>
</div></td></tr><tr><td class="navbox-abovebelow hlist" colspan="2"><div>
<ul><li><span class="noviewer" typeof="mw:File"><span title="Category"><img alt="" src="//upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/16px-Symbol_category_class.svg.png" decoding="async" width="16" height="16" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/23px-Symbol_category_class.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/31px-Symbol_category_class.svg.png 2x" data-file-width="180" data-file-height="185" /></span></span> <b><a href="/wiki/Category:Albert_Einstein" title="Category:Albert Einstein">Category</a></b></li></ul>
</div></td></tr></tbody></table></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"></div><div role="navigation" class="navbox" aria-labelledby="Links_to_related_articles" style="padding:3px"><table class="nowraplinks mw-collapsible mw-collapsed navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2" style="background:#e8e8ff;"><div id="Links_to_related_articles" style="font-size:114%;margin:0 4em">Links to related articles</div></th></tr><tr><td colspan="2" class="navbox-list navbox-odd" style="width:100%;padding:0;font-size:114%"><div style="padding:0px">
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"></div><div role="navigation" class="navbox" aria-labelledby="Copley_Medallists_(1901–1950)" style="padding:3px"><table class="nowraplinks hlist mw-collapsible autocollapse navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:Copley_Medallists_1901%E2%80%931950" title="Template:Copley Medallists 1901–1950"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:Copley_Medallists_1901%E2%80%931950" title="Template talk:Copley Medallists 1901–1950"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:Copley_Medallists_1901%E2%80%931950" title="Special:EditPage/Template:Copley Medallists 1901–1950"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="Copley_Medallists_(1901–1950)" style="font-size:114%;margin:0 4em"><a href="/wiki/Copley_Medal" title="Copley Medal">Copley Medallists</a> (1901–1950)</div></th></tr><tr><td colspan="2" class="navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap"><a href="/wiki/Josiah_Willard_Gibbs" title="Josiah Willard Gibbs">Josiah Willard Gibbs</a> (1901)</span></li>
<li><span class="nowrap"><a href="/wiki/Joseph_Lister" title="Joseph Lister">Joseph Lister</a> (1902)</span></li>
<li><span class="nowrap"><a href="/wiki/Eduard_Suess" title="Eduard Suess">Eduard Suess</a> (1903)</span></li>
<li><span class="nowrap"><a href="/wiki/William_Crookes" title="William Crookes">William Crookes</a> (1904)</span></li>
<li><span class="nowrap"><a href="/wiki/Dmitri_Mendeleev" title="Dmitri Mendeleev">Dmitri Mendeleev</a> (1905)</span></li>
<li><span class="nowrap"><a href="/wiki/%C3%89lie_Metchnikoff" title="Élie Metchnikoff">Élie Metchnikoff</a> (1906)</span></li>
<li><span class="nowrap"><a href="/wiki/Albert_A._Michelson" title="Albert A. Michelson">Albert A. Michelson</a> (1907)</span></li>
<li><span class="nowrap"><a href="/wiki/Alfred_Russel_Wallace" title="Alfred Russel Wallace">Alfred Russel Wallace</a> (1908)</span></li>
<li><span class="nowrap"><a href="/wiki/George_William_Hill" title="George William Hill">George William Hill</a> (1909)</span></li>
<li><span class="nowrap"><a href="/wiki/Francis_Galton" title="Francis Galton">Francis Galton</a> (1910)</span></li>
<li><span class="nowrap"><a href="/wiki/George_Darwin" title="George Darwin">George Darwin</a> (1911)</span></li>
<li><span class="nowrap"><a href="/wiki/Felix_Klein" title="Felix Klein">Felix Klein</a> (1912)</span></li>
<li><span class="nowrap"><a href="/wiki/Ray_Lankester" title="Ray Lankester">Ray Lankester</a> (1913)</span></li>
<li><span class="nowrap"><a href="/wiki/J._J._Thomson" title="J. J. Thomson">J. J. Thomson</a> (1914)</span></li>
<li><span class="nowrap"><a href="/wiki/Ivan_Pavlov" title="Ivan Pavlov">Ivan Pavlov</a> (1915)</span></li>
<li><span class="nowrap"><a href="/wiki/James_Dewar" title="James Dewar">James Dewar</a> (1916)</span></li>
<li><span class="nowrap"><a href="/wiki/Pierre_Paul_%C3%89mile_Roux" class="mw-redirect" title="Pierre Paul Émile Roux">Pierre Paul Émile Roux</a> (1917)</span></li>
<li><span class="nowrap"><a href="/wiki/Hendrik_Lorentz" title="Hendrik Lorentz">Hendrik Lorentz</a> (1918)</span></li>
<li><span class="nowrap"><a href="/wiki/William_Bayliss" title="William Bayliss">William Bayliss</a> (1919)</span></li>
<li><span class="nowrap"><a href="/wiki/Horace_Tabberer_Brown" title="Horace Tabberer Brown">Horace Tabberer Brown</a> (1920)</span></li>
<li><span class="nowrap"><a href="/wiki/Joseph_Larmor" title="Joseph Larmor">Joseph Larmor</a> (1921)</span></li>
<li><span class="nowrap"><a href="/wiki/Ernest_Rutherford" title="Ernest Rutherford">Ernest Rutherford</a> (1922)</span></li>
<li><span class="nowrap"><a href="/wiki/Horace_Lamb" title="Horace Lamb">Horace Lamb</a> (1923)</span></li>
<li><span class="nowrap"><a href="/wiki/Edward_Albert_Sharpey-Schafer" title="Edward Albert Sharpey-Schafer">Edward Albert Sharpey-Schafer</a> (1924)</span></li>
<li><span class="nowrap"><a class="mw-selflink selflink">Albert Einstein</a> (1925)</span></li>
<li><span class="nowrap"><a href="/wiki/Frederick_Gowland_Hopkins" title="Frederick Gowland Hopkins">Frederick Gowland Hopkins</a> (1926)</span></li>
<li><span class="nowrap"><a href="/wiki/Charles_Scott_Sherrington" title="Charles Scott Sherrington">Charles Scott Sherrington</a> (1927)</span></li>
<li><span class="nowrap"><a href="/wiki/Charles_Algernon_Parsons" title="Charles Algernon Parsons">Charles Algernon Parsons</a> (1928)</span></li>
<li><span class="nowrap"><a href="/wiki/Max_Planck" title="Max Planck">Max Planck</a> (1929)</span></li>
<li><span class="nowrap"><a href="/wiki/William_Henry_Bragg" title="William Henry Bragg">William Henry Bragg</a> (1930)</span></li>
<li><span class="nowrap"><a href="/wiki/Arthur_Schuster" title="Arthur Schuster">Arthur Schuster</a> (1931)</span></li>
<li><span class="nowrap"><a href="/wiki/George_Ellery_Hale" title="George Ellery Hale">George Ellery Hale</a> (1932)</span></li>
<li><span class="nowrap"><a href="/wiki/Theobald_Smith" title="Theobald Smith">Theobald Smith</a> (1933)</span></li>
<li><span class="nowrap"><a href="/wiki/John_Scott_Haldane" title="John Scott Haldane">John Scott Haldane</a> (1934)</span></li>
<li><span class="nowrap"><a href="/wiki/Charles_Thomson_Rees_Wilson" title="Charles Thomson Rees Wilson">Charles Thomson Rees Wilson</a> (1935)</span></li>
<li><span class="nowrap"><a href="/wiki/Arthur_Evans" title="Arthur Evans">Arthur Evans</a> (1936)</span></li>
<li><span class="nowrap"><a href="/wiki/Henry_Hallett_Dale" title="Henry Hallett Dale">Henry Hallett Dale</a> (1937)</span></li>
<li><span class="nowrap"><a href="/wiki/Niels_Bohr" title="Niels Bohr">Niels Bohr</a> (1938)</span></li>
<li><span class="nowrap"><a href="/wiki/Thomas_Hunt_Morgan" title="Thomas Hunt Morgan">Thomas Hunt Morgan</a> (1939)</span></li>
<li><span class="nowrap"><a href="/wiki/Paul_Langevin" title="Paul Langevin">Paul Langevin</a> (1940)</span></li>
<li><span class="nowrap"><a href="/wiki/Thomas_Lewis_(cardiologist)" title="Thomas Lewis (cardiologist)">Thomas Lewis</a> (1941)</span></li>
<li><span class="nowrap"><a href="/wiki/Robert_Robinson_(chemist)" title="Robert Robinson (chemist)">Robert Robinson</a> (1942)</span></li>
<li><span class="nowrap"><a href="/wiki/Joseph_Barcroft" title="Joseph Barcroft">Joseph Barcroft</a> (1943)</span></li>
<li><span class="nowrap"><a href="/wiki/G._I._Taylor" title="G. I. Taylor">Geoffrey Ingram Taylor</a> (1944)</span></li>
<li><span class="nowrap"><a href="/wiki/Oswald_Avery" title="Oswald Avery">Oswald Avery</a> (1945)</span></li>
<li><span class="nowrap"><a href="/wiki/Edgar_Adrian" title="Edgar Adrian">Edgar Douglas Adrian</a> (1946)</span></li>
<li><span class="nowrap"><a href="/wiki/G._H._Hardy" title="G. H. Hardy">G. H. Hardy</a> (1947)</span></li>
<li><span class="nowrap"><a href="/wiki/Archibald_Hill" title="Archibald Hill">Archibald Hill</a> (1948)</span></li>
<li><span class="nowrap"><a href="/wiki/George_de_Hevesy" title="George de Hevesy">George de Hevesy</a> (1949)</span></li>
<li><span class="nowrap"><a href="/wiki/James_Chadwick" title="James Chadwick">James Chadwick</a> (1950)</span></li></ul>
</div></td></tr></tbody></table></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"><style data-mw-deduplicate="TemplateStyles:r1220487116">html.skin-theme-clientpref-night .mw-parser-output div:not(.notheme)>.tmp-color,html.skin-theme-clientpref-night .mw-parser-output p>.tmp-color,html.skin-theme-clientpref-night .mw-parser-output table:not(.notheme) .tmp-color{color:inherit!important}@media(prefers-color-scheme:dark){html.skin-theme-clientpref-os .mw-parser-output div:not(.notheme)>.tmp-color,html.skin-theme-clientpref-os .mw-parser-output p>.tmp-color,html.skin-theme-clientpref-os .mw-parser-output table:not(.notheme) .tmp-color{color:inherit!important}}</style><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1220487116"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1220487116"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1220487116"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1220487116"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1220487116"></div><div role="navigation" class="navbox" aria-labelledby="Laureates_of_the_Nobel_Prize_in_Physics" style="padding:3px"><table class="nowraplinks hlist mw-collapsible autocollapse navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:Nobel_Prize_in_Physics" title="Template:Nobel Prize in Physics"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:Nobel_Prize_in_Physics" title="Template talk:Nobel Prize in Physics"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:Nobel_Prize_in_Physics" title="Special:EditPage/Template:Nobel Prize in Physics"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="Laureates_of_the_Nobel_Prize_in_Physics" style="font-size:114%;margin:0 4em"><a href="/wiki/List_of_Nobel_laureates_in_Physics" title="List of Nobel laureates in Physics">Laureates</a> of the <a href="/wiki/Nobel_Prize_in_Physics" title="Nobel Prize in Physics">Nobel Prize in Physics</a></div></th></tr><tr><th scope="row" class="navbox-group" style="width:1%">1901–1925</th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap">1901: <a href="/wiki/Wilhelm_R%C3%B6ntgen" title="Wilhelm Röntgen">Röntgen</a></span></li>
<li><span class="nowrap">1902: <a href="/wiki/Hendrik_Lorentz" title="Hendrik Lorentz">Lorentz</a> / <a href="/wiki/Pieter_Zeeman" title="Pieter Zeeman">Zeeman</a></span></li>
<li><span class="nowrap">1903: <a href="/wiki/Henri_Becquerel" title="Henri Becquerel">Becquerel</a> / <a href="/wiki/Pierre_Curie" title="Pierre Curie">P. Curie</a> / <a href="/wiki/Marie_Curie" title="Marie Curie">M. Curie</a></span></li>
<li><span class="nowrap">1904: <a href="/wiki/John_William_Strutt,_3rd_Baron_Rayleigh" title="John William Strutt, 3rd Baron Rayleigh">Rayleigh</a></span></li>
<li><span class="nowrap">1905: <a href="/wiki/Philipp_Lenard" title="Philipp Lenard">Lenard</a></span></li>
<li><span class="nowrap">1906: <a href="/wiki/J._J._Thomson" title="J. J. Thomson">J. J. Thomson</a></span></li>
<li><span class="nowrap">1907: <a href="/wiki/Albert_A._Michelson" title="Albert A. Michelson">Michelson</a></span></li>
<li><span class="nowrap">1908: <a href="/wiki/Gabriel_Lippmann" title="Gabriel Lippmann">Lippmann</a></span></li>
<li><span class="nowrap">1909: <a href="/wiki/Guglielmo_Marconi" title="Guglielmo Marconi">Marconi</a> / <a href="/wiki/Karl_Ferdinand_Braun" title="Karl Ferdinand Braun">Braun</a></span></li>
<li><span class="nowrap">1910: <a href="/wiki/Johannes_Diderik_van_der_Waals" title="Johannes Diderik van der Waals">Van der Waals</a></span></li>
<li><span class="nowrap">1911: <a href="/wiki/Wilhelm_Wien" title="Wilhelm Wien">Wien</a></span></li>
<li><span class="nowrap">1912: <a href="/wiki/Gustaf_Dal%C3%A9n" title="Gustaf Dalén">Dalén</a></span></li>
<li><span class="nowrap">1913: <a href="/wiki/Heike_Kamerlingh_Onnes" title="Heike Kamerlingh Onnes">Kamerlingh Onnes</a></span></li>
<li><span class="nowrap">1914: <a href="/wiki/Max_von_Laue" title="Max von Laue">Laue</a></span></li>
<li><span class="nowrap">1915: <a href="/wiki/Lawrence_Bragg" title="Lawrence Bragg">W. L. Bragg</a> / <a href="/wiki/William_Henry_Bragg" title="William Henry Bragg">W. H. Bragg</a></span></li>
<li><span class="nowrap"><span class="tmp-color" style="color:darkgrey">1916</span></span></li>
<li><span class="nowrap">1917: <a href="/wiki/Charles_Glover_Barkla" title="Charles Glover Barkla">Barkla</a></span></li>
<li><span class="nowrap">1918: <a href="/wiki/Max_Planck" title="Max Planck">Planck</a></span></li>
<li><span class="nowrap">1919: <a href="/wiki/Johannes_Stark" title="Johannes Stark">Stark</a></span></li>
<li><span class="nowrap">1920: <a href="/wiki/Charles_%C3%89douard_Guillaume" title="Charles Édouard Guillaume">Guillaume</a></span></li>
<li><span class="nowrap">1921: <a class="mw-selflink selflink">Einstein</a></span></li>
<li><span class="nowrap">1922: <a href="/wiki/Niels_Bohr" title="Niels Bohr">N. Bohr</a></span></li>
<li><span class="nowrap">1923: <a href="/wiki/Robert_Andrews_Millikan" title="Robert Andrews Millikan">Millikan</a></span></li>
<li><span class="nowrap">1924: <a href="/wiki/Manne_Siegbahn" title="Manne Siegbahn">M. Siegbahn</a></span></li>
<li><span class="nowrap">1925: <a href="/wiki/James_Franck" title="James Franck">Franck</a> / <a href="/wiki/Gustav_Ludwig_Hertz" title="Gustav Ludwig Hertz">Hertz</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">1926–1950</th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap">1926: <a href="/wiki/Jean_Baptiste_Perrin" title="Jean Baptiste Perrin">Perrin</a></span></li>
<li><span class="nowrap">1927: <a href="/wiki/Arthur_Compton" title="Arthur Compton">Compton</a> / <a href="/wiki/Charles_Thomson_Rees_Wilson" title="Charles Thomson Rees Wilson">C. Wilson</a></span></li>
<li><span class="nowrap">1928: <a href="/wiki/Owen_Willans_Richardson" title="Owen Willans Richardson">O. Richardson</a></span></li>
<li><span class="nowrap">1929: <a href="/wiki/Louis_de_Broglie" title="Louis de Broglie">De Broglie</a></span></li>
<li><span class="nowrap">1930: <a href="/wiki/C._V._Raman" title="C. V. Raman">Raman</a></span></li>
<li><span class="nowrap"><span class="tmp-color" style="color:darkgrey">1931</span></span></li>
<li><span class="nowrap">1932: <a href="/wiki/Werner_Heisenberg" title="Werner Heisenberg">Heisenberg</a></span></li>
<li><span class="nowrap">1933: <a href="/wiki/Erwin_Schr%C3%B6dinger" title="Erwin Schrödinger">Schrödinger</a> / <a href="/wiki/Paul_Dirac" title="Paul Dirac">Dirac</a></span></li>
<li><span class="nowrap"><span class="tmp-color" style="color:darkgrey">1934</span></span></li>
<li><span class="nowrap">1935: <a href="/wiki/James_Chadwick" title="James Chadwick">Chadwick</a></span></li>
<li><span class="nowrap">1936: <a href="/wiki/Victor_Francis_Hess" title="Victor Francis Hess">Hess</a> / <a href="/wiki/Carl_David_Anderson" title="Carl David Anderson">C. D. Anderson</a></span></li>
<li><span class="nowrap">1937: <a href="/wiki/Clinton_Davisson" title="Clinton Davisson">Davisson</a> / <a href="/wiki/George_Paget_Thomson" title="George Paget Thomson">G. P. Thomson</a></span></li>
<li><span class="nowrap">1938: <a href="/wiki/Enrico_Fermi" title="Enrico Fermi">Fermi</a></span></li>
<li><span class="nowrap">1939: <a href="/wiki/Ernest_Lawrence" title="Ernest Lawrence">Lawrence</a></span></li>
<li><span class="nowrap"><span class="tmp-color" style="color:darkgrey">1940</span></span></li>
<li><span class="nowrap"><span class="tmp-color" style="color:darkgrey">1941</span></span></li>
<li><span class="nowrap"><span class="tmp-color" style="color:darkgrey">1942</span></span></li>
<li><span class="nowrap">1943: <a href="/wiki/Otto_Stern" title="Otto Stern">Stern</a></span></li>
<li><span class="nowrap">1944: <a href="/wiki/Isidor_Isaac_Rabi" title="Isidor Isaac Rabi">Rabi</a></span></li>
<li><span class="nowrap">1945: <a href="/wiki/Wolfgang_Pauli" title="Wolfgang Pauli">Pauli</a></span></li>
<li><span class="nowrap">1946: <a href="/wiki/Percy_Williams_Bridgman" title="Percy Williams Bridgman">Bridgman</a></span></li>
<li><span class="nowrap">1947: <a href="/wiki/Edward_Victor_Appleton" title="Edward Victor Appleton">Appleton</a></span></li>
<li><span class="nowrap">1948: <a href="/wiki/Patrick_Blackett" title="Patrick Blackett">Blackett</a></span></li>
<li><span class="nowrap">1949: <a href="/wiki/Hideki_Yukawa" title="Hideki Yukawa">Yukawa</a></span></li>
<li><span class="nowrap">1950: <a href="/wiki/C._F._Powell" title="C. F. Powell">Powell</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">1951–1975</th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap">1951: <a href="/wiki/John_Cockcroft" title="John Cockcroft">Cockcroft</a> / <a href="/wiki/Ernest_Walton" title="Ernest Walton">Walton</a></span></li>
<li><span class="nowrap">1952: <a href="/wiki/Felix_Bloch" title="Felix Bloch">Bloch</a> / <a href="/wiki/Edward_Mills_Purcell" title="Edward Mills Purcell">Purcell</a></span></li>
<li><span class="nowrap">1953: <a href="/wiki/Frits_Zernike" title="Frits Zernike">Zernike</a></span></li>
<li><span class="nowrap">1954: <a href="/wiki/Max_Born" title="Max Born">Born</a> / <a href="/wiki/Walther_Bothe" title="Walther Bothe">Bothe</a></span></li>
<li><span class="nowrap">1955: <a href="/wiki/Willis_Lamb" title="Willis Lamb">Lamb</a> / <a href="/wiki/Polykarp_Kusch" title="Polykarp Kusch">Kusch</a></span></li>
<li><span class="nowrap">1956: <a href="/wiki/William_Shockley" title="William Shockley">Shockley</a> / <a href="/wiki/John_Bardeen" title="John Bardeen">Bardeen</a> / <a href="/wiki/Walter_Houser_Brattain" title="Walter Houser Brattain">Brattain</a></span></li>
<li><span class="nowrap">1957: <a href="/wiki/Yang_Chen-Ning" title="Yang Chen-Ning">C. N. Yang</a> / <a href="/wiki/Tsung-Dao_Lee" title="Tsung-Dao Lee">T. D. Lee</a></span></li>
<li><span class="nowrap">1958: <a href="/wiki/Pavel_Cherenkov" title="Pavel Cherenkov">Cherenkov</a> / <a href="/wiki/Ilya_Frank" title="Ilya Frank">Frank</a> / <a href="/wiki/Igor_Tamm" title="Igor Tamm">Tamm</a></span></li>
<li><span class="nowrap">1959: <a href="/wiki/Emilio_Segr%C3%A8" title="Emilio Segrè">Segrè</a> / <a href="/wiki/Owen_Chamberlain" title="Owen Chamberlain">Chamberlain</a></span></li>
<li><span class="nowrap">1960: <a href="/wiki/Donald_A._Glaser" title="Donald A. Glaser">Glaser</a></span></li>
<li><span class="nowrap">1961: <a href="/wiki/Robert_Hofstadter" title="Robert Hofstadter">Hofstadter</a> / <a href="/wiki/Rudolf_M%C3%B6ssbauer" title="Rudolf Mössbauer">Mössbauer</a></span></li>
<li><span class="nowrap">1962: <a href="/wiki/Lev_Landau" title="Lev Landau">Landau</a></span></li>
<li><span class="nowrap">1963: <a href="/wiki/Eugene_Wigner" title="Eugene Wigner">Wigner</a> / <a href="/wiki/Maria_Goeppert_Mayer" title="Maria Goeppert Mayer">Goeppert Mayer</a> / <a href="/wiki/J._Hans_D._Jensen" title="J. Hans D. Jensen">Jensen</a></span></li>
<li><span class="nowrap">1964: <a href="/wiki/Charles_H._Townes" title="Charles H. Townes">Townes</a> / <a href="/wiki/Nikolay_Basov" title="Nikolay Basov">Basov</a> / <a href="/wiki/Alexander_Prokhorov" title="Alexander Prokhorov">Prokhorov</a></span></li>
<li><span class="nowrap">1965: <a href="/wiki/Shin%27ichir%C5%8D_Tomonaga" title="Shin&#39;ichirō Tomonaga">Tomonaga</a> / <a href="/wiki/Julian_Schwinger" title="Julian Schwinger">Schwinger</a> / <a href="/wiki/Richard_Feynman" title="Richard Feynman">Feynman</a></span></li>
<li><span class="nowrap">1966: <a href="/wiki/Alfred_Kastler" title="Alfred Kastler">Kastler</a></span></li>
<li><span class="nowrap">1967: <a href="/wiki/Hans_Bethe" title="Hans Bethe">Bethe</a></span></li>
<li><span class="nowrap">1968: <a href="/wiki/Luis_Walter_Alvarez" title="Luis Walter Alvarez">Alvarez</a></span></li>
<li><span class="nowrap">1969: <a href="/wiki/Murray_Gell-Mann" title="Murray Gell-Mann">Gell-Mann</a></span></li>
<li><span class="nowrap">1970: <a href="/wiki/Hannes_Alfv%C3%A9n" title="Hannes Alfvén">Alfvén</a> / <a href="/wiki/Louis_N%C3%A9el" title="Louis Néel">Néel</a></span></li>
<li><span class="nowrap">1971: <a href="/wiki/Dennis_Gabor" title="Dennis Gabor">Gabor</a></span></li>
<li><span class="nowrap">1972: <a href="/wiki/John_Bardeen" title="John Bardeen">Bardeen</a> / <a href="/wiki/Leon_Cooper" title="Leon Cooper">Cooper</a> / <a href="/wiki/John_Robert_Schrieffer" title="John Robert Schrieffer">Schrieffer</a></span></li>
<li><span class="nowrap">1973: <a href="/wiki/Leo_Esaki" title="Leo Esaki">Esaki</a> / <a href="/wiki/Ivar_Giaever" title="Ivar Giaever">Giaever</a> / <a href="/wiki/Brian_Josephson" title="Brian Josephson">Josephson</a></span></li>
<li><span class="nowrap">1974: <a href="/wiki/Martin_Ryle" title="Martin Ryle">Ryle</a> / <a href="/wiki/Antony_Hewish" title="Antony Hewish">Hewish</a></span></li>
<li><span class="nowrap">1975: <a href="/wiki/Aage_Bohr" title="Aage Bohr">A. Bohr</a> / <a href="/wiki/Ben_Roy_Mottelson" title="Ben Roy Mottelson">Mottelson</a> / <a href="/wiki/James_Rainwater" title="James Rainwater">Rainwater</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">1976–2000</th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap">1976: <a href="/wiki/Burton_Richter" title="Burton Richter">Richter</a> / <a href="/wiki/Samuel_C._C._Ting" title="Samuel C. C. Ting">Ting</a></span></li>
<li><span class="nowrap">1977: <a href="/wiki/Philip_W._Anderson" title="Philip W. Anderson">P. W. Anderson</a> / <a href="/wiki/Nevill_Francis_Mott" title="Nevill Francis Mott">Mott</a> / <a href="/wiki/John_Hasbrouck_Van_Vleck" title="John Hasbrouck Van Vleck">Van Vleck</a></span></li>
<li><span class="nowrap">1978: <a href="/wiki/Pyotr_Kapitsa" title="Pyotr Kapitsa">Kapitsa</a> / <a href="/wiki/Arno_Allan_Penzias" title="Arno Allan Penzias">Penzias</a> / <a href="/wiki/Robert_Woodrow_Wilson" title="Robert Woodrow Wilson">R. Wilson</a></span></li>
<li><span class="nowrap">1979: <a href="/wiki/Sheldon_Glashow" title="Sheldon Glashow">Glashow</a> / <a href="/wiki/Abdus_Salam" title="Abdus Salam">Salam</a> / <a href="/wiki/Steven_Weinberg" title="Steven Weinberg">Weinberg</a></span></li>
<li><span class="nowrap">1980: <a href="/wiki/James_Cronin" title="James Cronin">Cronin</a> / <a href="/wiki/Val_Logsdon_Fitch" title="Val Logsdon Fitch">Fitch</a></span></li>
<li><span class="nowrap">1981: <a href="/wiki/Nicolaas_Bloembergen" title="Nicolaas Bloembergen">Bloembergen</a> / <a href="/wiki/Arthur_Leonard_Schawlow" title="Arthur Leonard Schawlow">Schawlow</a> / <a href="/wiki/Kai_Siegbahn" title="Kai Siegbahn">K. Siegbahn</a></span></li>
<li><span class="nowrap">1982: <a href="/wiki/Kenneth_G._Wilson" title="Kenneth G. Wilson">K. Wilson</a></span></li>
<li><span class="nowrap">1983: <a href="/wiki/Subrahmanyan_Chandrasekhar" title="Subrahmanyan Chandrasekhar">Chandrasekhar</a> / <a href="/wiki/William_Alfred_Fowler" title="William Alfred Fowler">Fowler</a></span></li>
<li><span class="nowrap">1984: <a href="/wiki/Carlo_Rubbia" title="Carlo Rubbia">Rubbia</a> / <a href="/wiki/Simon_van_der_Meer" title="Simon van der Meer">Van der Meer</a></span></li>
<li><span class="nowrap">1985: <a href="/wiki/Klaus_von_Klitzing" title="Klaus von Klitzing">von Klitzing</a></span></li>
<li><span class="nowrap">1986: <a href="/wiki/Ernst_Ruska" title="Ernst Ruska">Ruska</a> / <a href="/wiki/Gerd_Binnig" title="Gerd Binnig">Binnig</a> / <a href="/wiki/Heinrich_Rohrer" title="Heinrich Rohrer">Rohrer</a></span></li>
<li><span class="nowrap">1987: <a href="/wiki/Georg_Bednorz" title="Georg Bednorz">Bednorz</a> / <a href="/wiki/K._Alex_M%C3%BCller" title="K. Alex Müller">Müller</a></span></li>
<li><span class="nowrap">1988: <a href="/wiki/Leon_M._Lederman" title="Leon M. Lederman">Lederman</a> / <a href="/wiki/Melvin_Schwartz" title="Melvin Schwartz">Schwartz</a> / <a href="/wiki/Jack_Steinberger" title="Jack Steinberger">Steinberger</a></span></li>
<li><span class="nowrap">1989: <a href="/wiki/Norman_Foster_Ramsey_Jr." class="mw-redirect" title="Norman Foster Ramsey Jr.">Ramsey</a> / <a href="/wiki/Hans_Georg_Dehmelt" title="Hans Georg Dehmelt">Dehmelt</a> / <a href="/wiki/Wolfgang_Paul" title="Wolfgang Paul">Paul</a></span></li>
<li><span class="nowrap">1990: <a href="/wiki/Jerome_Isaac_Friedman" title="Jerome Isaac Friedman">Friedman</a> / <a href="/wiki/Henry_Way_Kendall" title="Henry Way Kendall">Kendall</a> / <a href="/wiki/Richard_E._Taylor" title="Richard E. Taylor">R. Taylor</a></span></li>
<li><span class="nowrap">1991: <a href="/wiki/Pierre-Gilles_de_Gennes" title="Pierre-Gilles de Gennes">de Gennes</a></span></li>
<li><span class="nowrap">1992: <a href="/wiki/Georges_Charpak" title="Georges Charpak">Charpak</a></span></li>
<li><span class="nowrap">1993: <a href="/wiki/Russell_Alan_Hulse" title="Russell Alan Hulse">Hulse</a> / <a href="/wiki/Joseph_Hooton_Taylor_Jr." title="Joseph Hooton Taylor Jr.">J. Taylor</a></span></li>
<li><span class="nowrap">1994: <a href="/wiki/Bertram_Brockhouse" title="Bertram Brockhouse">Brockhouse</a> / <a href="/wiki/Clifford_Shull" title="Clifford Shull">Shull</a></span></li>
<li><span class="nowrap">1995: <a href="/wiki/Martin_Lewis_Perl" title="Martin Lewis Perl">Perl</a> / <a href="/wiki/Frederick_Reines" title="Frederick Reines">Reines</a></span></li>
<li><span class="nowrap">1996: <a href="/wiki/David_Lee_(physicist)" title="David Lee (physicist)">D. Lee</a> / <a href="/wiki/Douglas_Osheroff" title="Douglas Osheroff">Osheroff</a> / <a href="/wiki/Robert_Coleman_Richardson" title="Robert Coleman Richardson">R. Richardson</a></span></li>
<li><span class="nowrap">1997: <a href="/wiki/Steven_Chu" title="Steven Chu">Chu</a> / <a href="/wiki/Claude_Cohen-Tannoudji" title="Claude Cohen-Tannoudji">Cohen-Tannoudji</a> / <a href="/wiki/William_Daniel_Phillips" title="William Daniel Phillips">Phillips</a></span></li>
<li><span class="nowrap">1998: <a href="/wiki/Robert_B._Laughlin" title="Robert B. Laughlin">Laughlin</a> / <a href="/wiki/Horst_Ludwig_St%C3%B6rmer" title="Horst Ludwig Störmer">Störmer</a> / <a href="/wiki/Daniel_C._Tsui" title="Daniel C. Tsui">Tsui</a></span></li>
<li><span class="nowrap">1999: <a href="/wiki/Gerard_%27t_Hooft" title="Gerard &#39;t Hooft">\'t Hooft</a> / <a href="/wiki/Martinus_J._G._Veltman" title="Martinus J. G. Veltman">Veltman</a></span></li>
<li><span class="nowrap">2000: <a href="/wiki/Zhores_Alferov" title="Zhores Alferov">Alferov</a> / <a href="/wiki/Herbert_Kroemer" title="Herbert Kroemer">Kroemer</a> / <a href="/wiki/Jack_Kilby" title="Jack Kilby">Kilby</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">2001–<br />present</th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap">2001: <a href="/wiki/Eric_Allin_Cornell" title="Eric Allin Cornell">Cornell</a> / <a href="/wiki/Wolfgang_Ketterle" title="Wolfgang Ketterle">Ketterle</a> / <a href="/wiki/Carl_Wieman" title="Carl Wieman">Wieman</a></span></li>
<li><span class="nowrap">2002: <a href="/wiki/Raymond_Davis_Jr." title="Raymond Davis Jr.">Davis</a> / <a href="/wiki/Masatoshi_Koshiba" title="Masatoshi Koshiba">Koshiba</a> / <a href="/wiki/Riccardo_Giacconi" title="Riccardo Giacconi">Giacconi</a></span></li>
<li><span class="nowrap">2003: <a href="/wiki/Alexei_Abrikosov_(physicist)" title="Alexei Abrikosov (physicist)">Abrikosov</a> / <a href="/wiki/Vitaly_Ginzburg" title="Vitaly Ginzburg">Ginzburg</a> / <a href="/wiki/Anthony_James_Leggett" title="Anthony James Leggett">Leggett</a></span></li>
<li><span class="nowrap">2004: <a href="/wiki/David_Gross" title="David Gross">Gross</a> / <a href="/wiki/Hugh_David_Politzer" title="Hugh David Politzer">Politzer</a> / <a href="/wiki/Frank_Wilczek" title="Frank Wilczek">Wilczek</a></span></li>
<li><span class="nowrap">2005: <a href="/wiki/Roy_J._Glauber" title="Roy J. Glauber">Glauber</a> / <a href="/wiki/John_L._Hall" title="John L. Hall">Hall</a> / <a href="/wiki/Theodor_W._H%C3%A4nsch" title="Theodor W. Hänsch">Hänsch</a></span></li>
<li><span class="nowrap">2006: <a href="/wiki/John_C._Mather" title="John C. Mather">Mather</a> / <a href="/wiki/George_Smoot" title="George Smoot">Smoot</a></span></li>
<li><span class="nowrap">2007: <a href="/wiki/Albert_Fert" title="Albert Fert">Fert</a> / <a href="/wiki/Peter_Gr%C3%BCnberg" title="Peter Grünberg">Grünberg</a></span></li>
<li><span class="nowrap">2008: <a href="/wiki/Yoichiro_Nambu" title="Yoichiro Nambu">Nambu</a> / <a href="/wiki/Makoto_Kobayashi_(physicist)" class="mw-redirect" title="Makoto Kobayashi (physicist)">Kobayashi</a> / <a href="/wiki/Toshihide_Maskawa" title="Toshihide Maskawa">Maskawa</a></span></li>
<li><span class="nowrap">2009: <a href="/wiki/Charles_K._Kao" title="Charles K. Kao">Kao</a> / <a href="/wiki/Willard_Boyle" title="Willard Boyle">Boyle</a> / <a href="/wiki/George_E._Smith" title="George E. Smith">Smith</a></span></li>
<li><span class="nowrap">2010: <a href="/wiki/Andre_Geim" title="Andre Geim">Geim</a> / <a href="/wiki/Konstantin_Novoselov" title="Konstantin Novoselov">Novoselov</a></span></li>
<li><span class="nowrap">2011: <a href="/wiki/Saul_Perlmutter" title="Saul Perlmutter">Perlmutter</a> / <a href="/wiki/Brian_Schmidt" title="Brian Schmidt">Schmidt</a> / <a href="/wiki/Adam_Riess" title="Adam Riess">Riess</a>  </span></li>
<li><span class="nowrap">2012: <a href="/wiki/David_J._Wineland" title="David J. Wineland">Wineland</a> / <a href="/wiki/Serge_Haroche" title="Serge Haroche">Haroche</a></span></li>
<li><span class="nowrap">2013: <a href="/wiki/Fran%C3%A7ois_Englert" title="François Englert">Englert</a> / <a href="/wiki/Peter_Higgs" title="Peter Higgs">Higgs</a></span></li>
<li><span class="nowrap">2014: <a href="/wiki/Isamu_Akasaki" title="Isamu Akasaki">Akasaki</a> / <a href="/wiki/Hiroshi_Amano" title="Hiroshi Amano">Amano</a> / <a href="/wiki/Shuji_Nakamura" title="Shuji Nakamura">Nakamura</a></span></li>
<li><span class="nowrap">2015: <a href="/wiki/Takaaki_Kajita" title="Takaaki Kajita">Kajita</a> / <a href="/wiki/Arthur_B._McDonald" title="Arthur B. McDonald">McDonald</a></span></li>
<li><span class="nowrap">2016: <a href="/wiki/David_J._Thouless" title="David J. Thouless">Thouless</a> / <a href="/wiki/Duncan_Haldane" title="Duncan Haldane">Haldane</a> / <a href="/wiki/J._Michael_Kosterlitz" title="J. Michael Kosterlitz">Kosterlitz</a></span></li>
<li><span class="nowrap">2017: <a href="/wiki/Rainer_Weiss" title="Rainer Weiss">Weiss</a> / <a href="/wiki/Barry_Barish" title="Barry Barish">Barish</a> / <a href="/wiki/Kip_Thorne" title="Kip Thorne">Thorne</a></span></li>
<li><span class="nowrap">2018: <a href="/wiki/Arthur_Ashkin" title="Arthur Ashkin">Ashkin</a> / <a href="/wiki/G%C3%A9rard_Mourou" title="Gérard Mourou">Mourou</a> / <a href="/wiki/Donna_Strickland" title="Donna Strickland">Strickland</a></span></li>
<li><span class="nowrap">2019: <a href="/wiki/Jim_Peebles" title="Jim Peebles">Peebles</a> / <a href="/wiki/Michel_Mayor" title="Michel Mayor">Mayor</a> / <a href="/wiki/Didier_Queloz" title="Didier Queloz">Queloz</a></span></li>
<li><span class="nowrap">2020: <a href="/wiki/Roger_Penrose" title="Roger Penrose">Penrose</a> / <a href="/wiki/Reinhard_Genzel" title="Reinhard Genzel">Genzel</a> / <a href="/wiki/Andrea_M._Ghez" title="Andrea M. Ghez">Ghez</a></span></li>
<li><span class="nowrap">2021: <a href="/wiki/Giorgio_Parisi" title="Giorgio Parisi">Parisi</a> / <a href="/wiki/Klaus_Hasselmann" title="Klaus Hasselmann">Hasselmann</a> / <a href="/wiki/Syukuro_Manabe" title="Syukuro Manabe">Manabe</a></span></li>
<li><span class="nowrap">2022: <a href="/wiki/Alain_Aspect" title="Alain Aspect">Aspect</a> / <a href="/wiki/John_Clauser" title="John Clauser">Clauser</a> / <a href="/wiki/Anton_Zeilinger" title="Anton Zeilinger">Zeilinger</a></span></li>
<li><span class="nowrap">2023: <a href="/wiki/Pierre_Agostini" title="Pierre Agostini">Agostini</a> / <a href="/wiki/Ferenc_Krausz" title="Ferenc Krausz">Krausz</a> / <a href="/wiki/Anne_L%27Huillier" title="Anne L&#39;Huillier">L\'Huillier</a></span></li></ul>
</div></td></tr></tbody></table></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"><style data-mw-deduplicate="TemplateStyles:r886047488">.mw-parser-output .nobold{font-weight:normal}</style></div><div role="navigation" class="navbox" aria-labelledby="1921_Nobel_Prize_laureates" style="padding:3px"><table class="nowraplinks hlist mw-collapsible autocollapse navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:1921_Nobel_Prize_winners" title="Template:1921 Nobel Prize winners"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:1921_Nobel_Prize_winners" title="Template talk:1921 Nobel Prize winners"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:1921_Nobel_Prize_winners" title="Special:EditPage/Template:1921 Nobel Prize winners"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="1921_Nobel_Prize_laureates" style="font-size:114%;margin:0 4em">1921 <a href="/wiki/Nobel_Prize" title="Nobel Prize">Nobel Prize</a> laureates</div></th></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Nobel_Prize_in_Chemistry" title="Nobel Prize in Chemistry">Chemistry</a></th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Frederick_Soddy" title="Frederick Soddy">Frederick Soddy</a> (Great Britain)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Nobel_Prize_in_Literature" title="Nobel Prize in Literature">Literature</a> (<a href="/wiki/1921_Nobel_Prize_in_Literature" title="1921 Nobel Prize in Literature">1921</a>)</th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Anatole_France" title="Anatole France">Anatole France</a> (France)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Nobel_Peace_Prize" title="Nobel Peace Prize">Peace</a></th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Hjalmar_Branting" title="Hjalmar Branting">Hjalmar Branting</a> (Sweden)</li>
<li><a href="/wiki/Christian_Lous_Lange" title="Christian Lous Lange">Christian Lous Lange</a> (Norway)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Nobel_Prize_in_Physics" title="Nobel Prize in Physics">Physics</a></th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a class="mw-selflink selflink">Albert Einstein</a> (Germany)</li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%"><a href="/wiki/Nobel_Prize_in_Physiology_or_Medicine" title="Nobel Prize in Physiology or Medicine">Physiology or Medicine</a></th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li>None</li></ul>
</div></td></tr><tr><td class="navbox-abovebelow" colspan="2"><div>
<dl><dt><span class="nobold"><a href="/wiki/List_of_Nobel_laureates" title="List of Nobel laureates">Nobel Prize recipients</a></span></dt>
<dd><a href="/wiki/Template:1916_Nobel_Prize_winners" title="Template:1916 Nobel Prize winners">1916</a></dd>
<dd><a href="/wiki/Template:1917_Nobel_Prize_winners" title="Template:1917 Nobel Prize winners">1917</a></dd>
<dd><a href="/wiki/Template:1918_Nobel_Prize_winners" title="Template:1918 Nobel Prize winners">1918</a></dd>
<dd><a href="/wiki/Template:1919_Nobel_Prize_winners" title="Template:1919 Nobel Prize winners">1919</a></dd>
<dd><a href="/wiki/Template:1920_Nobel_Prize_winners" title="Template:1920 Nobel Prize winners">1920</a></dd>
<dd><b>1921 </b></dd>
<dd><a href="/wiki/Template:1922_Nobel_Prize_winners" title="Template:1922 Nobel Prize winners">1922</a></dd>
<dd><a href="/wiki/Template:1923_Nobel_Prize_winners" title="Template:1923 Nobel Prize winners">1923</a></dd>
<dd><a href="/wiki/Template:1924_Nobel_Prize_winners" title="Template:1924 Nobel Prize winners">1924</a></dd>
<dd><a href="/wiki/Template:1925_Nobel_Prize_winners" title="Template:1925 Nobel Prize winners">1925</a></dd>
<dd><a href="/wiki/Template:1926_Nobel_Prize_winners" title="Template:1926 Nobel Prize winners">1926</a></dd></dl>
</div></td></tr></tbody></table></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"></div><div role="navigation" class="navbox" aria-labelledby="Fellows_of_the_Royal_Society_elected_in_1921" style="padding:3px"><table class="nowraplinks mw-collapsible autocollapse navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:FRS_1921" title="Template:FRS 1921"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:FRS_1921" title="Template talk:FRS 1921"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:FRS_1921" title="Special:EditPage/Template:FRS 1921"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="Fellows_of_the_Royal_Society_elected_in_1921" style="font-size:114%;margin:0 4em"><a href="/wiki/Fellow_of_the_Royal_Society" title="Fellow of the Royal Society">Fellows</a> of the <a href="/wiki/Royal_Society" title="Royal Society">Royal Society</a> elected <a href="/wiki/List_of_fellows_of_the_Royal_Society_elected_in_1921" title="List of fellows of the Royal Society elected in 1921">in 1921</a></div></th></tr><tr><th scope="row" class="navbox-group" style="width:1%">Fellows</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Wilfred_Eade_Agar" title="Wilfred Eade Agar">Wilfred Eade Agar</a></li>
<li><a href="/wiki/Francis_William_Aston" title="Francis William Aston">Francis William Aston</a></li>
<li><a href="/wiki/Lawrence_Bragg" title="Lawrence Bragg">Lawrence Bragg</a>&#160;</li>
<li><a href="/wiki/William_Thomas_Calman" title="William Thomas Calman">William Thomas Calman</a></li>
<li><a href="/wiki/Arthur_Harry_Church" title="Arthur Harry Church">Arthur Harry Church</a></li>
<li><a href="/wiki/Georges_Dreyer" title="Georges Dreyer">Georges Dreyer</a></li>
<li><a href="/wiki/William_Eccles_(physicist)" title="William Eccles (physicist)">William Eccles</a></li>
<li><a href="/wiki/John_Charles_Grant_Ledingham" title="John Charles Grant Ledingham">John Charles Grant Ledingham</a></li>
<li><a href="/wiki/Kennedy_J._P._Orton" title="Kennedy J. P. Orton">Kennedy Joseph Previte&#160;Orton</a></li>
<li><a href="/wiki/John_Herbert_Parsons" title="John Herbert Parsons">John Herbert Parsons</a></li>
<li><a href="https://www.wikidata.org/wiki/Q15633439" class="extiw" title="d:Q15633439">James Charles&#160;Philip</a></li>
<li><a href="/wiki/Alfred_Robb" title="Alfred Robb">Alfred Robb</a></li>
<li><a href="/wiki/Eustace_Tennyson_d%27Eyncourt" title="Eustace Tennyson d&#39;Eyncourt">Eustace Tennyson d\'Eyncourt</a></li>
<li><a href="/wiki/Udny_Yule" title="Udny Yule">Udny Yule</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Foreign</th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Albert_Calmette" title="Albert Calmette">Albert Calmette</a></li>
<li><a href="/wiki/Henri-Alexandre_Deslandres" title="Henri-Alexandre Deslandres">Henri-Alexandre Deslandres</a></li>
<li><a class="mw-selflink selflink">Albert&#160;Einstein</a></li>
<li><a href="/wiki/Albin_Haller" title="Albin Haller">Albin Haller</a></li>
<li><a href="/wiki/Edmund_Beecher_Wilson" title="Edmund Beecher Wilson">Edmund Beecher Wilson</a></li>
<li><a href="/wiki/Pieter_Zeeman" title="Pieter Zeeman">Pieter Zeeman</a></li></ul>
</div></td></tr></tbody></table></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"></div><div role="navigation" class="navbox" aria-labelledby="Relativity" style="padding:3px"><table class="nowraplinks mw-collapsible mw-collapsed navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2" style="text-align:center;"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:Relativity" title="Template:Relativity"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/wiki/Template_talk:Relativity" title="Template talk:Relativity"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:Relativity" title="Special:EditPage/Template:Relativity"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="Relativity" style="font-size:114%;margin:0 4em"><a href="/wiki/Theory_of_relativity" title="Theory of relativity">Relativity</a></div></th></tr><tr><th scope="row" class="navbox-group" style="text-align:center;;width:1%"><a href="/wiki/Special_relativity" title="Special relativity">Special<br />relativity</a></th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em"></div><table class="nowraplinks navbox-subgroup" style="border-spacing:0"><tbody><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Background</th><td class="navbox-list-with-group navbox-list navbox-odd" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Principle_of_relativity" title="Principle of relativity">Principle of relativity</a> (<a href="/wiki/Galilean_invariance" title="Galilean invariance">Galilean relativity</a></li>
<li><a href="/wiki/Galilean_transformation" title="Galilean transformation">Galilean transformation</a>)</li>
<li><a href="/wiki/Special_relativity" title="Special relativity">Special relativity</a></li>
<li><a href="/wiki/Doubly_special_relativity" title="Doubly special relativity">Doubly special relativity</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Fundamental<br />concepts</th><td class="navbox-list-with-group navbox-list navbox-even" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Frame_of_reference" title="Frame of reference">Frame of reference</a></li>
<li><a href="/wiki/Speed_of_light" title="Speed of light">Speed of light</a></li>
<li><a href="/wiki/Hyperbolic_orthogonality" title="Hyperbolic orthogonality">Hyperbolic orthogonality</a></li>
<li><a href="/wiki/Rapidity" title="Rapidity">Rapidity</a></li>
<li><a href="/wiki/Maxwell%27s_equations" title="Maxwell&#39;s equations">Maxwell\'s equations</a></li>
<li><a href="/wiki/Proper_length" title="Proper length">Proper length</a></li>
<li><a href="/wiki/Proper_time" title="Proper time">Proper time</a></li>
<li><a href="/wiki/Proper_acceleration" title="Proper acceleration">Proper acceleration</a></li>
<li><a href="/wiki/Mass_in_special_relativity" title="Mass in special relativity">Relativistic mass</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Formulation</th><td class="navbox-list-with-group navbox-list navbox-odd" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Lorentz_transformation" title="Lorentz transformation">Lorentz transformation</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Phenomena</th><td class="navbox-list-with-group navbox-list navbox-even" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Time_dilation" title="Time dilation">Time dilation</a></li>
<li><a href="/wiki/Mass%E2%80%93energy_equivalence" title="Mass–energy equivalence">Mass–energy equivalence (E=mc<sup>2</sup>)</a></li>
<li><a href="/wiki/Length_contraction" title="Length contraction">Length contraction</a></li>
<li><a href="/wiki/Relativity_of_simultaneity" title="Relativity of simultaneity">Relativity of simultaneity</a></li>
<li><a href="/wiki/Relativistic_Doppler_effect" title="Relativistic Doppler effect">Relativistic Doppler effect</a></li>
<li><a href="/wiki/Thomas_precession" title="Thomas precession">Thomas precession</a></li>
<li><a href="/wiki/Ladder_paradox" title="Ladder paradox">Ladder paradox</a></li>
<li><a href="/wiki/Twin_paradox" title="Twin paradox">Twin paradox</a></li>
<li><a href="/wiki/Terrell_rotation" title="Terrell rotation">Terrell rotation</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;"><a href="/wiki/Spacetime" title="Spacetime">Spacetime</a></th><td class="navbox-list-with-group navbox-list navbox-odd" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Light_cone" title="Light cone">Light cone</a></li>
<li><a href="/wiki/World_line" title="World line">World line</a></li>
<li><a href="/wiki/Minkowski_diagram" class="mw-redirect" title="Minkowski diagram">Minkowski diagram</a></li>
<li><a href="/wiki/Biquaternion" title="Biquaternion">Biquaternions</a></li>
<li><a href="/wiki/Minkowski_space" title="Minkowski space">Minkowski space</a></li></ul>
</div></td></tr></tbody></table><div></div></td></tr><tr><th scope="row" class="navbox-group" style="text-align:center;;width:1%"><a href="/wiki/General_relativity" title="General relativity">General<br />relativity</a></th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em"></div><table class="nowraplinks navbox-subgroup" style="border-spacing:0"><tbody><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Background</th><td class="navbox-list-with-group navbox-list navbox-even" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Introduction_to_general_relativity" title="Introduction to general relativity">Introduction</a></li>
<li><a href="/wiki/Mathematics_of_general_relativity" title="Mathematics of general relativity">Mathematical formulation</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Fundamental<br />concepts</th><td class="navbox-list-with-group navbox-list navbox-odd" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Equivalence_principle" title="Equivalence principle">Equivalence principle</a></li>
<li><a href="/wiki/Riemannian_geometry" title="Riemannian geometry">Riemannian geometry</a></li>
<li><a href="/wiki/Penrose_diagram" title="Penrose diagram">Penrose diagram</a></li>
<li><a href="/wiki/Geodesics_in_general_relativity" title="Geodesics in general relativity">Geodesics</a></li>
<li><a href="/wiki/Mach%27s_principle" title="Mach&#39;s principle">Mach\'s principle</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Formulation</th><td class="navbox-list-with-group navbox-list navbox-even" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/ADM_formalism" title="ADM formalism">ADM formalism</a></li>
<li><a href="/wiki/BSSN_formalism" title="BSSN formalism">BSSN formalism</a></li>
<li><a href="/wiki/Einstein_field_equations" title="Einstein field equations">Einstein field equations</a></li>
<li><a href="/wiki/Linearized_gravity" title="Linearized gravity">Linearized gravity</a></li>
<li><a href="/wiki/Parameterized_post-Newtonian_formalism" title="Parameterized post-Newtonian formalism">Post-Newtonian formalism</a></li>
<li><a href="/wiki/Raychaudhuri_equation" title="Raychaudhuri equation">Raychaudhuri equation</a></li>
<li><a href="/wiki/Hamilton%E2%80%93Jacobi%E2%80%93Einstein_equation" title="Hamilton–Jacobi–Einstein equation">Hamilton–Jacobi–Einstein equation</a></li>
<li><a href="/wiki/Ernst_equation" title="Ernst equation">Ernst equation</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Phenomena</th><td class="navbox-list-with-group navbox-list navbox-odd" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Black_hole" title="Black hole">Black hole</a></li>
<li><a href="/wiki/Event_horizon" title="Event horizon">Event horizon</a></li>
<li><a href="/wiki/Gravitational_singularity" title="Gravitational singularity">Singularity</a></li>
<li><a href="/wiki/Two-body_problem_in_general_relativity" title="Two-body problem in general relativity">Two-body problem</a></li></ul>
<ul><li><a href="/wiki/Gravitational_wave" title="Gravitational wave">Gravitational waves</a>: <a href="/wiki/Gravitational-wave_astronomy" title="Gravitational-wave astronomy">astronomy</a></li>
<li><a href="/wiki/Gravitational-wave_observatory" title="Gravitational-wave observatory">detectors</a> (<a href="/wiki/LIGO" title="LIGO">LIGO</a> and <a href="/wiki/LIGO_Scientific_Collaboration" title="LIGO Scientific Collaboration">collaboration</a></li>
<li><a href="/wiki/Virgo_interferometer" title="Virgo interferometer">Virgo</a></li>
<li><a href="/wiki/LISA_Pathfinder" title="LISA Pathfinder">LISA Pathfinder</a></li>
<li><a href="/wiki/GEO600" title="GEO600">GEO</a>)</li>
<li><a href="/wiki/Hulse%E2%80%93Taylor_binary" class="mw-redirect" title="Hulse–Taylor binary">Hulse–Taylor binary</a></li></ul>
<ul><li><a href="/wiki/Tests_of_general_relativity" title="Tests of general relativity">Other tests</a>: <a href="/wiki/Apsidal_precession" title="Apsidal precession">precession</a> of Mercury</li>
<li><a href="/wiki/Gravitational_lens" title="Gravitational lens">lensing</a> (together with <a href="/wiki/Einstein_cross" class="mw-redirect" title="Einstein cross">Einstein cross</a> and <a href="/wiki/Einstein_rings" class="mw-redirect" title="Einstein rings">Einstein rings</a>)</li>
<li><a href="/wiki/Gravitational_redshift" title="Gravitational redshift">redshift</a></li>
<li><a href="/wiki/Shapiro_time_delay" title="Shapiro time delay">Shapiro delay</a></li>
<li><a href="/wiki/Frame-dragging" title="Frame-dragging">frame-dragging</a> / <a href="/wiki/Geodetic_effect" title="Geodetic effect">geodetic effect</a> (<a href="/wiki/Lense%E2%80%93Thirring_precession" title="Lense–Thirring precession">Lense–Thirring precession</a>)</li>
<li><a href="/wiki/Pulsar_timing_array" title="Pulsar timing array">pulsar timing arrays</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;">Advanced<br />theories</th><td class="navbox-list-with-group navbox-list navbox-even" style="padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Brans%E2%80%93Dicke_theory" title="Brans–Dicke theory">Brans–Dicke theory</a></li>
<li><a href="/wiki/Kaluza%E2%80%93Klein_theory" title="Kaluza–Klein theory">Kaluza–Klein</a></li>
<li><a href="/wiki/Quantum_gravity" title="Quantum gravity">Quantum gravity</a></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:6em;text-align:center;"><a href="/wiki/Exact_solutions_in_general_relativity" title="Exact solutions in general relativity">Solutions</a></th><td class="navbox-list-with-group navbox-list navbox-odd" style="padding:0"><div style="padding:0 0.25em">
<ul><li>Cosmological: <a href="/wiki/Friedmann%E2%80%93Lema%C3%AEtre%E2%80%93Robertson%E2%80%93Walker_metric" title="Friedmann–Lemaître–Robertson–Walker metric">Friedmann–Lemaître–Robertson–Walker</a> (<a href="/wiki/Friedmann_equations" title="Friedmann equations">Friedmann equations</a>)</li>
<li><a href="/wiki/Lema%C3%AEtre%E2%80%93Tolman_metric" title="Lemaître–Tolman metric">Lemaître–Tolman</a></li>
<li><a href="/wiki/Kasner_metric" title="Kasner metric">Kasner</a></li>
<li><a href="/wiki/BKL_singularity" title="BKL singularity">BKL singularity</a></li>
<li><a href="/wiki/G%C3%B6del_metric" title="Gödel metric">Gödel</a></li>
<li><a href="/wiki/Milne_model" title="Milne model">Milne</a></li></ul>
<ul><li>Spherical: <a href="/wiki/Schwarzschild_metric" title="Schwarzschild metric">Schwarzschild</a> (<a href="/wiki/Interior_Schwarzschild_metric" title="Interior Schwarzschild metric">interior</a></li>
<li><a href="/wiki/Tolman%E2%80%93Oppenheimer%E2%80%93Volkoff_equation" title="Tolman–Oppenheimer–Volkoff equation">Tolman–Oppenheimer–Volkoff equation</a>)</li>
<li><a href="/wiki/Reissner%E2%80%93Nordstr%C3%B6m_metric" title="Reissner–Nordström metric">Reissner–Nordström</a></li></ul>
<ul><li>Axisymmetric: <a href="/wiki/Kerr_metric" title="Kerr metric">Kerr</a> (<a href="/wiki/Kerr%E2%80%93Newman_metric" title="Kerr–Newman metric">Kerr–Newman</a>)</li>
<li><a href="/wiki/Weyl%E2%88%92Lewis%E2%88%92Papapetrou_coordinates" class="mw-redirect" title="Weyl−Lewis−Papapetrou coordinates">Weyl−Lewis−Papapetrou</a></li>
<li><a href="/wiki/Taub%E2%80%93NUT_space" title="Taub–NUT space">Taub–NUT</a></li>
<li><a href="/wiki/Van_Stockum_dust" title="Van Stockum dust">van Stockum dust</a></li>
<li><a href="/wiki/Relativistic_disk" title="Relativistic disk">discs</a></li></ul>
<ul><li>Others: <a href="/wiki/Pp-wave_spacetime" title="Pp-wave spacetime">pp-wave</a></li>
<li><a href="/wiki/Ozsv%C3%A1th%E2%80%93Sch%C3%BCcking_metric" title="Ozsváth–Schücking metric">Ozsváth–Schücking</a></li>
<li><a href="/wiki/Alcubierre_drive" title="Alcubierre drive">Alcubierre</a></li></ul>
<ul><li>In computational physics: <a href="/wiki/Numerical_relativity" title="Numerical relativity">Numerical relativity</a></li></ul>
</div></td></tr></tbody></table><div></div></td></tr><tr><th scope="row" class="navbox-group" style="text-align:center;;width:1%">Scientists</th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><a href="/wiki/Henri_Poincar%C3%A9" title="Henri Poincaré">Poincaré</a></li>
<li><a href="/wiki/Hendrik_Lorentz" title="Hendrik Lorentz">Lorentz</a></li>
<li><a class="mw-selflink selflink">Einstein</a></li>
<li><a href="/wiki/David_Hilbert" title="David Hilbert">Hilbert</a></li>
<li><a href="/wiki/Karl_Schwarzschild" title="Karl Schwarzschild">Schwarzschild</a></li>
<li><a href="/wiki/Willem_de_Sitter" title="Willem de Sitter">de Sitter</a></li>
<li><a href="/wiki/Hermann_Weyl" title="Hermann Weyl">Weyl</a></li>
<li><a href="/wiki/Arthur_Eddington" title="Arthur Eddington">Eddington</a></li>
<li><a href="/wiki/Alexander_Friedmann" title="Alexander Friedmann">Friedmann</a></li>
<li><a href="/wiki/Georges_Lema%C3%AEtre" title="Georges Lemaître">Lemaître</a></li>
<li><a href="/wiki/Edward_Arthur_Milne" title="Edward Arthur Milne">Milne</a></li>
<li><a href="/wiki/Howard_P._Robertson" title="Howard P. Robertson">Robertson</a></li>
<li><a href="/wiki/Subrahmanyan_Chandrasekhar" title="Subrahmanyan Chandrasekhar">Chandrasekhar</a></li>
<li><a href="/wiki/Fritz_Zwicky" title="Fritz Zwicky">Zwicky</a></li>
<li><a href="/wiki/John_Archibald_Wheeler" title="John Archibald Wheeler">Wheeler</a></li>
<li><a href="/wiki/Yvonne_Choquet-Bruhat" title="Yvonne Choquet-Bruhat">Choquet-Bruhat</a></li>
<li><a href="/wiki/Roy_Kerr" title="Roy Kerr">Kerr</a></li>
<li><a href="/wiki/Yakov_Zeldovich" title="Yakov Zeldovich">Zel\'dovich</a></li>
<li><a href="/wiki/Igor_Dmitriyevich_Novikov" title="Igor Dmitriyevich Novikov">Novikov</a></li>
<li><a href="/wiki/J%C3%BCrgen_Ehlers" title="Jürgen Ehlers">Ehlers</a></li>
<li><a href="/wiki/Robert_Geroch" title="Robert Geroch">Geroch</a></li>
<li><a href="/wiki/Roger_Penrose" title="Roger Penrose">Penrose</a></li>
<li><a href="/wiki/Stephen_Hawking" title="Stephen Hawking">Hawking</a></li>
<li><a href="/wiki/Joseph_Hooton_Taylor_Jr." title="Joseph Hooton Taylor Jr.">Taylor</a></li>
<li><a href="/wiki/Russell_Alan_Hulse" title="Russell Alan Hulse">Hulse</a></li>
<li><a href="/wiki/Hermann_Bondi" title="Hermann Bondi">Bondi</a></li>
<li><a href="/wiki/Charles_W._Misner" title="Charles W. Misner">Misner</a></li>
<li><a href="/wiki/Shing-Tung_Yau" title="Shing-Tung Yau">Yau</a></li>
<li><a href="/wiki/Kip_Thorne" title="Kip Thorne">Thorne</a></li>
<li><a href="/wiki/Rainer_Weiss" title="Rainer Weiss">Weiss</a></li>
<li><a href="/wiki/List_of_contributors_to_general_relativity" title="List of contributors to general relativity"><i>others</i></a></li></ul>
</div></td></tr><tr><td class="navbox-abovebelow" colspan="2" style="text-align:center;"><div><span class="noviewer" typeof="mw:File"><span title="Category"><img alt="" src="//upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/16px-Symbol_category_class.svg.png" decoding="async" width="16" height="16" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/23px-Symbol_category_class.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/9/96/Symbol_category_class.svg/31px-Symbol_category_class.svg.png 2x" data-file-width="180" data-file-height="185" /></span></span> <a href="/wiki/Category:Theory_of_relativity" title="Category:Theory of relativity">Category</a></div></td></tr></tbody></table></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"></div><div role="navigation" class="navbox" aria-labelledby="Time_100:_The_Most_Important_People_of_the_20th_Century" style="padding:3px"><table class="nowraplinks mw-collapsible mw-collapsed navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1063604349"><div class="navbar plainlinks hlist navbar-mini"><ul><li class="nv-view"><a href="/wiki/Template:Time_100:_The_Most_Important_People_of_the_Century" title="Template:Time 100: The Most Important People of the Century"><abbr title="View this template">v</abbr></a></li><li class="nv-talk"><a href="/w/index.php?title=Template_talk:Time_100:_The_Most_Important_People_of_the_Century&amp;action=edit&amp;redlink=1" class="new" title="Template talk:Time 100: The Most Important People of the Century (page does not exist)"><abbr title="Discuss this template">t</abbr></a></li><li class="nv-edit"><a href="/wiki/Special:EditPage/Template:Time_100:_The_Most_Important_People_of_the_Century" title="Special:EditPage/Template:Time 100: The Most Important People of the Century"><abbr title="Edit this template">e</abbr></a></li></ul></div><div id="Time_100:_The_Most_Important_People_of_the_20th_Century" style="font-size:114%;margin:0 4em"><a href="/wiki/Time_100:_The_Most_Important_People_of_the_Century" title="Time 100: The Most Important People of the Century"><i>Time</i> 100: The Most Important People of the 20th Century</a></div></th></tr><tr><th scope="row" class="navbox-group" style="width:1%">Leaders &amp; revolutionaries</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap"><a href="/wiki/David_Ben-Gurion" title="David Ben-Gurion">David Ben-Gurion</a></span></li>
<li><span class="nowrap"><a href="/wiki/Winston_Churchill" title="Winston Churchill">Winston Churchill</a></span></li>
<li><span class="nowrap"><a href="/wiki/Mahatma_Gandhi" title="Mahatma Gandhi">Mahatma Gandhi</a></span></li>
<li><span class="nowrap"><a href="/wiki/Mikhail_Gorbachev" title="Mikhail Gorbachev">Mikhail Gorbachev</a></span></li>
<li><span class="nowrap"><a href="/wiki/Adolf_Hitler" title="Adolf Hitler">Adolf Hitler</a></span></li>
<li><span class="nowrap"><a href="/wiki/Ho_Chi_Minh" title="Ho Chi Minh">Ho Chi Minh</a></span></li>
<li><span class="nowrap"><a href="/wiki/Pope_John_Paul_II" title="Pope John Paul II">Pope John Paul II</a></span></li>
<li><span class="nowrap"><a href="/wiki/Ruhollah_Khomeini" title="Ruhollah Khomeini">Ruhollah Khomeini</a></span></li>
<li><span class="nowrap"><a href="/wiki/Martin_Luther_King_Jr." title="Martin Luther King Jr.">Martin Luther King Jr.</a></span></li>
<li><span class="nowrap"><a href="/wiki/Vladimir_Lenin" title="Vladimir Lenin">Vladimir Lenin</a></span></li>
<li><span class="nowrap"><a href="/wiki/Nelson_Mandela" title="Nelson Mandela">Nelson Mandela</a></span></li>
<li><span class="nowrap"><a href="/wiki/Mao_Zedong" title="Mao Zedong">Mao Zedong</a></span></li>
<li><span class="nowrap"><a href="/wiki/Ronald_Reagan" title="Ronald Reagan">Ronald Reagan</a></span></li>
<li><span class="nowrap"><a href="/wiki/Eleanor_Roosevelt" title="Eleanor Roosevelt">Eleanor Roosevelt</a></span></li>
<li><span class="nowrap"><a href="/wiki/Franklin_D._Roosevelt" title="Franklin D. Roosevelt">Franklin D. Roosevelt</a></span></li>
<li><span class="nowrap"><a href="/wiki/Theodore_Roosevelt" title="Theodore Roosevelt">Theodore Roosevelt</a></span></li>
<li><span class="nowrap"><a href="/wiki/Margaret_Sanger" title="Margaret Sanger">Margaret Sanger</a></span></li>
<li><span class="nowrap"><a href="/wiki/Margaret_Thatcher" title="Margaret Thatcher">Margaret Thatcher</a></span></li>
<li><span class="nowrap"><a href="/wiki/Tank_Man" title="Tank Man">Unknown Tiananmen Square rebel</a></span></li>
<li><span class="nowrap"><a href="/wiki/Lech_Wa%C5%82%C4%99sa" title="Lech Wałęsa">Lech Wałęsa</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Artists &amp; entertainers</th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap"><a href="/wiki/Louis_Armstrong" title="Louis Armstrong">Louis Armstrong</a></span></li>
<li><span class="nowrap"><a href="/wiki/Lucille_Ball" title="Lucille Ball">Lucille Ball</a></span></li>
<li><span class="nowrap"><a href="/wiki/The_Beatles" title="The Beatles">The Beatles</a></span></li>
<li><span class="nowrap"><a href="/wiki/Marlon_Brando" title="Marlon Brando">Marlon Brando</a></span></li>
<li><span class="nowrap"><a href="/wiki/Coco_Chanel" title="Coco Chanel">Coco Chanel</a></span></li>
<li><span class="nowrap"><a href="/wiki/Charlie_Chaplin" title="Charlie Chaplin">Charlie Chaplin</a></span></li>
<li><span class="nowrap"><a href="/wiki/Le_Corbusier" title="Le Corbusier">Le Corbusier</a></span></li>
<li><span class="nowrap"><a href="/wiki/Bob_Dylan" title="Bob Dylan">Bob Dylan</a></span></li>
<li><span class="nowrap"><a href="/wiki/T._S._Eliot" title="T. S. Eliot">T. S. Eliot</a></span></li>
<li><span class="nowrap"><a href="/wiki/Aretha_Franklin" title="Aretha Franklin">Aretha Franklin</a></span></li>
<li><span class="nowrap"><a href="/wiki/Martha_Graham" title="Martha Graham">Martha Graham</a></span></li>
<li><span class="nowrap"><a href="/wiki/Jim_Henson" title="Jim Henson">Jim Henson</a></span></li>
<li><span class="nowrap"><a href="/wiki/James_Joyce" title="James Joyce">James Joyce</a></span></li>
<li><span class="nowrap"><a href="/wiki/Pablo_Picasso" title="Pablo Picasso">Pablo Picasso</a></span></li>
<li><span class="nowrap"><a href="/wiki/Richard_Rodgers_and_Oscar_Hammerstein" class="mw-redirect" title="Richard Rodgers and Oscar Hammerstein">Richard Rodgers and Oscar Hammerstein</a></span></li>
<li><span class="nowrap"><a href="/wiki/Bart_Simpson" title="Bart Simpson">Bart Simpson</a></span></li>
<li><span class="nowrap"><a href="/wiki/Frank_Sinatra" title="Frank Sinatra">Frank Sinatra</a></span></li>
<li><span class="nowrap"><a href="/wiki/Steven_Spielberg" title="Steven Spielberg">Steven Spielberg</a></span></li>
<li><span class="nowrap"><a href="/wiki/Igor_Stravinsky" title="Igor Stravinsky">Igor Stravinsky</a></span></li>
<li><span class="nowrap"><a href="/wiki/Oprah_Winfrey" title="Oprah Winfrey">Oprah Winfrey</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Builders &amp; titans</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap"><a href="/wiki/Stephen_Bechtel_Sr." title="Stephen Bechtel Sr.">Stephen Bechtel Sr.</a></span></li>
<li><span class="nowrap"><a href="/wiki/Leo_Burnett" title="Leo Burnett">Leo Burnett</a></span></li>
<li><span class="nowrap"><a href="/wiki/Willis_Carrier" title="Willis Carrier">Willis Carrier</a></span></li>
<li><span class="nowrap"><a href="/wiki/Walt_Disney" title="Walt Disney">Walt Disney</a></span></li>
<li><span class="nowrap"><a href="/wiki/Henry_Ford" title="Henry Ford">Henry Ford</a></span></li>
<li><span class="nowrap"><a href="/wiki/Bill_Gates" title="Bill Gates">Bill Gates</a></span></li>
<li><span class="nowrap"><a href="/wiki/Amadeo_Giannini" title="Amadeo Giannini">Amadeo Giannini</a></span></li>
<li><span class="nowrap"><a href="/wiki/Ray_Kroc" title="Ray Kroc">Ray Kroc</a></span></li>
<li><span class="nowrap"><a href="/wiki/Est%C3%A9e_Lauder_(businesswoman)" title="Estée Lauder (businesswoman)">Estée Lauder</a></span></li>
<li><span class="nowrap"><a href="/wiki/William_Levitt" title="William Levitt">William Levitt</a></span></li>
<li><span class="nowrap"><a href="/wiki/Lucky_Luciano" title="Lucky Luciano">Lucky Luciano</a></span></li>
<li><span class="nowrap"><a href="/wiki/Louis_B._Mayer" title="Louis B. Mayer">Louis B. Mayer</a></span></li>
<li><span class="nowrap"><a href="/wiki/Charles_E._Merrill" title="Charles E. Merrill">Charles E. Merrill</a></span></li>
<li><span class="nowrap"><a href="/wiki/Akio_Morita" title="Akio Morita">Akio Morita</a></span></li>
<li><span class="nowrap"><a href="/wiki/Walter_Reuther" title="Walter Reuther">Walter Reuther</a></span></li>
<li><span class="nowrap"><a href="/wiki/Pete_Rozelle" title="Pete Rozelle">Pete Rozelle</a></span></li>
<li><span class="nowrap"><a href="/wiki/David_Sarnoff" title="David Sarnoff">David Sarnoff</a></span></li>
<li><span class="nowrap"><a href="/wiki/Juan_Trippe" title="Juan Trippe">Juan Trippe</a></span></li>
<li><span class="nowrap"><a href="/wiki/Sam_Walton" title="Sam Walton">Sam Walton</a></span></li>
<li><span class="nowrap"><a href="/wiki/Thomas_J._Watson_Jr." title="Thomas J. Watson Jr.">Thomas J. Watson Jr.</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Scientists &amp; thinkers</th><td class="navbox-list-with-group navbox-list navbox-even hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap"><a href="/wiki/Leo_Baekeland" title="Leo Baekeland">Leo Baekeland</a></span></li>
<li><span class="nowrap"><a href="/wiki/Tim_Berners-Lee" title="Tim Berners-Lee">Tim Berners-Lee</a></span></li>
<li><span class="nowrap"><a href="/wiki/Rachel_Carson" title="Rachel Carson">Rachel Carson</a></span></li>
<li><span class="nowrap"><a class="mw-selflink selflink">Albert Einstein</a></span></li>
<li><span class="nowrap"><a href="/wiki/Philo_Farnsworth" title="Philo Farnsworth">Philo Farnsworth</a></span></li>
<li><span class="nowrap"><a href="/wiki/Enrico_Fermi" title="Enrico Fermi">Enrico Fermi</a></span></li>
<li><span class="nowrap"><a href="/wiki/Alexander_Fleming" title="Alexander Fleming">Alexander Fleming</a></span></li>
<li><span class="nowrap"><a href="/wiki/Sigmund_Freud" title="Sigmund Freud">Sigmund Freud</a></span></li>
<li><span class="nowrap"><a href="/wiki/Robert_H._Goddard" title="Robert H. Goddard">Robert H. Goddard</a></span></li>
<li><span class="nowrap"><a href="/wiki/Kurt_G%C3%B6del" title="Kurt Gödel">Kurt Gödel</a></span></li>
<li><span class="nowrap"><a href="/wiki/Edwin_Hubble" title="Edwin Hubble">Edwin Hubble</a></span></li>
<li><span class="nowrap"><a href="/wiki/John_Maynard_Keynes" title="John Maynard Keynes">John Maynard Keynes</a></span></li>
<li><span class="nowrap"><a href="/wiki/Leakey_family" title="Leakey family">Leakey family</a></span></li>
<li><span class="nowrap"><a href="/wiki/Jean_Piaget" title="Jean Piaget">Jean Piaget</a></span></li>
<li><span class="nowrap"><a href="/wiki/Jonas_Salk" title="Jonas Salk">Jonas Salk</a></span></li>
<li><span class="nowrap"><a href="/wiki/William_Shockley" title="William Shockley">William Shockley</a></span></li>
<li><span class="nowrap"><a href="/wiki/Alan_Turing" title="Alan Turing">Alan Turing</a></span></li>
<li><span class="nowrap"><a href="/wiki/Francis_Crick" title="Francis Crick">Francis Crick</a> &amp; <a href="/wiki/James_Watson" title="James Watson">James Watson</a></span></li>
<li><span class="nowrap"><a href="/wiki/Ludwig_Wittgenstein" title="Ludwig Wittgenstein">Ludwig Wittgenstein</a></span></li>
<li><span class="nowrap"><a href="/wiki/Wright_brothers" title="Wright brothers">Wright brothers</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Heroes &amp; icons</th><td class="navbox-list-with-group navbox-list navbox-odd hlist" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="nowrap"><a href="/wiki/Muhammad_Ali" title="Muhammad Ali">Muhammad Ali</a></span></li>
<li><span class="nowrap"><a href="/wiki/G.I." title="G.I.">The American G.I.</a></span></li>
<li><span class="nowrap"><a href="/wiki/Diana,_Princess_of_Wales" title="Diana, Princess of Wales">Lady Diana Spencer</a></span></li>
<li><span class="nowrap"><a href="/wiki/Anne_Frank" title="Anne Frank">Anne Frank</a></span></li>
<li><span class="nowrap"><a href="/wiki/Billy_Graham" title="Billy Graham">Billy Graham</a></span></li>
<li><span class="nowrap"><a href="/wiki/Che_Guevara" title="Che Guevara">Che Guevara</a></span></li>
<li><span class="nowrap"><a href="/wiki/Edmund_Hillary" title="Edmund Hillary">Edmund Hillary</a> &amp; <a href="/wiki/Tenzing_Norgay" title="Tenzing Norgay">Tenzing Norgay</a></span></li>
<li><span class="nowrap"><a href="/wiki/Helen_Keller" title="Helen Keller">Helen Keller</a></span></li>
<li><span class="nowrap"><a href="/wiki/Kennedy_family" title="Kennedy family">Kennedy family</a></span></li>
<li><span class="nowrap"><a href="/wiki/Bruce_Lee" title="Bruce Lee">Bruce Lee</a></span></li>
<li><span class="nowrap"><a href="/wiki/Charles_Lindbergh" title="Charles Lindbergh">Charles Lindbergh</a></span></li>
<li><span class="nowrap"><a href="/wiki/Harvey_Milk" title="Harvey Milk">Harvey Milk</a></span></li>
<li><span class="nowrap"><a href="/wiki/Marilyn_Monroe" title="Marilyn Monroe">Marilyn Monroe</a></span></li>
<li><span class="nowrap"><a href="/wiki/Emmeline_Pankhurst" title="Emmeline Pankhurst">Emmeline Pankhurst</a></span></li>
<li><span class="nowrap"><a href="/wiki/Rosa_Parks" title="Rosa Parks">Rosa Parks</a></span></li>
<li><span class="nowrap"><a href="/wiki/Pel%C3%A9" title="Pelé">Pelé</a></span></li>
<li><span class="nowrap"><a href="/wiki/Jackie_Robinson" title="Jackie Robinson">Jackie Robinson</a></span></li>
<li><span class="nowrap"><a href="/wiki/Andrei_Sakharov" title="Andrei Sakharov">Andrei Sakharov</a></span></li>
<li><span class="nowrap"><a href="/wiki/Mother_Teresa" title="Mother Teresa">Mother Teresa</a></span></li>
<li><span class="nowrap"><a href="/wiki/Bill_W." title="Bill W.">Bill W.</a></span></li></ul>
</div></td></tr></tbody></table></div></div></td></tr></tbody></table></div>
<style data-mw-deduplicate="TemplateStyles:r1130092004">.mw-parser-output .portal-bar{font-size:88%;font-weight:bold;display:flex;justify-content:center;align-items:baseline}.mw-parser-output .portal-bar-bordered{padding:0 2em;background-color:#fdfdfd;border:1px solid #a2a9b1;clear:both;margin:1em auto 0}.mw-parser-output .portal-bar-related{font-size:100%;justify-content:flex-start}.mw-parser-output .portal-bar-unbordered{padding:0 1.7em;margin-left:0}.mw-parser-output .portal-bar-header{margin:0 1em 0 0.5em;flex:0 0 auto;min-height:24px}.mw-parser-output .portal-bar-content{display:flex;flex-flow:row wrap;flex:0 1 auto;padding:0.15em 0;column-gap:1em;align-items:baseline;margin:0;list-style:none}.mw-parser-output .portal-bar-content-related{margin:0;list-style:none}.mw-parser-output .portal-bar-item{display:inline-block;margin:0.15em 0.2em;min-height:24px;line-height:24px}@media screen and (max-width:768px){.mw-parser-output .portal-bar{font-size:88%;font-weight:bold;display:flex;flex-flow:column wrap;align-items:baseline}.mw-parser-output .portal-bar-header{text-align:center;flex:0;padding-left:0.5em;margin:0 auto}.mw-parser-output .portal-bar-related{font-size:100%;align-items:flex-start}.mw-parser-output .portal-bar-content{display:flex;flex-flow:row wrap;align-items:center;flex:0;column-gap:1em;border-top:1px solid #a2a9b1;margin:0 auto;list-style:none}.mw-parser-output .portal-bar-content-related{border-top:none;margin:0;list-style:none}}.mw-parser-output .navbox+link+.portal-bar,.mw-parser-output .navbox+style+.portal-bar,.mw-parser-output .navbox+link+.portal-bar-bordered,.mw-parser-output .navbox+style+.portal-bar-bordered,.mw-parser-output .sister-bar+link+.portal-bar,.mw-parser-output .sister-bar+style+.portal-bar,.mw-parser-output .portal-bar+.navbox-styles+.navbox,.mw-parser-output .portal-bar+.navbox-styles+.sister-bar{margin-top:-1px}</style><div class="portal-bar noprint metadata noviewer portal-bar-bordered" role="navigation" aria-label="Portals"><span class="portal-bar-header"><a href="/wiki/Wikipedia:Contents/Portals" title="Wikipedia:Contents/Portals">Portals</a>:</span><ul class="portal-bar-content"><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/en/thumb/6/69/P_vip.svg/19px-P_vip.svg.png" decoding="async" width="19" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/6/69/P_vip.svg/28px-P_vip.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/6/69/P_vip.svg/37px-P_vip.svg.png 2x" data-file-width="1911" data-file-height="1944" /></span></span> </span><a href="/wiki/Portal:Biography" title="Portal:Biography">Biography</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/4/49/Star_of_David.svg/16px-Star_of_David.svg.png" decoding="async" width="16" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/4/49/Star_of_David.svg/25px-Star_of_David.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/4/49/Star_of_David.svg/33px-Star_of_David.svg.png 2x" data-file-width="600" data-file-height="693" /></span></span> </span><a href="/wiki/Portal:Judaism" title="Portal:Judaism">Judaism</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><a href="/wiki/File:Nuvola_apps_edu_mathematics_blue-p.svg" class="mw-file-description"><img alt="icon" src="//upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Nuvola_apps_edu_mathematics_blue-p.svg/19px-Nuvola_apps_edu_mathematics_blue-p.svg.png" decoding="async" width="19" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Nuvola_apps_edu_mathematics_blue-p.svg/29px-Nuvola_apps_edu_mathematics_blue-p.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Nuvola_apps_edu_mathematics_blue-p.svg/38px-Nuvola_apps_edu_mathematics_blue-p.svg.png 2x" data-file-width="128" data-file-height="128" /></a></span> </span><a href="/wiki/Portal:Mathematics" title="Portal:Mathematics">Mathematics</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><a href="/wiki/File:Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg" class="mw-file-description"><img alt="icon" src="//upload.wikimedia.org/wikipedia/commons/thumb/6/6f/Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg/17px-Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg.png" decoding="async" width="17" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/6/6f/Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg/26px-Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/6/6f/Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg/34px-Stylised_atom_with_three_Bohr_model_orbits_and_stylised_nucleus.svg.png 2x" data-file-width="530" data-file-height="600" /></a></span> </span><a href="/wiki/Portal:Physics" title="Portal:Physics">Physics</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/0/00/Crab_Nebula.jpg/19px-Crab_Nebula.jpg" decoding="async" width="19" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/0/00/Crab_Nebula.jpg/29px-Crab_Nebula.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/0/00/Crab_Nebula.jpg/38px-Crab_Nebula.jpg 2x" data-file-width="3864" data-file-height="3864" /></span></span> </span><a href="/wiki/Portal:Astronomy" title="Portal:Astronomy">Astronomy</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><a href="/wiki/File:He1523a.jpg" class="mw-file-description"><img alt="icon" src="//upload.wikimedia.org/wikipedia/commons/thumb/5/5f/He1523a.jpg/16px-He1523a.jpg" decoding="async" width="16" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/5/5f/He1523a.jpg/25px-He1523a.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/5/5f/He1523a.jpg/33px-He1523a.jpg 2x" data-file-width="180" data-file-height="207" /></a></span> </span><a href="/wiki/Portal:Stars" title="Portal:Stars">Stars</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/d/d6/RocketSunIcon.svg/19px-RocketSunIcon.svg.png" decoding="async" width="19" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/d/d6/RocketSunIcon.svg/29px-RocketSunIcon.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/d/d6/RocketSunIcon.svg/38px-RocketSunIcon.svg.png 2x" data-file-width="128" data-file-height="128" /></span></span> </span><a href="/wiki/Portal:Spaceflight" title="Portal:Spaceflight">Spaceflight</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><span><img alt="" src="//upload.wikimedia.org/wikipedia/commons/thumb/5/5c/Earth-moon.jpg/21px-Earth-moon.jpg" decoding="async" width="21" height="17" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/5/5c/Earth-moon.jpg/32px-Earth-moon.jpg 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/5/5c/Earth-moon.jpg/42px-Earth-moon.jpg 2x" data-file-width="3000" data-file-height="2400" /></span></span> </span><a href="/wiki/Portal:Outer_space" title="Portal:Outer space">Outer space</a></li><li class="portal-bar-item"><span class="nowrap"><span typeof="mw:File"><a href="/wiki/File:Nuvola_apps_kalzium.svg" class="mw-file-description"><img alt="icon" src="//upload.wikimedia.org/wikipedia/commons/thumb/8/8b/Nuvola_apps_kalzium.svg/19px-Nuvola_apps_kalzium.svg.png" decoding="async" width="19" height="19" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/8/8b/Nuvola_apps_kalzium.svg/29px-Nuvola_apps_kalzium.svg.png 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/8/8b/Nuvola_apps_kalzium.svg/38px-Nuvola_apps_kalzium.svg.png 2x" data-file-width="128" data-file-height="128" /></a></span> </span><a href="/wiki/Portal:Science" title="Portal:Science">Science</a></li></ul></div>
<div class="navbox-styles"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1129693374"><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1061467846"><style data-mw-deduplicate="TemplateStyles:r1038841319">.mw-parser-output .tooltip-dotted{border-bottom:1px dotted;cursor:help}</style><link rel="mw-deduplicated-inline-style" href="mw-data:TemplateStyles:r1038841319"></div><div role="navigation" class="navbox authority-control" aria-labelledby="Authority_control_databases_frameless&amp;#124;text-top&amp;#124;10px&amp;#124;alt=Edit_this_at_Wikidata&amp;#124;link=https&amp;#58;//www.wikidata.org/wiki/Q937#identifiers&amp;#124;class=noprint&amp;#124;Edit_this_at_Wikidata" style="padding:3px"><table class="nowraplinks hlist mw-collapsible autocollapse navbox-inner" style="border-spacing:0;background:transparent;color:inherit"><tbody><tr><th scope="col" class="navbox-title" colspan="2"><div id="Authority_control_databases_frameless&amp;#124;text-top&amp;#124;10px&amp;#124;alt=Edit_this_at_Wikidata&amp;#124;link=https&amp;#58;//www.wikidata.org/wiki/Q937#identifiers&amp;#124;class=noprint&amp;#124;Edit_this_at_Wikidata" style="font-size:114%;margin:0 4em"><a href="/wiki/Help:Authority_control" title="Help:Authority control">Authority control databases</a> <span class="mw-valign-text-top noprint" typeof="mw:File/Frameless"><a href="https://www.wikidata.org/wiki/Q937#identifiers" title="Edit this at Wikidata"><img alt="Edit this at Wikidata" src="//upload.wikimedia.org/wikipedia/en/thumb/8/8a/OOjs_UI_icon_edit-ltr-progressive.svg/10px-OOjs_UI_icon_edit-ltr-progressive.svg.png" decoding="async" width="10" height="10" class="mw-file-element" srcset="//upload.wikimedia.org/wikipedia/en/thumb/8/8a/OOjs_UI_icon_edit-ltr-progressive.svg/15px-OOjs_UI_icon_edit-ltr-progressive.svg.png 1.5x, //upload.wikimedia.org/wikipedia/en/thumb/8/8a/OOjs_UI_icon_edit-ltr-progressive.svg/20px-OOjs_UI_icon_edit-ltr-progressive.svg.png 2x" data-file-width="20" data-file-height="20" /></a></span></div></th></tr><tr><th scope="row" class="navbox-group" style="width:1%">International</th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="http://id.worldcat.org/fast/32023/">FAST</a></span>
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="http://id.worldcat.org/fast/460651/">2</a></span></li></ul></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://isni.org/isni/000000012281955X">ISNI</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://viaf.org/viaf/75121530">VIAF</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://id.oclc.org/worldcat/entity/E39PBJkhFRgHDtmhvmC6JdfXh3">WorldCat</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">National</th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="https://authority.bibsys.no/authority/rest/authorities/html/90053072">Norway</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://www.bncatalogo.cl/F?func=direct&amp;local_base=red10&amp;doc_number=000034649">Chile</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://catalogo.bne.es/uhtbin/authoritybrowse.cgi?action=display&amp;authority_id=XX834035">Spain</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://catalogue.bnf.fr/ark:/12148/cb119016075">France</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://data.bnf.fr/ark:/12148/cb119016075">BnF data</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://cantic.bnc.cat/registre/981058511756306706">Catalonia</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://d-nb.info/gnd/118529579">Germany</a></span></li>
<li><span class="uid"><span class="rt-commentedText tooltip tooltip-dotted" title="Einstein, Albert"><a rel="nofollow" class="external text" href="https://opac.sbn.it/nome/CFIV035853">Italy</a></span></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://olduli.nli.org.il/F/?func=find-b&amp;local_base=NLX10&amp;find_code=UID&amp;request=987007260607605171">Israel</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://urn.fi/URN:NBN:fi:au:finaf:000215897">Finland</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://opac.kbr.be/LIBRARY/doc/AUTHORITY/14115549">Belgium</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://id.loc.gov/authorities/n79022889">United States</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://libris.kb.se/fcrtts5z33mrjqc">Sweden</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://kopkatalogs.lv/F?func=direct&amp;local_base=lnc10&amp;doc_number=000027126&amp;P_CON_LNG=ENG">Latvia</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://aleweb.ncl.edu.tw/F/?func=accref&amp;acc_sequence=369710&amp;CON_LNG=ENG">Taiwan</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://id.ndl.go.jp/auth/ndlna/00438728">Japan</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://aleph.nkp.cz/F/?func=find-c&amp;local_base=aut&amp;ccl_term=ica=jn19990002019&amp;CON_LNG=ENG">Czech Republic</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://nla.gov.au/anbd.aut-an36582360">Australia</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://data.nlg.gr/resource/authority/record76370">Greece</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://lod.nl.go.kr/resource/KAC200103196">Korea</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://aleph.bibnat.ro:8991/F/?func=direct&amp;local_base=NLR10&amp;doc_number=000074139">Romania</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://katalog.nsk.hr/F/?func=direct&amp;doc_number=000012537&amp;local_base=nsk10">Croatia</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://data.bibliotheken.nl/id/thes/p068350767">Netherlands</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://dbn.bn.org.pl/descriptor-details/9810646540205606">Poland</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://id.bnportugal.gov.pt/aut/catbnp/26339">Portugal</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="http://aleph.rsl.ru/F?func=find-b&amp;find_code=SYS&amp;adjacent=Y&amp;local_base=RSL11&amp;request=000021094&amp;CON_LNG=ENG">Russia</a></span></li>
<li><span class="uid"><a class="external text" href="https://wikidata-externalid-url.toolforge.org/?p=8034&amp;url_prefix=https://opac.vatlib.it/auth/detail/&amp;id=495/91752">Vatican</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Academics</th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="https://ci.nii.ac.jp/author/DA00708434?l=en">CiNii</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://scholar.google.com/citations?user=qc6CJjYAAAAJ">Google Scholar</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://www.leopoldina.org/mitgliederverzeichnis/mitglieder/member/Member/show/albert-einstein/">Leopoldina</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://mathscinet.ams.org/mathscinet/MRAuthorID/62280">MathSciNet</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://www.mathgenealogy.org/id.php?id=53269">Mathematics Genealogy Project</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://orcid.org/0000-0001-9183-9538">ORCID</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://www.scopus.com/authid/detail.uri?authorId=22988279600">Scopus</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://zbmath.org/authors/?q=ai:einstein.albert">zbMATH</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Artists</th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="https://musicbrainz.org/artist/c98c325e-7277-46e8-8b44-e3517f3e041a">MusicBrainz</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://www.getty.edu/vow/ULANFullDisplay?find=&amp;role=&amp;nation=&amp;subjectid=500240971">ULAN</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">People</th><td class="navbox-list-with-group navbox-list navbox-odd" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="https://www.deutsche-biographie.de/pnd118529579.html?language=en">Deutsche Biographie</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://trove.nla.gov.au/people/382451">Trove</a></span></li></ul>
</div></td></tr><tr><th scope="row" class="navbox-group" style="width:1%">Other</th><td class="navbox-list-with-group navbox-list navbox-even" style="width:100%;padding:0"><div style="padding:0 0.25em">
<ul><li><span class="uid"><a rel="nofollow" class="external text" href="http://esu.com.ua/search_articles.php?id=42829">Encyclopedia of Modern Ukraine</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://hls-dhs-dss.ch/fr/articles/028814">Historical Dictionary of Switzerland</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://catalog.archives.gov/id/10582637">NARA</a></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://rism.online/people/41024053">RISM</a></span></li>
<li><span class="uid"><span class="rt-commentedText tooltip tooltip-dotted" title="Einstein, Albert, 1879-1955"><a rel="nofollow" class="external text" href="https://snaccooperative.org/ark:/99166/w63c6p77">SNAC</a></span></span></li>
<li><span class="uid"><a rel="nofollow" class="external text" href="https://www.idref.fr/026849186">IdRef</a></span></li></ul>
</div></td></tr></tbody></table></div>
<!-- 
NewPP limit report
Parsed by mw1413
Cached time: 20240610134153
Cache expiry: 2592000
Reduced expiry: false
Complications: [vary‐revision‐sha1, show‐toc]
CPU time usage: 4.048 seconds
Real time usage: 5.030 seconds
Preprocessor visited node count: 32487/1000000
Post‐expand include size: 936631/2097152 bytes
Template argument size: 121628/2097152 bytes
Highest expansion depth: 19/100
Expensive parser function count: 103/500
Unstrip recursion depth: 1/20
Unstrip post‐expand size: 1172694/5000000 bytes
Lua time usage: 2.599/10.000 seconds
Lua memory usage: 25962698/52428800 bytes
Lua Profile:
    ?                                                                520 ms       18.3%
    MediaWiki\\Extension\\Scribunto\\Engines\\LuaSandbox\\LuaSandboxCallback::callParserFunction      260 ms        9.2%
    recursiveClone <mwInit.lua:45>                                   220 ms        7.7%
    <mw.lua:694>                                                     140 ms        4.9%
    MediaWiki\\Extension\\Scribunto\\Engines\\LuaSandbox\\LuaSandboxCallback::gsub      140 ms        4.9%
    dataWrapper <mw.lua:672>                                         140 ms        4.9%
    MediaWiki\\Extension\\Scribunto\\Engines\\LuaSandbox\\LuaSandboxCallback::getAllExpandedArguments      120 ms        4.2%
    MediaWiki\\Extension\\Scribunto\\Engines\\LuaSandbox\\LuaSandboxCallback::find      100 ms        3.5%
    (for generator)                                                   80 ms        2.8%
    MediaWiki\\Extension\\Scribunto\\Engines\\LuaSandbox\\LuaSandboxCallback::match       80 ms        2.8%
    [others]                                                        1040 ms       36.6%
Number of Wikibase entities loaded: 1/400
-->
<!--
Transclusion expansion time report (%,ms,calls,template)
100.00% 4349.476      1 -total
 32.29% 1404.477      2 Template:Reflist
 18.17%  790.178      1 Template:Infobox_scientist
 11.65%  506.852     71 Template:Cite_journal
 11.33%  492.968    136 Template:Sfnp
 10.76%  467.927     86 Template:Cite_book
  8.86%  385.457     81 Template:Cite_web
  4.32%  187.939      1 Template:Birth_date
  3.90%  169.529      2 Template:Lang
  3.70%  161.028      1 Template:Cosmology
-->

<!-- Saved in parser cache with key enwiki:pcache:idhash:736-0!canonical and timestamp 20240610134153 and revision id 1227307757. Rendering was triggered because: page-view
 -->
</div><!--esi <esi:include src="/esitest-fa8a495983347898/content" /> --><noscript><img src="https://login.wikimedia.org/wiki/Special:CentralAutoLogin/start?type=1x1" alt="" width="1" height="1" style="border: none; position: absolute;"></noscript>
<div class="printfooter" data-nosnippet="">Retrieved from "<a dir="ltr" href="https://en.wikipedia.org/w/index.php?title=Albert_Einstein&amp;oldid=1227307757">https://en.wikipedia.org/w/index.php?title=Albert_Einstein&amp;oldid=1227307757</a>"</div></div>
					<div id="catlinks" class="catlinks" data-mw="interface"><div id="mw-normal-catlinks" class="mw-normal-catlinks"><a href="/wiki/Help:Category" title="Help:Category">Categories</a>: <ul><li><a href="/wiki/Category:Albert_Einstein" title="Category:Albert Einstein">Albert Einstein</a></li><li><a href="/wiki/Category:1879_births" title="Category:1879 births">1879 births</a></li><li><a href="/wiki/Category:1955_deaths" title="Category:1955 deaths">1955 deaths</a></li><li><a href="/wiki/Category:19th-century_German_Jews" title="Category:19th-century German Jews">19th-century German Jews</a></li><li><a href="/wiki/Category:20th-century_American_engineers" title="Category:20th-century American engineers">20th-century American engineers</a></li><li><a href="/wiki/Category:20th-century_American_inventors" title="Category:20th-century American inventors">20th-century American inventors</a></li><li><a href="/wiki/Category:20th-century_American_male_writers" title="Category:20th-century American male writers">20th-century American male writers</a></li><li><a href="/wiki/Category:20th-century_American_non-fiction_writers" title="Category:20th-century American non-fiction writers">20th-century American non-fiction writers</a></li><li><a href="/wiki/Category:20th-century_American_physicists" title="Category:20th-century American physicists">20th-century American physicists</a></li><li><a href="/wiki/Category:20th-century_Swiss_inventors" title="Category:20th-century Swiss inventors">20th-century Swiss inventors</a></li><li><a href="/wiki/Category:Academic_staff_of_Charles_University" title="Category:Academic staff of Charles University">Academic staff of Charles University</a></li><li><a href="/wiki/Category:Academic_staff_of_ETH_Zurich" title="Category:Academic staff of ETH Zurich">Academic staff of ETH Zurich</a></li><li><a href="/wiki/Category:Academic_staff_of_the_University_of_Bern" title="Category:Academic staff of the University of Bern">Academic staff of the University of Bern</a></li><li><a href="/wiki/Category:Academic_staff_of_the_University_of_Zurich" title="Category:Academic staff of the University of Zurich">Academic staff of the University of Zurich</a></li><li><a href="/wiki/Category:American_agnostics" title="Category:American agnostics">American agnostics</a></li><li><a href="/wiki/Category:American_Ashkenazi_Jews" title="Category:American Ashkenazi Jews">American Ashkenazi Jews</a></li><li><a href="/wiki/Category:American_democratic_socialists" title="Category:American democratic socialists">American democratic socialists</a></li><li><a href="/wiki/Category:American_humanists" title="Category:American humanists">American humanists</a></li><li><a href="/wiki/Category:American_letter_writers" title="Category:American letter writers">American letter writers</a></li><li><a href="/wiki/Category:American_male_non-fiction_writers" title="Category:American male non-fiction writers">American male non-fiction writers</a></li><li><a href="/wiki/Category:American_Nobel_laureates" title="Category:American Nobel laureates">American Nobel laureates</a></li><li><a href="/wiki/Category:American_pacifists" title="Category:American pacifists">American pacifists</a></li><li><a href="/wiki/Category:American_relativity_theorists" title="Category:American relativity theorists">American relativity theorists</a></li><li><a href="/wiki/Category:American_science_writers" title="Category:American science writers">American science writers</a></li><li><a href="/wiki/Category:American_Zionists" title="Category:American Zionists">American Zionists</a></li><li><a href="/wiki/Category:Anti-nationalists" title="Category:Anti-nationalists">Anti-nationalists</a></li><li><a href="/wiki/Category:Deaths_from_abdominal_aortic_aneurysm" title="Category:Deaths from abdominal aortic aneurysm">Deaths from abdominal aortic aneurysm</a></li><li><a href="/wiki/Category:Denaturalized_citizens_of_Germany" title="Category:Denaturalized citizens of Germany">Denaturalized citizens of Germany</a></li><li><a href="/wiki/Category:Einstein_family" title="Category:Einstein family">Einstein family</a></li><li><a href="/wiki/Category:ETH_Zurich_alumni" title="Category:ETH Zurich alumni">ETH Zurich alumni</a></li><li><a href="/wiki/Category:European_democratic_socialists" title="Category:European democratic socialists">European democratic socialists</a></li><li><a href="/wiki/Category:German_agnostics" title="Category:German agnostics">German agnostics</a></li><li><a href="/wiki/Category:German_Ashkenazi_Jews" title="Category:German Ashkenazi Jews">German Ashkenazi Jews</a></li><li><a href="/wiki/Category:German_emigrants_to_Switzerland" title="Category:German emigrants to Switzerland">German emigrants to Switzerland</a></li><li><a href="/wiki/Category:German_humanists" title="Category:German humanists">German humanists</a></li><li><a href="/wiki/Category:German_male_non-fiction_writers" title="Category:German male non-fiction writers">German male non-fiction writers</a></li><li><a href="/wiki/Category:German_Nobel_laureates" title="Category:German Nobel laureates">German Nobel laureates</a></li><li><a href="/wiki/Category:German_relativity_theorists" title="Category:German relativity theorists">German relativity theorists</a></li><li><a href="/wiki/Category:German_Zionists" title="Category:German Zionists">German Zionists</a></li><li><a href="/wiki/Category:Institute_for_Advanced_Study_faculty" title="Category:Institute for Advanced Study faculty">Institute for Advanced Study faculty</a></li><li><a href="/wiki/Category:Jewish_agnostics" title="Category:Jewish agnostics">Jewish agnostics</a></li><li><a href="/wiki/Category:Jewish_American_non-fiction_writers" title="Category:Jewish American non-fiction writers">Jewish American non-fiction writers</a></li><li><a href="/wiki/Category:Jewish_American_physicists" title="Category:Jewish American physicists">Jewish American physicists</a></li><li><a href="/wiki/Category:Jewish_German_physicists" title="Category:Jewish German physicists">Jewish German physicists</a></li><li><a href="/wiki/Category:Jewish_emigrants_from_Nazi_Germany_to_the_United_States" title="Category:Jewish emigrants from Nazi Germany to the United States">Jewish emigrants from Nazi Germany to the United States</a></li><li><a href="/wiki/Category:Jewish_scientists" title="Category:Jewish scientists">Jewish scientists</a></li><li><a href="/wiki/Category:Jewish_socialists" title="Category:Jewish socialists">Jewish socialists</a></li><li><a href="/wiki/Category:Labor_Zionists" title="Category:Labor Zionists">Labor Zionists</a></li><li><a href="/wiki/Category:Max_Planck_Institute_directors" title="Category:Max Planck Institute directors">Max Planck Institute directors</a></li><li><a href="/wiki/Category:Members_of_the_American_Philosophical_Society" title="Category:Members of the American Philosophical Society">Members of the American Philosophical Society</a></li><li><a href="/wiki/Category:Members_of_the_Royal_Netherlands_Academy_of_Arts_and_Sciences" title="Category:Members of the Royal Netherlands Academy of Arts and Sciences">Members of the Royal Netherlands Academy of Arts and Sciences</a></li><li><a href="/wiki/Category:Members_of_the_United_States_National_Academy_of_Sciences" title="Category:Members of the United States National Academy of Sciences">Members of the United States National Academy of Sciences</a></li><li><a href="/wiki/Category:Naturalised_citizens_of_Austria" title="Category:Naturalised citizens of Austria">Naturalised citizens of Austria</a></li><li><a href="/wiki/Category:Naturalised_citizens_of_Switzerland" title="Category:Naturalised citizens of Switzerland">Naturalised citizens of Switzerland</a></li><li><a href="/wiki/Category:Naturalized_citizens_of_the_United_States" title="Category:Naturalized citizens of the United States">Naturalized citizens of the United States</a></li><li><a href="/wiki/Category:Nobel_laureates_in_Physics" title="Category:Nobel laureates in Physics">Nobel laureates in Physics</a></li><li><a href="/wiki/Category:Pantheists" title="Category:Pantheists">Pantheists</a></li><li><a href="/wiki/Category:Patent_examiners" title="Category:Patent examiners">Patent examiners</a></li><li><a href="/wiki/Category:People_from_Ulm" title="Category:People from Ulm">People from Ulm</a></li><li><a href="/wiki/Category:People_who_lost_German_citizenship" title="Category:People who lost German citizenship">People who lost German citizenship</a></li><li><a href="/wiki/Category:People_with_multiple_nationality" title="Category:People with multiple nationality">People with multiple nationality</a></li><li><a href="/wiki/Category:Philosophers_of_mathematics" title="Category:Philosophers of mathematics">Philosophers of mathematics</a></li><li><a href="/wiki/Category:Philosophers_of_science" title="Category:Philosophers of science">Philosophers of science</a></li><li><a href="/wiki/Category:Philosophy_of_science" title="Category:Philosophy of science">Philosophy of science</a></li><li><a href="/wiki/Category:Quantum_physicists" title="Category:Quantum physicists">Quantum physicists</a></li><li><a href="/wiki/Category:Recipients_of_Franklin_Medal" title="Category:Recipients of Franklin Medal">Recipients of Franklin Medal</a></li><li><a href="/wiki/Category:Scientists_from_Munich" title="Category:Scientists from Munich">Scientists from Munich</a></li><li><a href="/wiki/Category:Stateless_people" title="Category:Stateless people">Stateless people</a></li><li><a href="/wiki/Category:Swiss_agnostics" title="Category:Swiss agnostics">Swiss agnostics</a></li><li><a href="/wiki/Category:Swiss_Ashkenazi_Jews" title="Category:Swiss Ashkenazi Jews">Swiss Ashkenazi Jews</a></li><li><a href="/wiki/Category:Swiss_cosmologists" title="Category:Swiss cosmologists">Swiss cosmologists</a></li><li><a href="/wiki/Category:Swiss_emigrants_to_the_United_States" title="Category:Swiss emigrants to the United States">Swiss emigrants to the United States</a></li><li><a href="/wiki/Category:Swiss_Nobel_laureates" title="Category:Swiss Nobel laureates">Swiss Nobel laureates</a></li><li><a href="/wiki/Category:Swiss_physicists" title="Category:Swiss physicists">Swiss physicists</a></li><li><a href="/wiki/Category:University_of_Zurich_alumni" title="Category:University of Zurich alumni">University of Zurich alumni</a></li><li><a href="/wiki/Category:Winners_of_the_Max_Planck_Medal" title="Category:Winners of the Max Planck Medal">Winners of the Max Planck Medal</a></li><li><a href="/wiki/Category:W%C3%BCrttemberger_emigrants_to_the_United_States" title="Category:Württemberger emigrants to the United States">Württemberger emigrants to the United States</a></li></ul></div><div id="mw-hidden-catlinks" class="mw-hidden-catlinks mw-hidden-cats-hidden">Hidden categories: <ul><li><a href="/wiki/Category:Pages_using_the_Phonos_extension" title="Category:Pages using the Phonos extension">Pages using the Phonos extension</a></li><li><a href="/wiki/Category:CS1_German-language_sources_(de)" title="Category:CS1 German-language sources (de)">CS1 German-language sources (de)</a></li><li><a href="/wiki/Category:Webarchive_template_wayback_links" title="Category:Webarchive template wayback links">Webarchive template wayback links</a></li><li><a href="/wiki/Category:CS1_French-language_sources_(fr)" title="Category:CS1 French-language sources (fr)">CS1 French-language sources (fr)</a></li><li><a href="/wiki/Category:CS1_maint:_location_missing_publisher" title="Category:CS1 maint: location missing publisher">CS1 maint: location missing publisher</a></li><li><a href="/wiki/Category:CS1_location_test" title="Category:CS1 location test">CS1 location test</a></li><li><a href="/wiki/Category:CS1_maint:_DOI_inactive_as_of_January_2024" title="Category:CS1 maint: DOI inactive as of January 2024">CS1 maint: DOI inactive as of January 2024</a></li><li><a href="/wiki/Category:Articles_with_short_description" title="Category:Articles with short description">Articles with short description</a></li><li><a href="/wiki/Category:Short_description_is_different_from_Wikidata" title="Category:Short description is different from Wikidata">Short description is different from Wikidata</a></li><li><a href="/wiki/Category:Wikipedia_indefinitely_semi-protected_pages" title="Category:Wikipedia indefinitely semi-protected pages">Wikipedia indefinitely semi-protected pages</a></li><li><a href="/wiki/Category:Wikipedia_indefinitely_move-protected_pages" title="Category:Wikipedia indefinitely move-protected pages">Wikipedia indefinitely move-protected pages</a></li><li><a href="/wiki/Category:Good_articles" title="Category:Good articles">Good articles</a></li><li><a href="/wiki/Category:Use_American_English_from_November_2022" title="Category:Use American English from November 2022">Use American English from November 2022</a></li><li><a href="/wiki/Category:All_Wikipedia_articles_written_in_American_English" title="Category:All Wikipedia articles written in American English">All Wikipedia articles written in American English</a></li><li><a href="/wiki/Category:Use_dmy_dates_from_November_2022" title="Category:Use dmy dates from November 2022">Use dmy dates from November 2022</a></li><li><a href="/wiki/Category:Articles_containing_German-language_text" title="Category:Articles containing German-language text">Articles containing German-language text</a></li><li><a href="/wiki/Category:Articles_with_hAudio_microformats" title="Category:Articles with hAudio microformats">Articles with hAudio microformats</a></li><li><a href="/wiki/Category:Biography_with_signature" title="Category:Biography with signature">Biography with signature</a></li><li><a href="/wiki/Category:Articles_with_hCards" title="Category:Articles with hCards">Articles with hCards</a></li><li><a href="/wiki/Category:Pages_with_German_IPA" title="Category:Pages with German IPA">Pages with German IPA</a></li><li><a href="/wiki/Category:Pages_including_recorded_pronunciations" title="Category:Pages including recorded pronunciations">Pages including recorded pronunciations</a></li><li><a href="/wiki/Category:Pages_using_sidebar_with_the_child_parameter" title="Category:Pages using sidebar with the child parameter">Pages using sidebar with the child parameter</a></li><li><a href="/wiki/Category:CS1:_long_volume_value" title="Category:CS1: long volume value">CS1: long volume value</a></li><li><a href="/wiki/Category:Wikipedia_articles_incorporating_a_citation_from_the_1922_Encyclopaedia_Britannica_with_Wikisource_reference" title="Category:Wikipedia articles incorporating a citation from the 1922 Encyclopaedia Britannica with Wikisource reference">Wikipedia articles incorporating a citation from the 1922 Encyclopaedia Britannica with Wikisource reference</a></li><li><a href="/wiki/Category:Pages_using_Sister_project_links_with_hidden_wikidata" title="Category:Pages using Sister project links with hidden wikidata">Pages using Sister project links with hidden wikidata</a></li><li><a href="/wiki/Category:Articles_with_Curlie_links" title="Category:Articles with Curlie links">Articles with Curlie links</a></li><li><a href="/wiki/Category:Articles_with_Project_Gutenberg_links" title="Category:Articles with Project Gutenberg links">Articles with Project Gutenberg links</a></li><li><a href="/wiki/Category:Articles_with_Internet_Archive_links" title="Category:Articles with Internet Archive links">Articles with Internet Archive links</a></li><li><a href="/wiki/Category:Articles_with_LibriVox_links" title="Category:Articles with LibriVox links">Articles with LibriVox links</a></li><li><a href="/wiki/Category:Nobelprize_template_using_Wikidata_property_P8024" title="Category:Nobelprize template using Wikidata property P8024">Nobelprize template using Wikidata property P8024</a></li><li><a href="/wiki/Category:Articles_with_FAST_identifiers" title="Category:Articles with FAST identifiers">Articles with FAST identifiers</a></li><li><a href="/wiki/Category:Articles_with_ISNI_identifiers" title="Category:Articles with ISNI identifiers">Articles with ISNI identifiers</a></li><li><a href="/wiki/Category:Articles_with_VIAF_identifiers" title="Category:Articles with VIAF identifiers">Articles with VIAF identifiers</a></li><li><a href="/wiki/Category:Articles_with_WorldCat_Entities_identifiers" title="Category:Articles with WorldCat Entities identifiers">Articles with WorldCat Entities identifiers</a></li><li><a href="/wiki/Category:Articles_with_BIBSYS_identifiers" title="Category:Articles with BIBSYS identifiers">Articles with BIBSYS identifiers</a></li><li><a href="/wiki/Category:Articles_with_BNC_identifiers" title="Category:Articles with BNC identifiers">Articles with BNC identifiers</a></li><li><a href="/wiki/Category:Articles_with_BNE_identifiers" title="Category:Articles with BNE identifiers">Articles with BNE identifiers</a></li><li><a href="/wiki/Category:Articles_with_BNF_identifiers" title="Category:Articles with BNF identifiers">Articles with BNF identifiers</a></li><li><a href="/wiki/Category:Articles_with_BNFdata_identifiers" title="Category:Articles with BNFdata identifiers">Articles with BNFdata identifiers</a></li><li><a href="/wiki/Category:Articles_with_CANTICN_identifiers" title="Category:Articles with CANTICN identifiers">Articles with CANTICN identifiers</a></li><li><a href="/wiki/Category:Articles_with_GND_identifiers" title="Category:Articles with GND identifiers">Articles with GND identifiers</a></li><li><a href="/wiki/Category:Articles_with_ICCU_identifiers" title="Category:Articles with ICCU identifiers">Articles with ICCU identifiers</a></li><li><a href="/wiki/Category:Articles_with_J9U_identifiers" title="Category:Articles with J9U identifiers">Articles with J9U identifiers</a></li><li><a href="/wiki/Category:Articles_with_KANTO_identifiers" title="Category:Articles with KANTO identifiers">Articles with KANTO identifiers</a></li><li><a href="/wiki/Category:Articles_with_KBR_identifiers" title="Category:Articles with KBR identifiers">Articles with KBR identifiers</a></li><li><a href="/wiki/Category:Articles_with_LCCN_identifiers" title="Category:Articles with LCCN identifiers">Articles with LCCN identifiers</a></li><li><a href="/wiki/Category:Articles_with_Libris_identifiers" title="Category:Articles with Libris identifiers">Articles with Libris identifiers</a></li><li><a href="/wiki/Category:Articles_with_LNB_identifiers" title="Category:Articles with LNB identifiers">Articles with LNB identifiers</a></li><li><a href="/wiki/Category:Articles_with_NCL_identifiers" title="Category:Articles with NCL identifiers">Articles with NCL identifiers</a></li><li><a href="/wiki/Category:Articles_with_NDL_identifiers" title="Category:Articles with NDL identifiers">Articles with NDL identifiers</a></li><li><a href="/wiki/Category:Articles_with_NKC_identifiers" title="Category:Articles with NKC identifiers">Articles with NKC identifiers</a></li><li><a href="/wiki/Category:Articles_with_NLA_identifiers" title="Category:Articles with NLA identifiers">Articles with NLA identifiers</a></li><li><a href="/wiki/Category:Articles_with_NLG_identifiers" title="Category:Articles with NLG identifiers">Articles with NLG identifiers</a></li><li><a href="/wiki/Category:Articles_with_NLK_identifiers" title="Category:Articles with NLK identifiers">Articles with NLK identifiers</a></li><li><a href="/wiki/Category:Articles_with_NLR_identifiers" title="Category:Articles with NLR identifiers">Articles with NLR identifiers</a></li><li><a href="/wiki/Category:Articles_with_NSK_identifiers" title="Category:Articles with NSK identifiers">Articles with NSK identifiers</a></li><li><a href="/wiki/Category:Articles_with_NTA_identifiers" title="Category:Articles with NTA identifiers">Articles with NTA identifiers</a></li><li><a href="/wiki/Category:Articles_with_PLWABN_identifiers" title="Category:Articles with PLWABN identifiers">Articles with PLWABN identifiers</a></li><li><a href="/wiki/Category:Articles_with_PortugalA_identifiers" title="Category:Articles with PortugalA identifiers">Articles with PortugalA identifiers</a></li><li><a href="/wiki/Category:Articles_with_RSL_identifiers" title="Category:Articles with RSL identifiers">Articles with RSL identifiers</a></li><li><a href="/wiki/Category:Articles_with_VcBA_identifiers" title="Category:Articles with VcBA identifiers">Articles with VcBA identifiers</a></li><li><a href="/wiki/Category:Articles_with_CINII_identifiers" title="Category:Articles with CINII identifiers">Articles with CINII identifiers</a></li><li><a href="/wiki/Category:Articles_with_Google_Scholar_identifiers" title="Category:Articles with Google Scholar identifiers">Articles with Google Scholar identifiers</a></li><li><a href="/wiki/Category:Articles_with_Leopoldina_identifiers" title="Category:Articles with Leopoldina identifiers">Articles with Leopoldina identifiers</a></li><li><a href="/wiki/Category:Articles_with_MATHSN_identifiers" title="Category:Articles with MATHSN identifiers">Articles with MATHSN identifiers</a></li><li><a href="/wiki/Category:Articles_with_MGP_identifiers" title="Category:Articles with MGP identifiers">Articles with MGP identifiers</a></li><li><a href="/wiki/Category:Articles_with_ORCID_identifiers" title="Category:Articles with ORCID identifiers">Articles with ORCID identifiers</a></li><li><a href="/wiki/Category:Articles_with_Scopus_identifiers" title="Category:Articles with Scopus identifiers">Articles with Scopus identifiers</a></li><li><a href="/wiki/Category:Articles_with_ZBMATH_identifiers" title="Category:Articles with ZBMATH identifiers">Articles with ZBMATH identifiers</a></li><li><a href="/wiki/Category:Articles_with_MusicBrainz_identifiers" title="Category:Articles with MusicBrainz identifiers">Articles with MusicBrainz identifiers</a></li><li><a href="/wiki/Category:Articles_with_ULAN_identifiers" title="Category:Articles with ULAN identifiers">Articles with ULAN identifiers</a></li><li><a href="/wiki/Category:Articles_with_DTBIO_identifiers" title="Category:Articles with DTBIO identifiers">Articles with DTBIO identifiers</a></li><li><a href="/wiki/Category:Articles_with_Trove_identifiers" title="Category:Articles with Trove identifiers">Articles with Trove identifiers</a></li><li><a href="/wiki/Category:Articles_with_EMU_identifiers" title="Category:Articles with EMU identifiers">Articles with EMU identifiers</a></li><li><a href="/wiki/Category:Articles_with_HDS_identifiers" title="Category:Articles with HDS identifiers">Articles with HDS identifiers</a></li><li><a href="/wiki/Category:Articles_with_NARA_identifiers" title="Category:Articles with NARA identifiers">Articles with NARA identifiers</a></li><li><a href="/wiki/Category:Articles_with_RISM_identifiers" title="Category:Articles with RISM identifiers">Articles with RISM identifiers</a></li><li><a href="/wiki/Category:Articles_with_SNAC-ID_identifiers" title="Category:Articles with SNAC-ID identifiers">Articles with SNAC-ID identifiers</a></li><li><a href="/wiki/Category:Articles_with_SUDOC_identifiers" title="Category:Articles with SUDOC identifiers">Articles with SUDOC identifiers</a></li></ul></div></div>
				</div>
			</main>
			
		</div>
		<div class="mw-footer-container">
			
<footer id="footer" class="mw-footer" >
	<ul id="footer-info">
	<li id="footer-info-lastmod"> This page was last edited on 4 June 2024, at 23:38<span class="anonymous-show">&#160;(UTC)</span>.</li>
	<li id="footer-info-copyright">Text is available under the <a rel="license" href="//en.wikipedia.org/wiki/Wikipedia:Text_of_the_Creative_Commons_Attribution-ShareAlike_4.0_International_License">Creative Commons Attribution-ShareAlike License 4.0</a><a rel="license" href="//en.wikipedia.org/wiki/Wikipedia:Text_of_the_Creative_Commons_Attribution-ShareAlike_4.0_International_License" style="display:none;"></a>;
additional terms may apply. By using this site, you agree to the <a href="//foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Terms_of_Use">Terms of Use</a> and <a href="//foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Privacy_policy">Privacy Policy</a>. Wikipedia® is a registered trademark of the <a href="//www.wikimediafoundation.org/">Wikimedia Foundation, Inc.</a>, a non-profit organization.</li>
</ul>

	<ul id="footer-places">
	<li id="footer-places-privacy"><a href="https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Privacy_policy">Privacy policy</a></li>
	<li id="footer-places-about"><a href="/wiki/Wikipedia:About">About Wikipedia</a></li>
	<li id="footer-places-disclaimers"><a href="/wiki/Wikipedia:General_disclaimer">Disclaimers</a></li>
	<li id="footer-places-contact"><a href="//en.wikipedia.org/wiki/Wikipedia:Contact_us">Contact Wikipedia</a></li>
	<li id="footer-places-wm-codeofconduct"><a href="https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Universal_Code_of_Conduct">Code of Conduct</a></li>
	<li id="footer-places-developers"><a href="https://developer.wikimedia.org">Developers</a></li>
	<li id="footer-places-statslink"><a href="https://stats.wikimedia.org/#/en.wikipedia.org">Statistics</a></li>
	<li id="footer-places-cookiestatement"><a href="https://foundation.wikimedia.org/wiki/Special:MyLanguage/Policy:Cookie_statement">Cookie statement</a></li>
	<li id="footer-places-mobileview"><a href="//en.m.wikipedia.org/w/index.php?title=Albert_Einstein&amp;mobileaction=toggle_view_mobile" class="noprint stopMobileRedirectToggle">Mobile view</a></li>
</ul>

	<ul id="footer-icons" class="noprint">
	<li id="footer-copyrightico"><a href="https://wikimediafoundation.org/"><img src="/static/images/footer/wikimedia-button.png" srcset="/static/images/footer/wikimedia-button-1.5x.png 1.5x, /static/images/footer/wikimedia-button-2x.png 2x" width="88" height="31" alt="Wikimedia Foundation" loading="lazy" /></a></li>
	<li id="footer-poweredbyico"><a href="https://www.mediawiki.org/"><img src="/static/images/footer/poweredby_mediawiki_88x31.png" alt="Powered by MediaWiki" srcset="/static/images/footer/poweredby_mediawiki_132x47.png 1.5x, /static/images/footer/poweredby_mediawiki_176x62.png 2x" width="88" height="31" loading="lazy"></a></li>
</ul>

</footer>

		</div>
	</div> 
</div> 
<div class="vector-settings" id="p-dock-bottom">
	<ul>
		<li>
		<button class="cdx-button cdx-button--icon-only vector-limited-width-toggle"><span class="vector-icon mw-ui-icon-fullScreen mw-ui-icon-wikimedia-fullScreen"></span>

<span>Toggle limited content width</span>
</button>
</li>
	</ul>
</div>
<script>(RLQ=window.RLQ||[]).push(function(){mw.config.set({"wgHostname":"mw1373","wgBackendResponseTime":331,"wgPageParseReport":{"limitreport":{"cputime":"4.048","walltime":"5.030","ppvisitednodes":{"value":32487,"limit":1000000},"postexpandincludesize":{"value":936631,"limit":2097152},"templateargumentsize":{"value":121628,"limit":2097152},"expansiondepth":{"value":19,"limit":100},"expensivefunctioncount":{"value":103,"limit":500},"unstrip-depth":{"value":1,"limit":20},"unstrip-size":{"value":1172694,"limit":5000000},"entityaccesscount":{"value":1,"limit":400},"timingprofile":["100.00% 4349.476      1 -total"," 32.29% 1404.477      2 Template:Reflist"," 18.17%  790.178      1 Template:Infobox_scientist"," 11.65%  506.852     71 Template:Cite_journal"," 11.33%  492.968    136 Template:Sfnp"," 10.76%  467.927     86 Template:Cite_book","  8.86%  385.457     81 Template:Cite_web","  4.32%  187.939      1 Template:Birth_date","  3.90%  169.529      2 Template:Lang","  3.70%  161.028      1 Template:Cosmology"]},"scribunto":{"limitreport-timeusage":{"value":"2.599","limit":"10.000"},"limitreport-memusage":{"value":25962698,"limit":52428800},"limitreport-logs":"table#1 {\\n}\\n\\"\\"\\ntable#1 {\\n}\\n\\"\\"\\nanchor_id_list = table#1 {\\n    [\\"CITEREFAbbott2016\\"] = 1,\\n    [\\"CITEREFAlbert_Einstein_Archives1955\\"] = 1,\\n    [\\"CITEREFAlok2008\\"] = 1,\\n    [\\"CITEREFAmir_Aczel2014\\"] = 1,\\n    [\\"CITEREFAndrews2003\\"] = 1,\\n    [\\"CITEREFAndrzej2003\\"] = 1,\\n    [\\"CITEREFArntzenius2011\\"] = 1,\\n    [\\"CITEREFBell1966\\"] = 1,\\n    [\\"CITEREFBloom2012\\"] = 2,\\n    [\\"CITEREFBodanis2000\\"] = 1,\\n    [\\"CITEREFBohr,_N.\\"] = 1,\\n    [\\"CITEREFBondiGold1948\\"] = 1,\\n    [\\"CITEREFBoyko\\"] = 1,\\n    [\\"CITEREFBrian1996\\"] = 1,\\n    [\\"CITEREFByers1998\\"] = 1,\\n    [\\"CITEREFCalaprice2000\\"] = 1,\\n    [\\"CITEREFCalaprice2005\\"] = 1,\\n    [\\"CITEREFCalaprice2010\\"] = 1,\\n    [\\"CITEREFCalapriceKennefickSchulmann2015\\"] = 1,\\n    [\\"CITEREFCalapriceLipscombe2005\\"] = 1,\\n    [\\"CITEREFCastelvecchi2014\\"] = 1,\\n    [\\"CITEREFChaplin1964\\"] = 1,\\n    [\\"CITEREFClark1971\\"] = 1,\\n    [\\"CITEREFCohen,_J._R.Graver,_L._M.1995\\"] = 1,\\n    [\\"CITEREFCosgrove,_Ben2014\\"] = 1,\\n    [\\"CITEREFCosgroveMorse2014\\"] = 1,\\n    [\\"CITEREFDas2003\\"] = 1,\\n    [\\"CITEREFDennis_Overbye2005\\"] = 1,\\n    [\\"CITEREFDiehlMoltz2008\\"] = 1,\\n    [\\"CITEREFDowbiggin2003\\"] = 1,\\n    [\\"CITEREFDuchen,_Jessica2011\\"] = 1,\\n    [\\"CITEREFDuncanJanssen2019\\"] = 1,\\n    [\\"CITEREFDvorsky2012\\"] = 1,\\n    [\\"CITEREFEinstein1901\\"] = 1,\\n    [\\"CITEREFEinstein1905a\\"] = 1,\\n    [\\"CITEREFEinstein1905b\\"] = 1,\\n    [\\"CITEREFEinstein1905c\\"] = 1,\\n    [\\"CITEREFEinstein1905d\\"] = 1,\\n    [\\"CITEREFEinstein1905e\\"] = 1,\\n    [\\"CITEREFEinstein1915\\"] = 1,\\n    [\\"CITEREFEinstein1916\\"] = 1,\\n    [\\"CITEREFEinstein1917a\\"] = 1,\\n    [\\"CITEREFEinstein1917b\\"] = 1,\\n    [\\"CITEREFEinstein1918\\"] = 1,\\n    [\\"CITEREFEinstein1923\\"] = 1,\\n    [\\"CITEREFEinstein1924\\"] = 1,\\n    [\\"CITEREFEinstein1926\\"] = 1,\\n    [\\"CITEREFEinstein1926b\\"] = 1,\\n    [\\"CITEREFEinstein1931\\"] = 1,\\n    [\\"CITEREFEinstein1948\\"] = 1,\\n    [\\"CITEREFEinstein1949\\"] = 1,\\n    [\\"CITEREFEinstein1950\\"] = 1,\\n    [\\"CITEREFEinstein1952\\"] = 1,\\n    [\\"CITEREFEinstein1954\\"] = 1,\\n    [\\"CITEREFEinstein1969\\"] = 1,\\n    [\\"CITEREFEinstein1979\\"] = 1,\\n    [\\"CITEREFEinstein1995\\"] = 1,\\n    [\\"CITEREFEinstein2009\\"] = 1,\\n    [\\"CITEREFEinstein2013\\"] = 1,\\n    [\\"CITEREFEinsteinPodolskyRosen1935\\"] = 1,\\n    [\\"CITEREFEinsteinRosen1935\\"] = 1,\\n    [\\"CITEREFEinsteinRussell1955\\"] = 1,\\n    [\\"CITEREFEinsteinde_Haas1915\\"] = 2,\\n    [\\"CITEREFEinsteinde_Sitter1932\\"] = 1,\\n    [\\"CITEREFFahy2015\\"] = 1,\\n    [\\"CITEREFFine2017\\"] = 1,\\n    [\\"CITEREFFlood2018\\"] = 1,\\n    [\\"CITEREFFraknoi2022\\"] = 1,\\n    [\\"CITEREFFrancis2017\\"] = 2,\\n    [\\"CITEREFFred_JeromeRodger_Taylor2006\\"] = 1,\\n    [\\"CITEREFFölsing1997\\"] = 1,\\n    [\\"CITEREFGagnon2016\\"] = 1,\\n    [\\"CITEREFGalison2000\\"] = 1,\\n    [\\"CITEREFGanguiOrtiz2008\\"] = 1,\\n    [\\"CITEREFGanguiOrtiz2016\\"] = 1,\\n    [\\"CITEREFGhosh2016\\"] = 1,\\n    [\\"CITEREFGimbel2015\\"] = 1,\\n    [\\"CITEREFGlick1987\\"] = 1,\\n    [\\"CITEREFGoenner2004\\"] = 1,\\n    [\\"CITEREFGoldberg1958\\"] = 1,\\n    [\\"CITEREFGolden2000\\"] = 1,\\n    [\\"CITEREFGordin2020\\"] = 1,\\n    [\\"CITEREFGosling2010\\"] = 1,\\n    [\\"CITEREFGrandjean2017\\"] = 1,\\n    [\\"CITEREFGrandjean2018\\"] = 1,\\n    [\\"CITEREFGraydon2023\\"] = 1,\\n    [\\"CITEREFHalpern2019\\"] = 1,\\n    [\\"CITEREFHanle1979\\"] = 1,\\n    [\\"CITEREFHarriganSpekkens2010\\"] = 1,\\n    [\\"CITEREFHewlettAnderson1962\\"] = 1,\\n    [\\"CITEREFHighfield2006\\"] = 1,\\n    [\\"CITEREFHighfieldCarter1993\\"] = 1,\\n    [\\"CITEREFHitchens2007\\"] = 1,\\n    [\\"CITEREFHoffmann1972\\"] = 1,\\n    [\\"CITEREFHoffmann2013\\"] = 1,\\n    [\\"CITEREFHolton1984\\"] = 1,\\n    [\\"CITEREFHoward1990\\"] = 1,\\n    [\\"CITEREFHoward2005\\"] = 1,\\n    [\\"CITEREFHoward2014\\"] = 1,\\n    [\\"CITEREFHoyle1948\\"] = 1,\\n    [\\"CITEREFHunziker2015\\"] = 1,\\n    [\\"CITEREFIsaacson2007\\"] = 1,\\n    [\\"CITEREFIsaacson2008\\"] = 1,\\n    [\\"CITEREFIsaacson2009\\"] = 1,\\n    [\\"CITEREFJ._J._O\\u0026#039;ConnorE._F._Robertson2010\\"] = 1,\\n    [\\"CITEREFJerome2004\\"] = 1,\\n    [\\"CITEREFJerome2009\\"] = 1,\\n    [\\"CITEREFJohnston2024\\"] = 1,\\n    [\\"CITEREFKatz\\"] = 1,\\n    [\\"CITEREFKersting2019\\"] = 1,\\n    [\\"CITEREFKeyte2013\\"] = 1,\\n    [\\"CITEREFKuepper\\"] = 1,\\n    [\\"CITEREFLanouetteSilard1992\\"] = 1,\\n    [\\"CITEREFLate_City1955\\"] = 1,\\n    [\\"CITEREFLevenson\\"] = 1,\\n    [\\"CITEREFLevenson2017\\"] = 1,\\n    [\\"CITEREFLibman1939\\"] = 1,\\n    [\\"CITEREFLindemann\\"] = 1,\\n    [\\"CITEREFLindley2005\\"] = 1,\\n    [\\"CITEREFLindsayMargenau1981\\"] = 1,\\n    [\\"CITEREFLyth2019\\"] = 1,\\n    [\\"CITEREFMajor2007\\"] = 1,\\n    [\\"CITEREFMalament2012\\"] = 1,\\n    [\\"CITEREFMartin_Grandjean2017\\"] = 1,\\n    [\\"CITEREFMay2017\\"] = 1,\\n    [\\"CITEREFMcTee\\"] = 1,\\n    [\\"CITEREFMehra2001\\"] = 2,\\n    [\\"CITEREFMermin1993\\"] = 1,\\n    [\\"CITEREFMissner1985\\"] = 1,\\n    [\\"CITEREFMontes-Santiago2017\\"] = 1,\\n    [\\"CITEREFMoring2004\\"] = 1,\\n    [\\"CITEREFMurrellGrobert2002\\"] = 1,\\n    [\\"CITEREFNadia_Drake2016\\"] = 1,\\n    [\\"CITEREFNeffe2007\\"] = 1,\\n    [\\"CITEREFNorth1965\\"] = 1,\\n    [\\"CITEREFNorton1984\\"] = 1,\\n    [\\"CITEREFNovak2015\\"] = 1,\\n    [\\"CITEREFNussbaumer2014\\"] = 2,\\n    [\\"CITEREFNussbaumer_and_Bieri2009\\"] = 1,\\n    [\\"CITEREFO\\u0026#039;ConnorRobertson1997\\"] = 1,\\n    [\\"CITEREFO\\u0026#039;RaifeartaighMcCann2014\\"] = 1,\\n    [\\"CITEREFO\\u0026#039;RaifeartaighMcCannNahmMitton2014\\"] = 1,\\n    [\\"CITEREFOppenheimer1971\\"] = 1,\\n    [\\"CITEREFOppenheimer1979\\"] = 1,\\n    [\\"CITEREFOverbye2014\\"] = 1,\\n    [\\"CITEREFOverbye2015\\"] = 1,\\n    [\\"CITEREFOverbye2016\\"] = 1,\\n    [\\"CITEREFOverbye2017\\"] = 1,\\n    [\\"CITEREFPais1979\\"] = 1,\\n    [\\"CITEREFPais1982\\"] = 1,\\n    [\\"CITEREFPais1994\\"] = 1,\\n    [\\"CITEREFParker2000\\"] = 1,\\n    [\\"CITEREFPaul_Arthur_Schilpp1951\\"] = 1,\\n    [\\"CITEREFPaul_S._BoyerMelvyn_Dubofsky2001\\"] = 1,\\n    [\\"CITEREFPenrose2007\\"] = 1,\\n    [\\"CITEREFPeres2002\\"] = 1,\\n    [\\"CITEREFPeter_GalisonGerald_James_HoltonSilvan_S._Schweber2008\\"] = 1,\\n    [\\"CITEREFPietrow2019\\"] = 1,\\n    [\\"CITEREFPogrebin1998\\"] = 1,\\n    [\\"CITEREFRamanForman1969\\"] = 1,\\n    [\\"CITEREFReisman2006\\"] = 1,\\n    [\\"CITEREFRennSchulmann2000\\"] = 1,\\n    [\\"CITEREFRichard_Kroehling1991\\"] = 1,\\n    [\\"CITEREFRichardson1908\\"] = 1,\\n    [\\"CITEREFRobeson2002\\"] = 1,\\n    [\\"CITEREFRobinson2015\\"] = 1,\\n    [\\"CITEREFRobinson2018\\"] = 1,\\n    [\\"CITEREFRobinson2019\\"] = 1,\\n    [\\"CITEREFRogers2005\\"] = 1,\\n    [\\"CITEREFRosenkranz2002\\"] = 1,\\n    [\\"CITEREFRoweSchulmann2007\\"] = 1,\\n    [\\"CITEREFRoweSchulmann2007a\\"] = 1,\\n    [\\"CITEREFRoweSchulmann2013\\"] = 1,\\n    [\\"CITEREFSan_MiguelPallandre2024\\"] = 1,\\n    [\\"CITEREFScheideler2002\\"] = 1,\\n    [\\"CITEREFSchlosshauerKoflerZeilinger2013\\"] = 1,\\n    [\\"CITEREFSchweber2008\\"] = 1,\\n    [\\"CITEREFShine2018\\"] = 1,\\n    [\\"CITEREFSmith1996\\"] = 1,\\n    [\\"CITEREFSpielbergAnderson1995\\"] = 1,\\n    [\\"CITEREFStachel1966\\"] = 1,\\n    [\\"CITEREFStachel2002\\"] = 1,\\n    [\\"CITEREFStachel_et_al.2008\\"] = 1,\\n    [\\"CITEREFStone2013\\"] = 1,\\n    [\\"CITEREFTamir2012\\"] = 1,\\n    [\\"CITEREFTobies2012\\"] = 1,\\n    [\\"CITEREFTolmasquim2012\\"] = 1,\\n    [\\"CITEREFTroemel-Ploetz,_D.1990\\"] = 1,\\n    [\\"CITEREFUniversity_of_Pavia\\"] = 1,\\n    [\\"CITEREFUnna2007\\"] = 1,\\n    [\\"CITEREFWaldrop2017\\"] = 1,\\n    [\\"CITEREFWalker,_Evan_Harris1989\\"] = 1,\\n    [\\"CITEREFWeinberg1972\\"] = 1,\\n    [\\"CITEREFWeinberg2005\\"] = 1,\\n    [\\"CITEREFWeinstein2015\\"] = 1,\\n    [\\"CITEREFWells2008\\"] = 1,\\n    [\\"CITEREFWeyl2013\\"] = 1,\\n    [\\"CITEREFWheeler2010\\"] = 1,\\n    [\\"CITEREFWhittaker1955\\"] = 1,\\n    [\\"CITEREFWüthrich2015\\"] = 1,\\n    [\\"CITEREFYangHamilton2010\\"] = 1,\\n    [\\"CITEREFZimmer2013\\"] = 1,\\n    [\\"CITEREFvon_Hirschhausen,_Ulrike2007\\"] = 1,\\n}\\ntemplate_list = table#1 {\\n    [\\"!\\"] = 2,\\n    [\\"\' \\\\\\"\\"] = 1,\\n    [\\"1921 Nobel Prize winners\\"] = 1,\\n    [\\"Authority control\\"] = 1,\\n    [\\"Birth date\\"] = 1,\\n    [\\"Blockquote\\"] = 2,\\n    [\\"Br\\"] = 4,\\n    [\\"Cbignore\\"] = 4,\\n    [\\"Circa\\"] = 1,\\n    [\\"Cite EB1922\\"] = 1,\\n    [\\"Cite arXiv\\"] = 2,\\n    [\\"Cite book\\"] = 86,\\n    [\\"Cite journal\\"] = 71,\\n    [\\"Cite magazine\\"] = 6,\\n    [\\"Cite news\\"] = 28,\\n    [\\"Cite speech\\"] = 1,\\n    [\\"Cite thesis\\"] = 1,\\n    [\\"Cite web\\"] = 80,\\n    [\\"Copley Medallists 1901–1950\\"] = 1,\\n    [\\"Cosmology\\"] = 1,\\n    [\\"Curlie\\"] = 1,\\n    [\\"DEFAULTSORT:Einstein, Albert\\"] = 1,\\n    [\\"Death date and age\\"] = 1,\\n    [\\"Div col\\"] = 5,\\n    [\\"Div col end\\"] = 5,\\n    [\\"Einstein\\"] = 1,\\n    [\\"FRS 1921\\"] = 1,\\n    [\\"Flatlist\\"] = 1,\\n    [\\"Further\\"] = 1,\\n    [\\"GBurl\\"] = 36,\\n    [\\"Good article\\"] = 1,\\n    [\\"Google books\\"] = 2,\\n    [\\"Gutenberg author\\"] = 1,\\n    [\\"Harvid\\"] = 1,\\n    [\\"Harvp\\"] = 1,\\n    [\\"IMDb name\\"] = 1,\\n    [\\"IPA-de\\"] = 1,\\n    [\\"IPAc-en\\"] = 1,\\n    [\\"ISBN\\"] = 3,\\n    [\\"Indented plainlist\\"] = 4,\\n    [\\"Infobox person\\"] = 1,\\n    [\\"Infobox scientist\\"] = 1,\\n    [\\"Internet Archive author\\"] = 1,\\n    [\\"LINZ\\"] = 1,\\n    [\\"Lang\\"] = 2,\\n    [\\"Librivox author\\"] = 1,\\n    [\\"Listen\\"] = 1,\\n    [\\"Main\\"] = 21,\\n    [\\"Marriage\\"] = 2,\\n    [\\"Math\\"] = 1,\\n    [\\"Navboxes\\"] = 1,\\n    [\\"Nobel Prize in Physics Laureates 1901–1925\\"] = 1,\\n    [\\"Nobelprize\\"] = 1,\\n    [\\"Nowrap\\"] = 1,\\n    [\\"OCLC\\"] = 1,\\n    [\\"PM20\\"] = 1,\\n    [\\"Plainlist\\"] = 1,\\n    [\\"Portal bar\\"] = 1,\\n    [\\"Pp\\"] = 1,\\n    [\\"Pp-move\\"] = 1,\\n    [\\"Redirect\\"] = 1,\\n    [\\"Reflist\\"] = 2,\\n    [\\"Refn\\"] = 1,\\n    [\\"Relativity\\"] = 1,\\n    [\\"Respell\\"] = 1,\\n    [\\"Scholia\\"] = 1,\\n    [\\"See also\\"] = 3,\\n    [\\"Sfnp\\"] = 136,\\n    [\\"Short description\\"] = 1,\\n    [\\"Shy\\"] = 1,\\n    [\\"Sister project links\\"] = 1,\\n    [\\"Snd\\"] = 4,\\n    [\\"Time 100: The Most Important People of the Century\\"] = 1,\\n    [\\"US patent\\"] = 1,\\n    [\\"Use American English\\"] = 1,\\n    [\\"Use dmy dates\\"] = 1,\\n    [\\"W\\"] = 2,\\n    [\\"Webarchive\\"] = 3,\\n}\\narticle_whitelist = table#1 {\\n}\\ntable#1 {\\n    [\\"size\\"] = \\"tiny\\",\\n}\\n","limitreport-profile":[["?","520","18.3"],["MediaWiki\\\\Extension\\\\Scribunto\\\\Engines\\\\LuaSandbox\\\\LuaSandboxCallback::callParserFunction","260","9.2"],["recursiveClone \\u003CmwInit.lua:45\\u003E","220","7.7"],["\\u003Cmw.lua:694\\u003E","140","4.9"],["MediaWiki\\\\Extension\\\\Scribunto\\\\Engines\\\\LuaSandbox\\\\LuaSandboxCallback::gsub","140","4.9"],["dataWrapper \\u003Cmw.lua:672\\u003E","140","4.9"],["MediaWiki\\\\Extension\\\\Scribunto\\\\Engines\\\\LuaSandbox\\\\LuaSandboxCallback::getAllExpandedArguments","120","4.2"],["MediaWiki\\\\Extension\\\\Scribunto\\\\Engines\\\\LuaSandbox\\\\LuaSandboxCallback::find","100","3.5"],["(for generator)","80","2.8"],["MediaWiki\\\\Extension\\\\Scribunto\\\\Engines\\\\LuaSandbox\\\\LuaSandboxCallback::match","80","2.8"],["[others]","1040","36.6"]]},"cachereport":{"origin":"mw1413","timestamp":"20240610134153","ttl":2592000,"transientcontent":false}}});});</script>
<script type="application/ld+json">{"@context":"https:\\/\\/schema.org","@type":"Article","name":"Albert Einstein","url":"https:\\/\\/en.wikipedia.org\\/wiki\\/Albert_Einstein","sameAs":"http:\\/\\/www.wikidata.org\\/entity\\/Q937","mainEntity":"http:\\/\\/www.wikidata.org\\/entity\\/Q937","author":{"@type":"Organization","name":"Contributors to Wikimedia projects"},"publisher":{"@type":"Organization","name":"Wikimedia Foundation, Inc.","logo":{"@type":"ImageObject","url":"https:\\/\\/www.wikimedia.org\\/static\\/images\\/wmf-hor-googpub.png"}},"datePublished":"2001-11-05T18:26:16Z","dateModified":"2024-06-04T23:38:54Z","image":"https:\\/\\/upload.wikimedia.org\\/wikipedia\\/commons\\/3\\/3e\\/Einstein_1921_by_F_Schmutzer_-_restoration.jpg","headline":"German-born theoretical physicist; developer of the theory of relativity (1879\\u20131955)"}</script>
</body>
</html>'
];
